/* Generated by Cython 0.19.1 on Sun Jun 23 18:13:14 2013 */

#define PY_SSIZE_T_CLEAN
#ifndef CYTHON_USE_PYLONG_INTERNALS
#ifdef PYLONG_BITS_IN_DIGIT
#define CYTHON_USE_PYLONG_INTERNALS 0
#else
#include "pyconfig.h"
#ifdef PYLONG_BITS_IN_DIGIT
#define CYTHON_USE_PYLONG_INTERNALS 1
#else
#define CYTHON_USE_PYLONG_INTERNALS 0
#endif
#endif
#endif
#include "Python.h"
#ifndef Py_PYTHON_H
    #error Python headers needed to compile C extensions, please install development version of Python.
#elif PY_VERSION_HEX < 0x02040000
    #error Cython requires Python 2.4+.
#else
#include <stddef.h> /* For offsetof */
#ifndef offsetof
#define offsetof(type, member) ( (size_t) & ((type*)0) -> member )
#endif
#if !defined(WIN32) && !defined(MS_WINDOWS)
  #ifndef __stdcall
    #define __stdcall
  #endif
  #ifndef __cdecl
    #define __cdecl
  #endif
  #ifndef __fastcall
    #define __fastcall
  #endif
#endif
#ifndef DL_IMPORT
  #define DL_IMPORT(t) t
#endif
#ifndef DL_EXPORT
  #define DL_EXPORT(t) t
#endif
#ifndef PY_LONG_LONG
  #define PY_LONG_LONG LONG_LONG
#endif
#ifndef Py_HUGE_VAL
  #define Py_HUGE_VAL HUGE_VAL
#endif
#ifdef PYPY_VERSION
#define CYTHON_COMPILING_IN_PYPY 1
#define CYTHON_COMPILING_IN_CPYTHON 0
#else
#define CYTHON_COMPILING_IN_PYPY 0
#define CYTHON_COMPILING_IN_CPYTHON 1
#endif
#if PY_VERSION_HEX < 0x02050000
  typedef int Py_ssize_t;
  #define PY_SSIZE_T_MAX INT_MAX
  #define PY_SSIZE_T_MIN INT_MIN
  #define PY_FORMAT_SIZE_T ""
  #define CYTHON_FORMAT_SSIZE_T ""
  #define PyInt_FromSsize_t(z) PyInt_FromLong(z)
  #define PyInt_AsSsize_t(o)   __Pyx_PyInt_AsInt(o)
  #define PyNumber_Index(o)    ((PyNumber_Check(o) && !PyFloat_Check(o)) ? PyNumber_Int(o) : \
                                (PyErr_Format(PyExc_TypeError, \
                                              "expected index value, got %.200s", Py_TYPE(o)->tp_name), \
                                 (PyObject*)0))
  #define __Pyx_PyIndex_Check(o) (PyNumber_Check(o) && !PyFloat_Check(o) && \
                                  !PyComplex_Check(o))
  #define PyIndex_Check __Pyx_PyIndex_Check
  #define PyErr_WarnEx(category, message, stacklevel) PyErr_Warn(category, message)
  #define __PYX_BUILD_PY_SSIZE_T "i"
#else
  #define __PYX_BUILD_PY_SSIZE_T "n"
  #define CYTHON_FORMAT_SSIZE_T "z"
  #define __Pyx_PyIndex_Check PyIndex_Check
#endif
#if PY_VERSION_HEX < 0x02060000
  #define Py_REFCNT(ob) (((PyObject*)(ob))->ob_refcnt)
  #define Py_TYPE(ob)   (((PyObject*)(ob))->ob_type)
  #define Py_SIZE(ob)   (((PyVarObject*)(ob))->ob_size)
  #define PyVarObject_HEAD_INIT(type, size) \
          PyObject_HEAD_INIT(type) size,
  #define PyType_Modified(t)
  typedef struct {
     void *buf;
     PyObject *obj;
     Py_ssize_t len;
     Py_ssize_t itemsize;
     int readonly;
     int ndim;
     char *format;
     Py_ssize_t *shape;
     Py_ssize_t *strides;
     Py_ssize_t *suboffsets;
     void *internal;
  } Py_buffer;
  #define PyBUF_SIMPLE 0
  #define PyBUF_WRITABLE 0x0001
  #define PyBUF_FORMAT 0x0004
  #define PyBUF_ND 0x0008
  #define PyBUF_STRIDES (0x0010 | PyBUF_ND)
  #define PyBUF_C_CONTIGUOUS (0x0020 | PyBUF_STRIDES)
  #define PyBUF_F_CONTIGUOUS (0x0040 | PyBUF_STRIDES)
  #define PyBUF_ANY_CONTIGUOUS (0x0080 | PyBUF_STRIDES)
  #define PyBUF_INDIRECT (0x0100 | PyBUF_STRIDES)
  #define PyBUF_RECORDS (PyBUF_STRIDES | PyBUF_FORMAT | PyBUF_WRITABLE)
  #define PyBUF_FULL (PyBUF_INDIRECT | PyBUF_FORMAT | PyBUF_WRITABLE)
  typedef int (*getbufferproc)(PyObject *, Py_buffer *, int);
  typedef void (*releasebufferproc)(PyObject *, Py_buffer *);
#endif
#if PY_MAJOR_VERSION < 3
  #define __Pyx_BUILTIN_MODULE_NAME "__builtin__"
  #define __Pyx_PyCode_New(a, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos) \
          PyCode_New(a, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)
#else
  #define __Pyx_BUILTIN_MODULE_NAME "builtins"
  #define __Pyx_PyCode_New(a, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos) \
          PyCode_New(a, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)
#endif
#if PY_MAJOR_VERSION < 3 && PY_MINOR_VERSION < 6
  #define PyUnicode_FromString(s) PyUnicode_Decode(s, strlen(s), "UTF-8", "strict")
#endif
#if PY_MAJOR_VERSION >= 3
  #define Py_TPFLAGS_CHECKTYPES 0
  #define Py_TPFLAGS_HAVE_INDEX 0
#endif
#if (PY_VERSION_HEX < 0x02060000) || (PY_MAJOR_VERSION >= 3)
  #define Py_TPFLAGS_HAVE_NEWBUFFER 0
#endif
#if PY_VERSION_HEX < 0x02060000
  #define Py_TPFLAGS_HAVE_VERSION_TAG 0
#endif
#if PY_VERSION_HEX > 0x03030000 && defined(PyUnicode_KIND)
  #define CYTHON_PEP393_ENABLED 1
  #define __Pyx_PyUnicode_READY(op)       (likely(PyUnicode_IS_READY(op)) ? \
                                              0 : _PyUnicode_Ready((PyObject *)(op)))
  #define __Pyx_PyUnicode_GET_LENGTH(u)   PyUnicode_GET_LENGTH(u)
  #define __Pyx_PyUnicode_READ_CHAR(u, i) PyUnicode_READ_CHAR(u, i)
  #define __Pyx_PyUnicode_READ(k, d, i)   PyUnicode_READ(k, d, i)
#else
  #define CYTHON_PEP393_ENABLED 0
  #define __Pyx_PyUnicode_READY(op)       (0)
  #define __Pyx_PyUnicode_GET_LENGTH(u)   PyUnicode_GET_SIZE(u)
  #define __Pyx_PyUnicode_READ_CHAR(u, i) ((Py_UCS4)(PyUnicode_AS_UNICODE(u)[i]))
  #define __Pyx_PyUnicode_READ(k, d, i)   ((k=k), (Py_UCS4)(((Py_UNICODE*)d)[i]))
#endif
#if PY_MAJOR_VERSION >= 3
  #define PyBaseString_Type            PyUnicode_Type
  #define PyStringObject               PyUnicodeObject
  #define PyString_Type                PyUnicode_Type
  #define PyString_Check               PyUnicode_Check
  #define PyString_CheckExact          PyUnicode_CheckExact
#endif
#if PY_VERSION_HEX < 0x02060000
  #define PyBytesObject                PyStringObject
  #define PyBytes_Type                 PyString_Type
  #define PyBytes_Check                PyString_Check
  #define PyBytes_CheckExact           PyString_CheckExact
  #define PyBytes_FromString           PyString_FromString
  #define PyBytes_FromStringAndSize    PyString_FromStringAndSize
  #define PyBytes_FromFormat           PyString_FromFormat
  #define PyBytes_DecodeEscape         PyString_DecodeEscape
  #define PyBytes_AsString             PyString_AsString
  #define PyBytes_AsStringAndSize      PyString_AsStringAndSize
  #define PyBytes_Size                 PyString_Size
  #define PyBytes_AS_STRING            PyString_AS_STRING
  #define PyBytes_GET_SIZE             PyString_GET_SIZE
  #define PyBytes_Repr                 PyString_Repr
  #define PyBytes_Concat               PyString_Concat
  #define PyBytes_ConcatAndDel         PyString_ConcatAndDel
#endif
#if PY_MAJOR_VERSION >= 3
  #define __Pyx_PyBaseString_Check(obj) PyUnicode_Check(obj)
  #define __Pyx_PyBaseString_CheckExact(obj) PyUnicode_CheckExact(obj)
#else
  #define __Pyx_PyBaseString_Check(obj) (PyString_CheckExact(obj) || PyUnicode_CheckExact(obj) || \
                                         PyString_Check(obj) || PyUnicode_Check(obj))
  #define __Pyx_PyBaseString_CheckExact(obj) (Py_TYPE(obj) == &PyBaseString_Type)
#endif
#if PY_VERSION_HEX < 0x02060000
  #define PySet_Check(obj)             PyObject_TypeCheck(obj, &PySet_Type)
  #define PyFrozenSet_Check(obj)       PyObject_TypeCheck(obj, &PyFrozenSet_Type)
#endif
#ifndef PySet_CheckExact
  #define PySet_CheckExact(obj)        (Py_TYPE(obj) == &PySet_Type)
#endif
#define __Pyx_TypeCheck(obj, type) PyObject_TypeCheck(obj, (PyTypeObject *)type)
#if PY_MAJOR_VERSION >= 3
  #define PyIntObject                  PyLongObject
  #define PyInt_Type                   PyLong_Type
  #define PyInt_Check(op)              PyLong_Check(op)
  #define PyInt_CheckExact(op)         PyLong_CheckExact(op)
  #define PyInt_FromString             PyLong_FromString
  #define PyInt_FromUnicode            PyLong_FromUnicode
  #define PyInt_FromLong               PyLong_FromLong
  #define PyInt_FromSize_t             PyLong_FromSize_t
  #define PyInt_FromSsize_t            PyLong_FromSsize_t
  #define PyInt_AsLong                 PyLong_AsLong
  #define PyInt_AS_LONG                PyLong_AS_LONG
  #define PyInt_AsSsize_t              PyLong_AsSsize_t
  #define PyInt_AsUnsignedLongMask     PyLong_AsUnsignedLongMask
  #define PyInt_AsUnsignedLongLongMask PyLong_AsUnsignedLongLongMask
#endif
#if PY_MAJOR_VERSION >= 3
  #define PyBoolObject                 PyLongObject
#endif
#if PY_VERSION_HEX < 0x03020000
  typedef long Py_hash_t;
  #define __Pyx_PyInt_FromHash_t PyInt_FromLong
  #define __Pyx_PyInt_AsHash_t   PyInt_AsLong
#else
  #define __Pyx_PyInt_FromHash_t PyInt_FromSsize_t
  #define __Pyx_PyInt_AsHash_t   PyInt_AsSsize_t
#endif
#if (PY_MAJOR_VERSION < 3) || (PY_VERSION_HEX >= 0x03010300)
  #define __Pyx_PySequence_GetSlice(obj, a, b) PySequence_GetSlice(obj, a, b)
  #define __Pyx_PySequence_SetSlice(obj, a, b, value) PySequence_SetSlice(obj, a, b, value)
  #define __Pyx_PySequence_DelSlice(obj, a, b) PySequence_DelSlice(obj, a, b)
#else
  #define __Pyx_PySequence_GetSlice(obj, a, b) (unlikely(!(obj)) ? \
        (PyErr_SetString(PyExc_SystemError, "null argument to internal routine"), (PyObject*)0) : \
        (likely((obj)->ob_type->tp_as_mapping) ? (PySequence_GetSlice(obj, a, b)) : \
            (PyErr_Format(PyExc_TypeError, "'%.200s' object is unsliceable", (obj)->ob_type->tp_name), (PyObject*)0)))
  #define __Pyx_PySequence_SetSlice(obj, a, b, value) (unlikely(!(obj)) ? \
        (PyErr_SetString(PyExc_SystemError, "null argument to internal routine"), -1) : \
        (likely((obj)->ob_type->tp_as_mapping) ? (PySequence_SetSlice(obj, a, b, value)) : \
            (PyErr_Format(PyExc_TypeError, "'%.200s' object doesn't support slice assignment", (obj)->ob_type->tp_name), -1)))
  #define __Pyx_PySequence_DelSlice(obj, a, b) (unlikely(!(obj)) ? \
        (PyErr_SetString(PyExc_SystemError, "null argument to internal routine"), -1) : \
        (likely((obj)->ob_type->tp_as_mapping) ? (PySequence_DelSlice(obj, a, b)) : \
            (PyErr_Format(PyExc_TypeError, "'%.200s' object doesn't support slice deletion", (obj)->ob_type->tp_name), -1)))
#endif
#if PY_MAJOR_VERSION >= 3
  #define PyMethod_New(func, self, klass) ((self) ? PyMethod_New(func, self) : PyInstanceMethod_New(func))
#endif
#if PY_VERSION_HEX < 0x02050000
  #define __Pyx_GetAttrString(o,n)   PyObject_GetAttrString((o),((char *)(n)))
  #define __Pyx_SetAttrString(o,n,a) PyObject_SetAttrString((o),((char *)(n)),(a))
  #define __Pyx_DelAttrString(o,n)   PyObject_DelAttrString((o),((char *)(n)))
#else
  #define __Pyx_GetAttrString(o,n)   PyObject_GetAttrString((o),(n))
  #define __Pyx_SetAttrString(o,n,a) PyObject_SetAttrString((o),(n),(a))
  #define __Pyx_DelAttrString(o,n)   PyObject_DelAttrString((o),(n))
#endif
#if PY_VERSION_HEX < 0x02050000
  #define __Pyx_NAMESTR(n) ((char *)(n))
  #define __Pyx_DOCSTR(n)  ((char *)(n))
#else
  #define __Pyx_NAMESTR(n) (n)
  #define __Pyx_DOCSTR(n)  (n)
#endif
#ifndef CYTHON_INLINE
  #if defined(__GNUC__)
    #define CYTHON_INLINE __inline__
  #elif defined(_MSC_VER)
    #define CYTHON_INLINE __inline
  #elif defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L
    #define CYTHON_INLINE inline
  #else
    #define CYTHON_INLINE
  #endif
#endif
#ifndef CYTHON_RESTRICT
  #if defined(__GNUC__)
    #define CYTHON_RESTRICT __restrict__
  #elif defined(_MSC_VER)
    #define CYTHON_RESTRICT __restrict
  #elif defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L
    #define CYTHON_RESTRICT restrict
  #else
    #define CYTHON_RESTRICT
  #endif
#endif
#ifdef NAN
#define __PYX_NAN() ((float) NAN)
#else
static CYTHON_INLINE float __PYX_NAN() {
  /* Initialize NaN. The sign is irrelevant, an exponent with all bits 1 and
   a nonzero mantissa means NaN. If the first bit in the mantissa is 1, it is
   a quiet NaN. */
  float value;
  memset(&value, 0xFF, sizeof(value));
  return value;
}
#endif


#if PY_MAJOR_VERSION >= 3
  #define __Pyx_PyNumber_Divide(x,y)         PyNumber_TrueDivide(x,y)
  #define __Pyx_PyNumber_InPlaceDivide(x,y)  PyNumber_InPlaceTrueDivide(x,y)
#else
  #define __Pyx_PyNumber_Divide(x,y)         PyNumber_Divide(x,y)
  #define __Pyx_PyNumber_InPlaceDivide(x,y)  PyNumber_InPlaceDivide(x,y)
#endif

#ifndef __PYX_EXTERN_C
  #ifdef __cplusplus
    #define __PYX_EXTERN_C extern "C"
  #else
    #define __PYX_EXTERN_C extern
  #endif
#endif

#if defined(WIN32) || defined(MS_WINDOWS)
#define _USE_MATH_DEFINES
#endif
#include <math.h>
#define __PYX_HAVE__axon___loader
#define __PYX_HAVE_API__axon___loader
#include "string.h"
#include "stdio.h"
#include "datetime.h"
#include "stdlib.h"
#include "unicodeobject.h"
#include "bytesobject.h"
#include "utils.h"
#ifdef _OPENMP
#include <omp.h>
#endif /* _OPENMP */

#ifdef PYREX_WITHOUT_ASSERTIONS
#define CYTHON_WITHOUT_ASSERTIONS
#endif

#ifndef CYTHON_UNUSED
# if defined(__GNUC__)
#   if !(defined(__cplusplus)) || (__GNUC__ > 3 || (__GNUC__ == 3 && __GNUC_MINOR__ >= 4))
#     define CYTHON_UNUSED __attribute__ ((__unused__))
#   else
#     define CYTHON_UNUSED
#   endif
# elif defined(__ICC) || (defined(__INTEL_COMPILER) && !defined(_MSC_VER))
#   define CYTHON_UNUSED __attribute__ ((__unused__))
# else
#   define CYTHON_UNUSED
# endif
#endif
typedef struct {PyObject **p; char *s; const Py_ssize_t n; const char* encoding;
                const char is_unicode; const char is_str; const char intern; } __Pyx_StringTabEntry; /*proto*/

#define __PYX_DEFAULT_STRING_ENCODING_IS_ASCII 0
#define __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT 0
#define __PYX_DEFAULT_STRING_ENCODING ""
#define __Pyx_PyObject_FromString __Pyx_PyBytes_FromString
#define __Pyx_PyObject_FromStringAndSize __Pyx_PyBytes_FromStringAndSize
static CYTHON_INLINE char* __Pyx_PyObject_AsString(PyObject*);
static CYTHON_INLINE char* __Pyx_PyObject_AsStringAndSize(PyObject*, Py_ssize_t* length);
#define __Pyx_PyBytes_FromString        PyBytes_FromString
#define __Pyx_PyBytes_FromStringAndSize PyBytes_FromStringAndSize
static CYTHON_INLINE PyObject* __Pyx_PyUnicode_FromString(char*);
#if PY_MAJOR_VERSION < 3
    #define __Pyx_PyStr_FromString        __Pyx_PyBytes_FromString
    #define __Pyx_PyStr_FromStringAndSize __Pyx_PyBytes_FromStringAndSize
#else
    #define __Pyx_PyStr_FromString        __Pyx_PyUnicode_FromString
    #define __Pyx_PyStr_FromStringAndSize __Pyx_PyUnicode_FromStringAndSize
#endif
#define __Pyx_PyObject_AsUString(s)    ((unsigned char*) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_FromUString(s)  __Pyx_PyObject_FromString((char*)s)
#define __Pyx_PyBytes_FromUString(s)   __Pyx_PyBytes_FromString((char*)s)
#define __Pyx_PyStr_FromUString(s)     __Pyx_PyStr_FromString((char*)s)
#define __Pyx_PyUnicode_FromUString(s) __Pyx_PyUnicode_FromString((char*)s)
#if PY_MAJOR_VERSION < 3
static CYTHON_INLINE size_t __Pyx_Py_UNICODE_strlen(const Py_UNICODE *u)
{
    const Py_UNICODE *u_end = u;
    while (*u_end++) ;
    return u_end - u - 1;
}
#else
#define __Pyx_Py_UNICODE_strlen Py_UNICODE_strlen
#endif
#define __Pyx_PyUnicode_FromUnicode(u)       PyUnicode_FromUnicode(u, __Pyx_Py_UNICODE_strlen(u))
#define __Pyx_PyUnicode_FromUnicodeAndLength PyUnicode_FromUnicode
#define __Pyx_PyUnicode_AsUnicode            PyUnicode_AsUnicode
#define __Pyx_Owned_Py_None(b) (Py_INCREF(Py_None), Py_None)
#define __Pyx_PyBool_FromLong(b) ((b) ? (Py_INCREF(Py_True), Py_True) : (Py_INCREF(Py_False), Py_False))
static CYTHON_INLINE int __Pyx_PyObject_IsTrue(PyObject*);
static CYTHON_INLINE PyObject* __Pyx_PyNumber_Int(PyObject* x);
static CYTHON_INLINE Py_ssize_t __Pyx_PyIndex_AsSsize_t(PyObject*);
static CYTHON_INLINE PyObject * __Pyx_PyInt_FromSize_t(size_t);
static CYTHON_INLINE size_t __Pyx_PyInt_AsSize_t(PyObject*);
#if CYTHON_COMPILING_IN_CPYTHON
#define __pyx_PyFloat_AsDouble(x) (PyFloat_CheckExact(x) ? PyFloat_AS_DOUBLE(x) : PyFloat_AsDouble(x))
#else
#define __pyx_PyFloat_AsDouble(x) PyFloat_AsDouble(x)
#endif
#define __pyx_PyFloat_AsFloat(x) ((float) __pyx_PyFloat_AsDouble(x))
#if PY_MAJOR_VERSION < 3 && __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
static int __Pyx_sys_getdefaultencoding_not_ascii;
static int __Pyx_init_sys_getdefaultencoding_params() {
    PyObject* sys = NULL;
    PyObject* default_encoding = NULL;
    PyObject* ascii_chars_u = NULL;
    PyObject* ascii_chars_b = NULL;
    sys = PyImport_ImportModule("sys");
    if (sys == NULL) goto bad;
    default_encoding = PyObject_CallMethod(sys, (char*) (const char*) "getdefaultencoding", NULL);
    if (default_encoding == NULL) goto bad;
    if (strcmp(PyBytes_AsString(default_encoding), "ascii") == 0) {
        __Pyx_sys_getdefaultencoding_not_ascii = 0;
    } else {
        const char* default_encoding_c = PyBytes_AS_STRING(default_encoding);
        char ascii_chars[128];
        int c;
        for (c = 0; c < 128; c++) {
            ascii_chars[c] = c;
        }
        __Pyx_sys_getdefaultencoding_not_ascii = 1;
        ascii_chars_u = PyUnicode_DecodeASCII(ascii_chars, 128, NULL);
        if (ascii_chars_u == NULL) goto bad;
        ascii_chars_b = PyUnicode_AsEncodedString(ascii_chars_u, default_encoding_c, NULL);
        if (ascii_chars_b == NULL || strncmp(ascii_chars, PyBytes_AS_STRING(ascii_chars_b), 128) != 0) {
            PyErr_Format(
                PyExc_ValueError,
                "This module compiled with c_string_encoding=ascii, but default encoding '%s' is not a superset of ascii.",
                default_encoding_c);
            goto bad;
        }
    }
    Py_XDECREF(sys);
    Py_XDECREF(default_encoding);
    Py_XDECREF(ascii_chars_u);
    Py_XDECREF(ascii_chars_b);
    return 0;
bad:
    Py_XDECREF(sys);
    Py_XDECREF(default_encoding);
    Py_XDECREF(ascii_chars_u);
    Py_XDECREF(ascii_chars_b);
    return -1;
}
#endif
#if __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT && PY_MAJOR_VERSION >= 3
#define __Pyx_PyUnicode_FromStringAndSize(c_str, size) PyUnicode_DecodeUTF8(c_str, size, NULL)
#else
#define __Pyx_PyUnicode_FromStringAndSize(c_str, size) PyUnicode_Decode(c_str, size, __PYX_DEFAULT_STRING_ENCODING, NULL)
#if __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT
static char* __PYX_DEFAULT_STRING_ENCODING;
static int __Pyx_init_sys_getdefaultencoding_params() {
    PyObject* sys = NULL;
    PyObject* default_encoding = NULL;
    char* default_encoding_c;
    sys = PyImport_ImportModule("sys");
    if (sys == NULL) goto bad;
    default_encoding = PyObject_CallMethod(sys, (char*) (const char*) "getdefaultencoding", NULL);
    if (default_encoding == NULL) goto bad;
    default_encoding_c = PyBytes_AS_STRING(default_encoding);
    __PYX_DEFAULT_STRING_ENCODING = (char*) malloc(strlen(default_encoding_c));
    strcpy(__PYX_DEFAULT_STRING_ENCODING, default_encoding_c);
    Py_DECREF(sys);
    Py_DECREF(default_encoding);
    return 0;
bad:
    Py_XDECREF(sys);
    Py_XDECREF(default_encoding);
    return -1;
}
#endif
#endif


#ifdef __GNUC__
  /* Test for GCC > 2.95 */
  #if __GNUC__ > 2 || (__GNUC__ == 2 && (__GNUC_MINOR__ > 95))
    #define likely(x)   __builtin_expect(!!(x), 1)
    #define unlikely(x) __builtin_expect(!!(x), 0)
  #else /* __GNUC__ > 2 ... */
    #define likely(x)   (x)
    #define unlikely(x) (x)
  #endif /* __GNUC__ > 2 ... */
#else /* __GNUC__ */
  #define likely(x)   (x)
  #define unlikely(x) (x)
#endif /* __GNUC__ */

static PyObject *__pyx_m;
static PyObject *__pyx_d;
static PyObject *__pyx_b;
static PyObject *__pyx_empty_tuple;
static PyObject *__pyx_empty_bytes;
static int __pyx_lineno;
static int __pyx_clineno = 0;
static const char * __pyx_cfilenm= __FILE__;
static const char *__pyx_filename;


static const char *__pyx_f[] = {
  "_loader.py",
  "_loader.pxd",
  "array.pxd",
  "datetime.pxd",
  "_objects.pxd",
};

/*--- Type declarations ---*/
#ifndef _ARRAYARRAY_H
struct arrayobject;
typedef struct arrayobject arrayobject;
#endif
struct EmptyObject;
struct ReadonlyList;
struct FixedOffsetTZObject;
struct SequenceObject;
struct Attribute;
struct ReadonlyDict;
struct __pyx_obj_4axon_8_objects_NamedValue;
struct MappingObject;
struct UndefinedObject;
struct __pyx_obj_4axon_7_loader_Loader;
struct __pyx_obj_4axon_8_objects_Attrs;
struct __pyx_obj_4axon_8_objects_StringReader;
struct CollectionObject;
struct ElementObject;
struct SimpleBuilder;
struct __pyx_obj_4axon_7_loader___pyx_scope_struct__factory;
struct Builder;
struct InstanceObject;

/* "axon/_objects.pxd":96
 * 
 * 
 * ctypedef PyObject* PyObjectPtr             # <<<<<<<<<<<<<<
 * 
 * cdef public unicode empty_name
 */
typedef PyObject *__pyx_t_4axon_8_objects_PyObjectPtr;

/* "axon/_objects.pxd":156
 * #
 * @cython.final
 * cdef public class Empty[type EmptyType, object EmptyObject]:             # <<<<<<<<<<<<<<
 *     cdef public object name
 * 
 */
struct EmptyObject {
  PyObject_HEAD
  PyObject *name;
};

__PYX_EXTERN_C DL_EXPORT(PyTypeObject) EmptyType;

/* "axon/_objects.pxd":121
 * #
 * @cython.final
 * cdef public class rlist(list)[object ReadonlyList, type ReadonlyListType]:             # <<<<<<<<<<<<<<
 *     pass
 * 
 */
struct ReadonlyList {
  PyListObject __pyx_base;
};

__PYX_EXTERN_C DL_EXPORT(PyTypeObject) ReadonlyListType;

/* "axon/_loader.pxd":171
 * cdef dict tz_dict = {}
 * 
 * cdef public class FixedOffsetTZ(tzinfo)[object FixedOffsetTZObject, type FixedOffsetTZType]:             # <<<<<<<<<<<<<<
 *     """Fixed offset in minutes east from UTC."""
 * 
 */
struct FixedOffsetTZObject {
  PyDateTime_TZInfo __pyx_base;
  struct __pyx_vtabstruct_4axon_7_loader_FixedOffsetTZ *__pyx_vtab;
  PyObject *minutes;
};

__PYX_EXTERN_C DL_EXPORT(PyTypeObject) FixedOffsetTZType;

/* "axon/_objects.pxd":163
 * #
 * @cython.final
 * cdef public class Sequence[object SequenceObject, type SequenceType]:             # <<<<<<<<<<<<<<
 *     cdef public object name
 *     cdef public list sequence
 */
struct SequenceObject {
  PyObject_HEAD
  PyObject *name;
  PyObject *sequence;
};

__PYX_EXTERN_C DL_EXPORT(PyTypeObject) SequenceType;

/* "axon/_objects.pxd":137
 * #
 * @cython.final
 * cdef public class Attribute[type AttributeType, object Attribute]:             # <<<<<<<<<<<<<<
 *     cdef public unicode name
 *     cdef public object value
 */
struct Attribute {
  PyObject_HEAD
  PyObject *name;
  PyObject *value;
};

__PYX_EXTERN_C DL_EXPORT(PyTypeObject) AttributeType;

/* "axon/_objects.pxd":114
 * #
 * @cython.final
 * cdef public class rdict(dict)[object ReadonlyDict, type ReadonlyDictType]:             # <<<<<<<<<<<<<<
 *     pass
 * 
 */
struct ReadonlyDict {
  PyDictObject __pyx_base;
};

__PYX_EXTERN_C DL_EXPORT(PyTypeObject) ReadonlyDictType;

/* "axon/_objects.pxd":127
 * cdef public rlist c_empty_list
 * 
 * cdef class NamedValue:             # <<<<<<<<<<<<<<
 *     cdef public object __name__
 *     cdef public object __value__
 */
struct __pyx_obj_4axon_8_objects_NamedValue {
  PyObject_HEAD
  PyObject *__name__;
  PyObject *__value__;
};


/* "axon/_objects.pxd":181
 * #
 * @cython.final
 * cdef public class Mapping[object MappingObject, type MappingType]:             # <<<<<<<<<<<<<<
 *     cdef public object name
 *     cdef public dict mapping
 */
struct MappingObject {
  PyObject_HEAD
  PyObject *name;
  PyObject *mapping;
};

__PYX_EXTERN_C DL_EXPORT(PyTypeObject) MappingType;

/* "axon/_objects.pxd":107
 * 
 * @cython.final
 * cdef public class Undefined[object UndefinedObject, type UndefinedType]:             # <<<<<<<<<<<<<<
 *     pass
 * 
 */
struct UndefinedObject {
  PyObject_HEAD
};

__PYX_EXTERN_C DL_EXPORT(PyTypeObject) UndefinedType;

/* "axon/_loader.pxd":181
 * 
 * @cython.final
 * cdef class Loader:             # <<<<<<<<<<<<<<
 * 
 *     cdef object fd
 */
struct __pyx_obj_4axon_7_loader_Loader {
  PyObject_HEAD
  struct __pyx_vtabstruct_4axon_7_loader_Loader *__pyx_vtab;
  PyObject *fd;
  PyObject *readline;
  PyObject *encoding;
  PyObject *line;
  int eof;
  int pos;
  int lnum;
  PyObject *errto;
  int bc;
  int bs;
  int bq;
  int json;
  struct Builder *builder;
  struct SimpleBuilder *sbuilder;
  PyObject *c_constants;
  PyObject *labeled_objects;
  PyObject *ta;
  PyObject *da;
  PyObject *to;
  int is_nl;
  PyObject *idn_stack;
  int idn;
};


/* "axon/_objects.pxd":146
 * cdef public Attribute c_new_attribute(unicode name, object value)
 * 
 * cdef class Attrs(object):             # <<<<<<<<<<<<<<
 *     #
 *     cdef public dict mapping
 */
struct __pyx_obj_4axon_8_objects_Attrs {
  PyObject_HEAD
  PyObject *mapping;
};


/* "axon/_objects.pxd":227
 * cdef unicode NAME_IS_EMPTY
 * 
 * cdef class StringReader:             # <<<<<<<<<<<<<<
 *     cdef unicode buffer
 *     cdef int pos
 */
struct __pyx_obj_4axon_8_objects_StringReader {
  PyObject_HEAD
  struct __pyx_vtabstruct_4axon_8_objects_StringReader *__pyx_vtab;
  PyObject *buffer;
  int pos;
  int n;
};


/* "axon/_objects.pxd":172
 * #
 * @cython.final
 * cdef public class Collection[object CollectionObject, type CollectionType]:             # <<<<<<<<<<<<<<
 *     cdef public object name
 *     cdef public list sequence
 */
struct CollectionObject {
  PyObject_HEAD
  PyObject *name;
  PyObject *sequence;
};

__PYX_EXTERN_C DL_EXPORT(PyTypeObject) CollectionType;

/* "axon/_objects.pxd":190
 * #
 * @cython.final
 * cdef public class Element[object ElementObject, type ElementType]:             # <<<<<<<<<<<<<<
 *     cdef public object name
 *     cdef public dict mapping
 */
struct ElementObject {
  PyObject_HEAD
  PyObject *name;
  PyObject *mapping;
  PyObject *sequence;
};

__PYX_EXTERN_C DL_EXPORT(PyTypeObject) ElementType;

/* "axon/_loader.pxd":148
 *     cdef object (*create_empty)(object)
 * 
 * cdef public class SimpleBuilder[type SimpleBuilderType, object SimpleBuilder]:             # <<<<<<<<<<<<<<
 *     cdef object (*create_int)(unicode)
 *     cdef object (*create_float)(unicode)
 */
struct SimpleBuilder {
  PyObject_HEAD
  PyObject *(*create_int)(PyObject *);
  PyObject *(*create_float)(PyObject *);
  PyObject *(*create_decimal)(PyObject *);
  PyObject *(*create_time)(int, int, int, int, PyObject *);
  PyObject *(*create_date)(int, int, int);
  PyObject *(*create_datetime)(int, int, int, int, int, int, int, PyObject *);
  PyObject *(*create_tzinfo)(int);
  PyObject *(*create_inf)(void);
  PyObject *(*create_ninf)(void);
  PyObject *(*create_nan)(void);
};

__PYX_EXTERN_C DL_EXPORT(PyTypeObject) SimpleBuilderType;

/* "axon/_loader.py":33
 *     c_factory_dict = {}
 * 
 * def factory(name, factory_func=None):             # <<<<<<<<<<<<<<
 *     name = c_as_unicode(name)
 *     if factory_func is None:
 */
struct __pyx_obj_4axon_7_loader___pyx_scope_struct__factory {
  PyObject_HEAD
  PyObject *__pyx_v_name;
};


/* "axon/_loader.pxd":141
 * cdef object c_new_empty_strict(object name)
 * 
 * cdef public class Builder[type BuilderType, object Builder]:             # <<<<<<<<<<<<<<
 *     cdef object (*create_mapping)(object, dict)
 *     cdef object (*create_element)(object, dict, list)
 */
struct Builder {
  PyObject_HEAD
  PyObject *(*create_mapping)(PyObject *, PyObject *);
  PyObject *(*create_element)(PyObject *, PyObject *, PyObject *);
  PyObject *(*create_sequence)(PyObject *, PyObject *);
  PyObject *(*create_instance)(PyObject *, PyObject *, PyObject *);
  PyObject *(*create_empty)(PyObject *);
};

__PYX_EXTERN_C DL_EXPORT(PyTypeObject) BuilderType;

/* "axon/_objects.pxd":199
 * #
 * @cython.final
 * cdef public class Instance[object InstanceObject, type InstanceType]:             # <<<<<<<<<<<<<<
 *     cdef public object name
 *     cdef public tuple sequence
 */
struct InstanceObject {
  PyObject_HEAD
  PyObject *name;
  PyObject *sequence;
  PyObject *mapping;
};

__PYX_EXTERN_C DL_EXPORT(PyTypeObject) InstanceType;

__PYX_EXTERN_C DL_EXPORT(PyTypeObject) FixedOffsetTZType;

/* "axon/_loader.py":195
 * tz_dict = {}
 * 
 * class FixedOffsetTZ(tzinfo):             # <<<<<<<<<<<<<<
 *     """Fixed offset in minutes east from UTC."""
 * 
 */

struct __pyx_vtabstruct_4axon_7_loader_FixedOffsetTZ {
  void (*_init)(struct FixedOffsetTZObject *, PyObject *);
};
static struct __pyx_vtabstruct_4axon_7_loader_FixedOffsetTZ *__pyx_vtabptr_4axon_7_loader_FixedOffsetTZ;


/* "axon/_objects.pxd":227
 * cdef unicode NAME_IS_EMPTY
 * 
 * cdef class StringReader:             # <<<<<<<<<<<<<<
 *     cdef unicode buffer
 *     cdef int pos
 */

struct __pyx_vtabstruct_4axon_8_objects_StringReader {
  PyObject *(*readline)(struct __pyx_obj_4axon_8_objects_StringReader *, int __pyx_skip_dispatch);
  PyObject *(*close)(struct __pyx_obj_4axon_8_objects_StringReader *, int __pyx_skip_dispatch);
};
static struct __pyx_vtabstruct_4axon_8_objects_StringReader *__pyx_vtabptr_4axon_8_objects_StringReader;


/* "axon/_loader.py":284
 * # Loader
 * #
 * class Loader:             # <<<<<<<<<<<<<<
 * 
 *     '''
 */

struct __pyx_vtabstruct_4axon_7_loader_Loader {
  PyObject *(*_check_pairs)(struct __pyx_obj_4axon_7_loader_Loader *, int __pyx_skip_dispatch);
  PyObject *(*load)(struct __pyx_obj_4axon_7_loader_Loader *, int __pyx_skip_dispatch);
  Py_UCS4 (*moveto_next_token)(struct __pyx_obj_4axon_7_loader_Loader *);
  Py_UCS4 (*skip_spaces)(struct __pyx_obj_4axon_7_loader_Loader *);
  void (*skip_whitespace)(struct __pyx_obj_4axon_7_loader_Loader *);
  void (*next_line)(struct __pyx_obj_4axon_7_loader_Loader *);
  int (*get_dots)(struct __pyx_obj_4axon_7_loader_Loader *);
  int (*try_get_int)(struct __pyx_obj_4axon_7_loader_Loader *, int);
  int (*get_date)(struct __pyx_obj_4axon_7_loader_Loader *);
  int (*get_time)(struct __pyx_obj_4axon_7_loader_Loader *);
  int (*get_time_offset)(struct __pyx_obj_4axon_7_loader_Loader *);
  PyObject *(*get_tzinfo)(struct __pyx_obj_4axon_7_loader_Loader *);
  PyObject *(*get_number)(struct __pyx_obj_4axon_7_loader_Loader *);
  PyObject *(*get_name)(struct __pyx_obj_4axon_7_loader_Loader *);
  PyObject *(*get_key)(struct __pyx_obj_4axon_7_loader_Loader *);
  PyObject *(*try_get_name)(struct __pyx_obj_4axon_7_loader_Loader *);
  PyObject *(*try_get_key)(struct __pyx_obj_4axon_7_loader_Loader *);
  PyObject *(*try_get_label)(struct __pyx_obj_4axon_7_loader_Loader *);
  PyObject *(*get_unicode_hex)(struct __pyx_obj_4axon_7_loader_Loader *);
  PyObject *(*get_string)(struct __pyx_obj_4axon_7_loader_Loader *, Py_UCS4);
  PyObject *(*get_base64)(struct __pyx_obj_4axon_7_loader_Loader *);
  void (*skip_comment)(struct __pyx_obj_4axon_7_loader_Loader *);
  void (*skip_comments)(struct __pyx_obj_4axon_7_loader_Loader *);
  PyObject *(*get_constant_or_string)(struct __pyx_obj_4axon_7_loader_Loader *, PyObject *);
  PyObject *(*get_negative_constant)(struct __pyx_obj_4axon_7_loader_Loader *);
  PyObject *(*get_value)(struct __pyx_obj_4axon_7_loader_Loader *, int);
  PyObject *(*get_collection)(struct __pyx_obj_4axon_7_loader_Loader *, PyObject *, int);
  PyObject *(*get_complex_value)(struct __pyx_obj_4axon_7_loader_Loader *, PyObject *, int);
  PyObject *(*get_sequence_mapping)(struct __pyx_obj_4axon_7_loader_Loader *, PyObject *, PyObject *, int);
  PyObject *(*get_mapping_sequence)(struct __pyx_obj_4axon_7_loader_Loader *, PyObject *, PyObject *, int);
  PyObject *(*get_list_value)(struct __pyx_obj_4axon_7_loader_Loader *);
  PyObject *(*get_tuple_value)(struct __pyx_obj_4axon_7_loader_Loader *);
  PyObject *(*get_dict_value)(struct __pyx_obj_4axon_7_loader_Loader *);
  int (*get_mapping_part)(struct __pyx_obj_4axon_7_loader_Loader *, PyObject *, PyObject *, int);
  int (*get_sequence_part)(struct __pyx_obj_4axon_7_loader_Loader *, PyObject *, PyObject *, int);
};
static struct __pyx_vtabstruct_4axon_7_loader_Loader *__pyx_vtabptr_4axon_7_loader_Loader;
static PyObject *__pyx_f_4axon_7_loader_6Loader__check_pairs(struct __pyx_obj_4axon_7_loader_Loader *, int __pyx_skip_dispatch);
static PyObject *__pyx_f_4axon_7_loader_6Loader_load(struct __pyx_obj_4axon_7_loader_Loader *, int __pyx_skip_dispatch);
static CYTHON_INLINE Py_UCS4 __pyx_f_4axon_7_loader_6Loader_moveto_next_token(struct __pyx_obj_4axon_7_loader_Loader *);
static CYTHON_INLINE Py_UCS4 __pyx_f_4axon_7_loader_6Loader_skip_spaces(struct __pyx_obj_4axon_7_loader_Loader *);
static CYTHON_INLINE void __pyx_f_4axon_7_loader_6Loader_skip_whitespace(struct __pyx_obj_4axon_7_loader_Loader *);
static void __pyx_f_4axon_7_loader_6Loader_next_line(struct __pyx_obj_4axon_7_loader_Loader *);
static int __pyx_f_4axon_7_loader_6Loader_get_dots(struct __pyx_obj_4axon_7_loader_Loader *);
static int __pyx_f_4axon_7_loader_6Loader_try_get_int(struct __pyx_obj_4axon_7_loader_Loader *, int);
static int __pyx_f_4axon_7_loader_6Loader_get_date(struct __pyx_obj_4axon_7_loader_Loader *);
static int __pyx_f_4axon_7_loader_6Loader_get_time(struct __pyx_obj_4axon_7_loader_Loader *);
static int __pyx_f_4axon_7_loader_6Loader_get_time_offset(struct __pyx_obj_4axon_7_loader_Loader *);
static PyObject *__pyx_f_4axon_7_loader_6Loader_get_tzinfo(struct __pyx_obj_4axon_7_loader_Loader *);
static PyObject *__pyx_f_4axon_7_loader_6Loader_get_number(struct __pyx_obj_4axon_7_loader_Loader *);
static PyObject *__pyx_f_4axon_7_loader_6Loader_get_name(struct __pyx_obj_4axon_7_loader_Loader *);
static PyObject *__pyx_f_4axon_7_loader_6Loader_get_key(struct __pyx_obj_4axon_7_loader_Loader *);
static CYTHON_INLINE PyObject *__pyx_f_4axon_7_loader_6Loader_try_get_name(struct __pyx_obj_4axon_7_loader_Loader *);
static CYTHON_INLINE PyObject *__pyx_f_4axon_7_loader_6Loader_try_get_key(struct __pyx_obj_4axon_7_loader_Loader *);
static PyObject *__pyx_f_4axon_7_loader_6Loader_try_get_label(struct __pyx_obj_4axon_7_loader_Loader *);
static PyObject *__pyx_f_4axon_7_loader_6Loader_get_unicode_hex(struct __pyx_obj_4axon_7_loader_Loader *);
static PyObject *__pyx_f_4axon_7_loader_6Loader_get_string(struct __pyx_obj_4axon_7_loader_Loader *, Py_UCS4);
static PyObject *__pyx_f_4axon_7_loader_6Loader_get_base64(struct __pyx_obj_4axon_7_loader_Loader *);
static void __pyx_f_4axon_7_loader_6Loader_skip_comment(struct __pyx_obj_4axon_7_loader_Loader *);
static void __pyx_f_4axon_7_loader_6Loader_skip_comments(struct __pyx_obj_4axon_7_loader_Loader *);
static PyObject *__pyx_f_4axon_7_loader_6Loader_get_constant_or_string(struct __pyx_obj_4axon_7_loader_Loader *, PyObject *);
static PyObject *__pyx_f_4axon_7_loader_6Loader_get_negative_constant(struct __pyx_obj_4axon_7_loader_Loader *);
static PyObject *__pyx_f_4axon_7_loader_6Loader_get_value(struct __pyx_obj_4axon_7_loader_Loader *, int);
static PyObject *__pyx_f_4axon_7_loader_6Loader_get_collection(struct __pyx_obj_4axon_7_loader_Loader *, PyObject *, int);
static PyObject *__pyx_f_4axon_7_loader_6Loader_get_complex_value(struct __pyx_obj_4axon_7_loader_Loader *, PyObject *, int);
static PyObject *__pyx_f_4axon_7_loader_6Loader_get_sequence_mapping(struct __pyx_obj_4axon_7_loader_Loader *, PyObject *, PyObject *, int);
static PyObject *__pyx_f_4axon_7_loader_6Loader_get_mapping_sequence(struct __pyx_obj_4axon_7_loader_Loader *, PyObject *, PyObject *, int);
static PyObject *__pyx_f_4axon_7_loader_6Loader_get_list_value(struct __pyx_obj_4axon_7_loader_Loader *);
static PyObject *__pyx_f_4axon_7_loader_6Loader_get_tuple_value(struct __pyx_obj_4axon_7_loader_Loader *);
static PyObject *__pyx_f_4axon_7_loader_6Loader_get_dict_value(struct __pyx_obj_4axon_7_loader_Loader *);
static int __pyx_f_4axon_7_loader_6Loader_get_mapping_part(struct __pyx_obj_4axon_7_loader_Loader *, PyObject *, PyObject *, int);
static int __pyx_f_4axon_7_loader_6Loader_get_sequence_part(struct __pyx_obj_4axon_7_loader_Loader *, PyObject *, PyObject *, int);
#ifndef CYTHON_REFNANNY
  #define CYTHON_REFNANNY 0
#endif
#if CYTHON_REFNANNY
  typedef struct {
    void (*INCREF)(void*, PyObject*, int);
    void (*DECREF)(void*, PyObject*, int);
    void (*GOTREF)(void*, PyObject*, int);
    void (*GIVEREF)(void*, PyObject*, int);
    void* (*SetupContext)(const char*, int, const char*);
    void (*FinishContext)(void**);
  } __Pyx_RefNannyAPIStruct;
  static __Pyx_RefNannyAPIStruct *__Pyx_RefNanny = NULL;
  static __Pyx_RefNannyAPIStruct *__Pyx_RefNannyImportAPI(const char *modname); /*proto*/
  #define __Pyx_RefNannyDeclarations void *__pyx_refnanny = NULL;
#ifdef WITH_THREAD
  #define __Pyx_RefNannySetupContext(name, acquire_gil) \
          if (acquire_gil) { \
              PyGILState_STATE __pyx_gilstate_save = PyGILState_Ensure(); \
              __pyx_refnanny = __Pyx_RefNanny->SetupContext((name), __LINE__, __FILE__); \
              PyGILState_Release(__pyx_gilstate_save); \
          } else { \
              __pyx_refnanny = __Pyx_RefNanny->SetupContext((name), __LINE__, __FILE__); \
          }
#else
  #define __Pyx_RefNannySetupContext(name, acquire_gil) \
          __pyx_refnanny = __Pyx_RefNanny->SetupContext((name), __LINE__, __FILE__)
#endif
  #define __Pyx_RefNannyFinishContext() \
          __Pyx_RefNanny->FinishContext(&__pyx_refnanny)
  #define __Pyx_INCREF(r)  __Pyx_RefNanny->INCREF(__pyx_refnanny, (PyObject *)(r), __LINE__)
  #define __Pyx_DECREF(r)  __Pyx_RefNanny->DECREF(__pyx_refnanny, (PyObject *)(r), __LINE__)
  #define __Pyx_GOTREF(r)  __Pyx_RefNanny->GOTREF(__pyx_refnanny, (PyObject *)(r), __LINE__)
  #define __Pyx_GIVEREF(r) __Pyx_RefNanny->GIVEREF(__pyx_refnanny, (PyObject *)(r), __LINE__)
  #define __Pyx_XINCREF(r)  do { if((r) != NULL) {__Pyx_INCREF(r); }} while(0)
  #define __Pyx_XDECREF(r)  do { if((r) != NULL) {__Pyx_DECREF(r); }} while(0)
  #define __Pyx_XGOTREF(r)  do { if((r) != NULL) {__Pyx_GOTREF(r); }} while(0)
  #define __Pyx_XGIVEREF(r) do { if((r) != NULL) {__Pyx_GIVEREF(r);}} while(0)
#else
  #define __Pyx_RefNannyDeclarations
  #define __Pyx_RefNannySetupContext(name, acquire_gil)
  #define __Pyx_RefNannyFinishContext()
  #define __Pyx_INCREF(r) Py_INCREF(r)
  #define __Pyx_DECREF(r) Py_DECREF(r)
  #define __Pyx_GOTREF(r)
  #define __Pyx_GIVEREF(r)
  #define __Pyx_XINCREF(r) Py_XINCREF(r)
  #define __Pyx_XDECREF(r) Py_XDECREF(r)
  #define __Pyx_XGOTREF(r)
  #define __Pyx_XGIVEREF(r)
#endif /* CYTHON_REFNANNY */
#define __Pyx_CLEAR(r)    do { PyObject* tmp = ((PyObject*)(r)); r = NULL; __Pyx_DECREF(tmp);} while(0)
#define __Pyx_XCLEAR(r)   do { if((r) != NULL) {PyObject* tmp = ((PyObject*)(r)); r = NULL; __Pyx_DECREF(tmp);}} while(0)

#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetAttrStr(PyObject* obj, PyObject* attr_name) {
    PyTypeObject* tp = Py_TYPE(obj);
    if (likely(tp->tp_getattro))
        return tp->tp_getattro(obj, attr_name);
#if PY_MAJOR_VERSION < 3
    if (likely(tp->tp_getattr))
        return tp->tp_getattr(obj, PyString_AS_STRING(attr_name));
#endif
    return PyObject_GetAttr(obj, attr_name);
}
#else
#define __Pyx_PyObject_GetAttrStr(o,n) PyObject_GetAttr(o,n)
#endif

static PyObject *__Pyx_GetBuiltinName(PyObject *name); /*proto*/

static void __Pyx_RaiseDoubleKeywordsError(const char* func_name, PyObject* kw_name); /*proto*/

static int __Pyx_ParseOptionalKeywords(PyObject *kwds, PyObject **argnames[], \
    PyObject *kwds2, PyObject *values[], Py_ssize_t num_pos_args, \
    const char* function_name); /*proto*/

static void __Pyx_RaiseArgtupleInvalid(const char* func_name, int exact,
    Py_ssize_t num_min, Py_ssize_t num_max, Py_ssize_t num_found); /*proto*/

static CYTHON_INLINE void __Pyx_RaiseClosureNameError(const char *varname);

#define __Pyx_CyFunction_USED 1
#include <structmember.h>
#define __Pyx_CYFUNCTION_STATICMETHOD  0x01
#define __Pyx_CYFUNCTION_CLASSMETHOD   0x02
#define __Pyx_CYFUNCTION_CCLASS        0x04
#define __Pyx_CyFunction_GetClosure(f) \
    (((__pyx_CyFunctionObject *) (f))->func_closure)
#define __Pyx_CyFunction_GetClassObj(f) \
    (((__pyx_CyFunctionObject *) (f))->func_classobj)
#define __Pyx_CyFunction_Defaults(type, f) \
    ((type *)(((__pyx_CyFunctionObject *) (f))->defaults))
#define __Pyx_CyFunction_SetDefaultsGetter(f, g) \
    ((__pyx_CyFunctionObject *) (f))->defaults_getter = (g)
typedef struct {
    PyCFunctionObject func;
    int flags;
    PyObject *func_dict;
    PyObject *func_weakreflist;
    PyObject *func_name;
    PyObject *func_qualname;
    PyObject *func_doc;
    PyObject *func_code;
    PyObject *func_closure;
    PyObject *func_classobj; /* No-args super() class cell */
    void *defaults;
    int defaults_pyobjects;
    PyObject *defaults_tuple;   /* Const defaults tuple */
    PyObject *defaults_kwdict;  /* Const kwonly defaults dict */
    PyObject *(*defaults_getter)(PyObject *);
    PyObject *func_annotations; /* function annotations dict */
} __pyx_CyFunctionObject;
static PyTypeObject *__pyx_CyFunctionType = 0;
#define __Pyx_CyFunction_NewEx(ml, flags, qualname, self, module, code) \
    __Pyx_CyFunction_New(__pyx_CyFunctionType, ml, flags, qualname, self, module, code)
static PyObject *__Pyx_CyFunction_New(PyTypeObject *, PyMethodDef *ml,
                                      int flags, PyObject* qualname,
                                      PyObject *self, PyObject *module,
                                      PyObject* code);
static CYTHON_INLINE void *__Pyx_CyFunction_InitDefaults(PyObject *m,
                                                         size_t size,
                                                         int pyobjects);
static CYTHON_INLINE void __Pyx_CyFunction_SetDefaultsTuple(PyObject *m,
                                                            PyObject *tuple);
static CYTHON_INLINE void __Pyx_CyFunction_SetDefaultsKwDict(PyObject *m,
                                                             PyObject *dict);
static CYTHON_INLINE void __Pyx_CyFunction_SetAnnotationsDict(PyObject *m,
                                                              PyObject *dict);
static int __Pyx_CyFunction_init(void);

static PyObject* __Pyx_PyDict_GetItemDefault(PyObject* d, PyObject* key, PyObject* default_value); /*proto*/

static CYTHON_INLINE PyObject *__Pyx_GetModuleGlobalName(PyObject *name); /*proto*/

static CYTHON_INLINE void __Pyx_RaiseTooManyValuesError(Py_ssize_t expected);

static CYTHON_INLINE void __Pyx_RaiseNeedMoreValuesError(Py_ssize_t index);

static CYTHON_INLINE int __Pyx_IterFinish(void); /*proto*/

static int __Pyx_IternextUnpackEndCheck(PyObject *retval, Py_ssize_t expected); /*proto*/

#define __Pyx_SetItemInt(o, i, v, size, to_py_func, is_list, wraparound, boundscheck) \
    (((size) <= sizeof(Py_ssize_t)) ? \
    __Pyx_SetItemInt_Fast(o, i, v, is_list, wraparound, boundscheck) : \
    __Pyx_SetItemInt_Generic(o, to_py_func(i), v))
static CYTHON_INLINE int __Pyx_SetItemInt_Generic(PyObject *o, PyObject *j, PyObject *v);
static CYTHON_INLINE int __Pyx_SetItemInt_Fast(PyObject *o, Py_ssize_t i, PyObject *v,
                                               int is_list, int wraparound, int boundscheck);

static CYTHON_INLINE int __Pyx_CheckKeywordStrings(PyObject *kwdict, const char* function_name, int kw_allowed); /*proto*/

static CYTHON_INLINE void __Pyx_ErrRestore(PyObject *type, PyObject *value, PyObject *tb); /*proto*/
static CYTHON_INLINE void __Pyx_ErrFetch(PyObject **type, PyObject **value, PyObject **tb); /*proto*/

static void __Pyx_Raise(PyObject *type, PyObject *value, PyObject *tb, PyObject *cause); /*proto*/

#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE int __Pyx_PyList_Append(PyObject* list, PyObject* x) {
    PyListObject* L = (PyListObject*) list;
    Py_ssize_t len = Py_SIZE(list);
    if (likely(L->allocated > len) & likely(len > (L->allocated >> 1))) {
        Py_INCREF(x);
        PyList_SET_ITEM(list, len, x);
        Py_SIZE(list) = len+1;
        return 0;
    }
    return PyList_Append(list, x);
}
#else
#define __Pyx_PyList_Append(L,x) PyList_Append(L,x)
#endif

static CYTHON_INLINE int __Pyx_PyUnicode_Equals(PyObject* s1, PyObject* s2, int equals); /*proto*/

#define __Pyx_GetItemInt_Unicode(o, i, size, to_py_func, is_list, wraparound, boundscheck) \
    (((size) <= sizeof(Py_ssize_t)) ? \
    __Pyx_GetItemInt_Unicode_Fast(o, i, wraparound, boundscheck) : \
    __Pyx_GetItemInt_Unicode_Generic(o, to_py_func(i)))
static CYTHON_INLINE Py_UCS4 __Pyx_GetItemInt_Unicode_Fast(PyObject* ustring, Py_ssize_t i,
                                                           int wraparound, int boundscheck);
static CYTHON_INLINE Py_UCS4 __Pyx_GetItemInt_Unicode_Generic(PyObject* ustring, PyObject* j);

static void __Pyx_WriteUnraisable(const char *name, int clineno,
                                  int lineno, const char *filename); /*proto*/

static CYTHON_INLINE PyObject* __Pyx_PyUnicode_Substring(
            PyObject* text, Py_ssize_t start, Py_ssize_t stop);

static CYTHON_INLINE void __Pyx_RaiseUnboundLocalError(const char *varname);

#include <string.h>

static void __Pyx_call_next_tp_dealloc(PyObject* obj, destructor current_tp_dealloc);

static int __Pyx_call_next_tp_traverse(PyObject* obj, visitproc v, void *a, traverseproc current_tp_traverse);

static void __Pyx_call_next_tp_clear(PyObject* obj, inquiry current_tp_dealloc);

static int __Pyx_SetVtable(PyObject *dict, void *vtable); /*proto*/

static void* __Pyx_GetVtable(PyObject *dict); /*proto*/

static PyObject* __Pyx_ImportFrom(PyObject* module, PyObject* name); /*proto*/

static int __Pyx_GetException(PyObject **type, PyObject **value, PyObject **tb); /*proto*/

static double __Pyx__PyObject_AsDouble(PyObject* obj); /* proto */
#if CYTHON_COMPILING_IN_PYPY
#define __Pyx_PyObject_AsDouble(obj) \
(likely(PyFloat_CheckExact(obj)) ? PyFloat_AS_DOUBLE(obj) : \
 likely(PyInt_CheckExact(obj)) ? \
 PyFloat_AsDouble(obj) : __Pyx__PyObject_AsDouble(obj))
#else
#define __Pyx_PyObject_AsDouble(obj) \
((likely(PyFloat_CheckExact(obj))) ? \
 PyFloat_AS_DOUBLE(obj) : __Pyx__PyObject_AsDouble(obj))
#endif

#ifndef _ARRAYARRAY_H
#define _ARRAYARRAY_H
typedef struct arraydescr {
    int typecode;
    int itemsize;
    PyObject * (*getitem)(struct arrayobject *, Py_ssize_t);
    int (*setitem)(struct arrayobject *, Py_ssize_t, PyObject *);
#if PY_VERSION_HEX >= 0x03000000
    char *formats;
#endif
} arraydescr;
struct arrayobject {
    PyObject_HEAD
    Py_ssize_t ob_size;
    union {
        char *ob_item;
        float *as_floats;
        double *as_doubles;
        int *as_ints;
        unsigned int *as_uints;
        unsigned char *as_uchars;
        signed char *as_schars;
        char *as_chars;
        unsigned long *as_ulongs;
        long *as_longs;
        short *as_shorts;
        unsigned short *as_ushorts;
        Py_UNICODE *as_pyunicodes;
        void *as_voidptr;
    } data;
    Py_ssize_t allocated;
    struct arraydescr *ob_descr;
    PyObject *weakreflist; /* List of weak references */
#if PY_VERSION_HEX >= 0x03000000
        int ob_exports;  /* Number of exported buffers */
#endif
};
#ifndef NO_NEWARRAY_INLINE
static CYTHON_INLINE PyObject * newarrayobject(PyTypeObject *type, Py_ssize_t size,
    struct arraydescr *descr) {
    arrayobject *op;
    size_t nbytes;
    if (size < 0) {
        PyErr_BadInternalCall();
        return NULL;
    }
    nbytes = size * descr->itemsize;
    if (nbytes / descr->itemsize != (size_t)size) {
        return PyErr_NoMemory();
    }
    op = (arrayobject *) type->tp_alloc(type, 0);
    if (op == NULL) {
        return NULL;
    }
    op->ob_descr = descr;
    op->allocated = size;
    op->weakreflist = NULL;
    op->ob_size = size;
    if (size <= 0) {
        op->data.ob_item = NULL;
    }
    else {
        op->data.ob_item = PyMem_NEW(char, nbytes);
        if (op->data.ob_item == NULL) {
            Py_DECREF(op);
            return PyErr_NoMemory();
        }
    }
    return (PyObject *) op;
}
#else
PyObject* newarrayobject(PyTypeObject *type, Py_ssize_t size,
    struct arraydescr *descr);
#endif /* ifndef NO_NEWARRAY_INLINE */
static CYTHON_INLINE int resize(arrayobject *self, Py_ssize_t n) {
    void *items = (void*) self->data.ob_item;
    PyMem_Resize(items, char, (size_t)(n * self->ob_descr->itemsize));
    if (items == NULL) {
        PyErr_NoMemory();
        return -1;
    }
    self->data.ob_item = (char*) items;
    self->ob_size = n;
    self->allocated = n;
    return 0;
}
static CYTHON_INLINE int resize_smart(arrayobject *self, Py_ssize_t n) {
    void *items = (void*) self->data.ob_item;
    Py_ssize_t newsize;
    if (n < self->allocated) {
        if (n*4 > self->allocated) {
            self->ob_size = n;
            return 0;
        }
    }
    newsize = n  * 3 / 2 + 1;
    PyMem_Resize(items, char, (size_t)(newsize * self->ob_descr->itemsize));
    if (items == NULL) {
        PyErr_NoMemory();
        return -1;
    }
    self->data.ob_item = (char*) items;
    self->ob_size = n;
    self->allocated = newsize;
    return 0;
}
#endif

static CYTHON_INLINE void __Pyx_ExceptionSave(PyObject **type, PyObject **value, PyObject **tb); /*proto*/
static void __Pyx_ExceptionReset(PyObject *type, PyObject *value, PyObject *tb); /*proto*/

static PyObject *__Pyx_Import(PyObject *name, PyObject *from_list, int level); /*proto*/

static CYTHON_INLINE unsigned char __Pyx_PyInt_AsUnsignedChar(PyObject *);

static CYTHON_INLINE unsigned short __Pyx_PyInt_AsUnsignedShort(PyObject *);

static CYTHON_INLINE unsigned int __Pyx_PyInt_AsUnsignedInt(PyObject *);

static CYTHON_INLINE char __Pyx_PyInt_AsChar(PyObject *);

static CYTHON_INLINE short __Pyx_PyInt_AsShort(PyObject *);

static CYTHON_INLINE int __Pyx_PyInt_AsInt(PyObject *);

static CYTHON_INLINE signed char __Pyx_PyInt_AsSignedChar(PyObject *);

static CYTHON_INLINE signed short __Pyx_PyInt_AsSignedShort(PyObject *);

static CYTHON_INLINE signed int __Pyx_PyInt_AsSignedInt(PyObject *);

static CYTHON_INLINE int __Pyx_PyInt_AsLongDouble(PyObject *);

static CYTHON_INLINE unsigned long __Pyx_PyInt_AsUnsignedLong(PyObject *);

static CYTHON_INLINE unsigned PY_LONG_LONG __Pyx_PyInt_AsUnsignedLongLong(PyObject *);

static CYTHON_INLINE long __Pyx_PyInt_AsLong(PyObject *);

static CYTHON_INLINE PY_LONG_LONG __Pyx_PyInt_AsLongLong(PyObject *);

static CYTHON_INLINE signed long __Pyx_PyInt_AsSignedLong(PyObject *);

static CYTHON_INLINE signed PY_LONG_LONG __Pyx_PyInt_AsSignedLongLong(PyObject *);

static int __Pyx_check_binary_version(void);

#if CYTHON_COMPILING_IN_CPYTHON
#define __Pyx_PyObject_DelAttrStr(o,n) __Pyx_PyObject_SetAttrStr(o,n,NULL)
static CYTHON_INLINE int __Pyx_PyObject_SetAttrStr(PyObject* obj, PyObject* attr_name, PyObject* value) {
    PyTypeObject* tp = Py_TYPE(obj);
    if (likely(tp->tp_setattro))
        return tp->tp_setattro(obj, attr_name, value);
#if PY_MAJOR_VERSION < 3
    if (likely(tp->tp_setattr))
        return tp->tp_setattr(obj, PyString_AS_STRING(attr_name), value);
#endif
    return PyObject_SetAttr(obj, attr_name, value);
}
#else
#define __Pyx_PyObject_DelAttrStr(o,n)   PyObject_DelAttr(o,n)
#define __Pyx_PyObject_SetAttrStr(o,n,v) PyObject_SetAttr(o,n,v)
#endif

static int __Pyx_ExportVoidPtr(PyObject *name, void *p, const char *sig); /*proto*/

static int __Pyx_ExportFunction(const char *name, void (*f)(void), const char *sig); /*proto*/

#if !defined(__Pyx_PyIdentifier_FromString)
#if PY_MAJOR_VERSION < 3
  #define __Pyx_PyIdentifier_FromString(s) PyString_FromString(s)
#else
  #define __Pyx_PyIdentifier_FromString(s) PyUnicode_FromString(s)
#endif
#endif

static PyObject *__Pyx_ImportModule(const char *name); /*proto*/

static PyTypeObject *__Pyx_ImportType(const char *module_name, const char *class_name, size_t size, int strict);  /*proto*/

static int __Pyx_ImportVoidPtr(PyObject *module, const char *name, void **p, const char *sig); /*proto*/

static int __Pyx_ImportFunction(PyObject *module, const char *funcname, void (**f)(void), const char *sig); /*proto*/

typedef struct {
    int code_line;
    PyCodeObject* code_object;
} __Pyx_CodeObjectCacheEntry;
struct __Pyx_CodeObjectCache {
    int count;
    int max_count;
    __Pyx_CodeObjectCacheEntry* entries;
};
static struct __Pyx_CodeObjectCache __pyx_code_cache = {0,0,NULL};
static int __pyx_bisect_code_objects(__Pyx_CodeObjectCacheEntry* entries, int count, int code_line);
static PyCodeObject *__pyx_find_code_object(int code_line);
static void __pyx_insert_code_object(int code_line, PyCodeObject* code_object);

static void __Pyx_AddTraceback(const char *funcname, int c_line,
                               int py_line, const char *filename); /*proto*/

static int __Pyx_InitStrings(__Pyx_StringTabEntry *t); /*proto*/


/* Module declarations from 'cython' */

/* Module declarations from 'cpython.ref' */

/* Module declarations from 'libc.string' */

/* Module declarations from 'libc.stdio' */

/* Module declarations from 'cpython.object' */

/* Module declarations from 'cpython.dict' */

/* Module declarations from 'cpython.long' */

/* Module declarations from 'datetime' */

/* Module declarations from 'cpython.datetime' */
static PyTypeObject *__pyx_ptype_7cpython_8datetime_date = 0;
static PyTypeObject *__pyx_ptype_7cpython_8datetime_time = 0;
static PyTypeObject *__pyx_ptype_7cpython_8datetime_datetime = 0;
static PyTypeObject *__pyx_ptype_7cpython_8datetime_timedelta = 0;
static PyTypeObject *__pyx_ptype_7cpython_8datetime_tzinfo = 0;
static CYTHON_INLINE void __pyx_f_7cpython_8datetime_import_datetime(void); /*proto*/
static CYTHON_INLINE PyObject *__pyx_f_7cpython_8datetime_date_new(int, int, int); /*proto*/
static CYTHON_INLINE PyObject *__pyx_f_7cpython_8datetime_time_new(int, int, int, int, PyObject *); /*proto*/
static CYTHON_INLINE PyObject *__pyx_f_7cpython_8datetime_datetime_new(int, int, int, int, int, int, int, PyObject *); /*proto*/
static CYTHON_INLINE PyObject *__pyx_f_7cpython_8datetime_timedelta_new(int, int, int); /*proto*/

/* Module declarations from 'libc' */

/* Module declarations from 'libc.stdlib' */

/* Module declarations from 'cpython.exc' */

/* Module declarations from 'array' */

/* Module declarations from 'cpython.array' */
static PyTypeObject *__pyx_ptype_7cpython_5array_array = 0;
static CYTHON_INLINE int __pyx_f_7cpython_5array_extend_buffer(arrayobject *, char *, Py_ssize_t); /*proto*/

/* Module declarations from 'cpython.unicode' */

/* Module declarations from 'cpython.bytes' */

/* Module declarations from 'axon._objects' */
static PyTypeObject *__pyx_ptype_4axon_8_objects_Undefined = 0;
static PyTypeObject *__pyx_ptype_4axon_8_objects_rdict = 0;
static PyTypeObject *__pyx_ptype_4axon_8_objects_rlist = 0;
static PyTypeObject *__pyx_ptype_4axon_8_objects_NamedValue = 0;
static PyTypeObject *__pyx_ptype_4axon_8_objects_Attribute = 0;
static PyTypeObject *__pyx_ptype_4axon_8_objects_Attrs = 0;
static PyTypeObject *__pyx_ptype_4axon_8_objects_Empty = 0;
static PyTypeObject *__pyx_ptype_4axon_8_objects_Sequence = 0;
static PyTypeObject *__pyx_ptype_4axon_8_objects_Collection = 0;
static PyTypeObject *__pyx_ptype_4axon_8_objects_Mapping = 0;
static PyTypeObject *__pyx_ptype_4axon_8_objects_Element = 0;
static PyTypeObject *__pyx_ptype_4axon_8_objects_Instance = 0;
static PyTypeObject *__pyx_ptype_4axon_8_objects_StringReader = 0;
static PyObject **__pyx_vp_4axon_8_objects__decimal2str = 0;
#define __pyx_v_4axon_8_objects__decimal2str (*__pyx_vp_4axon_8_objects__decimal2str)
static PyObject **__pyx_vp_4axon_8_objects_empty_name = 0;
#define __pyx_v_4axon_8_objects_empty_name (*__pyx_vp_4axon_8_objects_empty_name)
static PyObject **__pyx_vp_4axon_8_objects_c_undescore = 0;
#define __pyx_v_4axon_8_objects_c_undescore (*__pyx_vp_4axon_8_objects_c_undescore)
static PyObject **__pyx_vp_4axon_8_objects_c_undefined = 0;
#define __pyx_v_4axon_8_objects_c_undefined (*__pyx_vp_4axon_8_objects_c_undefined)
static PyObject **__pyx_vp_4axon_8_objects_name_cache = 0;
#define __pyx_v_4axon_8_objects_name_cache (*__pyx_vp_4axon_8_objects_name_cache)
static PyObject **__pyx_vp_4axon_8_objects_c_str_type = 0;
#define __pyx_v_4axon_8_objects_c_str_type (*__pyx_vp_4axon_8_objects_c_str_type)
static struct ReadonlyDict **__pyx_vp_4axon_8_objects_c_empty_dict = 0;
#define __pyx_v_4axon_8_objects_c_empty_dict (*__pyx_vp_4axon_8_objects_c_empty_dict)
static struct ReadonlyList **__pyx_vp_4axon_8_objects_c_empty_list = 0;
#define __pyx_v_4axon_8_objects_c_empty_list (*__pyx_vp_4axon_8_objects_c_empty_list)
static PyObject **__pyx_vp_4axon_8_objects_NAME_IS_EMPTY = 0;
#define __pyx_v_4axon_8_objects_NAME_IS_EMPTY (*__pyx_vp_4axon_8_objects_NAME_IS_EMPTY)
static CYTHON_INLINE PyObject *__pyx_f_4axon_8_objects_c_as_tuple(PyObject *); /*proto*/
static CYTHON_INLINE PyObject *__pyx_f_4axon_8_objects_c_as_unicode(PyObject *); /*proto*/
static CYTHON_INLINE PyObject *__pyx_f_4axon_8_objects_c_as_name(PyObject *); /*proto*/
static CYTHON_INLINE PyObject *__pyx_f_4axon_8_objects_py_as_name(PyObject *); /*proto*/
static struct Attribute *(*__pyx_f_4axon_8_objects_c_new_attribute)(PyObject *, PyObject *); /*proto*/
static PyObject *(*__pyx_f_4axon_8_objects_c_new_sequence)(PyObject *, PyObject *); /*proto*/
static PyObject *(*__pyx_f_4axon_8_objects_c_new_collection)(PyObject *, PyObject *); /*proto*/
static PyObject *(*__pyx_f_4axon_8_objects_c_new_mapping)(PyObject *, PyObject *); /*proto*/
static PyObject *(*__pyx_f_4axon_8_objects_c_new_element)(PyObject *, PyObject *, PyObject *); /*proto*/
static PyObject *(*__pyx_f_4axon_8_objects_c_new_instance)(PyObject *, PyObject *, PyObject *); /*proto*/
static PyObject *(*__pyx_f_4axon_8_objects_c_new_empty)(PyObject *); /*proto*/

/* Module declarations from 'axon._loader' */
static PyTypeObject *__pyx_ptype_4axon_7_loader___pyx_scope_struct__factory = 0;
static PyTypeObject *__pyx_ptype_4axon_7_loader_Builder = 0;
static PyTypeObject *__pyx_ptype_4axon_7_loader_FixedOffsetTZ = 0;
static PyTypeObject *__pyx_ptype_4axon_7_loader_SimpleBuilder = 0;
static PyTypeObject *__pyx_ptype_4axon_7_loader_Loader = 0;
static PyObject *__pyx_v_4axon_7_loader_unicode_type = 0;
static PyObject *__pyx_v_4axon_7_loader_str_type = 0;
static PyObject *__pyx_v_4axon_7_loader_int_type = 0;
static PyObject *__pyx_v_4axon_7_loader_long_type = 0;
static PyObject *__pyx_v_4axon_7_loader_bool_type = 0;
static PyObject *__pyx_v_4axon_7_loader_float_type = 0;
static PyObject *__pyx_v_4axon_7_loader_bytes_type = 0;
static PyObject *__pyx_v_4axon_7_loader_c_constants = 0;
static PyObject *__pyx_v_4axon_7_loader_c_factory_dict = 0;
static PyObject *__pyx_v_4axon_7_loader__str2decimal = 0;
static PyObject *__pyx_v_4axon_7_loader__inf = 0;
static PyObject *__pyx_v_4axon_7_loader__ninf = 0;
static PyObject *__pyx_v_4axon_7_loader__nan = 0;
static PyObject *__pyx_v_4axon_7_loader_tz_dict = 0;
static CYTHON_INLINE PyObject *__pyx_f_4axon_7_loader_dict_get(PyObject *, PyObject *, PyObject *); /*proto*/
static CYTHON_INLINE PyObject *__pyx_f_4axon_7_loader_str2float(PyObject *); /*proto*/
static CYTHON_INLINE PyObject *__pyx_f_4axon_7_loader_str2decimal(PyObject *); /*proto*/
static CYTHON_INLINE PyObject *__pyx_f_4axon_7_loader_str2int(PyObject *); /*proto*/
static PyObject *__pyx_f_4axon_7_loader_time_fromargs(int, int, int, int, PyObject *); /*proto*/
static PyObject *__pyx_f_4axon_7_loader_date_fromargs(int, int, int); /*proto*/
static PyObject *__pyx_f_4axon_7_loader_datetime_fromargs(int, int, int, int, int, int, int, PyObject *); /*proto*/
static PyObject *__pyx_f_4axon_7_loader_float_inf(void); /*proto*/
static PyObject *__pyx_f_4axon_7_loader_float_ninf(void); /*proto*/
static PyObject *__pyx_f_4axon_7_loader_float_nan(void); /*proto*/
static PyObject *__pyx_f_4axon_7_loader_c_new_mapping_mixed(PyObject *, PyObject *); /*proto*/
static PyObject *__pyx_f_4axon_7_loader_c_new_sequence_mixed(PyObject *, PyObject *); /*proto*/
static PyObject *__pyx_f_4axon_7_loader_c_new_element_mixed(PyObject *, PyObject *, PyObject *); /*proto*/
static PyObject *__pyx_f_4axon_7_loader_c_new_instance_mixed(PyObject *, PyObject *, PyObject *); /*proto*/
static PyObject *__pyx_f_4axon_7_loader_c_new_empty_mixed(PyObject *); /*proto*/
static PyObject *__pyx_f_4axon_7_loader_c_new_mapping_strict(PyObject *, PyObject *); /*proto*/
static PyObject *__pyx_f_4axon_7_loader_c_new_sequence_strict(PyObject *, PyObject *); /*proto*/
static PyObject *__pyx_f_4axon_7_loader_c_new_element_strict(PyObject *, PyObject *, PyObject *); /*proto*/
static PyObject *__pyx_f_4axon_7_loader_c_new_instance_strict(PyObject *, PyObject *, PyObject *); /*proto*/
static PyObject *__pyx_f_4axon_7_loader_c_new_empty_strict(PyObject *); /*proto*/
static struct Builder *__pyx_f_4axon_7_loader_safe_builder(void); /*proto*/
static struct Builder *__pyx_f_4axon_7_loader_strict_builder(void); /*proto*/
static struct Builder *__pyx_f_4axon_7_loader_mixed_builder(void); /*proto*/
static PyObject *__pyx_f_4axon_7_loader_tzinfo_fromargs(int); /*proto*/
#define __Pyx_MODULE_NAME "axon._loader"
int __pyx_module_is_main_axon___loader = 0;

/* Implementation of 'axon._loader' */
static PyObject *__pyx_builtin_range;
static PyObject *__pyx_builtin_ValueError;
static PyObject *__pyx_builtin_open;
static PyObject *__pyx_builtin_StopIteration;
static PyObject *__pyx_builtin_TypeError;
static PyObject *__pyx_pf_4axon_7_loader_reset_factory(CYTHON_UNUSED PyObject *__pyx_self); /* proto */
static PyObject *__pyx_pf_4axon_7_loader_7factory__factory(PyObject *__pyx_self, PyObject *__pyx_v_factory_func); /* proto */
static PyObject *__pyx_pf_4axon_7_loader_2factory(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_name, PyObject *__pyx_v_factory_func); /* proto */
static PyObject *__pyx_pf_4axon_7_loader_4as_name(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_name); /* proto */
static int __pyx_pf_4axon_7_loader_13FixedOffsetTZ___init__(struct FixedOffsetTZObject *__pyx_v_self, PyObject *__pyx_v_minutes); /* proto */
static PyObject *__pyx_pf_4axon_7_loader_13FixedOffsetTZ_2utcoffset(struct FixedOffsetTZObject *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v_dt); /* proto */
static PyObject *__pyx_pf_4axon_7_loader_13FixedOffsetTZ_4tzname(struct FixedOffsetTZObject *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v_dt); /* proto */
static PyObject *__pyx_pf_4axon_7_loader_13FixedOffsetTZ_6dst(CYTHON_UNUSED struct FixedOffsetTZObject *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v_dt); /* proto */
static PyObject *__pyx_pf_4axon_7_loader_13FixedOffsetTZ_8__str__(struct FixedOffsetTZObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_4axon_7_loader_13FixedOffsetTZ_10__repr__(struct FixedOffsetTZObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_4axon_7_loader_13FixedOffsetTZ_7minutes___get__(struct FixedOffsetTZObject *__pyx_v_self); /* proto */
static int __pyx_pf_4axon_7_loader_13FixedOffsetTZ_7minutes_2__set__(struct FixedOffsetTZObject *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static int __pyx_pf_4axon_7_loader_13FixedOffsetTZ_7minutes_4__del__(struct FixedOffsetTZObject *__pyx_v_self); /* proto */
static int __pyx_pf_4axon_7_loader_13SimpleBuilder___init__(struct SimpleBuilder *__pyx_v_self); /* proto */
static int __pyx_pf_4axon_7_loader_6Loader___init__(struct __pyx_obj_4axon_7_loader_Loader *__pyx_v_self, PyObject *__pyx_v_fd, PyObject *__pyx_v_mode, PyObject *__pyx_v_errto, PyObject *__pyx_v_json); /* proto */
static PyObject *__pyx_pf_4axon_7_loader_6Loader_2__next__(struct __pyx_obj_4axon_7_loader_Loader *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_4axon_7_loader_6Loader_4_check_pairs(struct __pyx_obj_4axon_7_loader_Loader *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_4axon_7_loader_6Loader_6load(struct __pyx_obj_4axon_7_loader_Loader *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_4axon_7_loader_6Loader_8__iter__(struct __pyx_obj_4axon_7_loader_Loader *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_4axon_7_loader_6Loader_10get_empty_sequence(struct __pyx_obj_4axon_7_loader_Loader *__pyx_v_self, PyObject *__pyx_v_name, PyObject *__pyx_v_sequence, PyObject *__pyx_v_idn); /* proto */
static PyObject *__pyx_pf_4axon_7_loader_6Loader_12get_empty_mapping(struct __pyx_obj_4axon_7_loader_Loader *__pyx_v_self, PyObject *__pyx_v_name, PyObject *__pyx_v_mapping, PyObject *__pyx_v_idn); /* proto */
static PyObject *__pyx_pf_4axon_7_loader_6Loader_4line___get__(struct __pyx_obj_4axon_7_loader_Loader *__pyx_v_self); /* proto */
static int __pyx_pf_4axon_7_loader_6Loader_4line_2__set__(struct __pyx_obj_4axon_7_loader_Loader *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static int __pyx_pf_4axon_7_loader_6Loader_4line_4__del__(struct __pyx_obj_4axon_7_loader_Loader *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_4axon_7_loader_6Loader_3pos___get__(struct __pyx_obj_4axon_7_loader_Loader *__pyx_v_self); /* proto */
static int __pyx_pf_4axon_7_loader_6Loader_3pos_2__set__(struct __pyx_obj_4axon_7_loader_Loader *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static PyObject *__pyx_pf_4axon_7_loader_6Loader_4lnum___get__(struct __pyx_obj_4axon_7_loader_Loader *__pyx_v_self); /* proto */
static int __pyx_pf_4axon_7_loader_6Loader_4lnum_2__set__(struct __pyx_obj_4axon_7_loader_Loader *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static PyObject *__pyx_pf_4axon_7_loader_6Loader_5errto___get__(struct __pyx_obj_4axon_7_loader_Loader *__pyx_v_self); /* proto */
static int __pyx_pf_4axon_7_loader_6Loader_5errto_2__set__(struct __pyx_obj_4axon_7_loader_Loader *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static int __pyx_pf_4axon_7_loader_6Loader_5errto_4__del__(struct __pyx_obj_4axon_7_loader_Loader *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_4axon_7_loader_6Loader_3idn___get__(struct __pyx_obj_4axon_7_loader_Loader *__pyx_v_self); /* proto */
static int __pyx_pf_4axon_7_loader_6Loader_3idn_2__set__(struct __pyx_obj_4axon_7_loader_Loader *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static int __pyx_pf_7cpython_5array_5array___getbuffer__(arrayobject *__pyx_v_self, Py_buffer *__pyx_v_info, CYTHON_UNUSED int __pyx_v_flags); /* proto */
static void __pyx_pf_7cpython_5array_5array_2__releasebuffer__(CYTHON_UNUSED arrayobject *__pyx_v_self, Py_buffer *__pyx_v_info); /* proto */
static PyObject *__pyx_tp_new_4axon_7_loader___pyx_scope_struct__factory(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_4axon_7_loader_Builder(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_4axon_7_loader_FixedOffsetTZ(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_4axon_7_loader_SimpleBuilder(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_4axon_7_loader_Loader(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static char __pyx_k_3[] = "/Users/sz/Repos/axon/python/lib/axon/_loader.py";
static char __pyx_k_4[] = "factory.<locals>._factory";
static char __pyx_k_5[] = "axon._loader";
static char __pyx_k_6[] = "-";
static char __pyx_k_7[] = "+";
static char __pyx_k_8[] = "%s%02d:%02d";
static char __pyx_k_9[] = "%s%02d";
static char __pyx_k_11[] = "<tz:%s>";
static char __pyx_k_14[] = "Invalid mode: %s";
static char __pyx_k_15[] = "Missed closing }";
static char __pyx_k_16[] = "Extra closing }";
static char __pyx_k_17[] = "Missed closing ]";
static char __pyx_k_18[] = "Extra closing ]";
static char __pyx_k_19[] = "Missed closing )";
static char __pyx_k_20[] = "Extra closing )";
static char __pyx_k_21[] = "";
static char __pyx_k_22[] = "\n";
static char __pyx_k_23[] = "error_unexpected_end";
static char __pyx_k_24[] = "error_invalid_datetime";
static char __pyx_k_25[] = "error_unexpected_value";
static char __pyx_k_26[] = "after &";
static char __pyx_k_27[] = "Invalid unicode character %r";
static char __pyx_k_28[] = "'";
static char __pyx_k_29[] = "\"";
static char __pyx_k_30[] = "\r";
static char __pyx_k_31[] = "\t";
static char __pyx_k_32[] = "\\";
static char __pyx_k_33[] = "MIME Base64 string is not finished";
static char __pyx_k_34[] = "Invalid character %r in MIME Base64 string";
static char __pyx_k_35[] = "error_invalid_value_with_prefix";
static char __pyx_k_36[] = "error_unexpected_attribute";
static char __pyx_k_37[] = "expected named complex value";
static char __pyx_k_38[] = "Expected '{' or ':' here";
static char __pyx_k_39[] = "in named sequence-like structure";
static char __pyx_k_40[] = "in named element-like structure";
static char __pyx_k_41[] = "in named mapping-like structure";
static char __pyx_k_42[] = "in named instance-like structure";
static char __pyx_k_44[] = "This object %r is not unicode compatible";
static char __pyx_k_45[] = "axon.errors";
static char __pyx_k_46[] = "*";
static char __pyx_k_54[] = "default_decimal_context";
static char __pyx_k_55[] = "-inf";
static char __pyx_k__fd[] = "fd";
static char __pyx_k__wt[] = "wt";
static char __pyx_k__NaN[] = "NaN";
static char __pyx_k__get[] = "get";
static char __pyx_k__idn[] = "idn";
static char __pyx_k__inf[] = "inf";
static char __pyx_k__nan[] = "nan";
static char __pyx_k__sys[] = "sys";
static char __pyx_k___inf[] = "_inf";
static char __pyx_k___nan[] = "_nan";
static char __pyx_k__json[] = "json";
static char __pyx_k__mode[] = "mode";
static char __pyx_k__name[] = "name";
static char __pyx_k__null[] = "null";
static char __pyx_k__open[] = "open";
static char __pyx_k__safe[] = "safe";
static char __pyx_k__true[] = "true";
static char __pyx_k___ninf[] = "_ninf";
static char __pyx_k__close[] = "close";
static char __pyx_k__error[] = "error";
static char __pyx_k__errto[] = "errto";
static char __pyx_k__false[] = "false";
static char __pyx_k__mixed[] = "mixed";
static char __pyx_k__range[] = "range";
static char __pyx_k__base64[] = "base64";
static char __pyx_k__errors[] = "errors";
static char __pyx_k__stderr[] = "stderr";
static char __pyx_k__strict[] = "strict";
static char __pyx_k__tzname[] = "tzname";
static char __pyx_k__as_name[] = "as_name";
static char __pyx_k__decimal[] = "decimal";
static char __pyx_k__factory[] = "factory";
static char __pyx_k__mapping[] = "mapping";
static char __pyx_k__minutes[] = "minutes";
static char __pyx_k__tz_dict[] = "tz_dict";
static char __pyx_k__Infinity[] = "Infinity";
static char __pyx_k____main__[] = "__main__";
static char __pyx_k____test__[] = "__test__";
static char __pyx_k___decimal[] = "_decimal";
static char __pyx_k___factory[] = "_factory";
static char __pyx_k__cdecimal[] = "cdecimal";
static char __pyx_k__datetime[] = "datetime";
static char __pyx_k__int_type[] = "int_type";
static char __pyx_k__readline[] = "readline";
static char __pyx_k__sequence[] = "sequence";
static char __pyx_k__str_type[] = "str_type";
static char __pyx_k__TypeError[] = "TypeError";
static char __pyx_k__bool_type[] = "bool_type";
static char __pyx_k__long_type[] = "long_type";
static char __pyx_k__timedelta[] = "timedelta";
static char __pyx_k__ValueError[] = "ValueError";
static char __pyx_k____import__[] = "__import__";
static char __pyx_k__bytes_type[] = "bytes_type";
static char __pyx_k__float_type[] = "float_type";
static char __pyx_k__getcontext[] = "getcontext";
static char __pyx_k__pydatetime[] = "pydatetime";
static char __pyx_k__c_constants[] = "c_constants";
static char __pyx_k__decodebytes[] = "decodebytes";
static char __pyx_k____pyx_capi__[] = "__pyx_capi__";
static char __pyx_k___decimal2str[] = "_decimal2str";
static char __pyx_k___str2decimal[] = "_str2decimal";
static char __pyx_k__decodestring[] = "decodestring";
static char __pyx_k__factory_func[] = "factory_func";
static char __pyx_k__unicode_type[] = "unicode_type";
static char __pyx_k__StopIteration[] = "StopIteration";
static char __pyx_k__invalid_value[] = "invalid_value";
static char __pyx_k__reset_factory[] = "reset_factory";
static char __pyx_k__to_eng_string[] = "to_eng_string";
static char __pyx_k____pyx_vtable__[] = "__pyx_vtable__";
static char __pyx_k__c_factory_dict[] = "c_factory_dict";
static char __pyx_k__create_decimal[] = "create_decimal";
static char __pyx_k__error_getnumber[] = "error_getnumber";
static char __pyx_k__error_dict_value[] = "error_dict_value";
static char __pyx_k__error_indentation[] = "error_indentation";
static char __pyx_k__error_invalid_time[] = "error_invalid_time";
static PyObject *__pyx_kp_u_11;
static PyObject *__pyx_kp_u_14;
static PyObject *__pyx_kp_u_15;
static PyObject *__pyx_kp_u_16;
static PyObject *__pyx_kp_u_17;
static PyObject *__pyx_kp_u_18;
static PyObject *__pyx_kp_u_19;
static PyObject *__pyx_kp_u_20;
static PyObject *__pyx_kp_u_21;
static PyObject *__pyx_kp_u_22;
static PyObject *__pyx_n_s_23;
static PyObject *__pyx_n_s_24;
static PyObject *__pyx_n_s_25;
static PyObject *__pyx_kp_u_26;
static PyObject *__pyx_kp_u_27;
static PyObject *__pyx_kp_u_28;
static PyObject *__pyx_kp_u_29;
static PyObject *__pyx_kp_s_3;
static PyObject *__pyx_kp_u_30;
static PyObject *__pyx_kp_u_31;
static PyObject *__pyx_kp_u_32;
static PyObject *__pyx_kp_u_33;
static PyObject *__pyx_kp_u_34;
static PyObject *__pyx_n_s_35;
static PyObject *__pyx_n_s_36;
static PyObject *__pyx_kp_u_37;
static PyObject *__pyx_kp_u_38;
static PyObject *__pyx_kp_u_39;
static PyObject *__pyx_n_s_4;
static PyObject *__pyx_kp_u_40;
static PyObject *__pyx_kp_u_41;
static PyObject *__pyx_kp_u_42;
static PyObject *__pyx_kp_u_44;
static PyObject *__pyx_n_s_45;
static PyObject *__pyx_n_s_46;
static PyObject *__pyx_n_s_5;
static PyObject *__pyx_n_s_54;
static PyObject *__pyx_kp_u_55;
static PyObject *__pyx_kp_u_6;
static PyObject *__pyx_kp_u_7;
static PyObject *__pyx_kp_u_8;
static PyObject *__pyx_kp_u_9;
static PyObject *__pyx_n_u__Infinity;
static PyObject *__pyx_n_u__NaN;
static PyObject *__pyx_n_s__StopIteration;
static PyObject *__pyx_n_s__TypeError;
static PyObject *__pyx_n_s__ValueError;
static PyObject *__pyx_n_s____import__;
static PyObject *__pyx_n_s____main__;
static PyObject *__pyx_n_s____pyx_capi__;
static PyObject *__pyx_n_s____pyx_vtable__;
static PyObject *__pyx_n_s____test__;
static PyObject *__pyx_n_s___decimal;
static PyObject *__pyx_n_s___decimal2str;
static PyObject *__pyx_n_s___factory;
static PyObject *__pyx_n_s___inf;
static PyObject *__pyx_n_s___nan;
static PyObject *__pyx_n_s___ninf;
static PyObject *__pyx_n_s___str2decimal;
static PyObject *__pyx_n_s__as_name;
static PyObject *__pyx_n_s__base64;
static PyObject *__pyx_n_s__bool_type;
static PyObject *__pyx_n_s__bytes_type;
static PyObject *__pyx_n_s__c_constants;
static PyObject *__pyx_n_s__c_factory_dict;
static PyObject *__pyx_n_s__cdecimal;
static PyObject *__pyx_n_s__close;
static PyObject *__pyx_n_s__create_decimal;
static PyObject *__pyx_n_s__datetime;
static PyObject *__pyx_n_s__decimal;
static PyObject *__pyx_n_s__decodebytes;
static PyObject *__pyx_n_s__decodestring;
static PyObject *__pyx_n_s__error;
static PyObject *__pyx_n_s__error_dict_value;
static PyObject *__pyx_n_s__error_getnumber;
static PyObject *__pyx_n_s__error_indentation;
static PyObject *__pyx_n_s__error_invalid_time;
static PyObject *__pyx_n_s__errors;
static PyObject *__pyx_n_s__errto;
static PyObject *__pyx_n_s__factory;
static PyObject *__pyx_n_s__factory_func;
static PyObject *__pyx_n_u__false;
static PyObject *__pyx_n_s__fd;
static PyObject *__pyx_n_s__float_type;
static PyObject *__pyx_n_s__get;
static PyObject *__pyx_n_s__getcontext;
static PyObject *__pyx_n_s__idn;
static PyObject *__pyx_n_u__inf;
static PyObject *__pyx_n_s__int_type;
static PyObject *__pyx_n_s__invalid_value;
static PyObject *__pyx_n_s__json;
static PyObject *__pyx_n_s__long_type;
static PyObject *__pyx_n_s__mapping;
static PyObject *__pyx_n_s__minutes;
static PyObject *__pyx_n_u__mixed;
static PyObject *__pyx_n_s__mode;
static PyObject *__pyx_n_s__name;
static PyObject *__pyx_n_u__nan;
static PyObject *__pyx_n_u__null;
static PyObject *__pyx_n_s__open;
static PyObject *__pyx_n_s__pydatetime;
static PyObject *__pyx_n_s__range;
static PyObject *__pyx_n_s__readline;
static PyObject *__pyx_n_s__reset_factory;
static PyObject *__pyx_n_u__safe;
static PyObject *__pyx_n_s__sequence;
static PyObject *__pyx_n_s__stderr;
static PyObject *__pyx_n_s__str_type;
static PyObject *__pyx_n_u__strict;
static PyObject *__pyx_n_s__sys;
static PyObject *__pyx_n_s__timedelta;
static PyObject *__pyx_n_s__to_eng_string;
static PyObject *__pyx_n_u__true;
static PyObject *__pyx_n_s__tz_dict;
static PyObject *__pyx_n_s__tzname;
static PyObject *__pyx_n_s__unicode_type;
static PyObject *__pyx_n_u__wt;
static PyObject *__pyx_int_0;
static PyObject *__pyx_int_60;
static PyObject *__pyx_int_720;
static PyObject *__pyx_int_1440;
static PyObject *__pyx_k_13;
static PyObject *__pyx_k_tuple_1;
static PyObject *__pyx_k_tuple_10;
static PyObject *__pyx_k_tuple_12;
static PyObject *__pyx_k_tuple_43;
static PyObject *__pyx_k_tuple_47;
static PyObject *__pyx_k_tuple_49;
static PyObject *__pyx_k_tuple_51;
static PyObject *__pyx_k_tuple_52;
static PyObject *__pyx_k_codeobj_2;
static PyObject *__pyx_k_codeobj_48;
static PyObject *__pyx_k_codeobj_50;
static PyObject *__pyx_k_codeobj_53;

/* Python wrapper */
static PyObject *__pyx_pw_4axon_7_loader_1reset_factory(PyObject *__pyx_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyMethodDef __pyx_mdef_4axon_7_loader_1reset_factory = {__Pyx_NAMESTR("reset_factory"), (PyCFunction)__pyx_pw_4axon_7_loader_1reset_factory, METH_NOARGS, __Pyx_DOCSTR(0)};
static PyObject *__pyx_pw_4axon_7_loader_1reset_factory(PyObject *__pyx_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("reset_factory (wrapper)", 0);
  __pyx_r = __pyx_pf_4axon_7_loader_reset_factory(__pyx_self);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_loader.py":30
 * c_factory_dict = {}
 * 
 * def reset_factory():             # <<<<<<<<<<<<<<
 *     c_factory_dict = {}
 * 
 */

static PyObject *__pyx_pf_4axon_7_loader_reset_factory(CYTHON_UNUSED PyObject *__pyx_self) {
  CYTHON_UNUSED PyObject *__pyx_v_c_factory_dict = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("reset_factory", 0);

  /* "axon/_loader.py":31
 * 
 * def reset_factory():
 *     c_factory_dict = {}             # <<<<<<<<<<<<<<
 * 
 * def factory(name, factory_func=None):
 */
  __pyx_t_1 = PyDict_New(); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 31; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(((PyObject *)__pyx_t_1));
  __pyx_v_c_factory_dict = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("axon._loader.reset_factory", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_c_factory_dict);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_4axon_7_loader_3factory(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_4axon_7_loader_3factory = {__Pyx_NAMESTR("factory"), (PyCFunction)__pyx_pw_4axon_7_loader_3factory, METH_VARARGS|METH_KEYWORDS, __Pyx_DOCSTR(0)};
static PyObject *__pyx_pw_4axon_7_loader_3factory(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_name = 0;
  PyObject *__pyx_v_factory_func = 0;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("factory (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s__name,&__pyx_n_s__factory_func,0};
    PyObject* values[2] = {0,0};

    /* "axon/_loader.py":33
 *     c_factory_dict = {}
 * 
 * def factory(name, factory_func=None):             # <<<<<<<<<<<<<<
 *     name = c_as_unicode(name)
 *     if factory_func is None:
 */
    values[1] = ((PyObject *)((PyObject *)Py_None));
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s__name)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s__factory_func);
          if (value) { values[1] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "factory") < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 33; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_name = values[0];
    __pyx_v_factory_func = values[1];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("factory", 0, 1, 2, PyTuple_GET_SIZE(__pyx_args)); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 33; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  __pyx_L3_error:;
  __Pyx_AddTraceback("axon._loader.factory", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_4axon_7_loader_2factory(__pyx_self, __pyx_v_name, __pyx_v_factory_func);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_4axon_7_loader_7factory_1_factory(PyObject *__pyx_self, PyObject *__pyx_v_factory_func); /*proto*/
static PyMethodDef __pyx_mdef_4axon_7_loader_7factory_1_factory = {__Pyx_NAMESTR("_factory"), (PyCFunction)__pyx_pw_4axon_7_loader_7factory_1_factory, METH_O, __Pyx_DOCSTR(0)};
static PyObject *__pyx_pw_4axon_7_loader_7factory_1_factory(PyObject *__pyx_self, PyObject *__pyx_v_factory_func) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_factory (wrapper)", 0);
  __pyx_r = __pyx_pf_4axon_7_loader_7factory__factory(__pyx_self, ((PyObject *)__pyx_v_factory_func));
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_loader.py":36
 *     name = c_as_unicode(name)
 *     if factory_func is None:
 *         def _factory(factory_func):             # <<<<<<<<<<<<<<
 *             c_factory_dict[c_as_name(name)] = factory_func
 *             return factory_func
 */

static PyObject *__pyx_pf_4axon_7_loader_7factory__factory(PyObject *__pyx_self, PyObject *__pyx_v_factory_func) {
  struct __pyx_obj_4axon_7_loader___pyx_scope_struct__factory *__pyx_cur_scope;
  struct __pyx_obj_4axon_7_loader___pyx_scope_struct__factory *__pyx_outer_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_factory", 0);
  __pyx_outer_scope = (struct __pyx_obj_4axon_7_loader___pyx_scope_struct__factory *) __Pyx_CyFunction_GetClosure(__pyx_self);
  __pyx_cur_scope = __pyx_outer_scope;

  /* "axon/_loader.py":37
 *     if factory_func is None:
 *         def _factory(factory_func):
 *             c_factory_dict[c_as_name(name)] = factory_func             # <<<<<<<<<<<<<<
 *             return factory_func
 *         return _factory
 */
  if (unlikely(((PyObject *)__pyx_v_4axon_7_loader_c_factory_dict) == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    {__pyx_filename = __pyx_f[0]; __pyx_lineno = 37; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }
  if (unlikely(!__pyx_cur_scope->__pyx_v_name)) { __Pyx_RaiseClosureNameError("name"); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 37; __pyx_clineno = __LINE__; goto __pyx_L1_error;} }
  __pyx_t_1 = __pyx_cur_scope->__pyx_v_name;
  __Pyx_INCREF(__pyx_t_1);
  __pyx_t_2 = ((PyObject *)__pyx_f_4axon_8_objects_c_as_name(__pyx_t_1)); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 37; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (PyDict_SetItem(((PyObject *)__pyx_v_4axon_7_loader_c_factory_dict), __pyx_t_2, __pyx_v_factory_func) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 37; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "axon/_loader.py":38
 *         def _factory(factory_func):
 *             c_factory_dict[c_as_name(name)] = factory_func
 *             return factory_func             # <<<<<<<<<<<<<<
 *         return _factory
 *     else:
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_factory_func);
  __pyx_r = __pyx_v_factory_func;
  goto __pyx_L0;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("axon._loader.factory._factory", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_loader.py":33
 *     c_factory_dict = {}
 * 
 * def factory(name, factory_func=None):             # <<<<<<<<<<<<<<
 *     name = c_as_unicode(name)
 *     if factory_func is None:
 */

static PyObject *__pyx_pf_4axon_7_loader_2factory(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_name, PyObject *__pyx_v_factory_func) {
  struct __pyx_obj_4axon_7_loader___pyx_scope_struct__factory *__pyx_cur_scope;
  PyObject *__pyx_v__factory = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_t_3;
  int __pyx_t_4;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("factory", 0);
  __pyx_cur_scope = (struct __pyx_obj_4axon_7_loader___pyx_scope_struct__factory *)__pyx_tp_new_4axon_7_loader___pyx_scope_struct__factory(__pyx_ptype_4axon_7_loader___pyx_scope_struct__factory, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __Pyx_RefNannyFinishContext();
    return NULL;
  }
  __Pyx_GOTREF(__pyx_cur_scope);
  __pyx_cur_scope->__pyx_v_name = __pyx_v_name;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_name);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_name);

  /* "axon/_loader.py":34
 * 
 * def factory(name, factory_func=None):
 *     name = c_as_unicode(name)             # <<<<<<<<<<<<<<
 *     if factory_func is None:
 *         def _factory(factory_func):
 */
  __pyx_t_1 = __pyx_cur_scope->__pyx_v_name;
  __Pyx_INCREF(__pyx_t_1);
  __pyx_t_2 = ((PyObject *)__pyx_f_4axon_8_objects_c_as_unicode(__pyx_t_1)); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 34; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_GOTREF(__pyx_cur_scope->__pyx_v_name);
  __Pyx_DECREF(__pyx_cur_scope->__pyx_v_name);
  __Pyx_GIVEREF(__pyx_t_2);
  __pyx_cur_scope->__pyx_v_name = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "axon/_loader.py":35
 * def factory(name, factory_func=None):
 *     name = c_as_unicode(name)
 *     if factory_func is None:             # <<<<<<<<<<<<<<
 *         def _factory(factory_func):
 *             c_factory_dict[c_as_name(name)] = factory_func
 */
  __pyx_t_3 = (__pyx_v_factory_func == Py_None);
  __pyx_t_4 = (__pyx_t_3 != 0);
  if (__pyx_t_4) {

    /* "axon/_loader.py":36
 *     name = c_as_unicode(name)
 *     if factory_func is None:
 *         def _factory(factory_func):             # <<<<<<<<<<<<<<
 *             c_factory_dict[c_as_name(name)] = factory_func
 *             return factory_func
 */
    __pyx_t_2 = __Pyx_CyFunction_NewEx(&__pyx_mdef_4axon_7_loader_7factory_1_factory, 0, __pyx_n_s_4, ((PyObject*)__pyx_cur_scope), __pyx_n_s_5, ((PyObject *)__pyx_k_codeobj_2)); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 36; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_v__factory = __pyx_t_2;
    __pyx_t_2 = 0;

    /* "axon/_loader.py":39
 *             c_factory_dict[c_as_name(name)] = factory_func
 *             return factory_func
 *         return _factory             # <<<<<<<<<<<<<<
 *     else:
 *         c_factory_dict[c_as_name(name)] = factory_func
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_v__factory);
    __pyx_r = __pyx_v__factory;
    goto __pyx_L0;
    goto __pyx_L3;
  }
  /*else*/ {

    /* "axon/_loader.py":41
 *         return _factory
 *     else:
 *         c_factory_dict[c_as_name(name)] = factory_func             # <<<<<<<<<<<<<<
 * 
 * c_constants = {
 */
    if (unlikely(((PyObject *)__pyx_v_4axon_7_loader_c_factory_dict) == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      {__pyx_filename = __pyx_f[0]; __pyx_lineno = 41; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    }
    __pyx_t_2 = __pyx_cur_scope->__pyx_v_name;
    __Pyx_INCREF(__pyx_t_2);
    __pyx_t_1 = ((PyObject *)__pyx_f_4axon_8_objects_c_as_name(__pyx_t_2)); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 41; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (PyDict_SetItem(((PyObject *)__pyx_v_4axon_7_loader_c_factory_dict), __pyx_t_1, __pyx_v_factory_func) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 41; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }
  __pyx_L3:;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("axon._loader.factory", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v__factory);
  __Pyx_DECREF(((PyObject *)__pyx_cur_scope));
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_4axon_7_loader_5as_name(PyObject *__pyx_self, PyObject *__pyx_v_name); /*proto*/
static PyMethodDef __pyx_mdef_4axon_7_loader_5as_name = {__Pyx_NAMESTR("as_name"), (PyCFunction)__pyx_pw_4axon_7_loader_5as_name, METH_O, __Pyx_DOCSTR(0)};
static PyObject *__pyx_pw_4axon_7_loader_5as_name(PyObject *__pyx_self, PyObject *__pyx_v_name) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("as_name (wrapper)", 0);
  __pyx_r = __pyx_pf_4axon_7_loader_4as_name(__pyx_self, ((PyObject *)__pyx_v_name));
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_loader.py":51
 * }
 * 
 * def as_name(name):             # <<<<<<<<<<<<<<
 *     return c_as_name(name)
 * 
 */

static PyObject *__pyx_pf_4axon_7_loader_4as_name(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_name) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("as_name", 0);

  /* "axon/_loader.py":52
 * 
 * def as_name(name):
 *     return c_as_name(name)             # <<<<<<<<<<<<<<
 * 
 * import cython
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = ((PyObject *)__pyx_f_4axon_8_objects_c_as_name(__pyx_v_name)); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 52; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("axon._loader.as_name", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_loader.py":65
 * _decimal2str = default_decimal_context.to_eng_string
 * 
 * def str2float(text):             # <<<<<<<<<<<<<<
 *     n = len(text)
 *     num_buffer = PyBytes_FromStringAndSize(cython.NULL, n)
 */

static CYTHON_INLINE PyObject *__pyx_f_4axon_7_loader_str2float(PyObject *__pyx_v_text) {
  int __pyx_v_i;
  PyObject *__pyx_v_num_buffer = 0;
  char *__pyx_v_buf;
  int __pyx_v_n;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  Py_ssize_t __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  char *__pyx_t_3;
  int __pyx_t_4;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("str2float", 0);

  /* "axon/_loader.py":66
 * 
 * def str2float(text):
 *     n = len(text)             # <<<<<<<<<<<<<<
 *     num_buffer = PyBytes_FromStringAndSize(cython.NULL, n)
 * 
 */
  if (unlikely(((PyObject *)__pyx_v_text) == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "object of type 'NoneType' has no len()");
    {__pyx_filename = __pyx_f[0]; __pyx_lineno = 66; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }
  __pyx_t_1 = __Pyx_PyUnicode_GET_LENGTH(((PyObject *)__pyx_v_text)); if (unlikely(__pyx_t_1 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 66; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_v_n = __pyx_t_1;

  /* "axon/_loader.py":67
 * def str2float(text):
 *     n = len(text)
 *     num_buffer = PyBytes_FromStringAndSize(cython.NULL, n)             # <<<<<<<<<<<<<<
 * 
 *     buf = num_buffer
 */
  __pyx_t_2 = ((PyObject *)PyBytes_FromStringAndSize(NULL, __pyx_v_n)); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 67; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_v_num_buffer = ((PyObject*)__pyx_t_2);
  __pyx_t_2 = 0;

  /* "axon/_loader.py":69
 *     num_buffer = PyBytes_FromStringAndSize(cython.NULL, n)
 * 
 *     buf = num_buffer             # <<<<<<<<<<<<<<
 * 
 *     for i in range(n):
 */
  __pyx_t_3 = __Pyx_PyObject_AsString(((PyObject *)__pyx_v_num_buffer)); if (unlikely((!__pyx_t_3) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 69; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_v_buf = __pyx_t_3;

  /* "axon/_loader.py":71
 *     buf = num_buffer
 * 
 *     for i in range(n):             # <<<<<<<<<<<<<<
 *         buf[i] = c_unicode_char(text, i)
 * 
 */
  __pyx_t_4 = __pyx_v_n;
  for (__pyx_t_5 = 0; __pyx_t_5 < __pyx_t_4; __pyx_t_5+=1) {
    __pyx_v_i = __pyx_t_5;

    /* "axon/_loader.py":72
 * 
 *     for i in range(n):
 *         buf[i] = c_unicode_char(text, i)             # <<<<<<<<<<<<<<
 * 
 *     return c_float_fromstring(num_buffer)
 */
    (__pyx_v_buf[__pyx_v_i]) = c_unicode_char(__pyx_v_text, __pyx_v_i);
  }

  /* "axon/_loader.py":74
 *         buf[i] = c_unicode_char(text, i)
 * 
 *     return c_float_fromstring(num_buffer)             # <<<<<<<<<<<<<<
 * 
 * def str2decimal(text):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = c_float_fromstring(((PyObject *)__pyx_v_num_buffer)); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 74; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("axon._loader.str2float", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_num_buffer);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_loader.py":76
 *     return c_float_fromstring(num_buffer)
 * 
 * def str2decimal(text):             # <<<<<<<<<<<<<<
 *     return _str2decimal(text)
 * 
 */

static CYTHON_INLINE PyObject *__pyx_f_4axon_7_loader_str2decimal(PyObject *__pyx_v_text) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("str2decimal", 0);

  /* "axon/_loader.py":77
 * 
 * def str2decimal(text):
 *     return _str2decimal(text)             # <<<<<<<<<<<<<<
 * 
 * def str2int(text):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 77; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(((PyObject *)__pyx_v_text));
  PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_text));
  __Pyx_GIVEREF(((PyObject *)__pyx_v_text));
  __pyx_t_2 = PyObject_Call(__pyx_v_4axon_7_loader__str2decimal, ((PyObject *)__pyx_t_1), NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 77; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(((PyObject *)__pyx_t_1)); __pyx_t_1 = 0;
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("axon._loader.str2decimal", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_loader.py":79
 *     return _str2decimal(text)
 * 
 * def str2int(text):             # <<<<<<<<<<<<<<
 * 
 *     n = len(text)
 */

static CYTHON_INLINE PyObject *__pyx_f_4axon_7_loader_str2int(PyObject *__pyx_v_text) {
  int __pyx_v_i;
  PyObject *__pyx_v_num_buffer = 0;
  char *__pyx_v_buf;
  int __pyx_v_n;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  Py_ssize_t __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  char *__pyx_t_3;
  int __pyx_t_4;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("str2int", 0);

  /* "axon/_loader.py":81
 * def str2int(text):
 * 
 *     n = len(text)             # <<<<<<<<<<<<<<
 *     num_buffer = PyBytes_FromStringAndSize(cython.NULL, n+1)
 * 
 */
  if (unlikely(((PyObject *)__pyx_v_text) == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "object of type 'NoneType' has no len()");
    {__pyx_filename = __pyx_f[0]; __pyx_lineno = 81; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }
  __pyx_t_1 = __Pyx_PyUnicode_GET_LENGTH(((PyObject *)__pyx_v_text)); if (unlikely(__pyx_t_1 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 81; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_v_n = __pyx_t_1;

  /* "axon/_loader.py":82
 * 
 *     n = len(text)
 *     num_buffer = PyBytes_FromStringAndSize(cython.NULL, n+1)             # <<<<<<<<<<<<<<
 * 
 *     buf = num_buffer
 */
  __pyx_t_2 = ((PyObject *)PyBytes_FromStringAndSize(NULL, (__pyx_v_n + 1))); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 82; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_v_num_buffer = ((PyObject*)__pyx_t_2);
  __pyx_t_2 = 0;

  /* "axon/_loader.py":84
 *     num_buffer = PyBytes_FromStringAndSize(cython.NULL, n+1)
 * 
 *     buf = num_buffer             # <<<<<<<<<<<<<<
 * 
 *     for i in range(n):
 */
  __pyx_t_3 = __Pyx_PyObject_AsString(((PyObject *)__pyx_v_num_buffer)); if (unlikely((!__pyx_t_3) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 84; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_v_buf = __pyx_t_3;

  /* "axon/_loader.py":86
 *     buf = num_buffer
 * 
 *     for i in range(n):             # <<<<<<<<<<<<<<
 *         buf[i] = c_unicode_char(text, i)
 *     buf[n] = 0
 */
  __pyx_t_4 = __pyx_v_n;
  for (__pyx_t_5 = 0; __pyx_t_5 < __pyx_t_4; __pyx_t_5+=1) {
    __pyx_v_i = __pyx_t_5;

    /* "axon/_loader.py":87
 * 
 *     for i in range(n):
 *         buf[i] = c_unicode_char(text, i)             # <<<<<<<<<<<<<<
 *     buf[n] = 0
 * 
 */
    (__pyx_v_buf[__pyx_v_i]) = c_unicode_char(__pyx_v_text, __pyx_v_i);
  }

  /* "axon/_loader.py":88
 *     for i in range(n):
 *         buf[i] = c_unicode_char(text, i)
 *     buf[n] = 0             # <<<<<<<<<<<<<<
 * 
 *     return c_int_fromstring(buf)
 */
  (__pyx_v_buf[__pyx_v_n]) = 0;

  /* "axon/_loader.py":90
 *     buf[n] = 0
 * 
 *     return c_int_fromstring(buf)             # <<<<<<<<<<<<<<
 * 
 * def time_fromargs(h, m, s, ms, tz):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = c_int_fromstring(__pyx_v_buf); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 90; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("axon._loader.str2int", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_num_buffer);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_loader.py":92
 *     return c_int_fromstring(buf)
 * 
 * def time_fromargs(h, m, s, ms, tz):             # <<<<<<<<<<<<<<
 *     return time_new(h, m, s, ms, tz)
 * 
 */

static PyObject *__pyx_f_4axon_7_loader_time_fromargs(int __pyx_v_h, int __pyx_v_m, int __pyx_v_s, int __pyx_v_ms, PyObject *__pyx_v_tz) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("time_fromargs", 0);

  /* "axon/_loader.py":93
 * 
 * def time_fromargs(h, m, s, ms, tz):
 *     return time_new(h, m, s, ms, tz)             # <<<<<<<<<<<<<<
 * 
 * def timedelta_fromargs(d, s, ms):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_7cpython_8datetime_time_new(__pyx_v_h, __pyx_v_m, __pyx_v_s, __pyx_v_ms, __pyx_v_tz); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 93; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("axon._loader.time_fromargs", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_loader.py":95
 *     return time_new(h, m, s, ms, tz)
 * 
 * def timedelta_fromargs(d, s, ms):             # <<<<<<<<<<<<<<
 *     return timedelta_new(d, s, ms)
 * 
 */

static PyObject *__pyx_f_4axon_7_loader_timedelta_fromargs(int __pyx_v_d, int __pyx_v_s, int __pyx_v_ms) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("timedelta_fromargs", 0);

  /* "axon/_loader.py":96
 * 
 * def timedelta_fromargs(d, s, ms):
 *     return timedelta_new(d, s, ms)             # <<<<<<<<<<<<<<
 * 
 * def date_fromargs(y, m, d):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_7cpython_8datetime_timedelta_new(__pyx_v_d, __pyx_v_s, __pyx_v_ms); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 96; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("axon._loader.timedelta_fromargs", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_loader.py":98
 *     return timedelta_new(d, s, ms)
 * 
 * def date_fromargs(y, m, d):             # <<<<<<<<<<<<<<
 *     return date_new(y, m, d)
 * 
 */

static PyObject *__pyx_f_4axon_7_loader_date_fromargs(int __pyx_v_y, int __pyx_v_m, int __pyx_v_d) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("date_fromargs", 0);

  /* "axon/_loader.py":99
 * 
 * def date_fromargs(y, m, d):
 *     return date_new(y, m, d)             # <<<<<<<<<<<<<<
 * 
 * def datetime_fromargs(y, M, d, h, m, s, ms, tz):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_7cpython_8datetime_date_new(__pyx_v_y, __pyx_v_m, __pyx_v_d); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 99; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("axon._loader.date_fromargs", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_loader.py":101
 *     return date_new(y, m, d)
 * 
 * def datetime_fromargs(y, M, d, h, m, s, ms, tz):             # <<<<<<<<<<<<<<
 *     return datetime_new(y, M, d, h, m, s, ms, tz)
 * 
 */

static PyObject *__pyx_f_4axon_7_loader_datetime_fromargs(int __pyx_v_y, int __pyx_v_M, int __pyx_v_d, int __pyx_v_h, int __pyx_v_m, int __pyx_v_s, int __pyx_v_ms, PyObject *__pyx_v_tz) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("datetime_fromargs", 0);

  /* "axon/_loader.py":102
 * 
 * def datetime_fromargs(y, M, d, h, m, s, ms, tz):
 *     return datetime_new(y, M, d, h, m, s, ms, tz)             # <<<<<<<<<<<<<<
 * 
 * _inf = float('inf')
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_7cpython_8datetime_datetime_new(__pyx_v_y, __pyx_v_M, __pyx_v_d, __pyx_v_h, __pyx_v_m, __pyx_v_s, __pyx_v_ms, __pyx_v_tz); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 102; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("axon._loader.datetime_fromargs", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_loader.py":108
 * _nan = float('nan')
 * 
 * def float_inf():             # <<<<<<<<<<<<<<
 *     return _inf
 * 
 */

static PyObject *__pyx_f_4axon_7_loader_float_inf(void) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("float_inf", 0);

  /* "axon/_loader.py":109
 * 
 * def float_inf():
 *     return _inf             # <<<<<<<<<<<<<<
 * 
 * def float_ninf():
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_4axon_7_loader__inf);
  __pyx_r = __pyx_v_4axon_7_loader__inf;
  goto __pyx_L0;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_loader.py":111
 *     return _inf
 * 
 * def float_ninf():             # <<<<<<<<<<<<<<
 *     return _ninf
 * 
 */

static PyObject *__pyx_f_4axon_7_loader_float_ninf(void) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("float_ninf", 0);

  /* "axon/_loader.py":112
 * 
 * def float_ninf():
 *     return _ninf             # <<<<<<<<<<<<<<
 * 
 * def float_nan():
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_4axon_7_loader__ninf);
  __pyx_r = __pyx_v_4axon_7_loader__ninf;
  goto __pyx_L0;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_loader.py":114
 *     return _ninf
 * 
 * def float_nan():             # <<<<<<<<<<<<<<
 *     return _nan
 * 
 */

static PyObject *__pyx_f_4axon_7_loader_float_nan(void) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("float_nan", 0);

  /* "axon/_loader.py":115
 * 
 * def float_nan():
 *     return _nan             # <<<<<<<<<<<<<<
 * 
 * def c_new_mapping_mixed(name, mapping):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_4axon_7_loader__nan);
  __pyx_r = __pyx_v_4axon_7_loader__nan;
  goto __pyx_L0;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_loader.py":117
 *     return _nan
 * 
 * def c_new_mapping_mixed(name, mapping):             # <<<<<<<<<<<<<<
 *     handler = c_factory_dict.get(name)
 *     if handler is None:
 */

static PyObject *__pyx_f_4axon_7_loader_c_new_mapping_mixed(PyObject *__pyx_v_name, PyObject *__pyx_v_mapping) {
  PyObject *__pyx_v_handler = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("c_new_mapping_mixed", 0);

  /* "axon/_loader.py":118
 * 
 * def c_new_mapping_mixed(name, mapping):
 *     handler = c_factory_dict.get(name)             # <<<<<<<<<<<<<<
 *     if handler is None:
 *         return c_new_mapping(name, mapping)
 */
  if (unlikely(((PyObject *)__pyx_v_4axon_7_loader_c_factory_dict) == Py_None)) {
    PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%s'", "get");
    {__pyx_filename = __pyx_f[0]; __pyx_lineno = 118; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }
  __pyx_t_1 = __Pyx_PyDict_GetItemDefault(((PyObject *)__pyx_v_4axon_7_loader_c_factory_dict), __pyx_v_name, Py_None); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 118; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_handler = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "axon/_loader.py":119
 * def c_new_mapping_mixed(name, mapping):
 *     handler = c_factory_dict.get(name)
 *     if handler is None:             # <<<<<<<<<<<<<<
 *         return c_new_mapping(name, mapping)
 *     else:
 */
  __pyx_t_2 = (__pyx_v_handler == Py_None);
  __pyx_t_3 = (__pyx_t_2 != 0);
  if (__pyx_t_3) {

    /* "axon/_loader.py":120
 *     handler = c_factory_dict.get(name)
 *     if handler is None:
 *         return c_new_mapping(name, mapping)             # <<<<<<<<<<<<<<
 *     else:
 *         return handler(mapping)
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_1 = __pyx_f_4axon_8_objects_c_new_mapping(__pyx_v_name, __pyx_v_mapping); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 120; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_r = __pyx_t_1;
    __pyx_t_1 = 0;
    goto __pyx_L0;
    goto __pyx_L3;
  }
  /*else*/ {

    /* "axon/_loader.py":122
 *         return c_new_mapping(name, mapping)
 *     else:
 *         return handler(mapping)             # <<<<<<<<<<<<<<
 * #
 * def c_new_sequence_mixed(name, sequence):
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 122; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(((PyObject *)__pyx_v_mapping));
    PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_mapping));
    __Pyx_GIVEREF(((PyObject *)__pyx_v_mapping));
    __pyx_t_4 = PyObject_Call(__pyx_v_handler, ((PyObject *)__pyx_t_1), NULL); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 122; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(((PyObject *)__pyx_t_1)); __pyx_t_1 = 0;
    __pyx_r = __pyx_t_4;
    __pyx_t_4 = 0;
    goto __pyx_L0;
  }
  __pyx_L3:;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("axon._loader.c_new_mapping_mixed", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_handler);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_loader.py":124
 *         return handler(mapping)
 * #
 * def c_new_sequence_mixed(name, sequence):             # <<<<<<<<<<<<<<
 *     handler = c_factory_dict.get(name)
 *     if handler is None:
 */

static PyObject *__pyx_f_4axon_7_loader_c_new_sequence_mixed(PyObject *__pyx_v_name, PyObject *__pyx_v_sequence) {
  PyObject *__pyx_v_handler = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("c_new_sequence_mixed", 0);

  /* "axon/_loader.py":125
 * #
 * def c_new_sequence_mixed(name, sequence):
 *     handler = c_factory_dict.get(name)             # <<<<<<<<<<<<<<
 *     if handler is None:
 *         return c_new_sequence(name, sequence)
 */
  if (unlikely(((PyObject *)__pyx_v_4axon_7_loader_c_factory_dict) == Py_None)) {
    PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%s'", "get");
    {__pyx_filename = __pyx_f[0]; __pyx_lineno = 125; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }
  __pyx_t_1 = __Pyx_PyDict_GetItemDefault(((PyObject *)__pyx_v_4axon_7_loader_c_factory_dict), __pyx_v_name, Py_None); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 125; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_handler = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "axon/_loader.py":126
 * def c_new_sequence_mixed(name, sequence):
 *     handler = c_factory_dict.get(name)
 *     if handler is None:             # <<<<<<<<<<<<<<
 *         return c_new_sequence(name, sequence)
 *     else:
 */
  __pyx_t_2 = (__pyx_v_handler == Py_None);
  __pyx_t_3 = (__pyx_t_2 != 0);
  if (__pyx_t_3) {

    /* "axon/_loader.py":127
 *     handler = c_factory_dict.get(name)
 *     if handler is None:
 *         return c_new_sequence(name, sequence)             # <<<<<<<<<<<<<<
 *     else:
 *         return handler(sequence)
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_1 = __pyx_f_4axon_8_objects_c_new_sequence(__pyx_v_name, __pyx_v_sequence); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 127; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_r = __pyx_t_1;
    __pyx_t_1 = 0;
    goto __pyx_L0;
    goto __pyx_L3;
  }
  /*else*/ {

    /* "axon/_loader.py":129
 *         return c_new_sequence(name, sequence)
 *     else:
 *         return handler(sequence)             # <<<<<<<<<<<<<<
 * #
 * def c_new_element_mixed(name, mapping, sequence):
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 129; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(((PyObject *)__pyx_v_sequence));
    PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_sequence));
    __Pyx_GIVEREF(((PyObject *)__pyx_v_sequence));
    __pyx_t_4 = PyObject_Call(__pyx_v_handler, ((PyObject *)__pyx_t_1), NULL); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 129; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(((PyObject *)__pyx_t_1)); __pyx_t_1 = 0;
    __pyx_r = __pyx_t_4;
    __pyx_t_4 = 0;
    goto __pyx_L0;
  }
  __pyx_L3:;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("axon._loader.c_new_sequence_mixed", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_handler);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_loader.py":131
 *         return handler(sequence)
 * #
 * def c_new_element_mixed(name, mapping, sequence):             # <<<<<<<<<<<<<<
 *     handler = c_factory_dict.get(name)
 *     if handler is None:
 */

static PyObject *__pyx_f_4axon_7_loader_c_new_element_mixed(PyObject *__pyx_v_name, PyObject *__pyx_v_mapping, PyObject *__pyx_v_sequence) {
  PyObject *__pyx_v_handler = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("c_new_element_mixed", 0);

  /* "axon/_loader.py":132
 * #
 * def c_new_element_mixed(name, mapping, sequence):
 *     handler = c_factory_dict.get(name)             # <<<<<<<<<<<<<<
 *     if handler is None:
 *         return c_new_element(name, mapping, sequence)
 */
  if (unlikely(((PyObject *)__pyx_v_4axon_7_loader_c_factory_dict) == Py_None)) {
    PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%s'", "get");
    {__pyx_filename = __pyx_f[0]; __pyx_lineno = 132; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }
  __pyx_t_1 = __Pyx_PyDict_GetItemDefault(((PyObject *)__pyx_v_4axon_7_loader_c_factory_dict), __pyx_v_name, Py_None); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 132; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_handler = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "axon/_loader.py":133
 * def c_new_element_mixed(name, mapping, sequence):
 *     handler = c_factory_dict.get(name)
 *     if handler is None:             # <<<<<<<<<<<<<<
 *         return c_new_element(name, mapping, sequence)
 *     else:
 */
  __pyx_t_2 = (__pyx_v_handler == Py_None);
  __pyx_t_3 = (__pyx_t_2 != 0);
  if (__pyx_t_3) {

    /* "axon/_loader.py":134
 *     handler = c_factory_dict.get(name)
 *     if handler is None:
 *         return c_new_element(name, mapping, sequence)             # <<<<<<<<<<<<<<
 *     else:
 *         return handler(mapping, sequence)
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_1 = __pyx_f_4axon_8_objects_c_new_element(__pyx_v_name, __pyx_v_mapping, __pyx_v_sequence); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 134; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_r = __pyx_t_1;
    __pyx_t_1 = 0;
    goto __pyx_L0;
    goto __pyx_L3;
  }
  /*else*/ {

    /* "axon/_loader.py":136
 *         return c_new_element(name, mapping, sequence)
 *     else:
 *         return handler(mapping, sequence)             # <<<<<<<<<<<<<<
 * #
 * def c_new_instance_mixed(name, sequence, mapping):
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_1 = PyTuple_New(2); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 136; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(((PyObject *)__pyx_v_mapping));
    PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_mapping));
    __Pyx_GIVEREF(((PyObject *)__pyx_v_mapping));
    __Pyx_INCREF(((PyObject *)__pyx_v_sequence));
    PyTuple_SET_ITEM(__pyx_t_1, 1, ((PyObject *)__pyx_v_sequence));
    __Pyx_GIVEREF(((PyObject *)__pyx_v_sequence));
    __pyx_t_4 = PyObject_Call(__pyx_v_handler, ((PyObject *)__pyx_t_1), NULL); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 136; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(((PyObject *)__pyx_t_1)); __pyx_t_1 = 0;
    __pyx_r = __pyx_t_4;
    __pyx_t_4 = 0;
    goto __pyx_L0;
  }
  __pyx_L3:;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("axon._loader.c_new_element_mixed", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_handler);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_loader.py":138
 *         return handler(mapping, sequence)
 * #
 * def c_new_instance_mixed(name, sequence, mapping):             # <<<<<<<<<<<<<<
 *     handler = c_factory_dict.get(name)
 *     if handler is None:
 */

static PyObject *__pyx_f_4axon_7_loader_c_new_instance_mixed(PyObject *__pyx_v_name, PyObject *__pyx_v_sequence, PyObject *__pyx_v_mapping) {
  PyObject *__pyx_v_handler = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("c_new_instance_mixed", 0);

  /* "axon/_loader.py":139
 * #
 * def c_new_instance_mixed(name, sequence, mapping):
 *     handler = c_factory_dict.get(name)             # <<<<<<<<<<<<<<
 *     if handler is None:
 *         return c_new_instance(name, sequence, mapping)
 */
  if (unlikely(((PyObject *)__pyx_v_4axon_7_loader_c_factory_dict) == Py_None)) {
    PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%s'", "get");
    {__pyx_filename = __pyx_f[0]; __pyx_lineno = 139; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }
  __pyx_t_1 = __Pyx_PyDict_GetItemDefault(((PyObject *)__pyx_v_4axon_7_loader_c_factory_dict), __pyx_v_name, Py_None); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 139; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_handler = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "axon/_loader.py":140
 * def c_new_instance_mixed(name, sequence, mapping):
 *     handler = c_factory_dict.get(name)
 *     if handler is None:             # <<<<<<<<<<<<<<
 *         return c_new_instance(name, sequence, mapping)
 *     else:
 */
  __pyx_t_2 = (__pyx_v_handler == Py_None);
  __pyx_t_3 = (__pyx_t_2 != 0);
  if (__pyx_t_3) {

    /* "axon/_loader.py":141
 *     handler = c_factory_dict.get(name)
 *     if handler is None:
 *         return c_new_instance(name, sequence, mapping)             # <<<<<<<<<<<<<<
 *     else:
 *         return handler(sequence, mapping)
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_1 = __pyx_f_4axon_8_objects_c_new_instance(__pyx_v_name, __pyx_v_sequence, __pyx_v_mapping); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 141; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_r = __pyx_t_1;
    __pyx_t_1 = 0;
    goto __pyx_L0;
    goto __pyx_L3;
  }
  /*else*/ {

    /* "axon/_loader.py":143
 *         return c_new_instance(name, sequence, mapping)
 *     else:
 *         return handler(sequence, mapping)             # <<<<<<<<<<<<<<
 * #
 * def c_new_empty_mixed(name):
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_1 = PyTuple_New(2); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 143; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(((PyObject *)__pyx_v_sequence));
    PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_sequence));
    __Pyx_GIVEREF(((PyObject *)__pyx_v_sequence));
    __Pyx_INCREF(((PyObject *)__pyx_v_mapping));
    PyTuple_SET_ITEM(__pyx_t_1, 1, ((PyObject *)__pyx_v_mapping));
    __Pyx_GIVEREF(((PyObject *)__pyx_v_mapping));
    __pyx_t_4 = PyObject_Call(__pyx_v_handler, ((PyObject *)__pyx_t_1), NULL); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 143; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(((PyObject *)__pyx_t_1)); __pyx_t_1 = 0;
    __pyx_r = __pyx_t_4;
    __pyx_t_4 = 0;
    goto __pyx_L0;
  }
  __pyx_L3:;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("axon._loader.c_new_instance_mixed", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_handler);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_loader.py":145
 *         return handler(sequence, mapping)
 * #
 * def c_new_empty_mixed(name):             # <<<<<<<<<<<<<<
 *     handler = c_factory_dict.get(name)
 *     if handler is None:
 */

static PyObject *__pyx_f_4axon_7_loader_c_new_empty_mixed(PyObject *__pyx_v_name) {
  PyObject *__pyx_v_handler = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("c_new_empty_mixed", 0);

  /* "axon/_loader.py":146
 * #
 * def c_new_empty_mixed(name):
 *     handler = c_factory_dict.get(name)             # <<<<<<<<<<<<<<
 *     if handler is None:
 *         return c_new_empty(name)
 */
  if (unlikely(((PyObject *)__pyx_v_4axon_7_loader_c_factory_dict) == Py_None)) {
    PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%s'", "get");
    {__pyx_filename = __pyx_f[0]; __pyx_lineno = 146; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }
  __pyx_t_1 = __Pyx_PyDict_GetItemDefault(((PyObject *)__pyx_v_4axon_7_loader_c_factory_dict), __pyx_v_name, Py_None); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 146; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_handler = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "axon/_loader.py":147
 * def c_new_empty_mixed(name):
 *     handler = c_factory_dict.get(name)
 *     if handler is None:             # <<<<<<<<<<<<<<
 *         return c_new_empty(name)
 *     else:
 */
  __pyx_t_2 = (__pyx_v_handler == Py_None);
  __pyx_t_3 = (__pyx_t_2 != 0);
  if (__pyx_t_3) {

    /* "axon/_loader.py":148
 *     handler = c_factory_dict.get(name)
 *     if handler is None:
 *         return c_new_empty(name)             # <<<<<<<<<<<<<<
 *     else:
 *         return handler()
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_1 = __pyx_f_4axon_8_objects_c_new_empty(__pyx_v_name); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 148; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_r = __pyx_t_1;
    __pyx_t_1 = 0;
    goto __pyx_L0;
    goto __pyx_L3;
  }
  /*else*/ {

    /* "axon/_loader.py":150
 *         return c_new_empty(name)
 *     else:
 *         return handler()             # <<<<<<<<<<<<<<
 * #
 * #######################################################################
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_1 = PyObject_Call(__pyx_v_handler, ((PyObject *)__pyx_empty_tuple), NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 150; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_r = __pyx_t_1;
    __pyx_t_1 = 0;
    goto __pyx_L0;
  }
  __pyx_L3:;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("axon._loader.c_new_empty_mixed", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_handler);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_loader.py":155
 * #
 * 
 * def c_new_mapping_strict(name, mapping):             # <<<<<<<<<<<<<<
 *     handler = c_factory_dict.get(name)
 *     if handler is None:
 */

static PyObject *__pyx_f_4axon_7_loader_c_new_mapping_strict(PyObject *__pyx_v_name, PyObject *__pyx_v_mapping) {
  PyObject *__pyx_v_handler = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("c_new_mapping_strict", 0);

  /* "axon/_loader.py":156
 * 
 * def c_new_mapping_strict(name, mapping):
 *     handler = c_factory_dict.get(name)             # <<<<<<<<<<<<<<
 *     if handler is None:
 *         return c_undefined
 */
  if (unlikely(((PyObject *)__pyx_v_4axon_7_loader_c_factory_dict) == Py_None)) {
    PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%s'", "get");
    {__pyx_filename = __pyx_f[0]; __pyx_lineno = 156; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }
  __pyx_t_1 = __Pyx_PyDict_GetItemDefault(((PyObject *)__pyx_v_4axon_7_loader_c_factory_dict), __pyx_v_name, Py_None); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 156; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_handler = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "axon/_loader.py":157
 * def c_new_mapping_strict(name, mapping):
 *     handler = c_factory_dict.get(name)
 *     if handler is None:             # <<<<<<<<<<<<<<
 *         return c_undefined
 *     else:
 */
  __pyx_t_2 = (__pyx_v_handler == Py_None);
  __pyx_t_3 = (__pyx_t_2 != 0);
  if (__pyx_t_3) {

    /* "axon/_loader.py":158
 *     handler = c_factory_dict.get(name)
 *     if handler is None:
 *         return c_undefined             # <<<<<<<<<<<<<<
 *     else:
 *         return handler(mapping)
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_v_4axon_8_objects_c_undefined);
    __pyx_r = __pyx_v_4axon_8_objects_c_undefined;
    goto __pyx_L0;
    goto __pyx_L3;
  }
  /*else*/ {

    /* "axon/_loader.py":160
 *         return c_undefined
 *     else:
 *         return handler(mapping)             # <<<<<<<<<<<<<<
 * #
 * def c_new_sequence_strict(name, sequence):
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 160; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(((PyObject *)__pyx_v_mapping));
    PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_mapping));
    __Pyx_GIVEREF(((PyObject *)__pyx_v_mapping));
    __pyx_t_4 = PyObject_Call(__pyx_v_handler, ((PyObject *)__pyx_t_1), NULL); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 160; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(((PyObject *)__pyx_t_1)); __pyx_t_1 = 0;
    __pyx_r = __pyx_t_4;
    __pyx_t_4 = 0;
    goto __pyx_L0;
  }
  __pyx_L3:;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("axon._loader.c_new_mapping_strict", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_handler);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_loader.py":162
 *         return handler(mapping)
 * #
 * def c_new_sequence_strict(name, sequence):             # <<<<<<<<<<<<<<
 *     handler = c_factory_dict.get(name)
 *     if handler is None:
 */

static PyObject *__pyx_f_4axon_7_loader_c_new_sequence_strict(PyObject *__pyx_v_name, PyObject *__pyx_v_sequence) {
  PyObject *__pyx_v_handler = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("c_new_sequence_strict", 0);

  /* "axon/_loader.py":163
 * #
 * def c_new_sequence_strict(name, sequence):
 *     handler = c_factory_dict.get(name)             # <<<<<<<<<<<<<<
 *     if handler is None:
 *         return c_undefined
 */
  if (unlikely(((PyObject *)__pyx_v_4axon_7_loader_c_factory_dict) == Py_None)) {
    PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%s'", "get");
    {__pyx_filename = __pyx_f[0]; __pyx_lineno = 163; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }
  __pyx_t_1 = __Pyx_PyDict_GetItemDefault(((PyObject *)__pyx_v_4axon_7_loader_c_factory_dict), __pyx_v_name, Py_None); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 163; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_handler = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "axon/_loader.py":164
 * def c_new_sequence_strict(name, sequence):
 *     handler = c_factory_dict.get(name)
 *     if handler is None:             # <<<<<<<<<<<<<<
 *         return c_undefined
 *     else:
 */
  __pyx_t_2 = (__pyx_v_handler == Py_None);
  __pyx_t_3 = (__pyx_t_2 != 0);
  if (__pyx_t_3) {

    /* "axon/_loader.py":165
 *     handler = c_factory_dict.get(name)
 *     if handler is None:
 *         return c_undefined             # <<<<<<<<<<<<<<
 *     else:
 *         return handler(sequence)
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_v_4axon_8_objects_c_undefined);
    __pyx_r = __pyx_v_4axon_8_objects_c_undefined;
    goto __pyx_L0;
    goto __pyx_L3;
  }
  /*else*/ {

    /* "axon/_loader.py":167
 *         return c_undefined
 *     else:
 *         return handler(sequence)             # <<<<<<<<<<<<<<
 * #
 * def c_new_element_strict(name, mapping, sequence):
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 167; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(((PyObject *)__pyx_v_sequence));
    PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_sequence));
    __Pyx_GIVEREF(((PyObject *)__pyx_v_sequence));
    __pyx_t_4 = PyObject_Call(__pyx_v_handler, ((PyObject *)__pyx_t_1), NULL); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 167; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(((PyObject *)__pyx_t_1)); __pyx_t_1 = 0;
    __pyx_r = __pyx_t_4;
    __pyx_t_4 = 0;
    goto __pyx_L0;
  }
  __pyx_L3:;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("axon._loader.c_new_sequence_strict", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_handler);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_loader.py":169
 *         return handler(sequence)
 * #
 * def c_new_element_strict(name, mapping, sequence):             # <<<<<<<<<<<<<<
 *     handler = c_factory_dict.get(name)
 *     if handler is None:
 */

static PyObject *__pyx_f_4axon_7_loader_c_new_element_strict(PyObject *__pyx_v_name, PyObject *__pyx_v_mapping, PyObject *__pyx_v_sequence) {
  PyObject *__pyx_v_handler = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("c_new_element_strict", 0);

  /* "axon/_loader.py":170
 * #
 * def c_new_element_strict(name, mapping, sequence):
 *     handler = c_factory_dict.get(name)             # <<<<<<<<<<<<<<
 *     if handler is None:
 *         return c_undefined
 */
  if (unlikely(((PyObject *)__pyx_v_4axon_7_loader_c_factory_dict) == Py_None)) {
    PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%s'", "get");
    {__pyx_filename = __pyx_f[0]; __pyx_lineno = 170; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }
  __pyx_t_1 = __Pyx_PyDict_GetItemDefault(((PyObject *)__pyx_v_4axon_7_loader_c_factory_dict), __pyx_v_name, Py_None); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 170; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_handler = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "axon/_loader.py":171
 * def c_new_element_strict(name, mapping, sequence):
 *     handler = c_factory_dict.get(name)
 *     if handler is None:             # <<<<<<<<<<<<<<
 *         return c_undefined
 *     else:
 */
  __pyx_t_2 = (__pyx_v_handler == Py_None);
  __pyx_t_3 = (__pyx_t_2 != 0);
  if (__pyx_t_3) {

    /* "axon/_loader.py":172
 *     handler = c_factory_dict.get(name)
 *     if handler is None:
 *         return c_undefined             # <<<<<<<<<<<<<<
 *     else:
 *         return handler(mapping, sequence)
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_v_4axon_8_objects_c_undefined);
    __pyx_r = __pyx_v_4axon_8_objects_c_undefined;
    goto __pyx_L0;
    goto __pyx_L3;
  }
  /*else*/ {

    /* "axon/_loader.py":174
 *         return c_undefined
 *     else:
 *         return handler(mapping, sequence)             # <<<<<<<<<<<<<<
 * #
 * def c_new_instance_strict(name, sequence, mapping):
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_1 = PyTuple_New(2); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 174; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(((PyObject *)__pyx_v_mapping));
    PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_mapping));
    __Pyx_GIVEREF(((PyObject *)__pyx_v_mapping));
    __Pyx_INCREF(((PyObject *)__pyx_v_sequence));
    PyTuple_SET_ITEM(__pyx_t_1, 1, ((PyObject *)__pyx_v_sequence));
    __Pyx_GIVEREF(((PyObject *)__pyx_v_sequence));
    __pyx_t_4 = PyObject_Call(__pyx_v_handler, ((PyObject *)__pyx_t_1), NULL); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 174; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(((PyObject *)__pyx_t_1)); __pyx_t_1 = 0;
    __pyx_r = __pyx_t_4;
    __pyx_t_4 = 0;
    goto __pyx_L0;
  }
  __pyx_L3:;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("axon._loader.c_new_element_strict", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_handler);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_loader.py":176
 *         return handler(mapping, sequence)
 * #
 * def c_new_instance_strict(name, sequence, mapping):             # <<<<<<<<<<<<<<
 *     handler = c_factory_dict.get(name)
 *     if handler is None:
 */

static PyObject *__pyx_f_4axon_7_loader_c_new_instance_strict(PyObject *__pyx_v_name, PyObject *__pyx_v_sequence, PyObject *__pyx_v_mapping) {
  PyObject *__pyx_v_handler = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("c_new_instance_strict", 0);

  /* "axon/_loader.py":177
 * #
 * def c_new_instance_strict(name, sequence, mapping):
 *     handler = c_factory_dict.get(name)             # <<<<<<<<<<<<<<
 *     if handler is None:
 *         return c_undefined
 */
  if (unlikely(((PyObject *)__pyx_v_4axon_7_loader_c_factory_dict) == Py_None)) {
    PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%s'", "get");
    {__pyx_filename = __pyx_f[0]; __pyx_lineno = 177; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }
  __pyx_t_1 = __Pyx_PyDict_GetItemDefault(((PyObject *)__pyx_v_4axon_7_loader_c_factory_dict), __pyx_v_name, Py_None); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 177; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_handler = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "axon/_loader.py":178
 * def c_new_instance_strict(name, sequence, mapping):
 *     handler = c_factory_dict.get(name)
 *     if handler is None:             # <<<<<<<<<<<<<<
 *         return c_undefined
 *     else:
 */
  __pyx_t_2 = (__pyx_v_handler == Py_None);
  __pyx_t_3 = (__pyx_t_2 != 0);
  if (__pyx_t_3) {

    /* "axon/_loader.py":179
 *     handler = c_factory_dict.get(name)
 *     if handler is None:
 *         return c_undefined             # <<<<<<<<<<<<<<
 *     else:
 *         return handler(sequence, mapping)
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_v_4axon_8_objects_c_undefined);
    __pyx_r = __pyx_v_4axon_8_objects_c_undefined;
    goto __pyx_L0;
    goto __pyx_L3;
  }
  /*else*/ {

    /* "axon/_loader.py":181
 *         return c_undefined
 *     else:
 *         return handler(sequence, mapping)             # <<<<<<<<<<<<<<
 * #
 * def c_new_empty_strict(name):
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_1 = PyTuple_New(2); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 181; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(((PyObject *)__pyx_v_sequence));
    PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_sequence));
    __Pyx_GIVEREF(((PyObject *)__pyx_v_sequence));
    __Pyx_INCREF(((PyObject *)__pyx_v_mapping));
    PyTuple_SET_ITEM(__pyx_t_1, 1, ((PyObject *)__pyx_v_mapping));
    __Pyx_GIVEREF(((PyObject *)__pyx_v_mapping));
    __pyx_t_4 = PyObject_Call(__pyx_v_handler, ((PyObject *)__pyx_t_1), NULL); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 181; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(((PyObject *)__pyx_t_1)); __pyx_t_1 = 0;
    __pyx_r = __pyx_t_4;
    __pyx_t_4 = 0;
    goto __pyx_L0;
  }
  __pyx_L3:;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("axon._loader.c_new_instance_strict", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_handler);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_loader.py":183
 *         return handler(sequence, mapping)
 * #
 * def c_new_empty_strict(name):             # <<<<<<<<<<<<<<
 *     handler = c_factory_dict.get(name)
 *     if handler is None:
 */

static PyObject *__pyx_f_4axon_7_loader_c_new_empty_strict(PyObject *__pyx_v_name) {
  PyObject *__pyx_v_handler = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("c_new_empty_strict", 0);

  /* "axon/_loader.py":184
 * #
 * def c_new_empty_strict(name):
 *     handler = c_factory_dict.get(name)             # <<<<<<<<<<<<<<
 *     if handler is None:
 *         return c_undefined
 */
  if (unlikely(((PyObject *)__pyx_v_4axon_7_loader_c_factory_dict) == Py_None)) {
    PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%s'", "get");
    {__pyx_filename = __pyx_f[0]; __pyx_lineno = 184; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }
  __pyx_t_1 = __Pyx_PyDict_GetItemDefault(((PyObject *)__pyx_v_4axon_7_loader_c_factory_dict), __pyx_v_name, Py_None); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 184; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_handler = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "axon/_loader.py":185
 * def c_new_empty_strict(name):
 *     handler = c_factory_dict.get(name)
 *     if handler is None:             # <<<<<<<<<<<<<<
 *         return c_undefined
 *     else:
 */
  __pyx_t_2 = (__pyx_v_handler == Py_None);
  __pyx_t_3 = (__pyx_t_2 != 0);
  if (__pyx_t_3) {

    /* "axon/_loader.py":186
 *     handler = c_factory_dict.get(name)
 *     if handler is None:
 *         return c_undefined             # <<<<<<<<<<<<<<
 *     else:
 *         return handler()
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_v_4axon_8_objects_c_undefined);
    __pyx_r = __pyx_v_4axon_8_objects_c_undefined;
    goto __pyx_L0;
    goto __pyx_L3;
  }
  /*else*/ {

    /* "axon/_loader.py":188
 *         return c_undefined
 *     else:
 *         return handler()             # <<<<<<<<<<<<<<
 * 
 * class Builder:
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_1 = PyObject_Call(__pyx_v_handler, ((PyObject *)__pyx_empty_tuple), NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 188; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_r = __pyx_t_1;
    __pyx_t_1 = 0;
    goto __pyx_L0;
  }
  __pyx_L3:;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("axon._loader.c_new_empty_strict", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_handler);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_4axon_7_loader_13FixedOffsetTZ_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_4axon_7_loader_13FixedOffsetTZ_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_minutes = 0;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s__minutes,0};
    PyObject* values[1] = {0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s__minutes)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "__init__") < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 198; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 1) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
    }
    __pyx_v_minutes = values[0];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__init__", 1, 1, 1, PyTuple_GET_SIZE(__pyx_args)); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 198; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  __pyx_L3_error:;
  __Pyx_AddTraceback("axon._loader.FixedOffsetTZ.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_4axon_7_loader_13FixedOffsetTZ___init__(((struct FixedOffsetTZObject *)__pyx_v_self), __pyx_v_minutes);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_loader.py":198
 *     """Fixed offset in minutes east from UTC."""
 * 
 *     def __init__(self, minutes):             # <<<<<<<<<<<<<<
 *         self._init(minutes)
 * 
 */

static int __pyx_pf_4axon_7_loader_13FixedOffsetTZ___init__(struct FixedOffsetTZObject *__pyx_v_self, PyObject *__pyx_v_minutes) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__", 0);

  /* "axon/_loader.py":199
 * 
 *     def __init__(self, minutes):
 *         self._init(minutes)             # <<<<<<<<<<<<<<
 * 
 *     def _init(self, minutes):
 */
  ((struct __pyx_vtabstruct_4axon_7_loader_FixedOffsetTZ *)__pyx_v_self->__pyx_vtab)->_init(__pyx_v_self, __pyx_v_minutes);

  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_loader.py":201
 *         self._init(minutes)
 * 
 *     def _init(self, minutes):             # <<<<<<<<<<<<<<
 *         self.minutes = minutes
 * 
 */

static void __pyx_f_4axon_7_loader_13FixedOffsetTZ__init(struct FixedOffsetTZObject *__pyx_v_self, PyObject *__pyx_v_minutes) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_init", 0);

  /* "axon/_loader.py":202
 * 
 *     def _init(self, minutes):
 *         self.minutes = minutes             # <<<<<<<<<<<<<<
 * 
 *     def utcoffset(self, dt):
 */
  __Pyx_INCREF(__pyx_v_minutes);
  __Pyx_GIVEREF(__pyx_v_minutes);
  __Pyx_GOTREF(__pyx_v_self->minutes);
  __Pyx_DECREF(__pyx_v_self->minutes);
  __pyx_v_self->minutes = __pyx_v_minutes;

  __Pyx_RefNannyFinishContext();
}

/* Python wrapper */
static PyObject *__pyx_pw_4axon_7_loader_13FixedOffsetTZ_3utcoffset(PyObject *__pyx_v_self, PyObject *__pyx_v_dt); /*proto*/
static PyObject *__pyx_pw_4axon_7_loader_13FixedOffsetTZ_3utcoffset(PyObject *__pyx_v_self, PyObject *__pyx_v_dt) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("utcoffset (wrapper)", 0);
  __pyx_r = __pyx_pf_4axon_7_loader_13FixedOffsetTZ_2utcoffset(((struct FixedOffsetTZObject *)__pyx_v_self), ((PyObject *)__pyx_v_dt));
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_loader.py":204
 *         self.minutes = minutes
 * 
 *     def utcoffset(self, dt):             # <<<<<<<<<<<<<<
 *         return pydatetime.timedelta(minutes=self.minutes)
 * 
 */

static PyObject *__pyx_pf_4axon_7_loader_13FixedOffsetTZ_2utcoffset(struct FixedOffsetTZObject *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v_dt) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("utcoffset", 0);

  /* "axon/_loader.py":205
 * 
 *     def utcoffset(self, dt):
 *         return pydatetime.timedelta(minutes=self.minutes)             # <<<<<<<<<<<<<<
 * 
 *     def tzname(self, dt):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s__pydatetime); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 205; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s__timedelta); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 205; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyDict_New(); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 205; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(((PyObject *)__pyx_t_1));
  if (PyDict_SetItem(__pyx_t_1, ((PyObject *)__pyx_n_s__minutes), __pyx_v_self->minutes) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 205; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_t_3 = PyObject_Call(__pyx_t_2, ((PyObject *)__pyx_empty_tuple), ((PyObject *)__pyx_t_1)); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 205; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_1)); __pyx_t_1 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("axon._loader.FixedOffsetTZ.utcoffset", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_4axon_7_loader_13FixedOffsetTZ_5tzname(PyObject *__pyx_v_self, PyObject *__pyx_v_dt); /*proto*/
static PyObject *__pyx_pw_4axon_7_loader_13FixedOffsetTZ_5tzname(PyObject *__pyx_v_self, PyObject *__pyx_v_dt) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("tzname (wrapper)", 0);
  __pyx_r = __pyx_pf_4axon_7_loader_13FixedOffsetTZ_4tzname(((struct FixedOffsetTZObject *)__pyx_v_self), ((PyObject *)__pyx_v_dt));
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_loader.py":207
 *         return pydatetime.timedelta(minutes=self.minutes)
 * 
 *     def tzname(self, dt):             # <<<<<<<<<<<<<<
 *         if self.minutes > 720:
 *             minutes = 1440 - self.minutes
 */

static PyObject *__pyx_pf_4axon_7_loader_13FixedOffsetTZ_4tzname(struct FixedOffsetTZObject *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v_dt) {
  PyObject *__pyx_v_minutes = NULL;
  PyObject *__pyx_v_sign = NULL;
  PyObject *__pyx_v_h = NULL;
  PyObject *__pyx_v_m = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *(*__pyx_t_6)(PyObject *);
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("tzname", 0);

  /* "axon/_loader.py":208
 * 
 *     def tzname(self, dt):
 *         if self.minutes > 720:             # <<<<<<<<<<<<<<
 *             minutes = 1440 - self.minutes
 *             sign = '-'
 */
  __pyx_t_1 = PyObject_RichCompare(__pyx_v_self->minutes, __pyx_int_720, Py_GT); __Pyx_XGOTREF(__pyx_t_1); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 208; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_2 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 208; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_2) {

    /* "axon/_loader.py":209
 *     def tzname(self, dt):
 *         if self.minutes > 720:
 *             minutes = 1440 - self.minutes             # <<<<<<<<<<<<<<
 *             sign = '-'
 *         else:
 */
    __pyx_t_1 = PyNumber_Subtract(__pyx_int_1440, __pyx_v_self->minutes); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 209; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_v_minutes = __pyx_t_1;
    __pyx_t_1 = 0;

    /* "axon/_loader.py":210
 *         if self.minutes > 720:
 *             minutes = 1440 - self.minutes
 *             sign = '-'             # <<<<<<<<<<<<<<
 *         else:
 *             minutes = self.minutes
 */
    __Pyx_INCREF(((PyObject *)__pyx_kp_u_6));
    __pyx_v_sign = __pyx_kp_u_6;
    goto __pyx_L3;
  }
  /*else*/ {

    /* "axon/_loader.py":212
 *             sign = '-'
 *         else:
 *             minutes = self.minutes             # <<<<<<<<<<<<<<
 *             sign = '+'
 *         h, m = divmod(minutes, 60)
 */
    __pyx_t_1 = __pyx_v_self->minutes;
    __Pyx_INCREF(__pyx_t_1);
    __pyx_v_minutes = __pyx_t_1;
    __pyx_t_1 = 0;

    /* "axon/_loader.py":213
 *         else:
 *             minutes = self.minutes
 *             sign = '+'             # <<<<<<<<<<<<<<
 *         h, m = divmod(minutes, 60)
 *         if m:
 */
    __Pyx_INCREF(((PyObject *)__pyx_kp_u_7));
    __pyx_v_sign = __pyx_kp_u_7;
  }
  __pyx_L3:;

  /* "axon/_loader.py":214
 *             minutes = self.minutes
 *             sign = '+'
 *         h, m = divmod(minutes, 60)             # <<<<<<<<<<<<<<
 *         if m:
 *             return '%s%02d:%02d' % (sign, h, m)
 */
  __pyx_t_1 = PyNumber_Divmod(__pyx_v_minutes, __pyx_int_60); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 214; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if ((likely(PyTuple_CheckExact(__pyx_t_1))) || (PyList_CheckExact(__pyx_t_1))) {
    PyObject* sequence = __pyx_t_1;
    #if CYTHON_COMPILING_IN_CPYTHON
    Py_ssize_t size = Py_SIZE(sequence);
    #else
    Py_ssize_t size = PySequence_Size(sequence);
    #endif
    if (unlikely(size != 2)) {
      if (size > 2) __Pyx_RaiseTooManyValuesError(2);
      else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
      {__pyx_filename = __pyx_f[0]; __pyx_lineno = 214; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    }
    #if CYTHON_COMPILING_IN_CPYTHON
    if (likely(PyTuple_CheckExact(sequence))) {
      __pyx_t_3 = PyTuple_GET_ITEM(sequence, 0); 
      __pyx_t_4 = PyTuple_GET_ITEM(sequence, 1); 
    } else {
      __pyx_t_3 = PyList_GET_ITEM(sequence, 0); 
      __pyx_t_4 = PyList_GET_ITEM(sequence, 1); 
    }
    __Pyx_INCREF(__pyx_t_3);
    __Pyx_INCREF(__pyx_t_4);
    #else
    __pyx_t_3 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 214; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 214; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_4);
    #endif
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  } else
  {
    Py_ssize_t index = -1;
    __pyx_t_5 = PyObject_GetIter(__pyx_t_1); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 214; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_6 = Py_TYPE(__pyx_t_5)->tp_iternext;
    index = 0; __pyx_t_3 = __pyx_t_6(__pyx_t_5); if (unlikely(!__pyx_t_3)) goto __pyx_L4_unpacking_failed;
    __Pyx_GOTREF(__pyx_t_3);
    index = 1; __pyx_t_4 = __pyx_t_6(__pyx_t_5); if (unlikely(!__pyx_t_4)) goto __pyx_L4_unpacking_failed;
    __Pyx_GOTREF(__pyx_t_4);
    if (__Pyx_IternextUnpackEndCheck(__pyx_t_6(__pyx_t_5), 2) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 214; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __pyx_t_6 = NULL;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    goto __pyx_L5_unpacking_done;
    __pyx_L4_unpacking_failed:;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_6 = NULL;
    if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
    {__pyx_filename = __pyx_f[0]; __pyx_lineno = 214; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __pyx_L5_unpacking_done:;
  }
  __pyx_v_h = __pyx_t_3;
  __pyx_t_3 = 0;
  __pyx_v_m = __pyx_t_4;
  __pyx_t_4 = 0;

  /* "axon/_loader.py":215
 *             sign = '+'
 *         h, m = divmod(minutes, 60)
 *         if m:             # <<<<<<<<<<<<<<
 *             return '%s%02d:%02d' % (sign, h, m)
 *         else:
 */
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_v_m); if (unlikely(__pyx_t_2 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 215; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__pyx_t_2) {

    /* "axon/_loader.py":216
 *         h, m = divmod(minutes, 60)
 *         if m:
 *             return '%s%02d:%02d' % (sign, h, m)             # <<<<<<<<<<<<<<
 *         else:
 *             return '%s%02d' % (sign, h)
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_1 = PyTuple_New(3); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 216; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(((PyObject *)__pyx_v_sign));
    PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_sign));
    __Pyx_GIVEREF(((PyObject *)__pyx_v_sign));
    __Pyx_INCREF(__pyx_v_h);
    PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_v_h);
    __Pyx_GIVEREF(__pyx_v_h);
    __Pyx_INCREF(__pyx_v_m);
    PyTuple_SET_ITEM(__pyx_t_1, 2, __pyx_v_m);
    __Pyx_GIVEREF(__pyx_v_m);
    __pyx_t_4 = PyNumber_Remainder(((PyObject *)__pyx_kp_u_8), ((PyObject *)__pyx_t_1)); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 216; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(((PyObject *)__pyx_t_4));
    __Pyx_DECREF(((PyObject *)__pyx_t_1)); __pyx_t_1 = 0;
    __pyx_r = ((PyObject *)__pyx_t_4);
    __pyx_t_4 = 0;
    goto __pyx_L0;
    goto __pyx_L6;
  }
  /*else*/ {

    /* "axon/_loader.py":218
 *             return '%s%02d:%02d' % (sign, h, m)
 *         else:
 *             return '%s%02d' % (sign, h)             # <<<<<<<<<<<<<<
 * 
 *     def dst(self, dt):
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_4 = PyTuple_New(2); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 218; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_INCREF(((PyObject *)__pyx_v_sign));
    PyTuple_SET_ITEM(__pyx_t_4, 0, ((PyObject *)__pyx_v_sign));
    __Pyx_GIVEREF(((PyObject *)__pyx_v_sign));
    __Pyx_INCREF(__pyx_v_h);
    PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_v_h);
    __Pyx_GIVEREF(__pyx_v_h);
    __pyx_t_1 = PyNumber_Remainder(((PyObject *)__pyx_kp_u_9), ((PyObject *)__pyx_t_4)); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 218; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(((PyObject *)__pyx_t_1));
    __Pyx_DECREF(((PyObject *)__pyx_t_4)); __pyx_t_4 = 0;
    __pyx_r = ((PyObject *)__pyx_t_1);
    __pyx_t_1 = 0;
    goto __pyx_L0;
  }
  __pyx_L6:;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("axon._loader.FixedOffsetTZ.tzname", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_minutes);
  __Pyx_XDECREF(__pyx_v_sign);
  __Pyx_XDECREF(__pyx_v_h);
  __Pyx_XDECREF(__pyx_v_m);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_4axon_7_loader_13FixedOffsetTZ_7dst(PyObject *__pyx_v_self, PyObject *__pyx_v_dt); /*proto*/
static PyObject *__pyx_pw_4axon_7_loader_13FixedOffsetTZ_7dst(PyObject *__pyx_v_self, PyObject *__pyx_v_dt) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("dst (wrapper)", 0);
  __pyx_r = __pyx_pf_4axon_7_loader_13FixedOffsetTZ_6dst(((struct FixedOffsetTZObject *)__pyx_v_self), ((PyObject *)__pyx_v_dt));
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_loader.py":220
 *             return '%s%02d' % (sign, h)
 * 
 *     def dst(self, dt):             # <<<<<<<<<<<<<<
 *         return None
 * 
 */

static PyObject *__pyx_pf_4axon_7_loader_13FixedOffsetTZ_6dst(CYTHON_UNUSED struct FixedOffsetTZObject *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v_dt) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("dst", 0);

  /* "axon/_loader.py":221
 * 
 *     def dst(self, dt):
 *         return None             # <<<<<<<<<<<<<<
 * 
 *     def __str__(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(Py_None);
  __pyx_r = Py_None;
  goto __pyx_L0;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_4axon_7_loader_13FixedOffsetTZ_9__str__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_4axon_7_loader_13FixedOffsetTZ_9__str__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__str__ (wrapper)", 0);
  __pyx_r = __pyx_pf_4axon_7_loader_13FixedOffsetTZ_8__str__(((struct FixedOffsetTZObject *)__pyx_v_self));
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_loader.py":223
 *         return None
 * 
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         return self.tzname(None)
 * 
 */

static PyObject *__pyx_pf_4axon_7_loader_13FixedOffsetTZ_8__str__(struct FixedOffsetTZObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__str__", 0);

  /* "axon/_loader.py":224
 * 
 *     def __str__(self):
 *         return self.tzname(None)             # <<<<<<<<<<<<<<
 * 
 *     def __repr__(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s__tzname); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 224; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyObject_Call(__pyx_t_1, ((PyObject *)__pyx_k_tuple_10), NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 224; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("axon._loader.FixedOffsetTZ.__str__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_4axon_7_loader_13FixedOffsetTZ_11__repr__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_4axon_7_loader_13FixedOffsetTZ_11__repr__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__repr__ (wrapper)", 0);
  __pyx_r = __pyx_pf_4axon_7_loader_13FixedOffsetTZ_10__repr__(((struct FixedOffsetTZObject *)__pyx_v_self));
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_loader.py":226
 *         return self.tzname(None)
 * 
 *     def __repr__(self):             # <<<<<<<<<<<<<<
 *         return "<tz:%s>" % self.tzname(None)
 * 
 */

static PyObject *__pyx_pf_4axon_7_loader_13FixedOffsetTZ_10__repr__(struct FixedOffsetTZObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__repr__", 0);

  /* "axon/_loader.py":227
 * 
 *     def __repr__(self):
 *         return "<tz:%s>" % self.tzname(None)             # <<<<<<<<<<<<<<
 * 
 * def tzinfo_fromargs(minutes):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s__tzname); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 227; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyObject_Call(__pyx_t_1, ((PyObject *)__pyx_k_tuple_12), NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 227; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyNumber_Remainder(((PyObject *)__pyx_kp_u_11), __pyx_t_2); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 227; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(((PyObject *)__pyx_t_1));
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = ((PyObject *)__pyx_t_1);
  __pyx_t_1 = 0;
  goto __pyx_L0;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("axon._loader.FixedOffsetTZ.__repr__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_4axon_7_loader_13FixedOffsetTZ_7minutes_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_4axon_7_loader_13FixedOffsetTZ_7minutes_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_4axon_7_loader_13FixedOffsetTZ_7minutes___get__(((struct FixedOffsetTZObject *)__pyx_v_self));
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_loader.pxd":174
 *     """Fixed offset in minutes east from UTC."""
 * 
 *     cdef public object minutes             # <<<<<<<<<<<<<<
 * 
 *     cdef void _init(FixedOffsetTZ self, object minutes)
 */

static PyObject *__pyx_pf_4axon_7_loader_13FixedOffsetTZ_7minutes___get__(struct FixedOffsetTZObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->minutes);
  __pyx_r = __pyx_v_self->minutes;
  goto __pyx_L0;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_4axon_7_loader_13FixedOffsetTZ_7minutes_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_4axon_7_loader_13FixedOffsetTZ_7minutes_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_r = __pyx_pf_4axon_7_loader_13FixedOffsetTZ_7minutes_2__set__(((struct FixedOffsetTZObject *)__pyx_v_self), ((PyObject *)__pyx_v_value));
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_4axon_7_loader_13FixedOffsetTZ_7minutes_2__set__(struct FixedOffsetTZObject *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__", 0);
  __Pyx_INCREF(__pyx_v_value);
  __Pyx_GIVEREF(__pyx_v_value);
  __Pyx_GOTREF(__pyx_v_self->minutes);
  __Pyx_DECREF(__pyx_v_self->minutes);
  __pyx_v_self->minutes = __pyx_v_value;

  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_4axon_7_loader_13FixedOffsetTZ_7minutes_5__del__(PyObject *__pyx_v_self); /*proto*/
static int __pyx_pw_4axon_7_loader_13FixedOffsetTZ_7minutes_5__del__(PyObject *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__ (wrapper)", 0);
  __pyx_r = __pyx_pf_4axon_7_loader_13FixedOffsetTZ_7minutes_4__del__(((struct FixedOffsetTZObject *)__pyx_v_self));
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_4axon_7_loader_13FixedOffsetTZ_7minutes_4__del__(struct FixedOffsetTZObject *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__", 0);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->minutes);
  __Pyx_DECREF(__pyx_v_self->minutes);
  __pyx_v_self->minutes = Py_None;

  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_loader.py":229
 *         return "<tz:%s>" % self.tzname(None)
 * 
 * def tzinfo_fromargs(minutes):             # <<<<<<<<<<<<<<
 *     o_minutes = minutes
 *     tzinfo = tz_dict.get(o_minutes, None)
 */

static PyObject *__pyx_f_4axon_7_loader_tzinfo_fromargs(int __pyx_v_minutes) {
  int __pyx_v_o_minutes;
  PyObject *__pyx_v_tzinfo = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_t_3;
  int __pyx_t_4;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("tzinfo_fromargs", 0);

  /* "axon/_loader.py":230
 * 
 * def tzinfo_fromargs(minutes):
 *     o_minutes = minutes             # <<<<<<<<<<<<<<
 *     tzinfo = tz_dict.get(o_minutes, None)
 *     if tzinfo is None:
 */
  __pyx_v_o_minutes = __pyx_v_minutes;

  /* "axon/_loader.py":231
 * def tzinfo_fromargs(minutes):
 *     o_minutes = minutes
 *     tzinfo = tz_dict.get(o_minutes, None)             # <<<<<<<<<<<<<<
 *     if tzinfo is None:
 *         tzinfo = FixedOffsetTZ(o_minutes)
 */
  if (unlikely(((PyObject *)__pyx_v_4axon_7_loader_tz_dict) == Py_None)) {
    PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%s'", "get");
    {__pyx_filename = __pyx_f[0]; __pyx_lineno = 231; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }
  __pyx_t_1 = PyInt_FromLong(__pyx_v_o_minutes); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 231; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyDict_GetItemDefault(((PyObject *)__pyx_v_4axon_7_loader_tz_dict), __pyx_t_1, Py_None); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 231; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_tzinfo = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "axon/_loader.py":232
 *     o_minutes = minutes
 *     tzinfo = tz_dict.get(o_minutes, None)
 *     if tzinfo is None:             # <<<<<<<<<<<<<<
 *         tzinfo = FixedOffsetTZ(o_minutes)
 *         tz_dict[o_minutes] = tzinfo
 */
  __pyx_t_3 = (__pyx_v_tzinfo == Py_None);
  __pyx_t_4 = (__pyx_t_3 != 0);
  if (__pyx_t_4) {

    /* "axon/_loader.py":233
 *     tzinfo = tz_dict.get(o_minutes, None)
 *     if tzinfo is None:
 *         tzinfo = FixedOffsetTZ(o_minutes)             # <<<<<<<<<<<<<<
 *         tz_dict[o_minutes] = tzinfo
 *     return tzinfo
 */
    __pyx_t_2 = PyInt_FromLong(__pyx_v_o_minutes); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 233; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 233; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_t_2);
    __Pyx_GIVEREF(__pyx_t_2);
    __pyx_t_2 = 0;
    __pyx_t_2 = PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_4axon_7_loader_FixedOffsetTZ)), ((PyObject *)__pyx_t_1), NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 233; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(((PyObject *)__pyx_t_1)); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_v_tzinfo);
    __pyx_v_tzinfo = __pyx_t_2;
    __pyx_t_2 = 0;

    /* "axon/_loader.py":234
 *     if tzinfo is None:
 *         tzinfo = FixedOffsetTZ(o_minutes)
 *         tz_dict[o_minutes] = tzinfo             # <<<<<<<<<<<<<<
 *     return tzinfo
 * 
 */
    if (unlikely(((PyObject *)__pyx_v_4axon_7_loader_tz_dict) == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      {__pyx_filename = __pyx_f[0]; __pyx_lineno = 234; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    }
    if (__Pyx_SetItemInt(((PyObject *)__pyx_v_4axon_7_loader_tz_dict), __pyx_v_o_minutes, __pyx_v_tzinfo, sizeof(int), PyInt_FromLong, 0, 0, 0) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 234; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    goto __pyx_L3;
  }
  __pyx_L3:;

  /* "axon/_loader.py":235
 *         tzinfo = FixedOffsetTZ(o_minutes)
 *         tz_dict[o_minutes] = tzinfo
 *     return tzinfo             # <<<<<<<<<<<<<<
 * 
 * class SimpleBuilder:
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_tzinfo);
  __pyx_r = __pyx_v_tzinfo;
  goto __pyx_L0;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("axon._loader.tzinfo_fromargs", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_tzinfo);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_4axon_7_loader_13SimpleBuilder_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_4axon_7_loader_13SimpleBuilder_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  if (unlikely(PyTuple_GET_SIZE(__pyx_args) > 0)) {
    __Pyx_RaiseArgtupleInvalid("__init__", 1, 0, 0, PyTuple_GET_SIZE(__pyx_args)); return -1;}
  if (unlikely(__pyx_kwds) && unlikely(PyDict_Size(__pyx_kwds) > 0) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "__init__", 0))) return -1;
  __pyx_r = __pyx_pf_4axon_7_loader_13SimpleBuilder___init__(((struct SimpleBuilder *)__pyx_v_self));
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_loader.py":239
 * class SimpleBuilder:
 * 
 *     def __init__(self):             # <<<<<<<<<<<<<<
 *         self.create_int = str2int
 *         self.create_float = str2float
 */

static int __pyx_pf_4axon_7_loader_13SimpleBuilder___init__(struct SimpleBuilder *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__", 0);

  /* "axon/_loader.py":240
 * 
 *     def __init__(self):
 *         self.create_int = str2int             # <<<<<<<<<<<<<<
 *         self.create_float = str2float
 *         self.create_decimal = str2decimal
 */
  __pyx_v_self->create_int = __pyx_f_4axon_7_loader_str2int;

  /* "axon/_loader.py":241
 *     def __init__(self):
 *         self.create_int = str2int
 *         self.create_float = str2float             # <<<<<<<<<<<<<<
 *         self.create_decimal = str2decimal
 *         self.create_time = time_fromargs
 */
  __pyx_v_self->create_float = __pyx_f_4axon_7_loader_str2float;

  /* "axon/_loader.py":242
 *         self.create_int = str2int
 *         self.create_float = str2float
 *         self.create_decimal = str2decimal             # <<<<<<<<<<<<<<
 *         self.create_time = time_fromargs
 *         self.create_date = date_fromargs
 */
  __pyx_v_self->create_decimal = __pyx_f_4axon_7_loader_str2decimal;

  /* "axon/_loader.py":243
 *         self.create_float = str2float
 *         self.create_decimal = str2decimal
 *         self.create_time = time_fromargs             # <<<<<<<<<<<<<<
 *         self.create_date = date_fromargs
 *         self.create_datetime = datetime_fromargs
 */
  __pyx_v_self->create_time = __pyx_f_4axon_7_loader_time_fromargs;

  /* "axon/_loader.py":244
 *         self.create_decimal = str2decimal
 *         self.create_time = time_fromargs
 *         self.create_date = date_fromargs             # <<<<<<<<<<<<<<
 *         self.create_datetime = datetime_fromargs
 *         self.create_tzinfo = tzinfo_fromargs
 */
  __pyx_v_self->create_date = __pyx_f_4axon_7_loader_date_fromargs;

  /* "axon/_loader.py":245
 *         self.create_time = time_fromargs
 *         self.create_date = date_fromargs
 *         self.create_datetime = datetime_fromargs             # <<<<<<<<<<<<<<
 *         self.create_tzinfo = tzinfo_fromargs
 *         self.create_inf = float_inf
 */
  __pyx_v_self->create_datetime = __pyx_f_4axon_7_loader_datetime_fromargs;

  /* "axon/_loader.py":246
 *         self.create_date = date_fromargs
 *         self.create_datetime = datetime_fromargs
 *         self.create_tzinfo = tzinfo_fromargs             # <<<<<<<<<<<<<<
 *         self.create_inf = float_inf
 *         self.create_ninf = float_ninf
 */
  __pyx_v_self->create_tzinfo = __pyx_f_4axon_7_loader_tzinfo_fromargs;

  /* "axon/_loader.py":247
 *         self.create_datetime = datetime_fromargs
 *         self.create_tzinfo = tzinfo_fromargs
 *         self.create_inf = float_inf             # <<<<<<<<<<<<<<
 *         self.create_ninf = float_ninf
 *         self.create_nan = float_nan
 */
  __pyx_v_self->create_inf = __pyx_f_4axon_7_loader_float_inf;

  /* "axon/_loader.py":248
 *         self.create_tzinfo = tzinfo_fromargs
 *         self.create_inf = float_inf
 *         self.create_ninf = float_ninf             # <<<<<<<<<<<<<<
 *         self.create_nan = float_nan
 * 
 */
  __pyx_v_self->create_ninf = __pyx_f_4axon_7_loader_float_ninf;

  /* "axon/_loader.py":249
 *         self.create_inf = float_inf
 *         self.create_ninf = float_ninf
 *         self.create_nan = float_nan             # <<<<<<<<<<<<<<
 * 
 * def safe_builder():
 */
  __pyx_v_self->create_nan = __pyx_f_4axon_7_loader_float_nan;

  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_loader.py":251
 *         self.create_nan = float_nan
 * 
 * def safe_builder():             # <<<<<<<<<<<<<<
 *     builder = Builder()
 * 
 */

static struct Builder *__pyx_f_4axon_7_loader_safe_builder(void) {
  struct Builder *__pyx_v_builder = 0;
  struct Builder *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("safe_builder", 0);

  /* "axon/_loader.py":252
 * 
 * def safe_builder():
 *     builder = Builder()             # <<<<<<<<<<<<<<
 * 
 *     builder.create_sequence = c_new_sequence
 */
  __pyx_t_1 = PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_4axon_7_loader_Builder)), ((PyObject *)__pyx_empty_tuple), NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 252; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_builder = ((struct Builder *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "axon/_loader.py":254
 *     builder = Builder()
 * 
 *     builder.create_sequence = c_new_sequence             # <<<<<<<<<<<<<<
 *     builder.create_instance = c_new_instance
 *     builder.create_mapping = c_new_mapping
 */
  __pyx_v_builder->create_sequence = __pyx_f_4axon_8_objects_c_new_sequence;

  /* "axon/_loader.py":255
 * 
 *     builder.create_sequence = c_new_sequence
 *     builder.create_instance = c_new_instance             # <<<<<<<<<<<<<<
 *     builder.create_mapping = c_new_mapping
 *     builder.create_element = c_new_element
 */
  __pyx_v_builder->create_instance = __pyx_f_4axon_8_objects_c_new_instance;

  /* "axon/_loader.py":256
 *     builder.create_sequence = c_new_sequence
 *     builder.create_instance = c_new_instance
 *     builder.create_mapping = c_new_mapping             # <<<<<<<<<<<<<<
 *     builder.create_element = c_new_element
 *     builder.create_empty = c_new_empty
 */
  __pyx_v_builder->create_mapping = __pyx_f_4axon_8_objects_c_new_mapping;

  /* "axon/_loader.py":257
 *     builder.create_instance = c_new_instance
 *     builder.create_mapping = c_new_mapping
 *     builder.create_element = c_new_element             # <<<<<<<<<<<<<<
 *     builder.create_empty = c_new_empty
 *     return builder
 */
  __pyx_v_builder->create_element = __pyx_f_4axon_8_objects_c_new_element;

  /* "axon/_loader.py":258
 *     builder.create_mapping = c_new_mapping
 *     builder.create_element = c_new_element
 *     builder.create_empty = c_new_empty             # <<<<<<<<<<<<<<
 *     return builder
 * 
 */
  __pyx_v_builder->create_empty = __pyx_f_4axon_8_objects_c_new_empty;

  /* "axon/_loader.py":259
 *     builder.create_element = c_new_element
 *     builder.create_empty = c_new_empty
 *     return builder             # <<<<<<<<<<<<<<
 * 
 * def strict_builder():
 */
  __Pyx_XDECREF(((PyObject *)__pyx_r));
  __Pyx_INCREF(((PyObject *)__pyx_v_builder));
  __pyx_r = __pyx_v_builder;
  goto __pyx_L0;

  __pyx_r = ((struct Builder *)Py_None); __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("axon._loader.safe_builder", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_builder);
  __Pyx_XGIVEREF((PyObject *)__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_loader.py":261
 *     return builder
 * 
 * def strict_builder():             # <<<<<<<<<<<<<<
 *     builder = Builder()
 * 
 */

static struct Builder *__pyx_f_4axon_7_loader_strict_builder(void) {
  struct Builder *__pyx_v_builder = 0;
  struct Builder *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("strict_builder", 0);

  /* "axon/_loader.py":262
 * 
 * def strict_builder():
 *     builder = Builder()             # <<<<<<<<<<<<<<
 * 
 *     builder.create_sequence = c_new_sequence_strict
 */
  __pyx_t_1 = PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_4axon_7_loader_Builder)), ((PyObject *)__pyx_empty_tuple), NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 262; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_builder = ((struct Builder *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "axon/_loader.py":264
 *     builder = Builder()
 * 
 *     builder.create_sequence = c_new_sequence_strict             # <<<<<<<<<<<<<<
 *     builder.create_instance = c_new_instance_strict
 *     builder.create_mapping = c_new_mapping_strict
 */
  __pyx_v_builder->create_sequence = __pyx_f_4axon_7_loader_c_new_sequence_strict;

  /* "axon/_loader.py":265
 * 
 *     builder.create_sequence = c_new_sequence_strict
 *     builder.create_instance = c_new_instance_strict             # <<<<<<<<<<<<<<
 *     builder.create_mapping = c_new_mapping_strict
 *     builder.create_element = c_new_element_strict
 */
  __pyx_v_builder->create_instance = __pyx_f_4axon_7_loader_c_new_instance_strict;

  /* "axon/_loader.py":266
 *     builder.create_sequence = c_new_sequence_strict
 *     builder.create_instance = c_new_instance_strict
 *     builder.create_mapping = c_new_mapping_strict             # <<<<<<<<<<<<<<
 *     builder.create_element = c_new_element_strict
 *     builder.create_empty = c_new_empty_strict
 */
  __pyx_v_builder->create_mapping = __pyx_f_4axon_7_loader_c_new_mapping_strict;

  /* "axon/_loader.py":267
 *     builder.create_instance = c_new_instance_strict
 *     builder.create_mapping = c_new_mapping_strict
 *     builder.create_element = c_new_element_strict             # <<<<<<<<<<<<<<
 *     builder.create_empty = c_new_empty_strict
 *     return builder
 */
  __pyx_v_builder->create_element = __pyx_f_4axon_7_loader_c_new_element_strict;

  /* "axon/_loader.py":268
 *     builder.create_mapping = c_new_mapping_strict
 *     builder.create_element = c_new_element_strict
 *     builder.create_empty = c_new_empty_strict             # <<<<<<<<<<<<<<
 *     return builder
 * 
 */
  __pyx_v_builder->create_empty = __pyx_f_4axon_7_loader_c_new_empty_strict;

  /* "axon/_loader.py":269
 *     builder.create_element = c_new_element_strict
 *     builder.create_empty = c_new_empty_strict
 *     return builder             # <<<<<<<<<<<<<<
 * 
 * def mixed_builder():
 */
  __Pyx_XDECREF(((PyObject *)__pyx_r));
  __Pyx_INCREF(((PyObject *)__pyx_v_builder));
  __pyx_r = __pyx_v_builder;
  goto __pyx_L0;

  __pyx_r = ((struct Builder *)Py_None); __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("axon._loader.strict_builder", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_builder);
  __Pyx_XGIVEREF((PyObject *)__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_loader.py":271
 *     return builder
 * 
 * def mixed_builder():             # <<<<<<<<<<<<<<
 *     builder = Builder()
 * 
 */

static struct Builder *__pyx_f_4axon_7_loader_mixed_builder(void) {
  struct Builder *__pyx_v_builder = 0;
  struct Builder *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("mixed_builder", 0);

  /* "axon/_loader.py":272
 * 
 * def mixed_builder():
 *     builder = Builder()             # <<<<<<<<<<<<<<
 * 
 *     builder.create_sequence = c_new_sequence_mixed
 */
  __pyx_t_1 = PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_4axon_7_loader_Builder)), ((PyObject *)__pyx_empty_tuple), NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 272; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_builder = ((struct Builder *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "axon/_loader.py":274
 *     builder = Builder()
 * 
 *     builder.create_sequence = c_new_sequence_mixed             # <<<<<<<<<<<<<<
 *     builder.create_instance = c_new_instance_mixed
 *     builder.create_mapping = c_new_mapping_mixed
 */
  __pyx_v_builder->create_sequence = __pyx_f_4axon_7_loader_c_new_sequence_mixed;

  /* "axon/_loader.py":275
 * 
 *     builder.create_sequence = c_new_sequence_mixed
 *     builder.create_instance = c_new_instance_mixed             # <<<<<<<<<<<<<<
 *     builder.create_mapping = c_new_mapping_mixed
 *     builder.create_element = c_new_element_mixed
 */
  __pyx_v_builder->create_instance = __pyx_f_4axon_7_loader_c_new_instance_mixed;

  /* "axon/_loader.py":276
 *     builder.create_sequence = c_new_sequence_mixed
 *     builder.create_instance = c_new_instance_mixed
 *     builder.create_mapping = c_new_mapping_mixed             # <<<<<<<<<<<<<<
 *     builder.create_element = c_new_element_mixed
 *     builder.create_empty = c_new_empty_mixed
 */
  __pyx_v_builder->create_mapping = __pyx_f_4axon_7_loader_c_new_mapping_mixed;

  /* "axon/_loader.py":277
 *     builder.create_instance = c_new_instance_mixed
 *     builder.create_mapping = c_new_mapping_mixed
 *     builder.create_element = c_new_element_mixed             # <<<<<<<<<<<<<<
 *     builder.create_empty = c_new_empty_mixed
 *     return builder
 */
  __pyx_v_builder->create_element = __pyx_f_4axon_7_loader_c_new_element_mixed;

  /* "axon/_loader.py":278
 *     builder.create_mapping = c_new_mapping_mixed
 *     builder.create_element = c_new_element_mixed
 *     builder.create_empty = c_new_empty_mixed             # <<<<<<<<<<<<<<
 *     return builder
 * 
 */
  __pyx_v_builder->create_empty = __pyx_f_4axon_7_loader_c_new_empty_mixed;

  /* "axon/_loader.py":279
 *     builder.create_element = c_new_element_mixed
 *     builder.create_empty = c_new_empty_mixed
 *     return builder             # <<<<<<<<<<<<<<
 * 
 * #
 */
  __Pyx_XDECREF(((PyObject *)__pyx_r));
  __Pyx_INCREF(((PyObject *)__pyx_v_builder));
  __pyx_r = __pyx_v_builder;
  goto __pyx_L0;

  __pyx_r = ((struct Builder *)Py_None); __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("axon._loader.mixed_builder", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_builder);
  __Pyx_XGIVEREF((PyObject *)__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_4axon_7_loader_6Loader_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_4axon_7_loader_6Loader___init__[] = "\n        .. py:function:: Loader(fd, readline, builder=\"safe\", sbuilder=\"default\", errto=None)\n\n            :param fd:\n\n                File-like object with `.readline()` and `.close()` method\n\n            :param mode:\n\n                Specifies the method of building python objects for complex values\n\n            :param errto:\n\n                Name of file for reporting errors\n        ";
#if CYTHON_COMPILING_IN_CPYTHON
struct wrapperbase __pyx_wrapperbase_4axon_7_loader_6Loader___init__;
#endif
static int __pyx_pw_4axon_7_loader_6Loader_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_fd = 0;
  PyObject *__pyx_v_mode = 0;
  PyObject *__pyx_v_errto = 0;
  PyObject *__pyx_v_json = 0;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s__fd,&__pyx_n_s__mode,&__pyx_n_s__errto,&__pyx_n_s__json,0};
    PyObject* values[4] = {0,0,0,0};
    values[1] = ((PyObject *)__pyx_n_u__safe);

    /* "axon/_loader.py":307
 *     '''
 *     #
 *     def __init__(self, fd, mode='safe', errto=None, json=False):             # <<<<<<<<<<<<<<
 *         '''
 *         .. py:function:: Loader(fd, readline, builder="safe", sbuilder="default", errto=None)
 */
    values[2] = ((PyObject *)Py_None);
    values[3] = __pyx_k_13;
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s__fd)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s__mode);
          if (value) { values[1] = value; kw_args--; }
        }
        case  2:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s__errto);
          if (value) { values[2] = value; kw_args--; }
        }
        case  3:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s__json);
          if (value) { values[3] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "__init__") < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 307; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_fd = values[0];
    __pyx_v_mode = values[1];
    __pyx_v_errto = values[2];
    __pyx_v_json = values[3];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__init__", 0, 1, 4, PyTuple_GET_SIZE(__pyx_args)); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 307; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  __pyx_L3_error:;
  __Pyx_AddTraceback("axon._loader.Loader.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_4axon_7_loader_6Loader___init__(((struct __pyx_obj_4axon_7_loader_Loader *)__pyx_v_self), __pyx_v_fd, __pyx_v_mode, __pyx_v_errto, __pyx_v_json);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_4axon_7_loader_6Loader___init__(struct __pyx_obj_4axon_7_loader_Loader *__pyx_v_self, PyObject *__pyx_v_fd, PyObject *__pyx_v_mode, PyObject *__pyx_v_errto, PyObject *__pyx_v_json) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__init__", 0);

  /* "axon/_loader.py":323
 *                 Name of file for reporting errors
 *         '''
 *         self.fd = fd             # <<<<<<<<<<<<<<
 *         self.readline = fd.readline
 *         self.bc = 0
 */
  __Pyx_INCREF(__pyx_v_fd);
  __Pyx_GIVEREF(__pyx_v_fd);
  __Pyx_GOTREF(__pyx_v_self->fd);
  __Pyx_DECREF(__pyx_v_self->fd);
  __pyx_v_self->fd = __pyx_v_fd;

  /* "axon/_loader.py":324
 *         '''
 *         self.fd = fd
 *         self.readline = fd.readline             # <<<<<<<<<<<<<<
 *         self.bc = 0
 *         self.bs = 0
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_fd, __pyx_n_s__readline); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 324; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->readline);
  __Pyx_DECREF(__pyx_v_self->readline);
  __pyx_v_self->readline = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "axon/_loader.py":325
 *         self.fd = fd
 *         self.readline = fd.readline
 *         self.bc = 0             # <<<<<<<<<<<<<<
 *         self.bs = 0
 *         self.bq = 0
 */
  __pyx_v_self->bc = 0;

  /* "axon/_loader.py":326
 *         self.readline = fd.readline
 *         self.bc = 0
 *         self.bs = 0             # <<<<<<<<<<<<<<
 *         self.bq = 0
 *         self.labeled_objects = {}
 */
  __pyx_v_self->bs = 0;

  /* "axon/_loader.py":327
 *         self.bc = 0
 *         self.bs = 0
 *         self.bq = 0             # <<<<<<<<<<<<<<
 *         self.labeled_objects = {}
 * 
 */
  __pyx_v_self->bq = 0;

  /* "axon/_loader.py":328
 *         self.bs = 0
 *         self.bq = 0
 *         self.labeled_objects = {}             # <<<<<<<<<<<<<<
 * 
 *         if json:
 */
  __pyx_t_1 = PyDict_New(); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 328; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(((PyObject *)__pyx_t_1));
  __Pyx_GIVEREF(((PyObject *)__pyx_t_1));
  __Pyx_GOTREF(__pyx_v_self->labeled_objects);
  __Pyx_DECREF(((PyObject *)__pyx_v_self->labeled_objects));
  __pyx_v_self->labeled_objects = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "axon/_loader.py":330
 *         self.labeled_objects = {}
 * 
 *         if json:             # <<<<<<<<<<<<<<
 *             self.json = 1
 *         else:
 */
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_v_json); if (unlikely(__pyx_t_2 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 330; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__pyx_t_2) {

    /* "axon/_loader.py":331
 * 
 *         if json:
 *             self.json = 1             # <<<<<<<<<<<<<<
 *         else:
 *             self.json = 0
 */
    __pyx_v_self->json = 1;
    goto __pyx_L3;
  }
  /*else*/ {

    /* "axon/_loader.py":333
 *             self.json = 1
 *         else:
 *             self.json = 0             # <<<<<<<<<<<<<<
 * 
 *         if mode == "safe":
 */
    __pyx_v_self->json = 0;
  }
  __pyx_L3:;

  /* "axon/_loader.py":335
 *             self.json = 0
 * 
 *         if mode == "safe":             # <<<<<<<<<<<<<<
 *             self.builder = safe_builder()
 *         elif mode == "strict":
 */
  __pyx_t_1 = PyObject_RichCompare(__pyx_v_mode, ((PyObject *)__pyx_n_u__safe), Py_EQ); __Pyx_XGOTREF(__pyx_t_1); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 335; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_2 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 335; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_2) {

    /* "axon/_loader.py":336
 * 
 *         if mode == "safe":
 *             self.builder = safe_builder()             # <<<<<<<<<<<<<<
 *         elif mode == "strict":
 *             self.builder = strict_builder()
 */
    __pyx_t_1 = ((PyObject *)__pyx_f_4axon_7_loader_safe_builder()); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 336; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_GIVEREF(__pyx_t_1);
    __Pyx_GOTREF(__pyx_v_self->builder);
    __Pyx_DECREF(((PyObject *)__pyx_v_self->builder));
    __pyx_v_self->builder = ((struct Builder *)__pyx_t_1);
    __pyx_t_1 = 0;
    goto __pyx_L4;
  }

  /* "axon/_loader.py":337
 *         if mode == "safe":
 *             self.builder = safe_builder()
 *         elif mode == "strict":             # <<<<<<<<<<<<<<
 *             self.builder = strict_builder()
 *         elif mode == "mixed":
 */
  __pyx_t_1 = PyObject_RichCompare(__pyx_v_mode, ((PyObject *)__pyx_n_u__strict), Py_EQ); __Pyx_XGOTREF(__pyx_t_1); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 337; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_2 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 337; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_2) {

    /* "axon/_loader.py":338
 *             self.builder = safe_builder()
 *         elif mode == "strict":
 *             self.builder = strict_builder()             # <<<<<<<<<<<<<<
 *         elif mode == "mixed":
 *             self.builder = mixed_builder()
 */
    __pyx_t_1 = ((PyObject *)__pyx_f_4axon_7_loader_strict_builder()); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 338; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_GIVEREF(__pyx_t_1);
    __Pyx_GOTREF(__pyx_v_self->builder);
    __Pyx_DECREF(((PyObject *)__pyx_v_self->builder));
    __pyx_v_self->builder = ((struct Builder *)__pyx_t_1);
    __pyx_t_1 = 0;
    goto __pyx_L4;
  }

  /* "axon/_loader.py":339
 *         elif mode == "strict":
 *             self.builder = strict_builder()
 *         elif mode == "mixed":             # <<<<<<<<<<<<<<
 *             self.builder = mixed_builder()
 *         else:
 */
  __pyx_t_1 = PyObject_RichCompare(__pyx_v_mode, ((PyObject *)__pyx_n_u__mixed), Py_EQ); __Pyx_XGOTREF(__pyx_t_1); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 339; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_2 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 339; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_2) {

    /* "axon/_loader.py":340
 *             self.builder = strict_builder()
 *         elif mode == "mixed":
 *             self.builder = mixed_builder()             # <<<<<<<<<<<<<<
 *         else:
 *             raise ValueError("Invalid mode: %s", mode)
 */
    __pyx_t_1 = ((PyObject *)__pyx_f_4axon_7_loader_mixed_builder()); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 340; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_GIVEREF(__pyx_t_1);
    __Pyx_GOTREF(__pyx_v_self->builder);
    __Pyx_DECREF(((PyObject *)__pyx_v_self->builder));
    __pyx_v_self->builder = ((struct Builder *)__pyx_t_1);
    __pyx_t_1 = 0;
    goto __pyx_L4;
  }
  /*else*/ {

    /* "axon/_loader.py":342
 *             self.builder = mixed_builder()
 *         else:
 *             raise ValueError("Invalid mode: %s", mode)             # <<<<<<<<<<<<<<
 * 
 *         self.sbuilder = SimpleBuilder()
 */
    __pyx_t_1 = PyTuple_New(2); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 342; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(((PyObject *)__pyx_kp_u_14));
    PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_kp_u_14));
    __Pyx_GIVEREF(((PyObject *)__pyx_kp_u_14));
    __Pyx_INCREF(__pyx_v_mode);
    PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_v_mode);
    __Pyx_GIVEREF(__pyx_v_mode);
    __pyx_t_3 = PyObject_Call(__pyx_builtin_ValueError, ((PyObject *)__pyx_t_1), NULL); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 342; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(((PyObject *)__pyx_t_1)); __pyx_t_1 = 0;
    __Pyx_Raise(__pyx_t_3, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    {__pyx_filename = __pyx_f[0]; __pyx_lineno = 342; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }
  __pyx_L4:;

  /* "axon/_loader.py":344
 *             raise ValueError("Invalid mode: %s", mode)
 * 
 *         self.sbuilder = SimpleBuilder()             # <<<<<<<<<<<<<<
 * 
 *         self.c_constants = c_constants.copy()
 */
  __pyx_t_3 = PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_4axon_7_loader_SimpleBuilder)), ((PyObject *)__pyx_empty_tuple), NULL); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 344; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_3);
  __Pyx_GOTREF(__pyx_v_self->sbuilder);
  __Pyx_DECREF(((PyObject *)__pyx_v_self->sbuilder));
  __pyx_v_self->sbuilder = ((struct SimpleBuilder *)__pyx_t_3);
  __pyx_t_3 = 0;

  /* "axon/_loader.py":346
 *         self.sbuilder = SimpleBuilder()
 * 
 *         self.c_constants = c_constants.copy()             # <<<<<<<<<<<<<<
 *         self.c_constants[c_as_name(c_as_unicode('NaN'))] = self.sbuilder.create_nan()
 *         self.c_constants[c_as_name(c_as_unicode('Infinity'))] = self.sbuilder.create_inf()
 */
  if (unlikely(((PyObject *)__pyx_v_4axon_7_loader_c_constants) == Py_None)) {
    PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%s'", "copy");
    {__pyx_filename = __pyx_f[0]; __pyx_lineno = 346; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }
  __pyx_t_3 = ((PyObject *)PyDict_Copy(__pyx_v_4axon_7_loader_c_constants)); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 346; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_3);
  __Pyx_GOTREF(__pyx_v_self->c_constants);
  __Pyx_DECREF(((PyObject *)__pyx_v_self->c_constants));
  __pyx_v_self->c_constants = ((PyObject*)__pyx_t_3);
  __pyx_t_3 = 0;

  /* "axon/_loader.py":347
 * 
 *         self.c_constants = c_constants.copy()
 *         self.c_constants[c_as_name(c_as_unicode('NaN'))] = self.sbuilder.create_nan()             # <<<<<<<<<<<<<<
 *         self.c_constants[c_as_name(c_as_unicode('Infinity'))] = self.sbuilder.create_inf()
 * 
 */
  __pyx_t_3 = __pyx_v_self->sbuilder->create_nan(); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 347; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  if (unlikely(((PyObject *)__pyx_v_self->c_constants) == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    {__pyx_filename = __pyx_f[0]; __pyx_lineno = 347; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }
  __pyx_t_1 = ((PyObject *)__pyx_f_4axon_8_objects_c_as_unicode(((PyObject *)__pyx_n_u__NaN))); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 347; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_4 = ((PyObject *)__pyx_f_4axon_8_objects_c_as_name(__pyx_t_1)); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 347; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (PyDict_SetItem(((PyObject *)__pyx_v_self->c_constants), __pyx_t_4, __pyx_t_3) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 347; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "axon/_loader.py":348
 *         self.c_constants = c_constants.copy()
 *         self.c_constants[c_as_name(c_as_unicode('NaN'))] = self.sbuilder.create_nan()
 *         self.c_constants[c_as_name(c_as_unicode('Infinity'))] = self.sbuilder.create_inf()             # <<<<<<<<<<<<<<
 * 
 *         if errto is None:
 */
  __pyx_t_3 = __pyx_v_self->sbuilder->create_inf(); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 348; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  if (unlikely(((PyObject *)__pyx_v_self->c_constants) == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    {__pyx_filename = __pyx_f[0]; __pyx_lineno = 348; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }
  __pyx_t_4 = ((PyObject *)__pyx_f_4axon_8_objects_c_as_unicode(((PyObject *)__pyx_n_u__Infinity))); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 348; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_1 = ((PyObject *)__pyx_f_4axon_8_objects_c_as_name(__pyx_t_4)); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 348; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (PyDict_SetItem(((PyObject *)__pyx_v_self->c_constants), __pyx_t_1, __pyx_t_3) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 348; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "axon/_loader.py":350
 *         self.c_constants[c_as_name(c_as_unicode('Infinity'))] = self.sbuilder.create_inf()
 * 
 *         if errto is None:             # <<<<<<<<<<<<<<
 *             self.errto = sys.stderr
 *         else:
 */
  __pyx_t_2 = (__pyx_v_errto == Py_None);
  __pyx_t_5 = (__pyx_t_2 != 0);
  if (__pyx_t_5) {

    /* "axon/_loader.py":351
 * 
 *         if errto is None:
 *             self.errto = sys.stderr             # <<<<<<<<<<<<<<
 *         else:
 *             self.errto = open(errto, 'wt')
 */
    __pyx_t_3 = __Pyx_GetModuleGlobalName(__pyx_n_s__sys); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 351; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s__stderr); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 351; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_GIVEREF(__pyx_t_1);
    __Pyx_GOTREF(__pyx_v_self->errto);
    __Pyx_DECREF(__pyx_v_self->errto);
    __pyx_v_self->errto = __pyx_t_1;
    __pyx_t_1 = 0;
    goto __pyx_L5;
  }
  /*else*/ {

    /* "axon/_loader.py":353
 *             self.errto = sys.stderr
 *         else:
 *             self.errto = open(errto, 'wt')             # <<<<<<<<<<<<<<
 * 
 *         self.da = [0,0,0]
 */
    __pyx_t_1 = PyTuple_New(2); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 353; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(__pyx_v_errto);
    PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_errto);
    __Pyx_GIVEREF(__pyx_v_errto);
    __Pyx_INCREF(((PyObject *)__pyx_n_u__wt));
    PyTuple_SET_ITEM(__pyx_t_1, 1, ((PyObject *)__pyx_n_u__wt));
    __Pyx_GIVEREF(((PyObject *)__pyx_n_u__wt));
    __pyx_t_3 = PyObject_Call(__pyx_builtin_open, ((PyObject *)__pyx_t_1), NULL); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 353; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(((PyObject *)__pyx_t_1)); __pyx_t_1 = 0;
    __Pyx_GIVEREF(__pyx_t_3);
    __Pyx_GOTREF(__pyx_v_self->errto);
    __Pyx_DECREF(__pyx_v_self->errto);
    __pyx_v_self->errto = __pyx_t_3;
    __pyx_t_3 = 0;
  }
  __pyx_L5:;

  /* "axon/_loader.py":355
 *             self.errto = open(errto, 'wt')
 * 
 *         self.da = [0,0,0]             # <<<<<<<<<<<<<<
 *         self.ta = [0,0,0,0]
 *         self.to = [0,0]
 */
  __pyx_t_3 = PyList_New(3); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 355; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_INCREF(__pyx_int_0);
  PyList_SET_ITEM(__pyx_t_3, 0, __pyx_int_0);
  __Pyx_GIVEREF(__pyx_int_0);
  __Pyx_INCREF(__pyx_int_0);
  PyList_SET_ITEM(__pyx_t_3, 1, __pyx_int_0);
  __Pyx_GIVEREF(__pyx_int_0);
  __Pyx_INCREF(__pyx_int_0);
  PyList_SET_ITEM(__pyx_t_3, 2, __pyx_int_0);
  __Pyx_GIVEREF(__pyx_int_0);
  __Pyx_GIVEREF(((PyObject *)__pyx_t_3));
  __Pyx_GOTREF(__pyx_v_self->da);
  __Pyx_DECREF(((PyObject *)__pyx_v_self->da));
  __pyx_v_self->da = ((PyObject*)__pyx_t_3);
  __pyx_t_3 = 0;

  /* "axon/_loader.py":356
 * 
 *         self.da = [0,0,0]
 *         self.ta = [0,0,0,0]             # <<<<<<<<<<<<<<
 *         self.to = [0,0]
 * 
 */
  __pyx_t_3 = PyList_New(4); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 356; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_INCREF(__pyx_int_0);
  PyList_SET_ITEM(__pyx_t_3, 0, __pyx_int_0);
  __Pyx_GIVEREF(__pyx_int_0);
  __Pyx_INCREF(__pyx_int_0);
  PyList_SET_ITEM(__pyx_t_3, 1, __pyx_int_0);
  __Pyx_GIVEREF(__pyx_int_0);
  __Pyx_INCREF(__pyx_int_0);
  PyList_SET_ITEM(__pyx_t_3, 2, __pyx_int_0);
  __Pyx_GIVEREF(__pyx_int_0);
  __Pyx_INCREF(__pyx_int_0);
  PyList_SET_ITEM(__pyx_t_3, 3, __pyx_int_0);
  __Pyx_GIVEREF(__pyx_int_0);
  __Pyx_GIVEREF(((PyObject *)__pyx_t_3));
  __Pyx_GOTREF(__pyx_v_self->ta);
  __Pyx_DECREF(((PyObject *)__pyx_v_self->ta));
  __pyx_v_self->ta = ((PyObject*)__pyx_t_3);
  __pyx_t_3 = 0;

  /* "axon/_loader.py":357
 *         self.da = [0,0,0]
 *         self.ta = [0,0,0,0]
 *         self.to = [0,0]             # <<<<<<<<<<<<<<
 * 
 *         self.is_nl = 0
 */
  __pyx_t_3 = PyList_New(2); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 357; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_INCREF(__pyx_int_0);
  PyList_SET_ITEM(__pyx_t_3, 0, __pyx_int_0);
  __Pyx_GIVEREF(__pyx_int_0);
  __Pyx_INCREF(__pyx_int_0);
  PyList_SET_ITEM(__pyx_t_3, 1, __pyx_int_0);
  __Pyx_GIVEREF(__pyx_int_0);
  __Pyx_GIVEREF(((PyObject *)__pyx_t_3));
  __Pyx_GOTREF(__pyx_v_self->to);
  __Pyx_DECREF(((PyObject *)__pyx_v_self->to));
  __pyx_v_self->to = ((PyObject*)__pyx_t_3);
  __pyx_t_3 = 0;

  /* "axon/_loader.py":359
 *         self.to = [0,0]
 * 
 *         self.is_nl = 0             # <<<<<<<<<<<<<<
 * 
 *         #self.idn_stack = []
 */
  __pyx_v_self->is_nl = 0;

  /* "axon/_loader.py":364
 *         #self.idn = 0
 * 
 *         self.lnum = 0             # <<<<<<<<<<<<<<
 * 
 *         self.next_line()
 */
  __pyx_v_self->lnum = 0;

  /* "axon/_loader.py":366
 *         self.lnum = 0
 * 
 *         self.next_line()             # <<<<<<<<<<<<<<
 *     #
 *     def __next__(self):
 */
  __pyx_f_4axon_7_loader_6Loader_next_line(__pyx_v_self);

  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("axon._loader.Loader.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_4axon_7_loader_6Loader_3__next__(PyObject *__pyx_v_self); /*proto*/
static char __pyx_doc_4axon_7_loader_6Loader_2__next__[] = "\n        Get next value.\n        ";
#if CYTHON_COMPILING_IN_CPYTHON
struct wrapperbase __pyx_wrapperbase_4axon_7_loader_6Loader_2__next__;
#endif
static PyObject *__pyx_pw_4axon_7_loader_6Loader_3__next__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__next__ (wrapper)", 0);
  __pyx_r = __pyx_pf_4axon_7_loader_6Loader_2__next__(((struct __pyx_obj_4axon_7_loader_Loader *)__pyx_v_self));
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_loader.py":368
 *         self.next_line()
 *     #
 *     def __next__(self):             # <<<<<<<<<<<<<<
 *         '''
 *         Get next value.
 */

static PyObject *__pyx_pf_4axon_7_loader_6Loader_2__next__(struct __pyx_obj_4axon_7_loader_Loader *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__next__", 0);

  /* "axon/_loader.py":372
 *         Get next value.
 *         '''
 *         self.skip_spaces()             # <<<<<<<<<<<<<<
 *         if self.eof:
 *             self.fd.close()
 */
  __pyx_f_4axon_7_loader_6Loader_skip_spaces(__pyx_v_self);

  /* "axon/_loader.py":373
 *         '''
 *         self.skip_spaces()
 *         if self.eof:             # <<<<<<<<<<<<<<
 *             self.fd.close()
 *             self._check_pairs()
 */
  __pyx_t_1 = (__pyx_v_self->eof != 0);
  if (__pyx_t_1) {

    /* "axon/_loader.py":374
 *         self.skip_spaces()
 *         if self.eof:
 *             self.fd.close()             # <<<<<<<<<<<<<<
 *             self._check_pairs()
 *             if self.errto != sys.stderr:
 */
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self->fd, __pyx_n_s__close); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 374; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = PyObject_Call(__pyx_t_2, ((PyObject *)__pyx_empty_tuple), NULL); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 374; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "axon/_loader.py":375
 *         if self.eof:
 *             self.fd.close()
 *             self._check_pairs()             # <<<<<<<<<<<<<<
 *             if self.errto != sys.stderr:
 *                 self.errto.close()
 */
    __pyx_t_3 = __pyx_f_4axon_7_loader_6Loader__check_pairs(__pyx_v_self, 0); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 375; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "axon/_loader.py":376
 *             self.fd.close()
 *             self._check_pairs()
 *             if self.errto != sys.stderr:             # <<<<<<<<<<<<<<
 *                 self.errto.close()
 *             raise StopIteration
 */
    __pyx_t_3 = __Pyx_GetModuleGlobalName(__pyx_n_s__sys); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 376; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s__stderr); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 376; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = PyObject_RichCompare(__pyx_v_self->errto, __pyx_t_2, Py_NE); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 376; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely(__pyx_t_1 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 376; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (__pyx_t_1) {

      /* "axon/_loader.py":377
 *             self._check_pairs()
 *             if self.errto != sys.stderr:
 *                 self.errto.close()             # <<<<<<<<<<<<<<
 *             raise StopIteration
 *         return self.get_value(0)
 */
      __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self->errto, __pyx_n_s__close); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 377; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_2 = PyObject_Call(__pyx_t_3, ((PyObject *)__pyx_empty_tuple), NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 377; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      goto __pyx_L4;
    }
    __pyx_L4:;

    /* "axon/_loader.py":378
 *             if self.errto != sys.stderr:
 *                 self.errto.close()
 *             raise StopIteration             # <<<<<<<<<<<<<<
 *         return self.get_value(0)
 *     #
 */
    __Pyx_Raise(__pyx_builtin_StopIteration, 0, 0, 0);
    {__pyx_filename = __pyx_f[0]; __pyx_lineno = 378; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    goto __pyx_L3;
  }
  __pyx_L3:;

  /* "axon/_loader.py":379
 *                 self.errto.close()
 *             raise StopIteration
 *         return self.get_value(0)             # <<<<<<<<<<<<<<
 *     #
 *     def _check_pairs(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = __pyx_f_4axon_7_loader_6Loader_get_value(__pyx_v_self, 0); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 379; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("axon._loader.Loader.__next__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_loader.py":381
 *         return self.get_value(0)
 *     #
 *     def _check_pairs(self):             # <<<<<<<<<<<<<<
 *         if self.bc > 0:
 *             errors.error(self, 'Missed closing }')
 */

static PyObject *__pyx_pw_4axon_7_loader_6Loader_5_check_pairs(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyObject *__pyx_f_4axon_7_loader_6Loader__check_pairs(struct __pyx_obj_4axon_7_loader_Loader *__pyx_v_self, CYTHON_UNUSED int __pyx_skip_dispatch) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_check_pairs", 0);

  /* "axon/_loader.py":382
 *     #
 *     def _check_pairs(self):
 *         if self.bc > 0:             # <<<<<<<<<<<<<<
 *             errors.error(self, 'Missed closing }')
 *         elif self.bc < 0:
 */
  __pyx_t_1 = ((__pyx_v_self->bc > 0) != 0);
  if (__pyx_t_1) {

    /* "axon/_loader.py":383
 *     def _check_pairs(self):
 *         if self.bc > 0:
 *             errors.error(self, 'Missed closing }')             # <<<<<<<<<<<<<<
 *         elif self.bc < 0:
 *             errors.error(self, 'Extra closing }')
 */
    __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s__errors); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 383; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s__error); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 383; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = PyTuple_New(2); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 383; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_INCREF(((PyObject *)__pyx_v_self));
    PyTuple_SET_ITEM(__pyx_t_2, 0, ((PyObject *)__pyx_v_self));
    __Pyx_GIVEREF(((PyObject *)__pyx_v_self));
    __Pyx_INCREF(((PyObject *)__pyx_kp_u_15));
    PyTuple_SET_ITEM(__pyx_t_2, 1, ((PyObject *)__pyx_kp_u_15));
    __Pyx_GIVEREF(((PyObject *)__pyx_kp_u_15));
    __pyx_t_4 = PyObject_Call(__pyx_t_3, ((PyObject *)__pyx_t_2), NULL); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 383; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(((PyObject *)__pyx_t_2)); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    goto __pyx_L3;
  }

  /* "axon/_loader.py":384
 *         if self.bc > 0:
 *             errors.error(self, 'Missed closing }')
 *         elif self.bc < 0:             # <<<<<<<<<<<<<<
 *             errors.error(self, 'Extra closing }')
 *         if self.bs > 0:
 */
  __pyx_t_1 = ((__pyx_v_self->bc < 0) != 0);
  if (__pyx_t_1) {

    /* "axon/_loader.py":385
 *             errors.error(self, 'Missed closing }')
 *         elif self.bc < 0:
 *             errors.error(self, 'Extra closing }')             # <<<<<<<<<<<<<<
 *         if self.bs > 0:
 *             errors.error(self, 'Missed closing ]')
 */
    __pyx_t_4 = __Pyx_GetModuleGlobalName(__pyx_n_s__errors); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 385; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s__error); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 385; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = PyTuple_New(2); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 385; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_INCREF(((PyObject *)__pyx_v_self));
    PyTuple_SET_ITEM(__pyx_t_4, 0, ((PyObject *)__pyx_v_self));
    __Pyx_GIVEREF(((PyObject *)__pyx_v_self));
    __Pyx_INCREF(((PyObject *)__pyx_kp_u_16));
    PyTuple_SET_ITEM(__pyx_t_4, 1, ((PyObject *)__pyx_kp_u_16));
    __Pyx_GIVEREF(((PyObject *)__pyx_kp_u_16));
    __pyx_t_3 = PyObject_Call(__pyx_t_2, ((PyObject *)__pyx_t_4), NULL); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 385; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(((PyObject *)__pyx_t_4)); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    goto __pyx_L3;
  }
  __pyx_L3:;

  /* "axon/_loader.py":386
 *         elif self.bc < 0:
 *             errors.error(self, 'Extra closing }')
 *         if self.bs > 0:             # <<<<<<<<<<<<<<
 *             errors.error(self, 'Missed closing ]')
 *         elif self.bs < 0:
 */
  __pyx_t_1 = ((__pyx_v_self->bs > 0) != 0);
  if (__pyx_t_1) {

    /* "axon/_loader.py":387
 *             errors.error(self, 'Extra closing }')
 *         if self.bs > 0:
 *             errors.error(self, 'Missed closing ]')             # <<<<<<<<<<<<<<
 *         elif self.bs < 0:
 *             errors.error(self, 'Extra closing ]')
 */
    __pyx_t_3 = __Pyx_GetModuleGlobalName(__pyx_n_s__errors); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 387; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s__error); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 387; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 387; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_INCREF(((PyObject *)__pyx_v_self));
    PyTuple_SET_ITEM(__pyx_t_3, 0, ((PyObject *)__pyx_v_self));
    __Pyx_GIVEREF(((PyObject *)__pyx_v_self));
    __Pyx_INCREF(((PyObject *)__pyx_kp_u_17));
    PyTuple_SET_ITEM(__pyx_t_3, 1, ((PyObject *)__pyx_kp_u_17));
    __Pyx_GIVEREF(((PyObject *)__pyx_kp_u_17));
    __pyx_t_2 = PyObject_Call(__pyx_t_4, ((PyObject *)__pyx_t_3), NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 387; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(((PyObject *)__pyx_t_3)); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    goto __pyx_L4;
  }

  /* "axon/_loader.py":388
 *         if self.bs > 0:
 *             errors.error(self, 'Missed closing ]')
 *         elif self.bs < 0:             # <<<<<<<<<<<<<<
 *             errors.error(self, 'Extra closing ]')
 *         if self.bq > 0:
 */
  __pyx_t_1 = ((__pyx_v_self->bs < 0) != 0);
  if (__pyx_t_1) {

    /* "axon/_loader.py":389
 *             errors.error(self, 'Missed closing ]')
 *         elif self.bs < 0:
 *             errors.error(self, 'Extra closing ]')             # <<<<<<<<<<<<<<
 *         if self.bq > 0:
 *             errors.error(self, 'Missed closing )')
 */
    __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s__errors); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 389; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s__error); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 389; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = PyTuple_New(2); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 389; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_INCREF(((PyObject *)__pyx_v_self));
    PyTuple_SET_ITEM(__pyx_t_2, 0, ((PyObject *)__pyx_v_self));
    __Pyx_GIVEREF(((PyObject *)__pyx_v_self));
    __Pyx_INCREF(((PyObject *)__pyx_kp_u_18));
    PyTuple_SET_ITEM(__pyx_t_2, 1, ((PyObject *)__pyx_kp_u_18));
    __Pyx_GIVEREF(((PyObject *)__pyx_kp_u_18));
    __pyx_t_4 = PyObject_Call(__pyx_t_3, ((PyObject *)__pyx_t_2), NULL); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 389; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(((PyObject *)__pyx_t_2)); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    goto __pyx_L4;
  }
  __pyx_L4:;

  /* "axon/_loader.py":390
 *         elif self.bs < 0:
 *             errors.error(self, 'Extra closing ]')
 *         if self.bq > 0:             # <<<<<<<<<<<<<<
 *             errors.error(self, 'Missed closing )')
 *         elif self.bq < 0:
 */
  __pyx_t_1 = ((__pyx_v_self->bq > 0) != 0);
  if (__pyx_t_1) {

    /* "axon/_loader.py":391
 *             errors.error(self, 'Extra closing ]')
 *         if self.bq > 0:
 *             errors.error(self, 'Missed closing )')             # <<<<<<<<<<<<<<
 *         elif self.bq < 0:
 *             errors.error(self, 'Extra closing )')
 */
    __pyx_t_4 = __Pyx_GetModuleGlobalName(__pyx_n_s__errors); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 391; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s__error); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 391; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = PyTuple_New(2); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 391; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_INCREF(((PyObject *)__pyx_v_self));
    PyTuple_SET_ITEM(__pyx_t_4, 0, ((PyObject *)__pyx_v_self));
    __Pyx_GIVEREF(((PyObject *)__pyx_v_self));
    __Pyx_INCREF(((PyObject *)__pyx_kp_u_19));
    PyTuple_SET_ITEM(__pyx_t_4, 1, ((PyObject *)__pyx_kp_u_19));
    __Pyx_GIVEREF(((PyObject *)__pyx_kp_u_19));
    __pyx_t_3 = PyObject_Call(__pyx_t_2, ((PyObject *)__pyx_t_4), NULL); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 391; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(((PyObject *)__pyx_t_4)); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    goto __pyx_L5;
  }

  /* "axon/_loader.py":392
 *         if self.bq > 0:
 *             errors.error(self, 'Missed closing )')
 *         elif self.bq < 0:             # <<<<<<<<<<<<<<
 *             errors.error(self, 'Extra closing )')
 *     #
 */
  __pyx_t_1 = ((__pyx_v_self->bq < 0) != 0);
  if (__pyx_t_1) {

    /* "axon/_loader.py":393
 *             errors.error(self, 'Missed closing )')
 *         elif self.bq < 0:
 *             errors.error(self, 'Extra closing )')             # <<<<<<<<<<<<<<
 *     #
 *     def load(self):
 */
    __pyx_t_3 = __Pyx_GetModuleGlobalName(__pyx_n_s__errors); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 393; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s__error); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 393; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 393; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_INCREF(((PyObject *)__pyx_v_self));
    PyTuple_SET_ITEM(__pyx_t_3, 0, ((PyObject *)__pyx_v_self));
    __Pyx_GIVEREF(((PyObject *)__pyx_v_self));
    __Pyx_INCREF(((PyObject *)__pyx_kp_u_20));
    PyTuple_SET_ITEM(__pyx_t_3, 1, ((PyObject *)__pyx_kp_u_20));
    __Pyx_GIVEREF(((PyObject *)__pyx_kp_u_20));
    __pyx_t_2 = PyObject_Call(__pyx_t_4, ((PyObject *)__pyx_t_3), NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 393; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(((PyObject *)__pyx_t_3)); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    goto __pyx_L5;
  }
  __pyx_L5:;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("axon._loader.Loader._check_pairs", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_4axon_7_loader_6Loader_5_check_pairs(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyObject *__pyx_pw_4axon_7_loader_6Loader_5_check_pairs(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_check_pairs (wrapper)", 0);
  __pyx_r = __pyx_pf_4axon_7_loader_6Loader_4_check_pairs(((struct __pyx_obj_4axon_7_loader_Loader *)__pyx_v_self));
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_loader.py":381
 *         return self.get_value(0)
 *     #
 *     def _check_pairs(self):             # <<<<<<<<<<<<<<
 *         if self.bc > 0:
 *             errors.error(self, 'Missed closing }')
 */

static PyObject *__pyx_pf_4axon_7_loader_6Loader_4_check_pairs(struct __pyx_obj_4axon_7_loader_Loader *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_check_pairs", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_4axon_7_loader_6Loader__check_pairs(__pyx_v_self, 1); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 381; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("axon._loader.Loader._check_pairs", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_loader.py":395
 *             errors.error(self, 'Extra closing )')
 *     #
 *     def load(self):             # <<<<<<<<<<<<<<
 *         '''
 *         Load all values.
 */

static PyObject *__pyx_pw_4axon_7_loader_6Loader_7load(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyObject *__pyx_f_4axon_7_loader_6Loader_load(struct __pyx_obj_4axon_7_loader_Loader *__pyx_v_self, CYTHON_UNUSED int __pyx_skip_dispatch) {
  PyObject *__pyx_v_sequence = 0;
  PyObject *__pyx_v_val = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("load", 0);

  /* "axon/_loader.py":400
 *         '''
 * 
 *         sequence = []             # <<<<<<<<<<<<<<
 *         while 1:
 *             self.skip_spaces()
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 400; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_sequence = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "axon/_loader.py":401
 * 
 *         sequence = []
 *         while 1:             # <<<<<<<<<<<<<<
 *             self.skip_spaces()
 *             if self.eof:
 */
  while (1) {
    if (!1) break;

    /* "axon/_loader.py":402
 *         sequence = []
 *         while 1:
 *             self.skip_spaces()             # <<<<<<<<<<<<<<
 *             if self.eof:
 *                 self.fd.close()
 */
    __pyx_f_4axon_7_loader_6Loader_skip_spaces(__pyx_v_self);

    /* "axon/_loader.py":403
 *         while 1:
 *             self.skip_spaces()
 *             if self.eof:             # <<<<<<<<<<<<<<
 *                 self.fd.close()
 *                 self._check_pairs()
 */
    __pyx_t_2 = (__pyx_v_self->eof != 0);
    if (__pyx_t_2) {

      /* "axon/_loader.py":404
 *             self.skip_spaces()
 *             if self.eof:
 *                 self.fd.close()             # <<<<<<<<<<<<<<
 *                 self._check_pairs()
 *                 if self.errto != sys.stderr:
 */
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self->fd, __pyx_n_s__close); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 404; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_3 = PyObject_Call(__pyx_t_1, ((PyObject *)__pyx_empty_tuple), NULL); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 404; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

      /* "axon/_loader.py":405
 *             if self.eof:
 *                 self.fd.close()
 *                 self._check_pairs()             # <<<<<<<<<<<<<<
 *                 if self.errto != sys.stderr:
 *                     self.errto.close()
 */
      __pyx_t_3 = __pyx_f_4axon_7_loader_6Loader__check_pairs(__pyx_v_self, 0); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 405; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

      /* "axon/_loader.py":406
 *                 self.fd.close()
 *                 self._check_pairs()
 *                 if self.errto != sys.stderr:             # <<<<<<<<<<<<<<
 *                     self.errto.close()
 *                 break
 */
      __pyx_t_3 = __Pyx_GetModuleGlobalName(__pyx_n_s__sys); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 406; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s__stderr); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 406; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_3 = PyObject_RichCompare(__pyx_v_self->errto, __pyx_t_1, Py_NE); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 406; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely(__pyx_t_2 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 406; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (__pyx_t_2) {

        /* "axon/_loader.py":407
 *                 self._check_pairs()
 *                 if self.errto != sys.stderr:
 *                     self.errto.close()             # <<<<<<<<<<<<<<
 *                 break
 * 
 */
        __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self->errto, __pyx_n_s__close); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 407; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_3);
        __pyx_t_1 = PyObject_Call(__pyx_t_3, ((PyObject *)__pyx_empty_tuple), NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 407; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L6;
      }
      __pyx_L6:;

      /* "axon/_loader.py":408
 *                 if self.errto != sys.stderr:
 *                     self.errto.close()
 *                 break             # <<<<<<<<<<<<<<
 * 
 *             val = self.get_value(0)
 */
      goto __pyx_L4_break;
      goto __pyx_L5;
    }
    __pyx_L5:;

    /* "axon/_loader.py":410
 *                 break
 * 
 *             val = self.get_value(0)             # <<<<<<<<<<<<<<
 *             sequence.append(val)
 * 
 */
    __pyx_t_1 = __pyx_f_4axon_7_loader_6Loader_get_value(__pyx_v_self, 0); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 410; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_XDECREF(__pyx_v_val);
    __pyx_v_val = __pyx_t_1;
    __pyx_t_1 = 0;

    /* "axon/_loader.py":411
 * 
 *             val = self.get_value(0)
 *             sequence.append(val)             # <<<<<<<<<<<<<<
 * 
 *         return sequence
 */
    __pyx_t_4 = __Pyx_PyList_Append(__pyx_v_sequence, __pyx_v_val); if (unlikely(__pyx_t_4 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 411; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }
  __pyx_L4_break:;

  /* "axon/_loader.py":413
 *             sequence.append(val)
 * 
 *         return sequence             # <<<<<<<<<<<<<<
 *     #
 *     def __iter__(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(((PyObject *)__pyx_v_sequence));
  __pyx_r = ((PyObject *)__pyx_v_sequence);
  goto __pyx_L0;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("axon._loader.Loader.load", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_sequence);
  __Pyx_XDECREF(__pyx_v_val);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_4axon_7_loader_6Loader_7load(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_4axon_7_loader_6Loader_6load[] = "\n        Load all values.\n        ";
static PyObject *__pyx_pw_4axon_7_loader_6Loader_7load(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("load (wrapper)", 0);
  __pyx_r = __pyx_pf_4axon_7_loader_6Loader_6load(((struct __pyx_obj_4axon_7_loader_Loader *)__pyx_v_self));
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_loader.py":395
 *             errors.error(self, 'Extra closing )')
 *     #
 *     def load(self):             # <<<<<<<<<<<<<<
 *         '''
 *         Load all values.
 */

static PyObject *__pyx_pf_4axon_7_loader_6Loader_6load(struct __pyx_obj_4axon_7_loader_Loader *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("load", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_4axon_7_loader_6Loader_load(__pyx_v_self, 1); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 395; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("axon._loader.Loader.load", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_4axon_7_loader_6Loader_9__iter__(PyObject *__pyx_v_self); /*proto*/
static char __pyx_doc_4axon_7_loader_6Loader_8__iter__[] = "\n        Return iterator for iterative loading of values.\n        ";
#if CYTHON_COMPILING_IN_CPYTHON
struct wrapperbase __pyx_wrapperbase_4axon_7_loader_6Loader_8__iter__;
#endif
static PyObject *__pyx_pw_4axon_7_loader_6Loader_9__iter__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__iter__ (wrapper)", 0);
  __pyx_r = __pyx_pf_4axon_7_loader_6Loader_8__iter__(((struct __pyx_obj_4axon_7_loader_Loader *)__pyx_v_self));
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_loader.py":415
 *         return sequence
 *     #
 *     def __iter__(self):             # <<<<<<<<<<<<<<
 *         '''
 *         Return iterator for iterative loading of values.
 */

static PyObject *__pyx_pf_4axon_7_loader_6Loader_8__iter__(struct __pyx_obj_4axon_7_loader_Loader *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__iter__", 0);

  /* "axon/_loader.py":419
 *         Return iterator for iterative loading of values.
 *         '''
 *         return self             # <<<<<<<<<<<<<<
 *     #
 *     #def skip_char(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(((PyObject *)__pyx_v_self));
  __pyx_r = ((PyObject *)__pyx_v_self);
  goto __pyx_L0;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_loader.py":433
 *     #    return c_unicode_char(self.line, self.pos)
 *     #
 *     def next_line(self):             # <<<<<<<<<<<<<<
 * 
 *         line = self.readline()
 */

static void __pyx_f_4axon_7_loader_6Loader_next_line(struct __pyx_obj_4axon_7_loader_Loader *__pyx_v_self) {
  PyObject *__pyx_v_line = 0;
  Py_UCS4 __pyx_v_ch;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  Py_ssize_t __pyx_t_4;
  Py_ssize_t __pyx_t_5;
  Py_UCS4 __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("next_line", 0);

  /* "axon/_loader.py":435
 *     def next_line(self):
 * 
 *         line = self.readline()             # <<<<<<<<<<<<<<
 * 
 *         if line == '':
 */
  __pyx_t_1 = PyObject_Call(__pyx_v_self->readline, ((PyObject *)__pyx_empty_tuple), NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 435; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (!(likely(PyUnicode_CheckExact(__pyx_t_1))||((__pyx_t_1) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected unicode, got %.200s", Py_TYPE(__pyx_t_1)->tp_name), 0))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 435; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_v_line = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "axon/_loader.py":437
 *         line = self.readline()
 * 
 *         if line == '':             # <<<<<<<<<<<<<<
 *             self.eof = 1
 *         else:
 */
  __pyx_t_2 = (__Pyx_PyUnicode_Equals(((PyObject *)__pyx_v_line), ((PyObject *)__pyx_kp_u_21), Py_EQ)); if (unlikely(__pyx_t_2 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 437; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_t_3 = (__pyx_t_2 != 0);
  if (__pyx_t_3) {

    /* "axon/_loader.py":438
 * 
 *         if line == '':
 *             self.eof = 1             # <<<<<<<<<<<<<<
 *         else:
 *             ch = line[len(line) - 1]
 */
    __pyx_v_self->eof = 1;
    goto __pyx_L3;
  }
  /*else*/ {

    /* "axon/_loader.py":440
 *             self.eof = 1
 *         else:
 *             ch = line[len(line) - 1]             # <<<<<<<<<<<<<<
 *             if ch != '\n':
 *                 line += '\n'
 */
    if (unlikely(((PyObject *)__pyx_v_line) == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "object of type 'NoneType' has no len()");
      {__pyx_filename = __pyx_f[0]; __pyx_lineno = 440; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    }
    __pyx_t_4 = __Pyx_PyUnicode_GET_LENGTH(((PyObject *)__pyx_v_line)); if (unlikely(__pyx_t_4 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 440; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __pyx_t_5 = (__pyx_t_4 - 1);
    __pyx_t_6 = __Pyx_GetItemInt_Unicode(((PyObject *)__pyx_v_line), __pyx_t_5, sizeof(Py_ssize_t), PyInt_FromSsize_t, 0, 0, 0); if (unlikely(__pyx_t_6 == (Py_UCS4)-1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 440; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
    __pyx_v_ch = __pyx_t_6;

    /* "axon/_loader.py":441
 *         else:
 *             ch = line[len(line) - 1]
 *             if ch != '\n':             # <<<<<<<<<<<<<<
 *                 line += '\n'
 *             self.eof = 0
 */
    __pyx_t_3 = ((__pyx_v_ch != 10) != 0);
    if (__pyx_t_3) {

      /* "axon/_loader.py":442
 *             ch = line[len(line) - 1]
 *             if ch != '\n':
 *                 line += '\n'             # <<<<<<<<<<<<<<
 *             self.eof = 0
 *             self.lnum += 1
 */
      __pyx_t_1 = PyNumber_InPlaceAdd(((PyObject *)__pyx_v_line), ((PyObject *)__pyx_kp_u_22)); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 442; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(((PyObject *)__pyx_t_1));
      __Pyx_DECREF(((PyObject *)__pyx_v_line));
      __pyx_v_line = ((PyObject*)__pyx_t_1);
      __pyx_t_1 = 0;
      goto __pyx_L4;
    }
    __pyx_L4:;

    /* "axon/_loader.py":443
 *             if ch != '\n':
 *                 line += '\n'
 *             self.eof = 0             # <<<<<<<<<<<<<<
 *             self.lnum += 1
 * 
 */
    __pyx_v_self->eof = 0;

    /* "axon/_loader.py":444
 *                 line += '\n'
 *             self.eof = 0
 *             self.lnum += 1             # <<<<<<<<<<<<<<
 * 
 *             self.line = line
 */
    __pyx_v_self->lnum = (__pyx_v_self->lnum + 1);

    /* "axon/_loader.py":446
 *             self.lnum += 1
 * 
 *             self.line = line             # <<<<<<<<<<<<<<
 *             self.pos = 0
 *     #
 */
    __Pyx_INCREF(((PyObject *)__pyx_v_line));
    __Pyx_GIVEREF(((PyObject *)__pyx_v_line));
    __Pyx_GOTREF(__pyx_v_self->line);
    __Pyx_DECREF(((PyObject *)__pyx_v_self->line));
    __pyx_v_self->line = __pyx_v_line;

    /* "axon/_loader.py":447
 * 
 *             self.line = line
 *             self.pos = 0             # <<<<<<<<<<<<<<
 *     #
 *     def skip_spaces(self):
 */
    __pyx_v_self->pos = 0;
  }
  __pyx_L3:;

  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_WriteUnraisable("axon._loader.Loader.next_line", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_line);
  __Pyx_RefNannyFinishContext();
}

/* "axon/_loader.py":449
 *             self.pos = 0
 *     #
 *     def skip_spaces(self):             # <<<<<<<<<<<<<<
 *         self.is_nl = 0
 *         if self.eof:
 */

static CYTHON_INLINE Py_UCS4 __pyx_f_4axon_7_loader_6Loader_skip_spaces(struct __pyx_obj_4axon_7_loader_Loader *__pyx_v_self) {
  Py_UCS4 __pyx_v_ch;
  Py_UCS4 __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  __Pyx_RefNannySetupContext("skip_spaces", 0);

  /* "axon/_loader.py":450
 *     #
 *     def skip_spaces(self):
 *         self.is_nl = 0             # <<<<<<<<<<<<<<
 *         if self.eof:
 *             return 0
 */
  __pyx_v_self->is_nl = 0;

  /* "axon/_loader.py":451
 *     def skip_spaces(self):
 *         self.is_nl = 0
 *         if self.eof:             # <<<<<<<<<<<<<<
 *             return 0
 * 
 */
  __pyx_t_1 = (__pyx_v_self->eof != 0);
  if (__pyx_t_1) {

    /* "axon/_loader.py":452
 *         self.is_nl = 0
 *         if self.eof:
 *             return 0             # <<<<<<<<<<<<<<
 * 
 *         ch = current_char(self)
 */
    __pyx_r = 0;
    goto __pyx_L0;
    goto __pyx_L3;
  }
  __pyx_L3:;

  /* "axon/_loader.py":454
 *             return 0
 * 
 *         ch = current_char(self)             # <<<<<<<<<<<<<<
 *         while 1:
 *             if ch <= ' ':
 */
  __pyx_v_ch = current_char(__pyx_v_self);

  /* "axon/_loader.py":455
 * 
 *         ch = current_char(self)
 *         while 1:             # <<<<<<<<<<<<<<
 *             if ch <= ' ':
 *                 if ch == '\n' or ch == '\r':
 */
  while (1) {
    if (!1) break;

    /* "axon/_loader.py":456
 *         ch = current_char(self)
 *         while 1:
 *             if ch <= ' ':             # <<<<<<<<<<<<<<
 *                 if ch == '\n' or ch == '\r':
 *                     self.next_line()
 */
    __pyx_t_1 = ((__pyx_v_ch <= 32) != 0);
    if (__pyx_t_1) {

      /* "axon/_loader.py":457
 *         while 1:
 *             if ch <= ' ':
 *                 if ch == '\n' or ch == '\r':             # <<<<<<<<<<<<<<
 *                     self.next_line()
 *                     self.is_nl = 1
 */
      switch (__pyx_v_ch) {
        case 10:
        case 13:

        /* "axon/_loader.py":458
 *             if ch <= ' ':
 *                 if ch == '\n' or ch == '\r':
 *                     self.next_line()             # <<<<<<<<<<<<<<
 *                     self.is_nl = 1
 *                     if self.eof:
 */
        __pyx_f_4axon_7_loader_6Loader_next_line(__pyx_v_self);

        /* "axon/_loader.py":459
 *                 if ch == '\n' or ch == '\r':
 *                     self.next_line()
 *                     self.is_nl = 1             # <<<<<<<<<<<<<<
 *                     if self.eof:
 *                         return 0
 */
        __pyx_v_self->is_nl = 1;

        /* "axon/_loader.py":460
 *                     self.next_line()
 *                     self.is_nl = 1
 *                     if self.eof:             # <<<<<<<<<<<<<<
 *                         return 0
 *                     ch = current_char(self)
 */
        __pyx_t_1 = (__pyx_v_self->eof != 0);
        if (__pyx_t_1) {

          /* "axon/_loader.py":461
 *                     self.is_nl = 1
 *                     if self.eof:
 *                         return 0             # <<<<<<<<<<<<<<
 *                     ch = current_char(self)
 *                 else:
 */
          __pyx_r = 0;
          goto __pyx_L0;
          goto __pyx_L7;
        }
        __pyx_L7:;

        /* "axon/_loader.py":462
 *                     if self.eof:
 *                         return 0
 *                     ch = current_char(self)             # <<<<<<<<<<<<<<
 *                 else:
 *                     ch = next_char(self)
 */
        __pyx_v_ch = current_char(__pyx_v_self);
        break;
        default:

        /* "axon/_loader.py":464
 *                     ch = current_char(self)
 *                 else:
 *                     ch = next_char(self)             # <<<<<<<<<<<<<<
 *             else:
 *                 break
 */
        __pyx_v_ch = next_char(__pyx_v_self);
        break;
      }
      goto __pyx_L6;
    }
    /*else*/ {

      /* "axon/_loader.py":466
 *                     ch = next_char(self)
 *             else:
 *                 break             # <<<<<<<<<<<<<<
 *         return ch
 *     #
 */
      goto __pyx_L5_break;
    }
    __pyx_L6:;
  }
  __pyx_L5_break:;

  /* "axon/_loader.py":467
 *             else:
 *                 break
 *         return ch             # <<<<<<<<<<<<<<
 *     #
 *     def moveto_next_token(self):
 */
  __pyx_r = __pyx_v_ch;
  goto __pyx_L0;

  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_loader.py":469
 *         return ch
 *     #
 *     def moveto_next_token(self):             # <<<<<<<<<<<<<<
 *         if self.eof:
 *             errors.error_unexpected_end(self)
 */

static CYTHON_INLINE Py_UCS4 __pyx_f_4axon_7_loader_6Loader_moveto_next_token(struct __pyx_obj_4axon_7_loader_Loader *__pyx_v_self) {
  Py_UCS4 __pyx_v_ch;
  Py_UCS4 __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("moveto_next_token", 0);

  /* "axon/_loader.py":470
 *     #
 *     def moveto_next_token(self):
 *         if self.eof:             # <<<<<<<<<<<<<<
 *             errors.error_unexpected_end(self)
 *         self.is_nl = 0
 */
  __pyx_t_1 = (__pyx_v_self->eof != 0);
  if (__pyx_t_1) {

    /* "axon/_loader.py":471
 *     def moveto_next_token(self):
 *         if self.eof:
 *             errors.error_unexpected_end(self)             # <<<<<<<<<<<<<<
 *         self.is_nl = 0
 * 
 */
    __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s__errors); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 471; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_23); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 471; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 471; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_INCREF(((PyObject *)__pyx_v_self));
    PyTuple_SET_ITEM(__pyx_t_2, 0, ((PyObject *)__pyx_v_self));
    __Pyx_GIVEREF(((PyObject *)__pyx_v_self));
    __pyx_t_4 = PyObject_Call(__pyx_t_3, ((PyObject *)__pyx_t_2), NULL); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 471; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(((PyObject *)__pyx_t_2)); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    goto __pyx_L3;
  }
  __pyx_L3:;

  /* "axon/_loader.py":472
 *         if self.eof:
 *             errors.error_unexpected_end(self)
 *         self.is_nl = 0             # <<<<<<<<<<<<<<
 * 
 *         ch = current_char(self)
 */
  __pyx_v_self->is_nl = 0;

  /* "axon/_loader.py":474
 *         self.is_nl = 0
 * 
 *         ch = current_char(self)             # <<<<<<<<<<<<<<
 *         while 1:
 *             if ch <= ' ':
 */
  __pyx_v_ch = current_char(__pyx_v_self);

  /* "axon/_loader.py":475
 * 
 *         ch = current_char(self)
 *         while 1:             # <<<<<<<<<<<<<<
 *             if ch <= ' ':
 *                 if ch == '\n' or ch == '\r':
 */
  while (1) {
    if (!1) break;

    /* "axon/_loader.py":476
 *         ch = current_char(self)
 *         while 1:
 *             if ch <= ' ':             # <<<<<<<<<<<<<<
 *                 if ch == '\n' or ch == '\r':
 *                     self.next_line()
 */
    __pyx_t_1 = ((__pyx_v_ch <= 32) != 0);
    if (__pyx_t_1) {

      /* "axon/_loader.py":477
 *         while 1:
 *             if ch <= ' ':
 *                 if ch == '\n' or ch == '\r':             # <<<<<<<<<<<<<<
 *                     self.next_line()
 *                     self.is_nl = 1
 */
      switch (__pyx_v_ch) {
        case 10:
        case 13:

        /* "axon/_loader.py":478
 *             if ch <= ' ':
 *                 if ch == '\n' or ch == '\r':
 *                     self.next_line()             # <<<<<<<<<<<<<<
 *                     self.is_nl = 1
 *                     if self.eof:
 */
        __pyx_f_4axon_7_loader_6Loader_next_line(__pyx_v_self);

        /* "axon/_loader.py":479
 *                 if ch == '\n' or ch == '\r':
 *                     self.next_line()
 *                     self.is_nl = 1             # <<<<<<<<<<<<<<
 *                     if self.eof:
 *                         errors.error_unexpected_end(self)
 */
        __pyx_v_self->is_nl = 1;

        /* "axon/_loader.py":480
 *                     self.next_line()
 *                     self.is_nl = 1
 *                     if self.eof:             # <<<<<<<<<<<<<<
 *                         errors.error_unexpected_end(self)
 *                     ch = current_char(self)
 */
        __pyx_t_1 = (__pyx_v_self->eof != 0);
        if (__pyx_t_1) {

          /* "axon/_loader.py":481
 *                     self.is_nl = 1
 *                     if self.eof:
 *                         errors.error_unexpected_end(self)             # <<<<<<<<<<<<<<
 *                     ch = current_char(self)
 *                 else:
 */
          __pyx_t_4 = __Pyx_GetModuleGlobalName(__pyx_n_s__errors); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 481; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
          __Pyx_GOTREF(__pyx_t_4);
          __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_23); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 481; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          __pyx_t_4 = PyTuple_New(1); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 481; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
          __Pyx_GOTREF(__pyx_t_4);
          __Pyx_INCREF(((PyObject *)__pyx_v_self));
          PyTuple_SET_ITEM(__pyx_t_4, 0, ((PyObject *)__pyx_v_self));
          __Pyx_GIVEREF(((PyObject *)__pyx_v_self));
          __pyx_t_3 = PyObject_Call(__pyx_t_2, ((PyObject *)__pyx_t_4), NULL); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 481; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
          __Pyx_GOTREF(__pyx_t_3);
          __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
          __Pyx_DECREF(((PyObject *)__pyx_t_4)); __pyx_t_4 = 0;
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
          goto __pyx_L7;
        }
        __pyx_L7:;

        /* "axon/_loader.py":482
 *                     if self.eof:
 *                         errors.error_unexpected_end(self)
 *                     ch = current_char(self)             # <<<<<<<<<<<<<<
 *                 else:
 *                     ch = next_char(self)
 */
        __pyx_v_ch = current_char(__pyx_v_self);
        break;
        default:

        /* "axon/_loader.py":484
 *                     ch = current_char(self)
 *                 else:
 *                     ch = next_char(self)             # <<<<<<<<<<<<<<
 *             else:
 *                 break
 */
        __pyx_v_ch = next_char(__pyx_v_self);
        break;
      }
      goto __pyx_L6;
    }
    /*else*/ {

      /* "axon/_loader.py":486
 *                     ch = next_char(self)
 *             else:
 *                 break             # <<<<<<<<<<<<<<
 *         return ch
 *     #
 */
      goto __pyx_L5_break;
    }
    __pyx_L6:;
  }
  __pyx_L5_break:;

  /* "axon/_loader.py":487
 *             else:
 *                 break
 *         return ch             # <<<<<<<<<<<<<<
 *     #
 *     def skip_whitespace(self):
 */
  __pyx_r = __pyx_v_ch;
  goto __pyx_L0;

  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("axon._loader.Loader.moveto_next_token", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_loader.py":489
 *         return ch
 *     #
 *     def skip_whitespace(self):             # <<<<<<<<<<<<<<
 *         ch = current_char(self)
 *         while ch == ' ' or ch == '\t':
 */

static CYTHON_INLINE void __pyx_f_4axon_7_loader_6Loader_skip_whitespace(struct __pyx_obj_4axon_7_loader_Loader *__pyx_v_self) {
  Py_UCS4 __pyx_v_ch;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  __Pyx_RefNannySetupContext("skip_whitespace", 0);

  /* "axon/_loader.py":490
 *     #
 *     def skip_whitespace(self):
 *         ch = current_char(self)             # <<<<<<<<<<<<<<
 *         while ch == ' ' or ch == '\t':
 *             ch = next_char(self)
 */
  __pyx_v_ch = current_char(__pyx_v_self);

  /* "axon/_loader.py":491
 *     def skip_whitespace(self):
 *         ch = current_char(self)
 *         while ch == ' ' or ch == '\t':             # <<<<<<<<<<<<<<
 *             ch = next_char(self)
 *     #
 */
  while (1) {
    switch (__pyx_v_ch) {
      case 32:
      case 9:
      __pyx_t_1 = 1;
      break;
      default:
      __pyx_t_1 = 0;
      break;
    }
    if (!__pyx_t_1) break;

    /* "axon/_loader.py":492
 *         ch = current_char(self)
 *         while ch == ' ' or ch == '\t':
 *             ch = next_char(self)             # <<<<<<<<<<<<<<
 *     #
 *     #def valid_end_item(self):
 */
    __pyx_v_ch = next_char(__pyx_v_self);
  }

  __Pyx_RefNannyFinishContext();
}

/* "axon/_loader.py":498
 *     #    return ch <= ' ' or ch == '}' or ch == ']' or ch == ')' or ch == 0
 *     #
 *     def get_dots(self):             # <<<<<<<<<<<<<<
 *         ch = next_char(self)
 *         n = 1
 */

static int __pyx_f_4axon_7_loader_6Loader_get_dots(struct __pyx_obj_4axon_7_loader_Loader *__pyx_v_self) {
  Py_UCS4 __pyx_v_ch;
  int __pyx_v_n;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  __Pyx_RefNannySetupContext("get_dots", 0);

  /* "axon/_loader.py":499
 *     #
 *     def get_dots(self):
 *         ch = next_char(self)             # <<<<<<<<<<<<<<
 *         n = 1
 *         while ch == '.':
 */
  __pyx_v_ch = next_char(__pyx_v_self);

  /* "axon/_loader.py":500
 *     def get_dots(self):
 *         ch = next_char(self)
 *         n = 1             # <<<<<<<<<<<<<<
 *         while ch == '.':
 *             ch = next_char(self)
 */
  __pyx_v_n = 1;

  /* "axon/_loader.py":501
 *         ch = next_char(self)
 *         n = 1
 *         while ch == '.':             # <<<<<<<<<<<<<<
 *             ch = next_char(self)
 *             n += 1
 */
  while (1) {
    __pyx_t_1 = ((__pyx_v_ch == 46) != 0);
    if (!__pyx_t_1) break;

    /* "axon/_loader.py":502
 *         n = 1
 *         while ch == '.':
 *             ch = next_char(self)             # <<<<<<<<<<<<<<
 *             n += 1
 *         return n == 3
 */
    __pyx_v_ch = next_char(__pyx_v_self);

    /* "axon/_loader.py":503
 *         while ch == '.':
 *             ch = next_char(self)
 *             n += 1             # <<<<<<<<<<<<<<
 *         return n == 3
 *     #
 */
    __pyx_v_n = (__pyx_v_n + 1);
  }

  /* "axon/_loader.py":504
 *             ch = next_char(self)
 *             n += 1
 *         return n == 3             # <<<<<<<<<<<<<<
 *     #
 *     def try_get_int(self, maxsize):
 */
  __pyx_r = (__pyx_v_n == 3);
  goto __pyx_L0;

  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_loader.py":506
 *         return n == 3
 *     #
 *     def try_get_int(self, maxsize):             # <<<<<<<<<<<<<<
 * 
 *         val = 0
 */

static int __pyx_f_4axon_7_loader_6Loader_try_get_int(struct __pyx_obj_4axon_7_loader_Loader *__pyx_v_self, int __pyx_v_maxsize) {
  int __pyx_v_i;
  int __pyx_v_ch0;
  Py_UCS4 __pyx_v_ch;
  int __pyx_v_val;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  int __pyx_t_3;
  __Pyx_RefNannySetupContext("try_get_int", 0);

  /* "axon/_loader.py":508
 *     def try_get_int(self, maxsize):
 * 
 *         val = 0             # <<<<<<<<<<<<<<
 *         ch = current_char(self)
 *         i = 0
 */
  __pyx_v_val = 0;

  /* "axon/_loader.py":509
 * 
 *         val = 0
 *         ch = current_char(self)             # <<<<<<<<<<<<<<
 *         i = 0
 *         while ch >= '0' and ch <= '9':
 */
  __pyx_v_ch = current_char(__pyx_v_self);

  /* "axon/_loader.py":510
 *         val = 0
 *         ch = current_char(self)
 *         i = 0             # <<<<<<<<<<<<<<
 *         while ch >= '0' and ch <= '9':
 *             if i == maxsize:
 */
  __pyx_v_i = 0;

  /* "axon/_loader.py":511
 *         ch = current_char(self)
 *         i = 0
 *         while ch >= '0' and ch <= '9':             # <<<<<<<<<<<<<<
 *             if i == maxsize:
 *                 skip_char(self)
 */
  while (1) {
    __pyx_t_1 = ((__pyx_v_ch >= 48) != 0);
    if (__pyx_t_1) {
      __pyx_t_2 = ((__pyx_v_ch <= 57) != 0);
      __pyx_t_3 = __pyx_t_2;
    } else {
      __pyx_t_3 = __pyx_t_1;
    }
    if (!__pyx_t_3) break;

    /* "axon/_loader.py":512
 *         i = 0
 *         while ch >= '0' and ch <= '9':
 *             if i == maxsize:             # <<<<<<<<<<<<<<
 *                 skip_char(self)
 *                 break
 */
    __pyx_t_3 = ((__pyx_v_i == __pyx_v_maxsize) != 0);
    if (__pyx_t_3) {

      /* "axon/_loader.py":513
 *         while ch >= '0' and ch <= '9':
 *             if i == maxsize:
 *                 skip_char(self)             # <<<<<<<<<<<<<<
 *                 break
 * 
 */
      skip_char(__pyx_v_self);

      /* "axon/_loader.py":514
 *             if i == maxsize:
 *                 skip_char(self)
 *                 break             # <<<<<<<<<<<<<<
 * 
 *             ch0 = ch
 */
      goto __pyx_L4_break;
      goto __pyx_L5;
    }
    __pyx_L5:;

    /* "axon/_loader.py":516
 *                 break
 * 
 *             ch0 = ch             # <<<<<<<<<<<<<<
 *             val = 10*val + (ch0 - 48)
 *             ch = next_char(self)
 */
    __pyx_v_ch0 = __pyx_v_ch;

    /* "axon/_loader.py":517
 * 
 *             ch0 = ch
 *             val = 10*val + (ch0 - 48)             # <<<<<<<<<<<<<<
 *             ch = next_char(self)
 *             i += 1
 */
    __pyx_v_val = ((10 * __pyx_v_val) + (__pyx_v_ch0 - 48));

    /* "axon/_loader.py":518
 *             ch0 = ch
 *             val = 10*val + (ch0 - 48)
 *             ch = next_char(self)             # <<<<<<<<<<<<<<
 *             i += 1
 * 
 */
    __pyx_v_ch = next_char(__pyx_v_self);

    /* "axon/_loader.py":519
 *             val = 10*val + (ch0 - 48)
 *             ch = next_char(self)
 *             i += 1             # <<<<<<<<<<<<<<
 * 
 *         if i == 0:
 */
    __pyx_v_i = (__pyx_v_i + 1);
  }
  __pyx_L4_break:;

  /* "axon/_loader.py":521
 *             i += 1
 * 
 *         if i == 0:             # <<<<<<<<<<<<<<
 *             return -1
 * 
 */
  __pyx_t_3 = ((__pyx_v_i == 0) != 0);
  if (__pyx_t_3) {

    /* "axon/_loader.py":522
 * 
 *         if i == 0:
 *             return -1             # <<<<<<<<<<<<<<
 * 
 *         return val
 */
    __pyx_r = -1;
    goto __pyx_L0;
    goto __pyx_L6;
  }
  __pyx_L6:;

  /* "axon/_loader.py":524
 *             return -1
 * 
 *         return val             # <<<<<<<<<<<<<<
 *     #
 *     def get_date(self):
 */
  __pyx_r = __pyx_v_val;
  goto __pyx_L0;

  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_loader.py":526
 *         return val
 *     #
 *     def get_date(self):             # <<<<<<<<<<<<<<
 * 
 *         val = self.try_get_int(4)
 */

static int __pyx_f_4axon_7_loader_6Loader_get_date(struct __pyx_obj_4axon_7_loader_Loader *__pyx_v_self) {
  Py_UCS4 __pyx_v_ch;
  int __pyx_v_val;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_t_3;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_date", 0);

  /* "axon/_loader.py":528
 *     def get_date(self):
 * 
 *         val = self.try_get_int(4)             # <<<<<<<<<<<<<<
 *         if val < 0:
 *             return -1
 */
  __pyx_v_val = __pyx_f_4axon_7_loader_6Loader_try_get_int(__pyx_v_self, 4);

  /* "axon/_loader.py":529
 * 
 *         val = self.try_get_int(4)
 *         if val < 0:             # <<<<<<<<<<<<<<
 *             return -1
 *         else:
 */
  __pyx_t_1 = ((__pyx_v_val < 0) != 0);
  if (__pyx_t_1) {

    /* "axon/_loader.py":530
 *         val = self.try_get_int(4)
 *         if val < 0:
 *             return -1             # <<<<<<<<<<<<<<
 *         else:
 *             self.da[0] = val
 */
    __pyx_r = -1;
    goto __pyx_L0;
    goto __pyx_L3;
  }
  /*else*/ {

    /* "axon/_loader.py":532
 *             return -1
 *         else:
 *             self.da[0] = val             # <<<<<<<<<<<<<<
 * 
 *         ch = current_char(self)
 */
    __pyx_t_2 = PyInt_FromLong(__pyx_v_val); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 532; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    if (unlikely(((PyObject *)__pyx_v_self->da) == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      {__pyx_filename = __pyx_f[0]; __pyx_lineno = 532; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    }
    if (__Pyx_SetItemInt(((PyObject *)__pyx_v_self->da), 0, __pyx_t_2, sizeof(long), PyInt_FromLong, 1, 0, 0) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 532; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_L3:;

  /* "axon/_loader.py":534
 *             self.da[0] = val
 * 
 *         ch = current_char(self)             # <<<<<<<<<<<<<<
 *         if ch == '-':
 *             skip_char(self)
 */
  __pyx_v_ch = current_char(__pyx_v_self);

  /* "axon/_loader.py":535
 * 
 *         ch = current_char(self)
 *         if ch == '-':             # <<<<<<<<<<<<<<
 *             skip_char(self)
 *         else:
 */
  __pyx_t_1 = ((__pyx_v_ch == 45) != 0);
  if (__pyx_t_1) {

    /* "axon/_loader.py":536
 *         ch = current_char(self)
 *         if ch == '-':
 *             skip_char(self)             # <<<<<<<<<<<<<<
 *         else:
 *             return -1
 */
    skip_char(__pyx_v_self);
    goto __pyx_L4;
  }
  /*else*/ {

    /* "axon/_loader.py":538
 *             skip_char(self)
 *         else:
 *             return -1             # <<<<<<<<<<<<<<
 * 
 *         val = self.try_get_int(2)
 */
    __pyx_r = -1;
    goto __pyx_L0;
  }
  __pyx_L4:;

  /* "axon/_loader.py":540
 *             return -1
 * 
 *         val = self.try_get_int(2)             # <<<<<<<<<<<<<<
 *         if val < 0:
 *             return -1
 */
  __pyx_v_val = __pyx_f_4axon_7_loader_6Loader_try_get_int(__pyx_v_self, 2);

  /* "axon/_loader.py":541
 * 
 *         val = self.try_get_int(2)
 *         if val < 0:             # <<<<<<<<<<<<<<
 *             return -1
 *         else:
 */
  __pyx_t_1 = ((__pyx_v_val < 0) != 0);
  if (__pyx_t_1) {

    /* "axon/_loader.py":542
 *         val = self.try_get_int(2)
 *         if val < 0:
 *             return -1             # <<<<<<<<<<<<<<
 *         else:
 *             self.da[1] = val
 */
    __pyx_r = -1;
    goto __pyx_L0;
    goto __pyx_L5;
  }
  /*else*/ {

    /* "axon/_loader.py":544
 *             return -1
 *         else:
 *             self.da[1] = val             # <<<<<<<<<<<<<<
 * 
 *         ch = current_char(self)
 */
    __pyx_t_2 = PyInt_FromLong(__pyx_v_val); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 544; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    if (unlikely(((PyObject *)__pyx_v_self->da) == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      {__pyx_filename = __pyx_f[0]; __pyx_lineno = 544; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    }
    if (__Pyx_SetItemInt(((PyObject *)__pyx_v_self->da), 1, __pyx_t_2, sizeof(long), PyInt_FromLong, 1, 0, 0) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 544; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_L5:;

  /* "axon/_loader.py":546
 *             self.da[1] = val
 * 
 *         ch = current_char(self)             # <<<<<<<<<<<<<<
 *         if ch == '-':
 *             skip_char(self)
 */
  __pyx_v_ch = current_char(__pyx_v_self);

  /* "axon/_loader.py":547
 * 
 *         ch = current_char(self)
 *         if ch == '-':             # <<<<<<<<<<<<<<
 *             skip_char(self)
 *         else:
 */
  __pyx_t_1 = ((__pyx_v_ch == 45) != 0);
  if (__pyx_t_1) {

    /* "axon/_loader.py":548
 *         ch = current_char(self)
 *         if ch == '-':
 *             skip_char(self)             # <<<<<<<<<<<<<<
 *         else:
 *             return -1
 */
    skip_char(__pyx_v_self);
    goto __pyx_L6;
  }
  /*else*/ {

    /* "axon/_loader.py":550
 *             skip_char(self)
 *         else:
 *             return -1             # <<<<<<<<<<<<<<
 * 
 *         val = self.try_get_int(2)
 */
    __pyx_r = -1;
    goto __pyx_L0;
  }
  __pyx_L6:;

  /* "axon/_loader.py":552
 *             return -1
 * 
 *         val = self.try_get_int(2)             # <<<<<<<<<<<<<<
 *         if val < 0:
 *             return -1
 */
  __pyx_v_val = __pyx_f_4axon_7_loader_6Loader_try_get_int(__pyx_v_self, 2);

  /* "axon/_loader.py":553
 * 
 *         val = self.try_get_int(2)
 *         if val < 0:             # <<<<<<<<<<<<<<
 *             return -1
 *         else:
 */
  __pyx_t_1 = ((__pyx_v_val < 0) != 0);
  if (__pyx_t_1) {

    /* "axon/_loader.py":554
 *         val = self.try_get_int(2)
 *         if val < 0:
 *             return -1             # <<<<<<<<<<<<<<
 *         else:
 *             self.da[2] = val
 */
    __pyx_r = -1;
    goto __pyx_L0;
    goto __pyx_L7;
  }
  /*else*/ {

    /* "axon/_loader.py":556
 *             return -1
 *         else:
 *             self.da[2] = val             # <<<<<<<<<<<<<<
 * 
 *         ch = current_char(self)
 */
    __pyx_t_2 = PyInt_FromLong(__pyx_v_val); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 556; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    if (unlikely(((PyObject *)__pyx_v_self->da) == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      {__pyx_filename = __pyx_f[0]; __pyx_lineno = 556; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    }
    if (__Pyx_SetItemInt(((PyObject *)__pyx_v_self->da), 2, __pyx_t_2, sizeof(long), PyInt_FromLong, 1, 0, 0) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 556; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_L7:;

  /* "axon/_loader.py":558
 *             self.da[2] = val
 * 
 *         ch = current_char(self)             # <<<<<<<<<<<<<<
 *         if '0' <= ch <= '9':
 *             return -1
 */
  __pyx_v_ch = current_char(__pyx_v_self);

  /* "axon/_loader.py":559
 * 
 *         ch = current_char(self)
 *         if '0' <= ch <= '9':             # <<<<<<<<<<<<<<
 *             return -1
 * 
 */
  __pyx_t_1 = (48 <= __pyx_v_ch);
  if (__pyx_t_1) {
    __pyx_t_1 = (__pyx_v_ch <= 57);
  }
  __pyx_t_3 = (__pyx_t_1 != 0);
  if (__pyx_t_3) {

    /* "axon/_loader.py":560
 *         ch = current_char(self)
 *         if '0' <= ch <= '9':
 *             return -1             # <<<<<<<<<<<<<<
 * 
 *         return 0
 */
    __pyx_r = -1;
    goto __pyx_L0;
    goto __pyx_L8;
  }
  __pyx_L8:;

  /* "axon/_loader.py":562
 *             return -1
 * 
 *         return 0             # <<<<<<<<<<<<<<
 *     #
 *     def get_time(self):
 */
  __pyx_r = 0;
  goto __pyx_L0;

  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_WriteUnraisable("axon._loader.Loader.get_date", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_loader.py":564
 *         return 0
 *     #
 *     def get_time(self):             # <<<<<<<<<<<<<<
 *         val = self.try_get_int(2)
 *         if val < 0:
 */

static int __pyx_f_4axon_7_loader_6Loader_get_time(struct __pyx_obj_4axon_7_loader_Loader *__pyx_v_self) {
  Py_UCS4 __pyx_v_ch;
  int __pyx_v_val;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_t_3;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_time", 0);

  /* "axon/_loader.py":565
 *     #
 *     def get_time(self):
 *         val = self.try_get_int(2)             # <<<<<<<<<<<<<<
 *         if val < 0:
 *             return -1
 */
  __pyx_v_val = __pyx_f_4axon_7_loader_6Loader_try_get_int(__pyx_v_self, 2);

  /* "axon/_loader.py":566
 *     def get_time(self):
 *         val = self.try_get_int(2)
 *         if val < 0:             # <<<<<<<<<<<<<<
 *             return -1
 *         else:
 */
  __pyx_t_1 = ((__pyx_v_val < 0) != 0);
  if (__pyx_t_1) {

    /* "axon/_loader.py":567
 *         val = self.try_get_int(2)
 *         if val < 0:
 *             return -1             # <<<<<<<<<<<<<<
 *         else:
 *             self.ta[0] = val
 */
    __pyx_r = -1;
    goto __pyx_L0;
    goto __pyx_L3;
  }
  /*else*/ {

    /* "axon/_loader.py":569
 *             return -1
 *         else:
 *             self.ta[0] = val             # <<<<<<<<<<<<<<
 * 
 *         ch = current_char(self)
 */
    __pyx_t_2 = PyInt_FromLong(__pyx_v_val); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 569; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    if (unlikely(((PyObject *)__pyx_v_self->ta) == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      {__pyx_filename = __pyx_f[0]; __pyx_lineno = 569; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    }
    if (__Pyx_SetItemInt(((PyObject *)__pyx_v_self->ta), 0, __pyx_t_2, sizeof(long), PyInt_FromLong, 1, 0, 0) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 569; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_L3:;

  /* "axon/_loader.py":571
 *             self.ta[0] = val
 * 
 *         ch = current_char(self)             # <<<<<<<<<<<<<<
 *         if ch == ':':
 *             skip_char(self)
 */
  __pyx_v_ch = current_char(__pyx_v_self);

  /* "axon/_loader.py":572
 * 
 *         ch = current_char(self)
 *         if ch == ':':             # <<<<<<<<<<<<<<
 *             skip_char(self)
 *         else:
 */
  __pyx_t_1 = ((__pyx_v_ch == 58) != 0);
  if (__pyx_t_1) {

    /* "axon/_loader.py":573
 *         ch = current_char(self)
 *         if ch == ':':
 *             skip_char(self)             # <<<<<<<<<<<<<<
 *         else:
 *             return -1
 */
    skip_char(__pyx_v_self);
    goto __pyx_L4;
  }
  /*else*/ {

    /* "axon/_loader.py":575
 *             skip_char(self)
 *         else:
 *             return -1             # <<<<<<<<<<<<<<
 * 
 *         val = self.try_get_int(2)
 */
    __pyx_r = -1;
    goto __pyx_L0;
  }
  __pyx_L4:;

  /* "axon/_loader.py":577
 *             return -1
 * 
 *         val = self.try_get_int(2)             # <<<<<<<<<<<<<<
 *         if val < 0:
 *             return -1
 */
  __pyx_v_val = __pyx_f_4axon_7_loader_6Loader_try_get_int(__pyx_v_self, 2);

  /* "axon/_loader.py":578
 * 
 *         val = self.try_get_int(2)
 *         if val < 0:             # <<<<<<<<<<<<<<
 *             return -1
 *         else:
 */
  __pyx_t_1 = ((__pyx_v_val < 0) != 0);
  if (__pyx_t_1) {

    /* "axon/_loader.py":579
 *         val = self.try_get_int(2)
 *         if val < 0:
 *             return -1             # <<<<<<<<<<<<<<
 *         else:
 *             self.ta[1] = val
 */
    __pyx_r = -1;
    goto __pyx_L0;
    goto __pyx_L5;
  }
  /*else*/ {

    /* "axon/_loader.py":581
 *             return -1
 *         else:
 *             self.ta[1] = val             # <<<<<<<<<<<<<<
 * 
 *         ch = current_char(self)
 */
    __pyx_t_2 = PyInt_FromLong(__pyx_v_val); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 581; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    if (unlikely(((PyObject *)__pyx_v_self->ta) == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      {__pyx_filename = __pyx_f[0]; __pyx_lineno = 581; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    }
    if (__Pyx_SetItemInt(((PyObject *)__pyx_v_self->ta), 1, __pyx_t_2, sizeof(long), PyInt_FromLong, 1, 0, 0) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 581; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_L5:;

  /* "axon/_loader.py":583
 *             self.ta[1] = val
 * 
 *         ch = current_char(self)             # <<<<<<<<<<<<<<
 *         if ch == ':':
 *             skip_char(self)
 */
  __pyx_v_ch = current_char(__pyx_v_self);

  /* "axon/_loader.py":584
 * 
 *         ch = current_char(self)
 *         if ch == ':':             # <<<<<<<<<<<<<<
 *             skip_char(self)
 *         elif '0' <= ch <= '9':
 */
  __pyx_t_1 = ((__pyx_v_ch == 58) != 0);
  if (__pyx_t_1) {

    /* "axon/_loader.py":585
 *         ch = current_char(self)
 *         if ch == ':':
 *             skip_char(self)             # <<<<<<<<<<<<<<
 *         elif '0' <= ch <= '9':
 *             return -1
 */
    skip_char(__pyx_v_self);
    goto __pyx_L6;
  }

  /* "axon/_loader.py":586
 *         if ch == ':':
 *             skip_char(self)
 *         elif '0' <= ch <= '9':             # <<<<<<<<<<<<<<
 *             return -1
 *         else:
 */
  __pyx_t_1 = (48 <= __pyx_v_ch);
  if (__pyx_t_1) {
    __pyx_t_1 = (__pyx_v_ch <= 57);
  }
  __pyx_t_3 = (__pyx_t_1 != 0);
  if (__pyx_t_3) {

    /* "axon/_loader.py":587
 *             skip_char(self)
 *         elif '0' <= ch <= '9':
 *             return -1             # <<<<<<<<<<<<<<
 *         else:
 *             self.ta[2] = 0
 */
    __pyx_r = -1;
    goto __pyx_L0;
    goto __pyx_L6;
  }
  /*else*/ {

    /* "axon/_loader.py":589
 *             return -1
 *         else:
 *             self.ta[2] = 0             # <<<<<<<<<<<<<<
 *             self.ta[3] = 0
 *             return 0
 */
    if (unlikely(((PyObject *)__pyx_v_self->ta) == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      {__pyx_filename = __pyx_f[0]; __pyx_lineno = 589; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    }
    if (__Pyx_SetItemInt(((PyObject *)__pyx_v_self->ta), 2, __pyx_int_0, sizeof(long), PyInt_FromLong, 1, 0, 0) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 589; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

    /* "axon/_loader.py":590
 *         else:
 *             self.ta[2] = 0
 *             self.ta[3] = 0             # <<<<<<<<<<<<<<
 *             return 0
 * 
 */
    if (unlikely(((PyObject *)__pyx_v_self->ta) == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      {__pyx_filename = __pyx_f[0]; __pyx_lineno = 590; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    }
    if (__Pyx_SetItemInt(((PyObject *)__pyx_v_self->ta), 3, __pyx_int_0, sizeof(long), PyInt_FromLong, 1, 0, 0) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 590; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

    /* "axon/_loader.py":591
 *             self.ta[2] = 0
 *             self.ta[3] = 0
 *             return 0             # <<<<<<<<<<<<<<
 * 
 *         val = self.try_get_int(2)
 */
    __pyx_r = 0;
    goto __pyx_L0;
  }
  __pyx_L6:;

  /* "axon/_loader.py":593
 *             return 0
 * 
 *         val = self.try_get_int(2)             # <<<<<<<<<<<<<<
 *         if val < 0:
 *             return -1
 */
  __pyx_v_val = __pyx_f_4axon_7_loader_6Loader_try_get_int(__pyx_v_self, 2);

  /* "axon/_loader.py":594
 * 
 *         val = self.try_get_int(2)
 *         if val < 0:             # <<<<<<<<<<<<<<
 *             return -1
 *         else:
 */
  __pyx_t_3 = ((__pyx_v_val < 0) != 0);
  if (__pyx_t_3) {

    /* "axon/_loader.py":595
 *         val = self.try_get_int(2)
 *         if val < 0:
 *             return -1             # <<<<<<<<<<<<<<
 *         else:
 *             self.ta[2] = val
 */
    __pyx_r = -1;
    goto __pyx_L0;
    goto __pyx_L7;
  }
  /*else*/ {

    /* "axon/_loader.py":597
 *             return -1
 *         else:
 *             self.ta[2] = val             # <<<<<<<<<<<<<<
 * 
 *         ch = current_char(self)
 */
    __pyx_t_2 = PyInt_FromLong(__pyx_v_val); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 597; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    if (unlikely(((PyObject *)__pyx_v_self->ta) == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      {__pyx_filename = __pyx_f[0]; __pyx_lineno = 597; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    }
    if (__Pyx_SetItemInt(((PyObject *)__pyx_v_self->ta), 2, __pyx_t_2, sizeof(long), PyInt_FromLong, 1, 0, 0) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 597; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_L7:;

  /* "axon/_loader.py":599
 *             self.ta[2] = val
 * 
 *         ch = current_char(self)             # <<<<<<<<<<<<<<
 *         if ch == '.':
 *             skip_char(self)
 */
  __pyx_v_ch = current_char(__pyx_v_self);

  /* "axon/_loader.py":600
 * 
 *         ch = current_char(self)
 *         if ch == '.':             # <<<<<<<<<<<<<<
 *             skip_char(self)
 *         elif '0' <= ch <= '9':
 */
  __pyx_t_3 = ((__pyx_v_ch == 46) != 0);
  if (__pyx_t_3) {

    /* "axon/_loader.py":601
 *         ch = current_char(self)
 *         if ch == '.':
 *             skip_char(self)             # <<<<<<<<<<<<<<
 *         elif '0' <= ch <= '9':
 *             return -1
 */
    skip_char(__pyx_v_self);
    goto __pyx_L8;
  }

  /* "axon/_loader.py":602
 *         if ch == '.':
 *             skip_char(self)
 *         elif '0' <= ch <= '9':             # <<<<<<<<<<<<<<
 *             return -1
 *         else:
 */
  __pyx_t_3 = (48 <= __pyx_v_ch);
  if (__pyx_t_3) {
    __pyx_t_3 = (__pyx_v_ch <= 57);
  }
  __pyx_t_1 = (__pyx_t_3 != 0);
  if (__pyx_t_1) {

    /* "axon/_loader.py":603
 *             skip_char(self)
 *         elif '0' <= ch <= '9':
 *             return -1             # <<<<<<<<<<<<<<
 *         else:
 *             self.ta[3] = 0
 */
    __pyx_r = -1;
    goto __pyx_L0;
    goto __pyx_L8;
  }
  /*else*/ {

    /* "axon/_loader.py":605
 *             return -1
 *         else:
 *             self.ta[3] = 0             # <<<<<<<<<<<<<<
 *             return 0
 * 
 */
    if (unlikely(((PyObject *)__pyx_v_self->ta) == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      {__pyx_filename = __pyx_f[0]; __pyx_lineno = 605; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    }
    if (__Pyx_SetItemInt(((PyObject *)__pyx_v_self->ta), 3, __pyx_int_0, sizeof(long), PyInt_FromLong, 1, 0, 0) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 605; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

    /* "axon/_loader.py":606
 *         else:
 *             self.ta[3] = 0
 *             return 0             # <<<<<<<<<<<<<<
 * 
 *         val = self.try_get_int(6)
 */
    __pyx_r = 0;
    goto __pyx_L0;
  }
  __pyx_L8:;

  /* "axon/_loader.py":608
 *             return 0
 * 
 *         val = self.try_get_int(6)             # <<<<<<<<<<<<<<
 *         if val < 0:
 *             return -1
 */
  __pyx_v_val = __pyx_f_4axon_7_loader_6Loader_try_get_int(__pyx_v_self, 6);

  /* "axon/_loader.py":609
 * 
 *         val = self.try_get_int(6)
 *         if val < 0:             # <<<<<<<<<<<<<<
 *             return -1
 *         else:
 */
  __pyx_t_1 = ((__pyx_v_val < 0) != 0);
  if (__pyx_t_1) {

    /* "axon/_loader.py":610
 *         val = self.try_get_int(6)
 *         if val < 0:
 *             return -1             # <<<<<<<<<<<<<<
 *         else:
 *             self.ta[3] = val
 */
    __pyx_r = -1;
    goto __pyx_L0;
    goto __pyx_L9;
  }
  /*else*/ {

    /* "axon/_loader.py":612
 *             return -1
 *         else:
 *             self.ta[3] = val             # <<<<<<<<<<<<<<
 * 
 *         ch = current_char(self)
 */
    __pyx_t_2 = PyInt_FromLong(__pyx_v_val); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 612; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    if (unlikely(((PyObject *)__pyx_v_self->ta) == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      {__pyx_filename = __pyx_f[0]; __pyx_lineno = 612; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    }
    if (__Pyx_SetItemInt(((PyObject *)__pyx_v_self->ta), 3, __pyx_t_2, sizeof(long), PyInt_FromLong, 1, 0, 0) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 612; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_L9:;

  /* "axon/_loader.py":614
 *             self.ta[3] = val
 * 
 *         ch = current_char(self)             # <<<<<<<<<<<<<<
 *         if '0' <= ch <= '9':
 *             return -1
 */
  __pyx_v_ch = current_char(__pyx_v_self);

  /* "axon/_loader.py":615
 * 
 *         ch = current_char(self)
 *         if '0' <= ch <= '9':             # <<<<<<<<<<<<<<
 *             return -1
 * 
 */
  __pyx_t_1 = (48 <= __pyx_v_ch);
  if (__pyx_t_1) {
    __pyx_t_1 = (__pyx_v_ch <= 57);
  }
  __pyx_t_3 = (__pyx_t_1 != 0);
  if (__pyx_t_3) {

    /* "axon/_loader.py":616
 *         ch = current_char(self)
 *         if '0' <= ch <= '9':
 *             return -1             # <<<<<<<<<<<<<<
 * 
 *         return 0
 */
    __pyx_r = -1;
    goto __pyx_L0;
    goto __pyx_L10;
  }
  __pyx_L10:;

  /* "axon/_loader.py":618
 *             return -1
 * 
 *         return 0             # <<<<<<<<<<<<<<
 *     #
 *     def get_time_offset(self):
 */
  __pyx_r = 0;
  goto __pyx_L0;

  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_WriteUnraisable("axon._loader.Loader.get_time", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_loader.py":620
 *         return 0
 *     #
 *     def get_time_offset(self):             # <<<<<<<<<<<<<<
 * 
 *         val = self.try_get_int(2)
 */

static int __pyx_f_4axon_7_loader_6Loader_get_time_offset(struct __pyx_obj_4axon_7_loader_Loader *__pyx_v_self) {
  Py_UCS4 __pyx_v_ch;
  int __pyx_v_val;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_t_3;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_time_offset", 0);

  /* "axon/_loader.py":622
 *     def get_time_offset(self):
 * 
 *         val = self.try_get_int(2)             # <<<<<<<<<<<<<<
 *         if val < 0:
 *             return -1
 */
  __pyx_v_val = __pyx_f_4axon_7_loader_6Loader_try_get_int(__pyx_v_self, 2);

  /* "axon/_loader.py":623
 * 
 *         val = self.try_get_int(2)
 *         if val < 0:             # <<<<<<<<<<<<<<
 *             return -1
 *         else:
 */
  __pyx_t_1 = ((__pyx_v_val < 0) != 0);
  if (__pyx_t_1) {

    /* "axon/_loader.py":624
 *         val = self.try_get_int(2)
 *         if val < 0:
 *             return -1             # <<<<<<<<<<<<<<
 *         else:
 *             self.to[0] = val
 */
    __pyx_r = -1;
    goto __pyx_L0;
    goto __pyx_L3;
  }
  /*else*/ {

    /* "axon/_loader.py":626
 *             return -1
 *         else:
 *             self.to[0] = val             # <<<<<<<<<<<<<<
 * 
 *         ch = current_char(self)
 */
    __pyx_t_2 = PyInt_FromLong(__pyx_v_val); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 626; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    if (unlikely(((PyObject *)__pyx_v_self->to) == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      {__pyx_filename = __pyx_f[0]; __pyx_lineno = 626; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    }
    if (__Pyx_SetItemInt(((PyObject *)__pyx_v_self->to), 0, __pyx_t_2, sizeof(long), PyInt_FromLong, 1, 0, 0) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 626; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_L3:;

  /* "axon/_loader.py":628
 *             self.to[0] = val
 * 
 *         ch = current_char(self)             # <<<<<<<<<<<<<<
 *         if ch == ':':
 *             skip_char(self)
 */
  __pyx_v_ch = current_char(__pyx_v_self);

  /* "axon/_loader.py":629
 * 
 *         ch = current_char(self)
 *         if ch == ':':             # <<<<<<<<<<<<<<
 *             skip_char(self)
 *         elif '0' <= ch <= '9':
 */
  __pyx_t_1 = ((__pyx_v_ch == 58) != 0);
  if (__pyx_t_1) {

    /* "axon/_loader.py":630
 *         ch = current_char(self)
 *         if ch == ':':
 *             skip_char(self)             # <<<<<<<<<<<<<<
 *         elif '0' <= ch <= '9':
 *             return -1
 */
    skip_char(__pyx_v_self);
    goto __pyx_L4;
  }

  /* "axon/_loader.py":631
 *         if ch == ':':
 *             skip_char(self)
 *         elif '0' <= ch <= '9':             # <<<<<<<<<<<<<<
 *             return -1
 *         else:
 */
  __pyx_t_1 = (48 <= __pyx_v_ch);
  if (__pyx_t_1) {
    __pyx_t_1 = (__pyx_v_ch <= 57);
  }
  __pyx_t_3 = (__pyx_t_1 != 0);
  if (__pyx_t_3) {

    /* "axon/_loader.py":632
 *             skip_char(self)
 *         elif '0' <= ch <= '9':
 *             return -1             # <<<<<<<<<<<<<<
 *         else:
 *             self.to[1] = 0
 */
    __pyx_r = -1;
    goto __pyx_L0;
    goto __pyx_L4;
  }
  /*else*/ {

    /* "axon/_loader.py":634
 *             return -1
 *         else:
 *             self.to[1] = 0             # <<<<<<<<<<<<<<
 *             return 0
 * 
 */
    if (unlikely(((PyObject *)__pyx_v_self->to) == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      {__pyx_filename = __pyx_f[0]; __pyx_lineno = 634; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    }
    if (__Pyx_SetItemInt(((PyObject *)__pyx_v_self->to), 1, __pyx_int_0, sizeof(long), PyInt_FromLong, 1, 0, 0) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 634; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

    /* "axon/_loader.py":635
 *         else:
 *             self.to[1] = 0
 *             return 0             # <<<<<<<<<<<<<<
 * 
 *         val = self.try_get_int(2)
 */
    __pyx_r = 0;
    goto __pyx_L0;
  }
  __pyx_L4:;

  /* "axon/_loader.py":637
 *             return 0
 * 
 *         val = self.try_get_int(2)             # <<<<<<<<<<<<<<
 *         if val < 0:
 *             return -1
 */
  __pyx_v_val = __pyx_f_4axon_7_loader_6Loader_try_get_int(__pyx_v_self, 2);

  /* "axon/_loader.py":638
 * 
 *         val = self.try_get_int(2)
 *         if val < 0:             # <<<<<<<<<<<<<<
 *             return -1
 *         else:
 */
  __pyx_t_3 = ((__pyx_v_val < 0) != 0);
  if (__pyx_t_3) {

    /* "axon/_loader.py":639
 *         val = self.try_get_int(2)
 *         if val < 0:
 *             return -1             # <<<<<<<<<<<<<<
 *         else:
 *             self.to[1] = val
 */
    __pyx_r = -1;
    goto __pyx_L0;
    goto __pyx_L5;
  }
  /*else*/ {

    /* "axon/_loader.py":641
 *             return -1
 *         else:
 *             self.to[1] = val             # <<<<<<<<<<<<<<
 * 
 *         ch = current_char(self)
 */
    __pyx_t_2 = PyInt_FromLong(__pyx_v_val); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 641; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    if (unlikely(((PyObject *)__pyx_v_self->to) == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      {__pyx_filename = __pyx_f[0]; __pyx_lineno = 641; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    }
    if (__Pyx_SetItemInt(((PyObject *)__pyx_v_self->to), 1, __pyx_t_2, sizeof(long), PyInt_FromLong, 1, 0, 0) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 641; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_L5:;

  /* "axon/_loader.py":643
 *             self.to[1] = val
 * 
 *         ch = current_char(self)             # <<<<<<<<<<<<<<
 *         if '0' <= ch <= '9':
 *             return -1
 */
  __pyx_v_ch = current_char(__pyx_v_self);

  /* "axon/_loader.py":644
 * 
 *         ch = current_char(self)
 *         if '0' <= ch <= '9':             # <<<<<<<<<<<<<<
 *             return -1
 * 
 */
  __pyx_t_3 = (48 <= __pyx_v_ch);
  if (__pyx_t_3) {
    __pyx_t_3 = (__pyx_v_ch <= 57);
  }
  __pyx_t_1 = (__pyx_t_3 != 0);
  if (__pyx_t_1) {

    /* "axon/_loader.py":645
 *         ch = current_char(self)
 *         if '0' <= ch <= '9':
 *             return -1             # <<<<<<<<<<<<<<
 * 
 *         return 0
 */
    __pyx_r = -1;
    goto __pyx_L0;
    goto __pyx_L6;
  }
  __pyx_L6:;

  /* "axon/_loader.py":647
 *             return -1
 * 
 *         return 0             # <<<<<<<<<<<<<<
 *     #
 *     def get_tzinfo(self):
 */
  __pyx_r = 0;
  goto __pyx_L0;

  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_WriteUnraisable("axon._loader.Loader.get_time_offset", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_loader.py":649
 *         return 0
 *     #
 *     def get_tzinfo(self):             # <<<<<<<<<<<<<<
 *         v = 0
 *         sign = 0
 */

static PyObject *__pyx_f_4axon_7_loader_6Loader_get_tzinfo(struct __pyx_obj_4axon_7_loader_Loader *__pyx_v_self) {
  Py_UCS4 __pyx_v_ch;
  int __pyx_v_minutes;
  int __pyx_v_v;
  int __pyx_v_h;
  int __pyx_v_m;
  int __pyx_v_sign;
  PyObject *__pyx_v_tzinfo = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_t_6;
  int __pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_tzinfo", 0);

  /* "axon/_loader.py":650
 *     #
 *     def get_tzinfo(self):
 *         v = 0             # <<<<<<<<<<<<<<
 *         sign = 0
 *         ch = current_char(self)
 */
  __pyx_v_v = 0;

  /* "axon/_loader.py":651
 *     def get_tzinfo(self):
 *         v = 0
 *         sign = 0             # <<<<<<<<<<<<<<
 *         ch = current_char(self)
 *         if ch == '-':
 */
  __pyx_v_sign = 0;

  /* "axon/_loader.py":652
 *         v = 0
 *         sign = 0
 *         ch = current_char(self)             # <<<<<<<<<<<<<<
 *         if ch == '-':
 *             skip_char(self)
 */
  __pyx_v_ch = current_char(__pyx_v_self);

  /* "axon/_loader.py":653
 *         sign = 0
 *         ch = current_char(self)
 *         if ch == '-':             # <<<<<<<<<<<<<<
 *             skip_char(self)
 *             sign = 1
 */
  __pyx_t_1 = ((__pyx_v_ch == 45) != 0);
  if (__pyx_t_1) {

    /* "axon/_loader.py":654
 *         ch = current_char(self)
 *         if ch == '-':
 *             skip_char(self)             # <<<<<<<<<<<<<<
 *             sign = 1
 *             v = self.get_time_offset()
 */
    skip_char(__pyx_v_self);

    /* "axon/_loader.py":655
 *         if ch == '-':
 *             skip_char(self)
 *             sign = 1             # <<<<<<<<<<<<<<
 *             v = self.get_time_offset()
 *             if v < 0:
 */
    __pyx_v_sign = 1;

    /* "axon/_loader.py":656
 *             skip_char(self)
 *             sign = 1
 *             v = self.get_time_offset()             # <<<<<<<<<<<<<<
 *             if v < 0:
 *                 errors.error_invalid_time(self)
 */
    __pyx_v_v = __pyx_f_4axon_7_loader_6Loader_get_time_offset(__pyx_v_self);

    /* "axon/_loader.py":657
 *             sign = 1
 *             v = self.get_time_offset()
 *             if v < 0:             # <<<<<<<<<<<<<<
 *                 errors.error_invalid_time(self)
 *         elif ch == '+':
 */
    __pyx_t_1 = ((__pyx_v_v < 0) != 0);
    if (__pyx_t_1) {

      /* "axon/_loader.py":658
 *             v = self.get_time_offset()
 *             if v < 0:
 *                 errors.error_invalid_time(self)             # <<<<<<<<<<<<<<
 *         elif ch == '+':
 *             skip_char(self)
 */
      __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s__errors); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 658; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s__error_invalid_time); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 658; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 658; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_INCREF(((PyObject *)__pyx_v_self));
      PyTuple_SET_ITEM(__pyx_t_2, 0, ((PyObject *)__pyx_v_self));
      __Pyx_GIVEREF(((PyObject *)__pyx_v_self));
      __pyx_t_4 = PyObject_Call(__pyx_t_3, ((PyObject *)__pyx_t_2), NULL); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 658; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF(((PyObject *)__pyx_t_2)); __pyx_t_2 = 0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      goto __pyx_L4;
    }
    __pyx_L4:;
    goto __pyx_L3;
  }

  /* "axon/_loader.py":659
 *             if v < 0:
 *                 errors.error_invalid_time(self)
 *         elif ch == '+':             # <<<<<<<<<<<<<<
 *             skip_char(self)
 *             v = self.get_time_offset()
 */
  __pyx_t_1 = ((__pyx_v_ch == 43) != 0);
  if (__pyx_t_1) {

    /* "axon/_loader.py":660
 *                 errors.error_invalid_time(self)
 *         elif ch == '+':
 *             skip_char(self)             # <<<<<<<<<<<<<<
 *             v = self.get_time_offset()
 *             if v < 0:
 */
    skip_char(__pyx_v_self);

    /* "axon/_loader.py":661
 *         elif ch == '+':
 *             skip_char(self)
 *             v = self.get_time_offset()             # <<<<<<<<<<<<<<
 *             if v < 0:
 *                 errors.error_invalid_time(self)
 */
    __pyx_v_v = __pyx_f_4axon_7_loader_6Loader_get_time_offset(__pyx_v_self);

    /* "axon/_loader.py":662
 *             skip_char(self)
 *             v = self.get_time_offset()
 *             if v < 0:             # <<<<<<<<<<<<<<
 *                 errors.error_invalid_time(self)
 *         elif '0' <= ch <= '9':
 */
    __pyx_t_1 = ((__pyx_v_v < 0) != 0);
    if (__pyx_t_1) {

      /* "axon/_loader.py":663
 *             v = self.get_time_offset()
 *             if v < 0:
 *                 errors.error_invalid_time(self)             # <<<<<<<<<<<<<<
 *         elif '0' <= ch <= '9':
 *             v = self.get_time_offset()
 */
      __pyx_t_4 = __Pyx_GetModuleGlobalName(__pyx_n_s__errors); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 663; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s__error_invalid_time); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 663; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_4 = PyTuple_New(1); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 663; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_INCREF(((PyObject *)__pyx_v_self));
      PyTuple_SET_ITEM(__pyx_t_4, 0, ((PyObject *)__pyx_v_self));
      __Pyx_GIVEREF(((PyObject *)__pyx_v_self));
      __pyx_t_3 = PyObject_Call(__pyx_t_2, ((PyObject *)__pyx_t_4), NULL); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 663; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_DECREF(((PyObject *)__pyx_t_4)); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      goto __pyx_L5;
    }
    __pyx_L5:;
    goto __pyx_L3;
  }

  /* "axon/_loader.py":664
 *             if v < 0:
 *                 errors.error_invalid_time(self)
 *         elif '0' <= ch <= '9':             # <<<<<<<<<<<<<<
 *             v = self.get_time_offset()
 *             if v < 0:
 */
  __pyx_t_1 = (48 <= __pyx_v_ch);
  if (__pyx_t_1) {
    __pyx_t_1 = (__pyx_v_ch <= 57);
  }
  __pyx_t_5 = (__pyx_t_1 != 0);
  if (__pyx_t_5) {

    /* "axon/_loader.py":665
 *                 errors.error_invalid_time(self)
 *         elif '0' <= ch <= '9':
 *             v = self.get_time_offset()             # <<<<<<<<<<<<<<
 *             if v < 0:
 *                 errors.error_invalid_time(self)
 */
    __pyx_v_v = __pyx_f_4axon_7_loader_6Loader_get_time_offset(__pyx_v_self);

    /* "axon/_loader.py":666
 *         elif '0' <= ch <= '9':
 *             v = self.get_time_offset()
 *             if v < 0:             # <<<<<<<<<<<<<<
 *                 errors.error_invalid_time(self)
 *         else:
 */
    __pyx_t_5 = ((__pyx_v_v < 0) != 0);
    if (__pyx_t_5) {

      /* "axon/_loader.py":667
 *             v = self.get_time_offset()
 *             if v < 0:
 *                 errors.error_invalid_time(self)             # <<<<<<<<<<<<<<
 *         else:
 *             return None
 */
      __pyx_t_3 = __Pyx_GetModuleGlobalName(__pyx_n_s__errors); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 667; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s__error_invalid_time); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 667; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 667; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_INCREF(((PyObject *)__pyx_v_self));
      PyTuple_SET_ITEM(__pyx_t_3, 0, ((PyObject *)__pyx_v_self));
      __Pyx_GIVEREF(((PyObject *)__pyx_v_self));
      __pyx_t_2 = PyObject_Call(__pyx_t_4, ((PyObject *)__pyx_t_3), NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 667; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(((PyObject *)__pyx_t_3)); __pyx_t_3 = 0;
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      goto __pyx_L6;
    }
    __pyx_L6:;
    goto __pyx_L3;
  }
  /*else*/ {

    /* "axon/_loader.py":669
 *                 errors.error_invalid_time(self)
 *         else:
 *             return None             # <<<<<<<<<<<<<<
 * 
 *         h = self.to[0]
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(Py_None);
    __pyx_r = Py_None;
    goto __pyx_L0;
  }
  __pyx_L3:;

  /* "axon/_loader.py":671
 *             return None
 * 
 *         h = self.to[0]             # <<<<<<<<<<<<<<
 *         m = self.to[1]
 * 
 */
  if (unlikely(((PyObject *)__pyx_v_self->to) == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    {__pyx_filename = __pyx_f[0]; __pyx_lineno = 671; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }
  __pyx_t_6 = __Pyx_PyInt_AsInt(PyList_GET_ITEM(__pyx_v_self->to, 0)); if (unlikely((__pyx_t_6 == (int)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 671; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_v_h = __pyx_t_6;

  /* "axon/_loader.py":672
 * 
 *         h = self.to[0]
 *         m = self.to[1]             # <<<<<<<<<<<<<<
 * 
 *         minutes = h * 60 + m
 */
  if (unlikely(((PyObject *)__pyx_v_self->to) == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    {__pyx_filename = __pyx_f[0]; __pyx_lineno = 672; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }
  __pyx_t_6 = __Pyx_PyInt_AsInt(PyList_GET_ITEM(__pyx_v_self->to, 1)); if (unlikely((__pyx_t_6 == (int)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 672; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_v_m = __pyx_t_6;

  /* "axon/_loader.py":674
 *         m = self.to[1]
 * 
 *         minutes = h * 60 + m             # <<<<<<<<<<<<<<
 * 
 *         if minutes > 1440 or minutes < 0:
 */
  __pyx_v_minutes = ((__pyx_v_h * 60) + __pyx_v_m);

  /* "axon/_loader.py":676
 *         minutes = h * 60 + m
 * 
 *         if minutes > 1440 or minutes < 0:             # <<<<<<<<<<<<<<
 *             errors.error_invalid_time(self)
 * 
 */
  __pyx_t_5 = ((__pyx_v_minutes > 1440) != 0);
  if (!__pyx_t_5) {
    __pyx_t_1 = ((__pyx_v_minutes < 0) != 0);
    __pyx_t_7 = __pyx_t_1;
  } else {
    __pyx_t_7 = __pyx_t_5;
  }
  if (__pyx_t_7) {

    /* "axon/_loader.py":677
 * 
 *         if minutes > 1440 or minutes < 0:
 *             errors.error_invalid_time(self)             # <<<<<<<<<<<<<<
 * 
 *         if sign:
 */
    __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s__errors); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 677; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s__error_invalid_time); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 677; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 677; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_INCREF(((PyObject *)__pyx_v_self));
    PyTuple_SET_ITEM(__pyx_t_2, 0, ((PyObject *)__pyx_v_self));
    __Pyx_GIVEREF(((PyObject *)__pyx_v_self));
    __pyx_t_4 = PyObject_Call(__pyx_t_3, ((PyObject *)__pyx_t_2), NULL); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 677; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(((PyObject *)__pyx_t_2)); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    goto __pyx_L7;
  }
  __pyx_L7:;

  /* "axon/_loader.py":679
 *             errors.error_invalid_time(self)
 * 
 *         if sign:             # <<<<<<<<<<<<<<
 *             minutes = 1440 - minutes
 * 
 */
  __pyx_t_7 = (__pyx_v_sign != 0);
  if (__pyx_t_7) {

    /* "axon/_loader.py":680
 * 
 *         if sign:
 *             minutes = 1440 - minutes             # <<<<<<<<<<<<<<
 * 
 *         tzinfo = self.sbuilder.create_tzinfo(minutes)
 */
    __pyx_v_minutes = (1440 - __pyx_v_minutes);
    goto __pyx_L8;
  }
  __pyx_L8:;

  /* "axon/_loader.py":682
 *             minutes = 1440 - minutes
 * 
 *         tzinfo = self.sbuilder.create_tzinfo(minutes)             # <<<<<<<<<<<<<<
 * 
 *         return tzinfo
 */
  __pyx_t_4 = __pyx_v_self->sbuilder->create_tzinfo(__pyx_v_minutes); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 682; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_v_tzinfo = __pyx_t_4;
  __pyx_t_4 = 0;

  /* "axon/_loader.py":684
 *         tzinfo = self.sbuilder.create_tzinfo(minutes)
 * 
 *         return tzinfo             # <<<<<<<<<<<<<<
 *     #
 *     def get_number(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_tzinfo);
  __pyx_r = __pyx_v_tzinfo;
  goto __pyx_L0;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("axon._loader.Loader.get_tzinfo", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_tzinfo);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_loader.py":686
 *         return tzinfo
 *     #
 *     def get_number(self):             # <<<<<<<<<<<<<<
 * 
 *         numtype = 1
 */

static PyObject *__pyx_f_4axon_7_loader_6Loader_get_number(struct __pyx_obj_4axon_7_loader_Loader *__pyx_v_self) {
  PyObject *__pyx_v_text = 0;
  Py_UCS4 __pyx_v_ch;
  int __pyx_v_pos0;
  int __pyx_v_numtype;
  int __pyx_v_v;
  PyObject *__pyx_v_tzinfo = NULL;
  PyObject *__pyx_v_val = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  int __pyx_t_3;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_t_8;
  int __pyx_t_9;
  int __pyx_t_10;
  int __pyx_t_11;
  int __pyx_t_12;
  int __pyx_t_13;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_number", 0);

  /* "axon/_loader.py":688
 *     def get_number(self):
 * 
 *         numtype = 1             # <<<<<<<<<<<<<<
 *         pos0 = self.pos
 *         ch = next_char(self)
 */
  __pyx_v_numtype = 1;

  /* "axon/_loader.py":689
 * 
 *         numtype = 1
 *         pos0 = self.pos             # <<<<<<<<<<<<<<
 *         ch = next_char(self)
 *         while ch >= '0' and ch <= '9':
 */
  __pyx_t_1 = __pyx_v_self->pos;
  __pyx_v_pos0 = __pyx_t_1;

  /* "axon/_loader.py":690
 *         numtype = 1
 *         pos0 = self.pos
 *         ch = next_char(self)             # <<<<<<<<<<<<<<
 *         while ch >= '0' and ch <= '9':
 *             ch = next_char(self)
 */
  __pyx_v_ch = next_char(__pyx_v_self);

  /* "axon/_loader.py":691
 *         pos0 = self.pos
 *         ch = next_char(self)
 *         while ch >= '0' and ch <= '9':             # <<<<<<<<<<<<<<
 *             ch = next_char(self)
 * 
 */
  while (1) {
    __pyx_t_2 = ((__pyx_v_ch >= 48) != 0);
    if (__pyx_t_2) {
      __pyx_t_3 = ((__pyx_v_ch <= 57) != 0);
      __pyx_t_4 = __pyx_t_3;
    } else {
      __pyx_t_4 = __pyx_t_2;
    }
    if (!__pyx_t_4) break;

    /* "axon/_loader.py":692
 *         ch = next_char(self)
 *         while ch >= '0' and ch <= '9':
 *             ch = next_char(self)             # <<<<<<<<<<<<<<
 * 
 *         if ch == '.':
 */
    __pyx_v_ch = next_char(__pyx_v_self);
  }

  /* "axon/_loader.py":723
 * 
 *             return val
 *         elif ch == ':':             # <<<<<<<<<<<<<<
 *             self.pos = pos0
 * 
 */
  switch (__pyx_v_ch) {

    /* "axon/_loader.py":694
 *             ch = next_char(self)
 * 
 *         if ch == '.':             # <<<<<<<<<<<<<<
 *             numtype = 2
 *             ch = next_char(self)
 */
    case 46:

    /* "axon/_loader.py":695
 * 
 *         if ch == '.':
 *             numtype = 2             # <<<<<<<<<<<<<<
 *             ch = next_char(self)
 *             while ch >= '0' and ch <= '9':
 */
    __pyx_v_numtype = 2;

    /* "axon/_loader.py":696
 *         if ch == '.':
 *             numtype = 2
 *             ch = next_char(self)             # <<<<<<<<<<<<<<
 *             while ch >= '0' and ch <= '9':
 *                 ch = next_char(self)
 */
    __pyx_v_ch = next_char(__pyx_v_self);

    /* "axon/_loader.py":697
 *             numtype = 2
 *             ch = next_char(self)
 *             while ch >= '0' and ch <= '9':             # <<<<<<<<<<<<<<
 *                 ch = next_char(self)
 *         elif ch == '-':
 */
    while (1) {
      __pyx_t_4 = ((__pyx_v_ch >= 48) != 0);
      if (__pyx_t_4) {
        __pyx_t_2 = ((__pyx_v_ch <= 57) != 0);
        __pyx_t_3 = __pyx_t_2;
      } else {
        __pyx_t_3 = __pyx_t_4;
      }
      if (!__pyx_t_3) break;

      /* "axon/_loader.py":698
 *             ch = next_char(self)
 *             while ch >= '0' and ch <= '9':
 *                 ch = next_char(self)             # <<<<<<<<<<<<<<
 *         elif ch == '-':
 *             self.pos = pos0
 */
      __pyx_v_ch = next_char(__pyx_v_self);
    }
    break;

    /* "axon/_loader.py":699
 *             while ch >= '0' and ch <= '9':
 *                 ch = next_char(self)
 *         elif ch == '-':             # <<<<<<<<<<<<<<
 *             self.pos = pos0
 * 
 */
    case 45:

    /* "axon/_loader.py":700
 *                 ch = next_char(self)
 *         elif ch == '-':
 *             self.pos = pos0             # <<<<<<<<<<<<<<
 * 
 *             v = self.get_date()
 */
    __pyx_v_self->pos = __pyx_v_pos0;

    /* "axon/_loader.py":702
 *             self.pos = pos0
 * 
 *             v = self.get_date()             # <<<<<<<<<<<<<<
 *             if v < 0:
 *                 errors.error_invalid_datetime(self)
 */
    __pyx_v_v = __pyx_f_4axon_7_loader_6Loader_get_date(__pyx_v_self);

    /* "axon/_loader.py":703
 * 
 *             v = self.get_date()
 *             if v < 0:             # <<<<<<<<<<<<<<
 *                 errors.error_invalid_datetime(self)
 * 
 */
    __pyx_t_3 = ((__pyx_v_v < 0) != 0);
    if (__pyx_t_3) {

      /* "axon/_loader.py":704
 *             v = self.get_date()
 *             if v < 0:
 *                 errors.error_invalid_datetime(self)             # <<<<<<<<<<<<<<
 * 
 *             ch = current_char(self)
 */
      __pyx_t_5 = __Pyx_GetModuleGlobalName(__pyx_n_s__errors); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 704; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_24); if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 704; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_5 = PyTuple_New(1); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 704; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_INCREF(((PyObject *)__pyx_v_self));
      PyTuple_SET_ITEM(__pyx_t_5, 0, ((PyObject *)__pyx_v_self));
      __Pyx_GIVEREF(((PyObject *)__pyx_v_self));
      __pyx_t_7 = PyObject_Call(__pyx_t_6, ((PyObject *)__pyx_t_5), NULL); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 704; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_DECREF(((PyObject *)__pyx_t_5)); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      goto __pyx_L7;
    }
    __pyx_L7:;

    /* "axon/_loader.py":706
 *                 errors.error_invalid_datetime(self)
 * 
 *             ch = current_char(self)             # <<<<<<<<<<<<<<
 *             if ch == 'T':
 *                 skip_char(self)
 */
    __pyx_v_ch = current_char(__pyx_v_self);

    /* "axon/_loader.py":707
 * 
 *             ch = current_char(self)
 *             if ch == 'T':             # <<<<<<<<<<<<<<
 *                 skip_char(self)
 *                 v = self.get_time()
 */
    __pyx_t_3 = ((__pyx_v_ch == 84) != 0);
    if (__pyx_t_3) {

      /* "axon/_loader.py":708
 *             ch = current_char(self)
 *             if ch == 'T':
 *                 skip_char(self)             # <<<<<<<<<<<<<<
 *                 v = self.get_time()
 *                 if v < 0:
 */
      skip_char(__pyx_v_self);

      /* "axon/_loader.py":709
 *             if ch == 'T':
 *                 skip_char(self)
 *                 v = self.get_time()             # <<<<<<<<<<<<<<
 *                 if v < 0:
 *                     errors.error_invalid_datetime(self)
 */
      __pyx_v_v = __pyx_f_4axon_7_loader_6Loader_get_time(__pyx_v_self);

      /* "axon/_loader.py":710
 *                 skip_char(self)
 *                 v = self.get_time()
 *                 if v < 0:             # <<<<<<<<<<<<<<
 *                     errors.error_invalid_datetime(self)
 * 
 */
      __pyx_t_3 = ((__pyx_v_v < 0) != 0);
      if (__pyx_t_3) {

        /* "axon/_loader.py":711
 *                 v = self.get_time()
 *                 if v < 0:
 *                     errors.error_invalid_datetime(self)             # <<<<<<<<<<<<<<
 * 
 *                 tzinfo = self.get_tzinfo()
 */
        __pyx_t_7 = __Pyx_GetModuleGlobalName(__pyx_n_s__errors); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 711; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_7);
        __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_24); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 711; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        __pyx_t_7 = PyTuple_New(1); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 711; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_INCREF(((PyObject *)__pyx_v_self));
        PyTuple_SET_ITEM(__pyx_t_7, 0, ((PyObject *)__pyx_v_self));
        __Pyx_GIVEREF(((PyObject *)__pyx_v_self));
        __pyx_t_6 = PyObject_Call(__pyx_t_5, ((PyObject *)__pyx_t_7), NULL); if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 711; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_DECREF(((PyObject *)__pyx_t_7)); __pyx_t_7 = 0;
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        goto __pyx_L9;
      }
      __pyx_L9:;

      /* "axon/_loader.py":713
 *                     errors.error_invalid_datetime(self)
 * 
 *                 tzinfo = self.get_tzinfo()             # <<<<<<<<<<<<<<
 * 
 *                 val = self.sbuilder.create_datetime(
 */
      __pyx_t_6 = __pyx_f_4axon_7_loader_6Loader_get_tzinfo(__pyx_v_self); if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 713; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_v_tzinfo = __pyx_t_6;
      __pyx_t_6 = 0;

      /* "axon/_loader.py":716
 * 
 *                 val = self.sbuilder.create_datetime(
 *                             self.da[0], self.da[1], self.da[2],             # <<<<<<<<<<<<<<
 *                             self.ta[0], self.ta[1], self.ta[2], self.ta[3], tzinfo)
 *             else:
 */
      if (unlikely(((PyObject *)__pyx_v_self->da) == Py_None)) {
        PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
        {__pyx_filename = __pyx_f[0]; __pyx_lineno = 716; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      }
      __pyx_t_1 = __Pyx_PyInt_AsInt(PyList_GET_ITEM(__pyx_v_self->da, 0)); if (unlikely((__pyx_t_1 == (int)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 716; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      if (unlikely(((PyObject *)__pyx_v_self->da) == Py_None)) {
        PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
        {__pyx_filename = __pyx_f[0]; __pyx_lineno = 716; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      }
      __pyx_t_8 = __Pyx_PyInt_AsInt(PyList_GET_ITEM(__pyx_v_self->da, 1)); if (unlikely((__pyx_t_8 == (int)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 716; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      if (unlikely(((PyObject *)__pyx_v_self->da) == Py_None)) {
        PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
        {__pyx_filename = __pyx_f[0]; __pyx_lineno = 716; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      }
      __pyx_t_9 = __Pyx_PyInt_AsInt(PyList_GET_ITEM(__pyx_v_self->da, 2)); if (unlikely((__pyx_t_9 == (int)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 716; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

      /* "axon/_loader.py":717
 *                 val = self.sbuilder.create_datetime(
 *                             self.da[0], self.da[1], self.da[2],
 *                             self.ta[0], self.ta[1], self.ta[2], self.ta[3], tzinfo)             # <<<<<<<<<<<<<<
 *             else:
 *                 val = self.sbuilder.create_date(
 */
      if (unlikely(((PyObject *)__pyx_v_self->ta) == Py_None)) {
        PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
        {__pyx_filename = __pyx_f[0]; __pyx_lineno = 717; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      }
      __pyx_t_10 = __Pyx_PyInt_AsInt(PyList_GET_ITEM(__pyx_v_self->ta, 0)); if (unlikely((__pyx_t_10 == (int)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 717; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      if (unlikely(((PyObject *)__pyx_v_self->ta) == Py_None)) {
        PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
        {__pyx_filename = __pyx_f[0]; __pyx_lineno = 717; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      }
      __pyx_t_11 = __Pyx_PyInt_AsInt(PyList_GET_ITEM(__pyx_v_self->ta, 1)); if (unlikely((__pyx_t_11 == (int)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 717; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      if (unlikely(((PyObject *)__pyx_v_self->ta) == Py_None)) {
        PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
        {__pyx_filename = __pyx_f[0]; __pyx_lineno = 717; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      }
      __pyx_t_12 = __Pyx_PyInt_AsInt(PyList_GET_ITEM(__pyx_v_self->ta, 2)); if (unlikely((__pyx_t_12 == (int)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 717; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      if (unlikely(((PyObject *)__pyx_v_self->ta) == Py_None)) {
        PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
        {__pyx_filename = __pyx_f[0]; __pyx_lineno = 717; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      }
      __pyx_t_13 = __Pyx_PyInt_AsInt(PyList_GET_ITEM(__pyx_v_self->ta, 3)); if (unlikely((__pyx_t_13 == (int)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 717; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __pyx_t_6 = __pyx_v_self->sbuilder->create_datetime(__pyx_t_1, __pyx_t_8, __pyx_t_9, __pyx_t_10, __pyx_t_11, __pyx_t_12, __pyx_t_13, __pyx_v_tzinfo); if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 715; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_v_val = __pyx_t_6;
      __pyx_t_6 = 0;
      goto __pyx_L8;
    }
    /*else*/ {

      /* "axon/_loader.py":720
 *             else:
 *                 val = self.sbuilder.create_date(
 *                             self.da[0], self.da[1], self.da[2])             # <<<<<<<<<<<<<<
 * 
 *             return val
 */
      if (unlikely(((PyObject *)__pyx_v_self->da) == Py_None)) {
        PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
        {__pyx_filename = __pyx_f[0]; __pyx_lineno = 720; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      }
      __pyx_t_13 = __Pyx_PyInt_AsInt(PyList_GET_ITEM(__pyx_v_self->da, 0)); if (unlikely((__pyx_t_13 == (int)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 720; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      if (unlikely(((PyObject *)__pyx_v_self->da) == Py_None)) {
        PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
        {__pyx_filename = __pyx_f[0]; __pyx_lineno = 720; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      }
      __pyx_t_12 = __Pyx_PyInt_AsInt(PyList_GET_ITEM(__pyx_v_self->da, 1)); if (unlikely((__pyx_t_12 == (int)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 720; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      if (unlikely(((PyObject *)__pyx_v_self->da) == Py_None)) {
        PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
        {__pyx_filename = __pyx_f[0]; __pyx_lineno = 720; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      }
      __pyx_t_11 = __Pyx_PyInt_AsInt(PyList_GET_ITEM(__pyx_v_self->da, 2)); if (unlikely((__pyx_t_11 == (int)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 720; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __pyx_t_6 = __pyx_v_self->sbuilder->create_date(__pyx_t_13, __pyx_t_12, __pyx_t_11); if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 719; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_v_val = __pyx_t_6;
      __pyx_t_6 = 0;
    }
    __pyx_L8:;

    /* "axon/_loader.py":722
 *                             self.da[0], self.da[1], self.da[2])
 * 
 *             return val             # <<<<<<<<<<<<<<
 *         elif ch == ':':
 *             self.pos = pos0
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_v_val);
    __pyx_r = __pyx_v_val;
    goto __pyx_L0;
    break;

    /* "axon/_loader.py":723
 * 
 *             return val
 *         elif ch == ':':             # <<<<<<<<<<<<<<
 *             self.pos = pos0
 * 
 */
    case 58:

    /* "axon/_loader.py":724
 *             return val
 *         elif ch == ':':
 *             self.pos = pos0             # <<<<<<<<<<<<<<
 * 
 *             v = self.get_time()
 */
    __pyx_v_self->pos = __pyx_v_pos0;

    /* "axon/_loader.py":726
 *             self.pos = pos0
 * 
 *             v = self.get_time()             # <<<<<<<<<<<<<<
 *             if v < 0:
 *                 errors.error_invalid_time(self)
 */
    __pyx_v_v = __pyx_f_4axon_7_loader_6Loader_get_time(__pyx_v_self);

    /* "axon/_loader.py":727
 * 
 *             v = self.get_time()
 *             if v < 0:             # <<<<<<<<<<<<<<
 *                 errors.error_invalid_time(self)
 * 
 */
    __pyx_t_3 = ((__pyx_v_v < 0) != 0);
    if (__pyx_t_3) {

      /* "axon/_loader.py":728
 *             v = self.get_time()
 *             if v < 0:
 *                 errors.error_invalid_time(self)             # <<<<<<<<<<<<<<
 * 
 *             tzinfo = self.get_tzinfo()
 */
      __pyx_t_6 = __Pyx_GetModuleGlobalName(__pyx_n_s__errors); if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 728; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s__error_invalid_time); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 728; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_t_6 = PyTuple_New(1); if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 728; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_INCREF(((PyObject *)__pyx_v_self));
      PyTuple_SET_ITEM(__pyx_t_6, 0, ((PyObject *)__pyx_v_self));
      __Pyx_GIVEREF(((PyObject *)__pyx_v_self));
      __pyx_t_5 = PyObject_Call(__pyx_t_7, ((PyObject *)__pyx_t_6), NULL); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 728; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_DECREF(((PyObject *)__pyx_t_6)); __pyx_t_6 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      goto __pyx_L10;
    }
    __pyx_L10:;

    /* "axon/_loader.py":730
 *                 errors.error_invalid_time(self)
 * 
 *             tzinfo = self.get_tzinfo()             # <<<<<<<<<<<<<<
 * 
 *             val = self.sbuilder.create_time(self.ta[0], self.ta[1], self.ta[2], self.ta[3], tzinfo)
 */
    __pyx_t_5 = __pyx_f_4axon_7_loader_6Loader_get_tzinfo(__pyx_v_self); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 730; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_v_tzinfo = __pyx_t_5;
    __pyx_t_5 = 0;

    /* "axon/_loader.py":732
 *             tzinfo = self.get_tzinfo()
 * 
 *             val = self.sbuilder.create_time(self.ta[0], self.ta[1], self.ta[2], self.ta[3], tzinfo)             # <<<<<<<<<<<<<<
 *             return val
 * 
 */
    if (unlikely(((PyObject *)__pyx_v_self->ta) == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      {__pyx_filename = __pyx_f[0]; __pyx_lineno = 732; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    }
    __pyx_t_11 = __Pyx_PyInt_AsInt(PyList_GET_ITEM(__pyx_v_self->ta, 0)); if (unlikely((__pyx_t_11 == (int)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 732; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    if (unlikely(((PyObject *)__pyx_v_self->ta) == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      {__pyx_filename = __pyx_f[0]; __pyx_lineno = 732; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    }
    __pyx_t_12 = __Pyx_PyInt_AsInt(PyList_GET_ITEM(__pyx_v_self->ta, 1)); if (unlikely((__pyx_t_12 == (int)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 732; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    if (unlikely(((PyObject *)__pyx_v_self->ta) == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      {__pyx_filename = __pyx_f[0]; __pyx_lineno = 732; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    }
    __pyx_t_13 = __Pyx_PyInt_AsInt(PyList_GET_ITEM(__pyx_v_self->ta, 2)); if (unlikely((__pyx_t_13 == (int)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 732; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    if (unlikely(((PyObject *)__pyx_v_self->ta) == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      {__pyx_filename = __pyx_f[0]; __pyx_lineno = 732; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    }
    __pyx_t_10 = __Pyx_PyInt_AsInt(PyList_GET_ITEM(__pyx_v_self->ta, 3)); if (unlikely((__pyx_t_10 == (int)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 732; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __pyx_t_5 = __pyx_v_self->sbuilder->create_time(__pyx_t_11, __pyx_t_12, __pyx_t_13, __pyx_t_10, __pyx_v_tzinfo); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 732; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_v_val = __pyx_t_5;
    __pyx_t_5 = 0;

    /* "axon/_loader.py":733
 * 
 *             val = self.sbuilder.create_time(self.ta[0], self.ta[1], self.ta[2], self.ta[3], tzinfo)
 *             return val             # <<<<<<<<<<<<<<
 * 
 *         if ch == 'e' or ch == 'E':
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_v_val);
    __pyx_r = __pyx_v_val;
    goto __pyx_L0;
    break;
  }

  /* "axon/_loader.py":735
 *             return val
 * 
 *         if ch == 'e' or ch == 'E':             # <<<<<<<<<<<<<<
 *             numtype = 2
 *             ch = next_char(self)
 */
  switch (__pyx_v_ch) {
    case 101:
    case 69:

    /* "axon/_loader.py":736
 * 
 *         if ch == 'e' or ch == 'E':
 *             numtype = 2             # <<<<<<<<<<<<<<
 *             ch = next_char(self)
 *             if ch == '-' or ch == '+':
 */
    __pyx_v_numtype = 2;

    /* "axon/_loader.py":737
 *         if ch == 'e' or ch == 'E':
 *             numtype = 2
 *             ch = next_char(self)             # <<<<<<<<<<<<<<
 *             if ch == '-' or ch == '+':
 *                 ch = next_char(self)
 */
    __pyx_v_ch = next_char(__pyx_v_self);

    /* "axon/_loader.py":738
 *             numtype = 2
 *             ch = next_char(self)
 *             if ch == '-' or ch == '+':             # <<<<<<<<<<<<<<
 *                 ch = next_char(self)
 *             if ch >= '0' and ch <= '9':
 */
    __pyx_t_3 = ((__pyx_v_ch == 45) != 0);
    if (!__pyx_t_3) {
      __pyx_t_4 = ((__pyx_v_ch == 43) != 0);
      __pyx_t_2 = __pyx_t_4;
    } else {
      __pyx_t_2 = __pyx_t_3;
    }
    if (__pyx_t_2) {

      /* "axon/_loader.py":739
 *             ch = next_char(self)
 *             if ch == '-' or ch == '+':
 *                 ch = next_char(self)             # <<<<<<<<<<<<<<
 *             if ch >= '0' and ch <= '9':
 *                 ch = next_char(self)
 */
      __pyx_v_ch = next_char(__pyx_v_self);
      goto __pyx_L11;
    }
    __pyx_L11:;

    /* "axon/_loader.py":740
 *             if ch == '-' or ch == '+':
 *                 ch = next_char(self)
 *             if ch >= '0' and ch <= '9':             # <<<<<<<<<<<<<<
 *                 ch = next_char(self)
 *                 while ch >= '0' and ch <= '9':
 */
    __pyx_t_2 = ((__pyx_v_ch >= 48) != 0);
    if (__pyx_t_2) {
      __pyx_t_3 = ((__pyx_v_ch <= 57) != 0);
      __pyx_t_4 = __pyx_t_3;
    } else {
      __pyx_t_4 = __pyx_t_2;
    }
    if (__pyx_t_4) {

      /* "axon/_loader.py":741
 *                 ch = next_char(self)
 *             if ch >= '0' and ch <= '9':
 *                 ch = next_char(self)             # <<<<<<<<<<<<<<
 *                 while ch >= '0' and ch <= '9':
 *                     ch = next_char(self)
 */
      __pyx_v_ch = next_char(__pyx_v_self);

      /* "axon/_loader.py":742
 *             if ch >= '0' and ch <= '9':
 *                 ch = next_char(self)
 *                 while ch >= '0' and ch <= '9':             # <<<<<<<<<<<<<<
 *                     ch = next_char(self)
 *             else:
 */
      while (1) {
        __pyx_t_4 = ((__pyx_v_ch >= 48) != 0);
        if (__pyx_t_4) {
          __pyx_t_2 = ((__pyx_v_ch <= 57) != 0);
          __pyx_t_3 = __pyx_t_2;
        } else {
          __pyx_t_3 = __pyx_t_4;
        }
        if (!__pyx_t_3) break;

        /* "axon/_loader.py":743
 *                 ch = next_char(self)
 *                 while ch >= '0' and ch <= '9':
 *                     ch = next_char(self)             # <<<<<<<<<<<<<<
 *             else:
 *                 errors.error_getnumber(self)
 */
        __pyx_v_ch = next_char(__pyx_v_self);
      }
      goto __pyx_L12;
    }
    /*else*/ {

      /* "axon/_loader.py":745
 *                     ch = next_char(self)
 *             else:
 *                 errors.error_getnumber(self)             # <<<<<<<<<<<<<<
 * 
 *         text = get_token(self, pos0)
 */
      __pyx_t_5 = __Pyx_GetModuleGlobalName(__pyx_n_s__errors); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 745; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s__error_getnumber); if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 745; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_5 = PyTuple_New(1); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 745; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_INCREF(((PyObject *)__pyx_v_self));
      PyTuple_SET_ITEM(__pyx_t_5, 0, ((PyObject *)__pyx_v_self));
      __Pyx_GIVEREF(((PyObject *)__pyx_v_self));
      __pyx_t_7 = PyObject_Call(__pyx_t_6, ((PyObject *)__pyx_t_5), NULL); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 745; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_DECREF(((PyObject *)__pyx_t_5)); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    }
    __pyx_L12:;
    break;
  }

  /* "axon/_loader.py":747
 *                 errors.error_getnumber(self)
 * 
 *         text = get_token(self, pos0)             # <<<<<<<<<<<<<<
 * 
 *         if ch == '$':
 */
  __pyx_t_7 = ((PyObject *)get_token(__pyx_v_self, __pyx_v_pos0)); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 747; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_v_text = ((PyObject*)__pyx_t_7);
  __pyx_t_7 = 0;

  /* "axon/_loader.py":749
 *         text = get_token(self, pos0)
 * 
 *         if ch == '$':             # <<<<<<<<<<<<<<
 *             next_char(self)
 *             return self.sbuilder.create_decimal(text)
 */
  __pyx_t_3 = ((__pyx_v_ch == 36) != 0);
  if (__pyx_t_3) {

    /* "axon/_loader.py":750
 * 
 *         if ch == '$':
 *             next_char(self)             # <<<<<<<<<<<<<<
 *             return self.sbuilder.create_decimal(text)
 * 
 */
    next_char(__pyx_v_self);

    /* "axon/_loader.py":751
 *         if ch == '$':
 *             next_char(self)
 *             return self.sbuilder.create_decimal(text)             # <<<<<<<<<<<<<<
 * 
 *         if numtype == 1:
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_7 = __pyx_v_self->sbuilder->create_decimal(__pyx_v_text); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 751; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_r = __pyx_t_7;
    __pyx_t_7 = 0;
    goto __pyx_L0;
    goto __pyx_L15;
  }
  __pyx_L15:;

  /* "axon/_loader.py":753
 *             return self.sbuilder.create_decimal(text)
 * 
 *         if numtype == 1:             # <<<<<<<<<<<<<<
 *             return self.sbuilder.create_int(text)
 *         else:
 */
  __pyx_t_3 = ((__pyx_v_numtype == 1) != 0);
  if (__pyx_t_3) {

    /* "axon/_loader.py":754
 * 
 *         if numtype == 1:
 *             return self.sbuilder.create_int(text)             # <<<<<<<<<<<<<<
 *         else:
 *             return self.sbuilder.create_float(text)
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_7 = __pyx_v_self->sbuilder->create_int(__pyx_v_text); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 754; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_r = __pyx_t_7;
    __pyx_t_7 = 0;
    goto __pyx_L0;
    goto __pyx_L16;
  }
  /*else*/ {

    /* "axon/_loader.py":756
 *             return self.sbuilder.create_int(text)
 *         else:
 *             return self.sbuilder.create_float(text)             # <<<<<<<<<<<<<<
 *     #
 *     def get_name(self):
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_7 = __pyx_v_self->sbuilder->create_float(__pyx_v_text); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 756; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_r = __pyx_t_7;
    __pyx_t_7 = 0;
    goto __pyx_L0;
  }
  __pyx_L16:;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("axon._loader.Loader.get_number", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_text);
  __Pyx_XDECREF(__pyx_v_tzinfo);
  __Pyx_XDECREF(__pyx_v_val);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_loader.py":758
 *             return self.sbuilder.create_float(text)
 *     #
 *     def get_name(self):             # <<<<<<<<<<<<<<
 *         pos0 = self.pos
 *         ch = next_char(self)
 */

static PyObject *__pyx_f_4axon_7_loader_6Loader_get_name(struct __pyx_obj_4axon_7_loader_Loader *__pyx_v_self) {
  Py_UCS4 __pyx_v_ch;
  int __pyx_v_pos0;
  PyObject *__pyx_v_name0 = NULL;
  PyObject *__pyx_v_name = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  int __pyx_t_3;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_name", 0);

  /* "axon/_loader.py":759
 *     #
 *     def get_name(self):
 *         pos0 = self.pos             # <<<<<<<<<<<<<<
 *         ch = next_char(self)
 *         while ch.isalnum() or ch == '_':
 */
  __pyx_t_1 = __pyx_v_self->pos;
  __pyx_v_pos0 = __pyx_t_1;

  /* "axon/_loader.py":760
 *     def get_name(self):
 *         pos0 = self.pos
 *         ch = next_char(self)             # <<<<<<<<<<<<<<
 *         while ch.isalnum() or ch == '_':
 *             ch = next_char(self)
 */
  __pyx_v_ch = next_char(__pyx_v_self);

  /* "axon/_loader.py":761
 *         pos0 = self.pos
 *         ch = next_char(self)
 *         while ch.isalnum() or ch == '_':             # <<<<<<<<<<<<<<
 *             ch = next_char(self)
 * 
 */
  while (1) {
    __pyx_t_2 = Py_UNICODE_ISALNUM(__pyx_v_ch); 
    if (!(__pyx_t_2 != 0)) {
      __pyx_t_3 = (__pyx_v_ch == 95);
      __pyx_t_4 = __pyx_t_3;
    } else {
      __pyx_t_4 = (__pyx_t_2 != 0);
    }
    if (!__pyx_t_4) break;

    /* "axon/_loader.py":762
 *         ch = next_char(self)
 *         while ch.isalnum() or ch == '_':
 *             ch = next_char(self)             # <<<<<<<<<<<<<<
 * 
 *         name0 = get_token(self, pos0)
 */
    __pyx_v_ch = next_char(__pyx_v_self);
  }

  /* "axon/_loader.py":764
 *             ch = next_char(self)
 * 
 *         name0 = get_token(self, pos0)             # <<<<<<<<<<<<<<
 *         #name = name_cache.get(name0, None)
 *         name = dict_get(name_cache, name0, None)
 */
  __pyx_t_5 = ((PyObject *)get_token(__pyx_v_self, __pyx_v_pos0)); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 764; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_v_name0 = ((PyObject*)__pyx_t_5);
  __pyx_t_5 = 0;

  /* "axon/_loader.py":766
 *         name0 = get_token(self, pos0)
 *         #name = name_cache.get(name0, None)
 *         name = dict_get(name_cache, name0, None)             # <<<<<<<<<<<<<<
 *         if name is None:
 *             name_cache[name0] = name0
 */
  __pyx_t_5 = ((PyObject *)__pyx_v_4axon_8_objects_name_cache);
  __Pyx_INCREF(__pyx_t_5);
  __pyx_t_6 = __pyx_f_4axon_7_loader_dict_get(__pyx_t_5, ((PyObject *)__pyx_v_name0), Py_None); if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 766; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_v_name = __pyx_t_6;
  __pyx_t_6 = 0;

  /* "axon/_loader.py":767
 *         #name = name_cache.get(name0, None)
 *         name = dict_get(name_cache, name0, None)
 *         if name is None:             # <<<<<<<<<<<<<<
 *             name_cache[name0] = name0
 *             return name0
 */
  __pyx_t_4 = (__pyx_v_name == Py_None);
  __pyx_t_2 = (__pyx_t_4 != 0);
  if (__pyx_t_2) {

    /* "axon/_loader.py":768
 *         name = dict_get(name_cache, name0, None)
 *         if name is None:
 *             name_cache[name0] = name0             # <<<<<<<<<<<<<<
 *             return name0
 *         else:
 */
    if (unlikely(((PyObject *)__pyx_v_4axon_8_objects_name_cache) == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      {__pyx_filename = __pyx_f[0]; __pyx_lineno = 768; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    }
    if (PyDict_SetItem(((PyObject *)__pyx_v_4axon_8_objects_name_cache), ((PyObject *)__pyx_v_name0), ((PyObject *)__pyx_v_name0)) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 768; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

    /* "axon/_loader.py":769
 *         if name is None:
 *             name_cache[name0] = name0
 *             return name0             # <<<<<<<<<<<<<<
 *         else:
 *             return name
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(((PyObject *)__pyx_v_name0));
    __pyx_r = ((PyObject *)__pyx_v_name0);
    goto __pyx_L0;
    goto __pyx_L5;
  }
  /*else*/ {

    /* "axon/_loader.py":771
 *             return name0
 *         else:
 *             return name             # <<<<<<<<<<<<<<
 *     #
 *     def get_key(self):
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_v_name);
    __pyx_r = __pyx_v_name;
    goto __pyx_L0;
  }
  __pyx_L5:;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("axon._loader.Loader.get_name", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_name0);
  __Pyx_XDECREF(__pyx_v_name);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_loader.py":773
 *             return name
 *     #
 *     def get_key(self):             # <<<<<<<<<<<<<<
 *         pos0 = self.pos
 *         ch = next_char(self)
 */

static PyObject *__pyx_f_4axon_7_loader_6Loader_get_key(struct __pyx_obj_4axon_7_loader_Loader *__pyx_v_self) {
  Py_UCS4 __pyx_v_ch;
  int __pyx_v_pos0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  int __pyx_t_3;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_key", 0);

  /* "axon/_loader.py":774
 *     #
 *     def get_key(self):
 *         pos0 = self.pos             # <<<<<<<<<<<<<<
 *         ch = next_char(self)
 *         while ch.isalnum() or ch == '_':
 */
  __pyx_t_1 = __pyx_v_self->pos;
  __pyx_v_pos0 = __pyx_t_1;

  /* "axon/_loader.py":775
 *     def get_key(self):
 *         pos0 = self.pos
 *         ch = next_char(self)             # <<<<<<<<<<<<<<
 *         while ch.isalnum() or ch == '_':
 *             ch = next_char(self)
 */
  __pyx_v_ch = next_char(__pyx_v_self);

  /* "axon/_loader.py":776
 *         pos0 = self.pos
 *         ch = next_char(self)
 *         while ch.isalnum() or ch == '_':             # <<<<<<<<<<<<<<
 *             ch = next_char(self)
 * 
 */
  while (1) {
    __pyx_t_2 = Py_UNICODE_ISALNUM(__pyx_v_ch); 
    if (!(__pyx_t_2 != 0)) {
      __pyx_t_3 = (__pyx_v_ch == 95);
      __pyx_t_4 = __pyx_t_3;
    } else {
      __pyx_t_4 = (__pyx_t_2 != 0);
    }
    if (!__pyx_t_4) break;

    /* "axon/_loader.py":777
 *         ch = next_char(self)
 *         while ch.isalnum() or ch == '_':
 *             ch = next_char(self)             # <<<<<<<<<<<<<<
 * 
 *         return get_token(self, pos0)
 */
    __pyx_v_ch = next_char(__pyx_v_self);
  }

  /* "axon/_loader.py":779
 *             ch = next_char(self)
 * 
 *         return get_token(self, pos0)             # <<<<<<<<<<<<<<
 *     #
 *     def try_get_name(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_5 = ((PyObject *)get_token(__pyx_v_self, __pyx_v_pos0)); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 779; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_r = __pyx_t_5;
  __pyx_t_5 = 0;
  goto __pyx_L0;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("axon._loader.Loader.get_key", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_loader.py":781
 *         return get_token(self, pos0)
 *     #
 *     def try_get_name(self):             # <<<<<<<<<<<<<<
 *         ch = current_char(self)
 *         if ch.isalpha() or ch == '_':
 */

static CYTHON_INLINE PyObject *__pyx_f_4axon_7_loader_6Loader_try_get_name(struct __pyx_obj_4axon_7_loader_Loader *__pyx_v_self) {
  Py_UCS4 __pyx_v_ch;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("try_get_name", 0);

  /* "axon/_loader.py":782
 *     #
 *     def try_get_name(self):
 *         ch = current_char(self)             # <<<<<<<<<<<<<<
 *         if ch.isalpha() or ch == '_':
 *             return self.get_name()
 */
  __pyx_v_ch = current_char(__pyx_v_self);

  /* "axon/_loader.py":783
 *     def try_get_name(self):
 *         ch = current_char(self)
 *         if ch.isalpha() or ch == '_':             # <<<<<<<<<<<<<<
 *             return self.get_name()
 *         elif ch == "'":
 */
  __pyx_t_1 = Py_UNICODE_ISALPHA(__pyx_v_ch); 
  if (!(__pyx_t_1 != 0)) {
    __pyx_t_2 = (__pyx_v_ch == 95);
    __pyx_t_3 = __pyx_t_2;
  } else {
    __pyx_t_3 = (__pyx_t_1 != 0);
  }
  if (__pyx_t_3) {

    /* "axon/_loader.py":784
 *         ch = current_char(self)
 *         if ch.isalpha() or ch == '_':
 *             return self.get_name()             # <<<<<<<<<<<<<<
 *         elif ch == "'":
 *             return self.get_string(ch)
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_4 = __pyx_f_4axon_7_loader_6Loader_get_name(__pyx_v_self); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 784; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_r = __pyx_t_4;
    __pyx_t_4 = 0;
    goto __pyx_L0;
    goto __pyx_L3;
  }

  /* "axon/_loader.py":785
 *         if ch.isalpha() or ch == '_':
 *             return self.get_name()
 *         elif ch == "'":             # <<<<<<<<<<<<<<
 *             return self.get_string(ch)
 *         else:
 */
  __pyx_t_3 = ((__pyx_v_ch == 39) != 0);
  if (__pyx_t_3) {

    /* "axon/_loader.py":786
 *             return self.get_name()
 *         elif ch == "'":
 *             return self.get_string(ch)             # <<<<<<<<<<<<<<
 *         else:
 *             return None
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_4 = __pyx_f_4axon_7_loader_6Loader_get_string(__pyx_v_self, __pyx_v_ch); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 786; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_r = __pyx_t_4;
    __pyx_t_4 = 0;
    goto __pyx_L0;
    goto __pyx_L3;
  }
  /*else*/ {

    /* "axon/_loader.py":788
 *             return self.get_string(ch)
 *         else:
 *             return None             # <<<<<<<<<<<<<<
 *     #
 *     def try_get_key(self):
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(Py_None);
    __pyx_r = Py_None;
    goto __pyx_L0;
  }
  __pyx_L3:;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("axon._loader.Loader.try_get_name", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_loader.py":790
 *             return None
 *     #
 *     def try_get_key(self):             # <<<<<<<<<<<<<<
 *         ch = current_char(self)
 *         if ch.isalpha() or ch == '_':
 */

static CYTHON_INLINE PyObject *__pyx_f_4axon_7_loader_6Loader_try_get_key(struct __pyx_obj_4axon_7_loader_Loader *__pyx_v_self) {
  Py_UCS4 __pyx_v_ch;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("try_get_key", 0);

  /* "axon/_loader.py":791
 *     #
 *     def try_get_key(self):
 *         ch = current_char(self)             # <<<<<<<<<<<<<<
 *         if ch.isalpha() or ch == '_':
 *             return self.get_key()
 */
  __pyx_v_ch = current_char(__pyx_v_self);

  /* "axon/_loader.py":792
 *     def try_get_key(self):
 *         ch = current_char(self)
 *         if ch.isalpha() or ch == '_':             # <<<<<<<<<<<<<<
 *             return self.get_key()
 *         elif ch == "'":
 */
  __pyx_t_1 = Py_UNICODE_ISALPHA(__pyx_v_ch); 
  if (!(__pyx_t_1 != 0)) {
    __pyx_t_2 = (__pyx_v_ch == 95);
    __pyx_t_3 = __pyx_t_2;
  } else {
    __pyx_t_3 = (__pyx_t_1 != 0);
  }
  if (__pyx_t_3) {

    /* "axon/_loader.py":793
 *         ch = current_char(self)
 *         if ch.isalpha() or ch == '_':
 *             return self.get_key()             # <<<<<<<<<<<<<<
 *         elif ch == "'":
 *             return self.get_string(ch)
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_4 = __pyx_f_4axon_7_loader_6Loader_get_key(__pyx_v_self); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 793; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_r = __pyx_t_4;
    __pyx_t_4 = 0;
    goto __pyx_L0;
    goto __pyx_L3;
  }

  /* "axon/_loader.py":794
 *         if ch.isalpha() or ch == '_':
 *             return self.get_key()
 *         elif ch == "'":             # <<<<<<<<<<<<<<
 *             return self.get_string(ch)
 *         elif ch == '"':
 */
  __pyx_t_3 = ((__pyx_v_ch == 39) != 0);
  if (__pyx_t_3) {

    /* "axon/_loader.py":795
 *             return self.get_key()
 *         elif ch == "'":
 *             return self.get_string(ch)             # <<<<<<<<<<<<<<
 *         elif ch == '"':
 *             return self.get_string(ch)
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_4 = __pyx_f_4axon_7_loader_6Loader_get_string(__pyx_v_self, __pyx_v_ch); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 795; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_r = __pyx_t_4;
    __pyx_t_4 = 0;
    goto __pyx_L0;
    goto __pyx_L3;
  }

  /* "axon/_loader.py":796
 *         elif ch == "'":
 *             return self.get_string(ch)
 *         elif ch == '"':             # <<<<<<<<<<<<<<
 *             return self.get_string(ch)
 *         else:
 */
  __pyx_t_3 = ((__pyx_v_ch == 34) != 0);
  if (__pyx_t_3) {

    /* "axon/_loader.py":797
 *             return self.get_string(ch)
 *         elif ch == '"':
 *             return self.get_string(ch)             # <<<<<<<<<<<<<<
 *         else:
 *             return None
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_4 = __pyx_f_4axon_7_loader_6Loader_get_string(__pyx_v_self, __pyx_v_ch); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 797; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_r = __pyx_t_4;
    __pyx_t_4 = 0;
    goto __pyx_L0;
    goto __pyx_L3;
  }
  /*else*/ {

    /* "axon/_loader.py":799
 *             return self.get_string(ch)
 *         else:
 *             return None             # <<<<<<<<<<<<<<
 *     #
 *     def try_get_label(self):
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(Py_None);
    __pyx_r = Py_None;
    goto __pyx_L0;
  }
  __pyx_L3:;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("axon._loader.Loader.try_get_key", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_loader.py":801
 *             return None
 *     #
 *     def try_get_label(self):             # <<<<<<<<<<<<<<
 *         pos0 = self.pos
 *         ch = current_char(self)
 */

static PyObject *__pyx_f_4axon_7_loader_6Loader_try_get_label(struct __pyx_obj_4axon_7_loader_Loader *__pyx_v_self) {
  Py_UCS4 __pyx_v_ch;
  int __pyx_v_pos0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  int __pyx_t_3;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("try_get_label", 0);

  /* "axon/_loader.py":802
 *     #
 *     def try_get_label(self):
 *         pos0 = self.pos             # <<<<<<<<<<<<<<
 *         ch = current_char(self)
 * 
 */
  __pyx_t_1 = __pyx_v_self->pos;
  __pyx_v_pos0 = __pyx_t_1;

  /* "axon/_loader.py":803
 *     def try_get_label(self):
 *         pos0 = self.pos
 *         ch = current_char(self)             # <<<<<<<<<<<<<<
 * 
 *         while ch.isalnum() or ch == '_':
 */
  __pyx_v_ch = current_char(__pyx_v_self);

  /* "axon/_loader.py":805
 *         ch = current_char(self)
 * 
 *         while ch.isalnum() or ch == '_':             # <<<<<<<<<<<<<<
 *             ch = next_char(self)
 * 
 */
  while (1) {
    __pyx_t_2 = Py_UNICODE_ISALNUM(__pyx_v_ch); 
    if (!(__pyx_t_2 != 0)) {
      __pyx_t_3 = (__pyx_v_ch == 95);
      __pyx_t_4 = __pyx_t_3;
    } else {
      __pyx_t_4 = (__pyx_t_2 != 0);
    }
    if (!__pyx_t_4) break;

    /* "axon/_loader.py":806
 * 
 *         while ch.isalnum() or ch == '_':
 *             ch = next_char(self)             # <<<<<<<<<<<<<<
 * 
 *         if self.pos == pos0:
 */
    __pyx_v_ch = next_char(__pyx_v_self);
  }

  /* "axon/_loader.py":808
 *             ch = next_char(self)
 * 
 *         if self.pos == pos0:             # <<<<<<<<<<<<<<
 *             errors.error_unexpected_value(self, 'after &')
 * 
 */
  __pyx_t_4 = ((__pyx_v_self->pos == __pyx_v_pos0) != 0);
  if (__pyx_t_4) {

    /* "axon/_loader.py":809
 * 
 *         if self.pos == pos0:
 *             errors.error_unexpected_value(self, 'after &')             # <<<<<<<<<<<<<<
 * 
 *         return get_token(self, pos0)
 */
    __pyx_t_5 = __Pyx_GetModuleGlobalName(__pyx_n_s__errors); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 809; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_25); if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 809; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_5 = PyTuple_New(2); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 809; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_INCREF(((PyObject *)__pyx_v_self));
    PyTuple_SET_ITEM(__pyx_t_5, 0, ((PyObject *)__pyx_v_self));
    __Pyx_GIVEREF(((PyObject *)__pyx_v_self));
    __Pyx_INCREF(((PyObject *)__pyx_kp_u_26));
    PyTuple_SET_ITEM(__pyx_t_5, 1, ((PyObject *)__pyx_kp_u_26));
    __Pyx_GIVEREF(((PyObject *)__pyx_kp_u_26));
    __pyx_t_7 = PyObject_Call(__pyx_t_6, ((PyObject *)__pyx_t_5), NULL); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 809; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_DECREF(((PyObject *)__pyx_t_5)); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    goto __pyx_L5;
  }
  __pyx_L5:;

  /* "axon/_loader.py":811
 *             errors.error_unexpected_value(self, 'after &')
 * 
 *         return get_token(self, pos0)             # <<<<<<<<<<<<<<
 *     #
 *     def get_unicode_hex(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_7 = ((PyObject *)get_token(__pyx_v_self, __pyx_v_pos0)); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 811; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_r = __pyx_t_7;
  __pyx_t_7 = 0;
  goto __pyx_L0;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("axon._loader.Loader.try_get_label", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_loader.py":813
 *         return get_token(self, pos0)
 *     #
 *     def get_unicode_hex(self):             # <<<<<<<<<<<<<<
 * 
 *         flag = 1
 */

static PyObject *__pyx_f_4axon_7_loader_6Loader_get_unicode_hex(struct __pyx_obj_4axon_7_loader_Loader *__pyx_v_self) {
  int __pyx_v_ch0;
  int __pyx_v_flag;
  Py_UCS4 __pyx_v_ch;
  int __pyx_v_val;
  CYTHON_UNUSED int __pyx_v_i;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  int __pyx_t_3;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_unicode_hex", 0);

  /* "axon/_loader.py":815
 *     def get_unicode_hex(self):
 * 
 *         flag = 1             # <<<<<<<<<<<<<<
 *         val = 0
 *         for i in range(4):
 */
  __pyx_v_flag = 1;

  /* "axon/_loader.py":816
 * 
 *         flag = 1
 *         val = 0             # <<<<<<<<<<<<<<
 *         for i in range(4):
 *             ch = current_char(self)
 */
  __pyx_v_val = 0;

  /* "axon/_loader.py":817
 *         flag = 1
 *         val = 0
 *         for i in range(4):             # <<<<<<<<<<<<<<
 *             ch = current_char(self)
 *             if ch >= '0' and ch <= '9':
 */
  for (__pyx_t_1 = 0; __pyx_t_1 < 4; __pyx_t_1+=1) {
    __pyx_v_i = __pyx_t_1;

    /* "axon/_loader.py":818
 *         val = 0
 *         for i in range(4):
 *             ch = current_char(self)             # <<<<<<<<<<<<<<
 *             if ch >= '0' and ch <= '9':
 *                     ch0 = ch
 */
    __pyx_v_ch = current_char(__pyx_v_self);

    /* "axon/_loader.py":819
 *         for i in range(4):
 *             ch = current_char(self)
 *             if ch >= '0' and ch <= '9':             # <<<<<<<<<<<<<<
 *                     ch0 = ch
 *                     #dig = ch0 - 48
 */
    __pyx_t_2 = ((__pyx_v_ch >= 48) != 0);
    if (__pyx_t_2) {
      __pyx_t_3 = ((__pyx_v_ch <= 57) != 0);
      __pyx_t_4 = __pyx_t_3;
    } else {
      __pyx_t_4 = __pyx_t_2;
    }
    if (__pyx_t_4) {

      /* "axon/_loader.py":820
 *             ch = current_char(self)
 *             if ch >= '0' and ch <= '9':
 *                     ch0 = ch             # <<<<<<<<<<<<<<
 *                     #dig = ch0 - 48
 *                     val = 16*val + (ch0 - 48)
 */
      __pyx_v_ch0 = __pyx_v_ch;

      /* "axon/_loader.py":822
 *                     ch0 = ch
 *                     #dig = ch0 - 48
 *                     val = 16*val + (ch0 - 48)             # <<<<<<<<<<<<<<
 *                     skip_char(self)
 *             elif ch >= 'a' and ch <= 'f':
 */
      __pyx_v_val = ((16 * __pyx_v_val) + (__pyx_v_ch0 - 48));

      /* "axon/_loader.py":823
 *                     #dig = ch0 - 48
 *                     val = 16*val + (ch0 - 48)
 *                     skip_char(self)             # <<<<<<<<<<<<<<
 *             elif ch >= 'a' and ch <= 'f':
 *                     ch0 = ch
 */
      skip_char(__pyx_v_self);
      goto __pyx_L5;
    }

    /* "axon/_loader.py":824
 *                     val = 16*val + (ch0 - 48)
 *                     skip_char(self)
 *             elif ch >= 'a' and ch <= 'f':             # <<<<<<<<<<<<<<
 *                     ch0 = ch
 *                     #dig = ch0 - 97 + 10
 */
    __pyx_t_4 = ((__pyx_v_ch >= 97) != 0);
    if (__pyx_t_4) {
      __pyx_t_2 = ((__pyx_v_ch <= 102) != 0);
      __pyx_t_3 = __pyx_t_2;
    } else {
      __pyx_t_3 = __pyx_t_4;
    }
    if (__pyx_t_3) {

      /* "axon/_loader.py":825
 *                     skip_char(self)
 *             elif ch >= 'a' and ch <= 'f':
 *                     ch0 = ch             # <<<<<<<<<<<<<<
 *                     #dig = ch0 - 97 + 10
 *                     val = 16*val + (ch0 - 87)
 */
      __pyx_v_ch0 = __pyx_v_ch;

      /* "axon/_loader.py":827
 *                     ch0 = ch
 *                     #dig = ch0 - 97 + 10
 *                     val = 16*val + (ch0 - 87)             # <<<<<<<<<<<<<<
 *                     skip_char(self)
 *             elif ch >= 'A' and ch <= 'F':
 */
      __pyx_v_val = ((16 * __pyx_v_val) + (__pyx_v_ch0 - 87));

      /* "axon/_loader.py":828
 *                     #dig = ch0 - 97 + 10
 *                     val = 16*val + (ch0 - 87)
 *                     skip_char(self)             # <<<<<<<<<<<<<<
 *             elif ch >= 'A' and ch <= 'F':
 *                     ch0 = ch
 */
      skip_char(__pyx_v_self);
      goto __pyx_L5;
    }

    /* "axon/_loader.py":829
 *                     val = 16*val + (ch0 - 87)
 *                     skip_char(self)
 *             elif ch >= 'A' and ch <= 'F':             # <<<<<<<<<<<<<<
 *                     ch0 = ch
 *                     #dig = ch0 - 65 + 10
 */
    __pyx_t_3 = ((__pyx_v_ch >= 65) != 0);
    if (__pyx_t_3) {
      __pyx_t_4 = ((__pyx_v_ch <= 70) != 0);
      __pyx_t_2 = __pyx_t_4;
    } else {
      __pyx_t_2 = __pyx_t_3;
    }
    if (__pyx_t_2) {

      /* "axon/_loader.py":830
 *                     skip_char(self)
 *             elif ch >= 'A' and ch <= 'F':
 *                     ch0 = ch             # <<<<<<<<<<<<<<
 *                     #dig = ch0 - 65 + 10
 *                     val = 16*val + (ch0 - 55)
 */
      __pyx_v_ch0 = __pyx_v_ch;

      /* "axon/_loader.py":832
 *                     ch0 = ch
 *                     #dig = ch0 - 65 + 10
 *                     val = 16*val + (ch0 - 55)             # <<<<<<<<<<<<<<
 *                     skip_char(self)
 *             else:
 */
      __pyx_v_val = ((16 * __pyx_v_val) + (__pyx_v_ch0 - 55));

      /* "axon/_loader.py":833
 *                     #dig = ch0 - 65 + 10
 *                     val = 16*val + (ch0 - 55)
 *                     skip_char(self)             # <<<<<<<<<<<<<<
 *             else:
 *                 flag = 0
 */
      skip_char(__pyx_v_self);
      goto __pyx_L5;
    }
    /*else*/ {

      /* "axon/_loader.py":835
 *                     skip_char(self)
 *             else:
 *                 flag = 0             # <<<<<<<<<<<<<<
 *                 break
 *         if flag:
 */
      __pyx_v_flag = 0;

      /* "axon/_loader.py":836
 *             else:
 *                 flag = 0
 *                 break             # <<<<<<<<<<<<<<
 *         if flag:
 *             return PyUnicode_FromOrdinal(val)
 */
      goto __pyx_L4_break;
    }
    __pyx_L5:;
  }
  __pyx_L4_break:;

  /* "axon/_loader.py":837
 *                 flag = 0
 *                 break
 *         if flag:             # <<<<<<<<<<<<<<
 *             return PyUnicode_FromOrdinal(val)
 *         else:
 */
  __pyx_t_2 = (__pyx_v_flag != 0);
  if (__pyx_t_2) {

    /* "axon/_loader.py":838
 *                 break
 *         if flag:
 *             return PyUnicode_FromOrdinal(val)             # <<<<<<<<<<<<<<
 *         else:
 *             errors.error(self, 'Invalid unicode character %r' % self.line[self.pos-4:self.pos+1])
 */
    __Pyx_XDECREF(((PyObject *)__pyx_r));
    __pyx_t_5 = ((PyObject *)PyUnicode_FromOrdinal(__pyx_v_val)); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 838; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_r = ((PyObject*)__pyx_t_5);
    __pyx_t_5 = 0;
    goto __pyx_L0;
    goto __pyx_L6;
  }
  /*else*/ {

    /* "axon/_loader.py":840
 *             return PyUnicode_FromOrdinal(val)
 *         else:
 *             errors.error(self, 'Invalid unicode character %r' % self.line[self.pos-4:self.pos+1])             # <<<<<<<<<<<<<<
 *     #
 *     #
 */
    __pyx_t_5 = __Pyx_GetModuleGlobalName(__pyx_n_s__errors); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 840; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s__error); if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 840; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(((PyObject *)__pyx_v_self->line) == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      {__pyx_filename = __pyx_f[0]; __pyx_lineno = 840; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    }
    __pyx_t_5 = __Pyx_PyUnicode_Substring(__pyx_v_self->line, (__pyx_v_self->pos - 4), (__pyx_v_self->pos + 1)); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 840; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(((PyObject *)__pyx_t_5));
    __pyx_t_7 = PyNumber_Remainder(((PyObject *)__pyx_kp_u_27), ((PyObject *)__pyx_t_5)); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 840; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(((PyObject *)__pyx_t_7));
    __Pyx_DECREF(((PyObject *)__pyx_t_5)); __pyx_t_5 = 0;
    __pyx_t_5 = PyTuple_New(2); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 840; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_INCREF(((PyObject *)__pyx_v_self));
    PyTuple_SET_ITEM(__pyx_t_5, 0, ((PyObject *)__pyx_v_self));
    __Pyx_GIVEREF(((PyObject *)__pyx_v_self));
    PyTuple_SET_ITEM(__pyx_t_5, 1, ((PyObject *)__pyx_t_7));
    __Pyx_GIVEREF(((PyObject *)__pyx_t_7));
    __pyx_t_7 = 0;
    __pyx_t_7 = PyObject_Call(__pyx_t_6, ((PyObject *)__pyx_t_5), NULL); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 840; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_DECREF(((PyObject *)__pyx_t_5)); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  }
  __pyx_L6:;

  __pyx_r = ((PyObject*)Py_None); __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("axon._loader.Loader.get_unicode_hex", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_loader.py":843
 *     #
 *     #
 *     def get_string(self, endch):             # <<<<<<<<<<<<<<
 *         text = None
 *         ch = next_char(self)
 */

static PyObject *__pyx_f_4axon_7_loader_6Loader_get_string(struct __pyx_obj_4axon_7_loader_Loader *__pyx_v_self, Py_UCS4 __pyx_v_endch) {
  PyObject *__pyx_v_text = 0;
  Py_UCS4 __pyx_v_ch;
  int __pyx_v_pos0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_string", 0);

  /* "axon/_loader.py":844
 *     #
 *     def get_string(self, endch):
 *         text = None             # <<<<<<<<<<<<<<
 *         ch = next_char(self)
 *         pos0 = self.pos
 */
  __Pyx_INCREF(Py_None);
  __pyx_v_text = ((PyObject*)Py_None);

  /* "axon/_loader.py":845
 *     def get_string(self, endch):
 *         text = None
 *         ch = next_char(self)             # <<<<<<<<<<<<<<
 *         pos0 = self.pos
 *         while 1:
 */
  __pyx_v_ch = next_char(__pyx_v_self);

  /* "axon/_loader.py":846
 *         text = None
 *         ch = next_char(self)
 *         pos0 = self.pos             # <<<<<<<<<<<<<<
 *         while 1:
 *             if ch == endch:
 */
  __pyx_t_1 = __pyx_v_self->pos;
  __pyx_v_pos0 = __pyx_t_1;

  /* "axon/_loader.py":847
 *         ch = next_char(self)
 *         pos0 = self.pos
 *         while 1:             # <<<<<<<<<<<<<<
 *             if ch == endch:
 *                 if text is None:
 */
  while (1) {
    if (!1) break;

    /* "axon/_loader.py":848
 *         pos0 = self.pos
 *         while 1:
 *             if ch == endch:             # <<<<<<<<<<<<<<
 *                 if text is None:
 *                     text = get_token(self, pos0)
 */
    __pyx_t_2 = ((__pyx_v_ch == __pyx_v_endch) != 0);
    if (__pyx_t_2) {

      /* "axon/_loader.py":849
 *         while 1:
 *             if ch == endch:
 *                 if text is None:             # <<<<<<<<<<<<<<
 *                     text = get_token(self, pos0)
 *                 else:
 */
      __pyx_t_2 = (__pyx_v_text == ((PyObject*)Py_None));
      __pyx_t_3 = (__pyx_t_2 != 0);
      if (__pyx_t_3) {

        /* "axon/_loader.py":850
 *             if ch == endch:
 *                 if text is None:
 *                     text = get_token(self, pos0)             # <<<<<<<<<<<<<<
 *                 else:
 *                     text += get_token(self, pos0)
 */
        __pyx_t_4 = ((PyObject *)get_token(__pyx_v_self, __pyx_v_pos0)); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 850; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(((PyObject *)__pyx_v_text));
        __pyx_v_text = ((PyObject*)__pyx_t_4);
        __pyx_t_4 = 0;
        goto __pyx_L6;
      }
      /*else*/ {

        /* "axon/_loader.py":852
 *                     text = get_token(self, pos0)
 *                 else:
 *                     text += get_token(self, pos0)             # <<<<<<<<<<<<<<
 *                 skip_char(self)
 *                 return text
 */
        __pyx_t_4 = ((PyObject *)get_token(__pyx_v_self, __pyx_v_pos0)); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 852; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_4);
        __pyx_t_5 = PyNumber_InPlaceAdd(((PyObject *)__pyx_v_text), __pyx_t_4); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 852; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(((PyObject *)__pyx_t_5));
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_DECREF(((PyObject *)__pyx_v_text));
        __pyx_v_text = ((PyObject*)__pyx_t_5);
        __pyx_t_5 = 0;
      }
      __pyx_L6:;

      /* "axon/_loader.py":853
 *                 else:
 *                     text += get_token(self, pos0)
 *                 skip_char(self)             # <<<<<<<<<<<<<<
 *                 return text
 * 
 */
      skip_char(__pyx_v_self);

      /* "axon/_loader.py":854
 *                     text += get_token(self, pos0)
 *                 skip_char(self)
 *                 return text             # <<<<<<<<<<<<<<
 * 
 *             elif ch == '\n' or ch == '\r':
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(((PyObject *)__pyx_v_text));
      __pyx_r = ((PyObject *)__pyx_v_text);
      goto __pyx_L0;
      goto __pyx_L5;
    }

    /* "axon/_loader.py":856
 *                 return text
 * 
 *             elif ch == '\n' or ch == '\r':             # <<<<<<<<<<<<<<
 *                 if text is None:
 *                     text = get_token(self, pos0)
 */
    switch (__pyx_v_ch) {
      case 10:
      case 13:
      __pyx_t_3 = 1;
      break;
      default:
      __pyx_t_3 = 0;
      break;
    }
    if (__pyx_t_3) {

      /* "axon/_loader.py":857
 * 
 *             elif ch == '\n' or ch == '\r':
 *                 if text is None:             # <<<<<<<<<<<<<<
 *                     text = get_token(self, pos0)
 *                 else:
 */
      __pyx_t_3 = (__pyx_v_text == ((PyObject*)Py_None));
      __pyx_t_2 = (__pyx_t_3 != 0);
      if (__pyx_t_2) {

        /* "axon/_loader.py":858
 *             elif ch == '\n' or ch == '\r':
 *                 if text is None:
 *                     text = get_token(self, pos0)             # <<<<<<<<<<<<<<
 *                 else:
 *                     text += get_token(self, pos0)
 */
        __pyx_t_5 = ((PyObject *)get_token(__pyx_v_self, __pyx_v_pos0)); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 858; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(((PyObject *)__pyx_v_text));
        __pyx_v_text = ((PyObject*)__pyx_t_5);
        __pyx_t_5 = 0;
        goto __pyx_L7;
      }
      /*else*/ {

        /* "axon/_loader.py":860
 *                     text = get_token(self, pos0)
 *                 else:
 *                     text += get_token(self, pos0)             # <<<<<<<<<<<<<<
 *                 text += '\n'
 * 
 */
        __pyx_t_5 = ((PyObject *)get_token(__pyx_v_self, __pyx_v_pos0)); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 860; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_5);
        __pyx_t_4 = PyNumber_InPlaceAdd(((PyObject *)__pyx_v_text), __pyx_t_5); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 860; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(((PyObject *)__pyx_t_4));
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_DECREF(((PyObject *)__pyx_v_text));
        __pyx_v_text = ((PyObject*)__pyx_t_4);
        __pyx_t_4 = 0;
      }
      __pyx_L7:;

      /* "axon/_loader.py":861
 *                 else:
 *                     text += get_token(self, pos0)
 *                 text += '\n'             # <<<<<<<<<<<<<<
 * 
 *                 self.next_line()
 */
      __pyx_t_4 = PyNumber_InPlaceAdd(((PyObject *)__pyx_v_text), ((PyObject *)__pyx_kp_u_22)); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 861; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(((PyObject *)__pyx_t_4));
      __Pyx_DECREF(((PyObject *)__pyx_v_text));
      __pyx_v_text = ((PyObject*)__pyx_t_4);
      __pyx_t_4 = 0;

      /* "axon/_loader.py":863
 *                 text += '\n'
 * 
 *                 self.next_line()             # <<<<<<<<<<<<<<
 *                 if self.eof:
 *                     errors.error_unexpected_end(self)
 */
      __pyx_f_4axon_7_loader_6Loader_next_line(__pyx_v_self);

      /* "axon/_loader.py":864
 * 
 *                 self.next_line()
 *                 if self.eof:             # <<<<<<<<<<<<<<
 *                     errors.error_unexpected_end(self)
 * 
 */
      __pyx_t_2 = (__pyx_v_self->eof != 0);
      if (__pyx_t_2) {

        /* "axon/_loader.py":865
 *                 self.next_line()
 *                 if self.eof:
 *                     errors.error_unexpected_end(self)             # <<<<<<<<<<<<<<
 * 
 *                 #self.skip_whitespace()
 */
        __pyx_t_4 = __Pyx_GetModuleGlobalName(__pyx_n_s__errors); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 865; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_4);
        __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_23); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 865; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __pyx_t_4 = PyTuple_New(1); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 865; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_INCREF(((PyObject *)__pyx_v_self));
        PyTuple_SET_ITEM(__pyx_t_4, 0, ((PyObject *)__pyx_v_self));
        __Pyx_GIVEREF(((PyObject *)__pyx_v_self));
        __pyx_t_6 = PyObject_Call(__pyx_t_5, ((PyObject *)__pyx_t_4), NULL); if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 865; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_DECREF(((PyObject *)__pyx_t_4)); __pyx_t_4 = 0;
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        goto __pyx_L8;
      }
      __pyx_L8:;

      /* "axon/_loader.py":869
 *                 #self.skip_whitespace()
 * 
 *                 pos0 = self.pos             # <<<<<<<<<<<<<<
 *                 ch = current_char(self)
 *             elif ch == '\\':
 */
      __pyx_t_1 = __pyx_v_self->pos;
      __pyx_v_pos0 = __pyx_t_1;

      /* "axon/_loader.py":870
 * 
 *                 pos0 = self.pos
 *                 ch = current_char(self)             # <<<<<<<<<<<<<<
 *             elif ch == '\\':
 *                 if text is None:
 */
      __pyx_v_ch = current_char(__pyx_v_self);
      goto __pyx_L5;
    }

    /* "axon/_loader.py":871
 *                 pos0 = self.pos
 *                 ch = current_char(self)
 *             elif ch == '\\':             # <<<<<<<<<<<<<<
 *                 if text is None:
 *                     text = get_token(self, pos0)
 */
    __pyx_t_2 = ((__pyx_v_ch == 92) != 0);
    if (__pyx_t_2) {

      /* "axon/_loader.py":872
 *                 ch = current_char(self)
 *             elif ch == '\\':
 *                 if text is None:             # <<<<<<<<<<<<<<
 *                     text = get_token(self, pos0)
 *                 else:
 */
      __pyx_t_2 = (__pyx_v_text == ((PyObject*)Py_None));
      __pyx_t_3 = (__pyx_t_2 != 0);
      if (__pyx_t_3) {

        /* "axon/_loader.py":873
 *             elif ch == '\\':
 *                 if text is None:
 *                     text = get_token(self, pos0)             # <<<<<<<<<<<<<<
 *                 else:
 *                     text += get_token(self, pos0)
 */
        __pyx_t_6 = ((PyObject *)get_token(__pyx_v_self, __pyx_v_pos0)); if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 873; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(((PyObject *)__pyx_v_text));
        __pyx_v_text = ((PyObject*)__pyx_t_6);
        __pyx_t_6 = 0;
        goto __pyx_L9;
      }
      /*else*/ {

        /* "axon/_loader.py":875
 *                     text = get_token(self, pos0)
 *                 else:
 *                     text += get_token(self, pos0)             # <<<<<<<<<<<<<<
 * 
 *                 ch = next_char(self)
 */
        __pyx_t_6 = ((PyObject *)get_token(__pyx_v_self, __pyx_v_pos0)); if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 875; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_6);
        __pyx_t_4 = PyNumber_InPlaceAdd(((PyObject *)__pyx_v_text), __pyx_t_6); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 875; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(((PyObject *)__pyx_t_4));
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_DECREF(((PyObject *)__pyx_v_text));
        __pyx_v_text = ((PyObject*)__pyx_t_4);
        __pyx_t_4 = 0;
      }
      __pyx_L9:;

      /* "axon/_loader.py":877
 *                     text += get_token(self, pos0)
 * 
 *                 ch = next_char(self)             # <<<<<<<<<<<<<<
 *                 if ch == endch:
 *                     if endch == "'":
 */
      __pyx_v_ch = next_char(__pyx_v_self);

      /* "axon/_loader.py":878
 * 
 *                 ch = next_char(self)
 *                 if ch == endch:             # <<<<<<<<<<<<<<
 *                     if endch == "'":
 *                         text += "'"
 */
      __pyx_t_3 = ((__pyx_v_ch == __pyx_v_endch) != 0);
      if (__pyx_t_3) {

        /* "axon/_loader.py":881
 *                     if endch == "'":
 *                         text += "'"
 *                     elif endch == '"':             # <<<<<<<<<<<<<<
 *                         text += '"'
 *                     skip_char(self)
 */
        switch (__pyx_v_endch) {

          /* "axon/_loader.py":879
 *                 ch = next_char(self)
 *                 if ch == endch:
 *                     if endch == "'":             # <<<<<<<<<<<<<<
 *                         text += "'"
 *                     elif endch == '"':
 */
          case 39:

          /* "axon/_loader.py":880
 *                 if ch == endch:
 *                     if endch == "'":
 *                         text += "'"             # <<<<<<<<<<<<<<
 *                     elif endch == '"':
 *                         text += '"'
 */
          __pyx_t_4 = PyNumber_InPlaceAdd(((PyObject *)__pyx_v_text), ((PyObject *)__pyx_kp_u_28)); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 880; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
          __Pyx_GOTREF(((PyObject *)__pyx_t_4));
          __Pyx_DECREF(((PyObject *)__pyx_v_text));
          __pyx_v_text = ((PyObject*)__pyx_t_4);
          __pyx_t_4 = 0;
          break;

          /* "axon/_loader.py":881
 *                     if endch == "'":
 *                         text += "'"
 *                     elif endch == '"':             # <<<<<<<<<<<<<<
 *                         text += '"'
 *                     skip_char(self)
 */
          case 34:

          /* "axon/_loader.py":882
 *                         text += "'"
 *                     elif endch == '"':
 *                         text += '"'             # <<<<<<<<<<<<<<
 *                     skip_char(self)
 *                 elif ch == '\n' or ch == '\r':
 */
          __pyx_t_4 = PyNumber_InPlaceAdd(((PyObject *)__pyx_v_text), ((PyObject *)__pyx_kp_u_29)); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 882; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
          __Pyx_GOTREF(((PyObject *)__pyx_t_4));
          __Pyx_DECREF(((PyObject *)__pyx_v_text));
          __pyx_v_text = ((PyObject*)__pyx_t_4);
          __pyx_t_4 = 0;
          break;
        }

        /* "axon/_loader.py":883
 *                     elif endch == '"':
 *                         text += '"'
 *                     skip_char(self)             # <<<<<<<<<<<<<<
 *                 elif ch == '\n' or ch == '\r':
 *                     if text is None:
 */
        skip_char(__pyx_v_self);
        goto __pyx_L10;
      }

      /* "axon/_loader.py":884
 *                         text += '"'
 *                     skip_char(self)
 *                 elif ch == '\n' or ch == '\r':             # <<<<<<<<<<<<<<
 *                     if text is None:
 *                         text = get_token(self, pos0)
 */
      switch (__pyx_v_ch) {
        case 10:
        case 13:
        __pyx_t_3 = 1;
        break;
        default:
        __pyx_t_3 = 0;
        break;
      }
      if (__pyx_t_3) {

        /* "axon/_loader.py":885
 *                     skip_char(self)
 *                 elif ch == '\n' or ch == '\r':
 *                     if text is None:             # <<<<<<<<<<<<<<
 *                         text = get_token(self, pos0)
 *                     else:
 */
        __pyx_t_3 = (__pyx_v_text == ((PyObject*)Py_None));
        __pyx_t_2 = (__pyx_t_3 != 0);
        if (__pyx_t_2) {

          /* "axon/_loader.py":886
 *                 elif ch == '\n' or ch == '\r':
 *                     if text is None:
 *                         text = get_token(self, pos0)             # <<<<<<<<<<<<<<
 *                     else:
 *                         text += get_token(self, pos0)
 */
          __pyx_t_4 = ((PyObject *)get_token(__pyx_v_self, __pyx_v_pos0)); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 886; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
          __Pyx_GOTREF(__pyx_t_4);
          __Pyx_DECREF(((PyObject *)__pyx_v_text));
          __pyx_v_text = ((PyObject*)__pyx_t_4);
          __pyx_t_4 = 0;
          goto __pyx_L11;
        }
        /*else*/ {

          /* "axon/_loader.py":888
 *                         text = get_token(self, pos0)
 *                     else:
 *                         text += get_token(self, pos0)             # <<<<<<<<<<<<<<
 * 
 *                     self.next_line()
 */
          __pyx_t_4 = ((PyObject *)get_token(__pyx_v_self, __pyx_v_pos0)); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 888; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
          __Pyx_GOTREF(__pyx_t_4);
          __pyx_t_6 = PyNumber_InPlaceAdd(((PyObject *)__pyx_v_text), __pyx_t_4); if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 888; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
          __Pyx_GOTREF(((PyObject *)__pyx_t_6));
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          __Pyx_DECREF(((PyObject *)__pyx_v_text));
          __pyx_v_text = ((PyObject*)__pyx_t_6);
          __pyx_t_6 = 0;
        }
        __pyx_L11:;

        /* "axon/_loader.py":890
 *                         text += get_token(self, pos0)
 * 
 *                     self.next_line()             # <<<<<<<<<<<<<<
 *                     if self.eof:
 *                         errors.error_unexpected_end(self)
 */
        __pyx_f_4axon_7_loader_6Loader_next_line(__pyx_v_self);

        /* "axon/_loader.py":891
 * 
 *                     self.next_line()
 *                     if self.eof:             # <<<<<<<<<<<<<<
 *                         errors.error_unexpected_end(self)
 *                 elif ch == 'n':
 */
        __pyx_t_2 = (__pyx_v_self->eof != 0);
        if (__pyx_t_2) {

          /* "axon/_loader.py":892
 *                     self.next_line()
 *                     if self.eof:
 *                         errors.error_unexpected_end(self)             # <<<<<<<<<<<<<<
 *                 elif ch == 'n':
 *                     text += "\n"
 */
          __pyx_t_6 = __Pyx_GetModuleGlobalName(__pyx_n_s__errors); if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 892; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
          __Pyx_GOTREF(__pyx_t_6);
          __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_23); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 892; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
          __Pyx_GOTREF(__pyx_t_4);
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
          __pyx_t_6 = PyTuple_New(1); if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 892; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
          __Pyx_GOTREF(__pyx_t_6);
          __Pyx_INCREF(((PyObject *)__pyx_v_self));
          PyTuple_SET_ITEM(__pyx_t_6, 0, ((PyObject *)__pyx_v_self));
          __Pyx_GIVEREF(((PyObject *)__pyx_v_self));
          __pyx_t_5 = PyObject_Call(__pyx_t_4, ((PyObject *)__pyx_t_6), NULL); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 892; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
          __Pyx_GOTREF(__pyx_t_5);
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          __Pyx_DECREF(((PyObject *)__pyx_t_6)); __pyx_t_6 = 0;
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
          goto __pyx_L12;
        }
        __pyx_L12:;
        goto __pyx_L10;
      }

      /* "axon/_loader.py":893
 *                     if self.eof:
 *                         errors.error_unexpected_end(self)
 *                 elif ch == 'n':             # <<<<<<<<<<<<<<
 *                     text += "\n"
 *                     skip_char(self)
 */
      __pyx_t_2 = ((__pyx_v_ch == 110) != 0);
      if (__pyx_t_2) {

        /* "axon/_loader.py":894
 *                         errors.error_unexpected_end(self)
 *                 elif ch == 'n':
 *                     text += "\n"             # <<<<<<<<<<<<<<
 *                     skip_char(self)
 *                 elif ch == 'r':
 */
        __pyx_t_5 = PyNumber_InPlaceAdd(((PyObject *)__pyx_v_text), ((PyObject *)__pyx_kp_u_22)); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 894; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(((PyObject *)__pyx_t_5));
        __Pyx_DECREF(((PyObject *)__pyx_v_text));
        __pyx_v_text = ((PyObject*)__pyx_t_5);
        __pyx_t_5 = 0;

        /* "axon/_loader.py":895
 *                 elif ch == 'n':
 *                     text += "\n"
 *                     skip_char(self)             # <<<<<<<<<<<<<<
 *                 elif ch == 'r':
 *                     text += "\r"
 */
        skip_char(__pyx_v_self);
        goto __pyx_L10;
      }

      /* "axon/_loader.py":896
 *                     text += "\n"
 *                     skip_char(self)
 *                 elif ch == 'r':             # <<<<<<<<<<<<<<
 *                     text += "\r"
 *                     skip_char(self)
 */
      __pyx_t_2 = ((__pyx_v_ch == 114) != 0);
      if (__pyx_t_2) {

        /* "axon/_loader.py":897
 *                     skip_char(self)
 *                 elif ch == 'r':
 *                     text += "\r"             # <<<<<<<<<<<<<<
 *                     skip_char(self)
 *                 elif ch == 't':
 */
        __pyx_t_5 = PyNumber_InPlaceAdd(((PyObject *)__pyx_v_text), ((PyObject *)__pyx_kp_u_30)); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 897; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(((PyObject *)__pyx_t_5));
        __Pyx_DECREF(((PyObject *)__pyx_v_text));
        __pyx_v_text = ((PyObject*)__pyx_t_5);
        __pyx_t_5 = 0;

        /* "axon/_loader.py":898
 *                 elif ch == 'r':
 *                     text += "\r"
 *                     skip_char(self)             # <<<<<<<<<<<<<<
 *                 elif ch == 't':
 *                     text += "\t"
 */
        skip_char(__pyx_v_self);
        goto __pyx_L10;
      }

      /* "axon/_loader.py":899
 *                     text += "\r"
 *                     skip_char(self)
 *                 elif ch == 't':             # <<<<<<<<<<<<<<
 *                     text += "\t"
 *                     skip_char(self)
 */
      __pyx_t_2 = ((__pyx_v_ch == 116) != 0);
      if (__pyx_t_2) {

        /* "axon/_loader.py":900
 *                     skip_char(self)
 *                 elif ch == 't':
 *                     text += "\t"             # <<<<<<<<<<<<<<
 *                     skip_char(self)
 *                 elif ch == 'u' or ch == 'U':
 */
        __pyx_t_5 = PyNumber_InPlaceAdd(((PyObject *)__pyx_v_text), ((PyObject *)__pyx_kp_u_31)); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 900; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(((PyObject *)__pyx_t_5));
        __Pyx_DECREF(((PyObject *)__pyx_v_text));
        __pyx_v_text = ((PyObject*)__pyx_t_5);
        __pyx_t_5 = 0;

        /* "axon/_loader.py":901
 *                 elif ch == 't':
 *                     text += "\t"
 *                     skip_char(self)             # <<<<<<<<<<<<<<
 *                 elif ch == 'u' or ch == 'U':
 *                     skip_char(self)
 */
        skip_char(__pyx_v_self);
        goto __pyx_L10;
      }

      /* "axon/_loader.py":902
 *                     text += "\t"
 *                     skip_char(self)
 *                 elif ch == 'u' or ch == 'U':             # <<<<<<<<<<<<<<
 *                     skip_char(self)
 *                     text += self.get_unicode_hex()
 */
      switch (__pyx_v_ch) {
        case 117:
        case 85:
        __pyx_t_2 = 1;
        break;
        default:
        __pyx_t_2 = 0;
        break;
      }
      if (__pyx_t_2) {

        /* "axon/_loader.py":903
 *                     skip_char(self)
 *                 elif ch == 'u' or ch == 'U':
 *                     skip_char(self)             # <<<<<<<<<<<<<<
 *                     text += self.get_unicode_hex()
 *                 else:
 */
        skip_char(__pyx_v_self);

        /* "axon/_loader.py":904
 *                 elif ch == 'u' or ch == 'U':
 *                     skip_char(self)
 *                     text += self.get_unicode_hex()             # <<<<<<<<<<<<<<
 *                 else:
 *                     text += '\\'
 */
        __pyx_t_5 = ((PyObject *)__pyx_f_4axon_7_loader_6Loader_get_unicode_hex(__pyx_v_self)); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 904; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_5);
        __pyx_t_6 = PyNumber_InPlaceAdd(((PyObject *)__pyx_v_text), __pyx_t_5); if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 904; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(((PyObject *)__pyx_t_6));
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_DECREF(((PyObject *)__pyx_v_text));
        __pyx_v_text = ((PyObject*)__pyx_t_6);
        __pyx_t_6 = 0;
        goto __pyx_L10;
      }
      /*else*/ {

        /* "axon/_loader.py":906
 *                     text += self.get_unicode_hex()
 *                 else:
 *                     text += '\\'             # <<<<<<<<<<<<<<
 *                 pos0 = self.pos
 *                 ch = current_char(self)
 */
        __pyx_t_6 = PyNumber_InPlaceAdd(((PyObject *)__pyx_v_text), ((PyObject *)__pyx_kp_u_32)); if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 906; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(((PyObject *)__pyx_t_6));
        __Pyx_DECREF(((PyObject *)__pyx_v_text));
        __pyx_v_text = ((PyObject*)__pyx_t_6);
        __pyx_t_6 = 0;
      }
      __pyx_L10:;

      /* "axon/_loader.py":907
 *                 else:
 *                     text += '\\'
 *                 pos0 = self.pos             # <<<<<<<<<<<<<<
 *                 ch = current_char(self)
 *             else:
 */
      __pyx_t_1 = __pyx_v_self->pos;
      __pyx_v_pos0 = __pyx_t_1;

      /* "axon/_loader.py":908
 *                     text += '\\'
 *                 pos0 = self.pos
 *                 ch = current_char(self)             # <<<<<<<<<<<<<<
 *             else:
 *                 ch = next_char(self)
 */
      __pyx_v_ch = current_char(__pyx_v_self);
      goto __pyx_L5;
    }
    /*else*/ {

      /* "axon/_loader.py":910
 *                 ch = current_char(self)
 *             else:
 *                 ch = next_char(self)             # <<<<<<<<<<<<<<
 *     #
 *     def get_base64(self):
 */
      __pyx_v_ch = next_char(__pyx_v_self);
    }
    __pyx_L5:;
  }

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("axon._loader.Loader.get_string", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_text);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_loader.py":912
 *                 ch = next_char(self)
 *     #
 *     def get_base64(self):             # <<<<<<<<<<<<<<
 * 
 *         text = None
 */

static PyObject *__pyx_f_4axon_7_loader_6Loader_get_base64(struct __pyx_obj_4axon_7_loader_Loader *__pyx_v_self) {
  PyObject *__pyx_v_text = 0;
  Py_UCS4 __pyx_v_ch;
  int __pyx_v_pos0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  int __pyx_t_3;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  Py_UCS4 __pyx_t_8;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_base64", 0);

  /* "axon/_loader.py":914
 *     def get_base64(self):
 * 
 *         text = None             # <<<<<<<<<<<<<<
 *         ch = next_char(self)
 *         pos0 = self.pos
 */
  __Pyx_INCREF(Py_None);
  __pyx_v_text = ((PyObject*)Py_None);

  /* "axon/_loader.py":915
 * 
 *         text = None
 *         ch = next_char(self)             # <<<<<<<<<<<<<<
 *         pos0 = self.pos
 *         while 1:
 */
  __pyx_v_ch = next_char(__pyx_v_self);

  /* "axon/_loader.py":916
 *         text = None
 *         ch = next_char(self)
 *         pos0 = self.pos             # <<<<<<<<<<<<<<
 *         while 1:
 *             if ch >= '0' and ch <= '9':
 */
  __pyx_t_1 = __pyx_v_self->pos;
  __pyx_v_pos0 = __pyx_t_1;

  /* "axon/_loader.py":917
 *         ch = next_char(self)
 *         pos0 = self.pos
 *         while 1:             # <<<<<<<<<<<<<<
 *             if ch >= '0' and ch <= '9':
 *                 ch = next_char(self)
 */
  while (1) {
    if (!1) break;

    /* "axon/_loader.py":918
 *         pos0 = self.pos
 *         while 1:
 *             if ch >= '0' and ch <= '9':             # <<<<<<<<<<<<<<
 *                 ch = next_char(self)
 *             elif ch >= 'a' and ch <= 'z':
 */
    __pyx_t_2 = ((__pyx_v_ch >= 48) != 0);
    if (__pyx_t_2) {
      __pyx_t_3 = ((__pyx_v_ch <= 57) != 0);
      __pyx_t_4 = __pyx_t_3;
    } else {
      __pyx_t_4 = __pyx_t_2;
    }
    if (__pyx_t_4) {

      /* "axon/_loader.py":919
 *         while 1:
 *             if ch >= '0' and ch <= '9':
 *                 ch = next_char(self)             # <<<<<<<<<<<<<<
 *             elif ch >= 'a' and ch <= 'z':
 *                 ch = next_char(self)
 */
      __pyx_v_ch = next_char(__pyx_v_self);
      goto __pyx_L5;
    }

    /* "axon/_loader.py":920
 *             if ch >= '0' and ch <= '9':
 *                 ch = next_char(self)
 *             elif ch >= 'a' and ch <= 'z':             # <<<<<<<<<<<<<<
 *                 ch = next_char(self)
 *             elif ch >= 'A' and ch <= 'Z':
 */
    __pyx_t_4 = ((__pyx_v_ch >= 97) != 0);
    if (__pyx_t_4) {
      __pyx_t_2 = ((__pyx_v_ch <= 122) != 0);
      __pyx_t_3 = __pyx_t_2;
    } else {
      __pyx_t_3 = __pyx_t_4;
    }
    if (__pyx_t_3) {

      /* "axon/_loader.py":921
 *                 ch = next_char(self)
 *             elif ch >= 'a' and ch <= 'z':
 *                 ch = next_char(self)             # <<<<<<<<<<<<<<
 *             elif ch >= 'A' and ch <= 'Z':
 *                 ch = next_char(self)
 */
      __pyx_v_ch = next_char(__pyx_v_self);
      goto __pyx_L5;
    }

    /* "axon/_loader.py":922
 *             elif ch >= 'a' and ch <= 'z':
 *                 ch = next_char(self)
 *             elif ch >= 'A' and ch <= 'Z':             # <<<<<<<<<<<<<<
 *                 ch = next_char(self)
 *             elif ch == '+' or ch == '/':
 */
    __pyx_t_3 = ((__pyx_v_ch >= 65) != 0);
    if (__pyx_t_3) {
      __pyx_t_4 = ((__pyx_v_ch <= 90) != 0);
      __pyx_t_2 = __pyx_t_4;
    } else {
      __pyx_t_2 = __pyx_t_3;
    }
    if (__pyx_t_2) {

      /* "axon/_loader.py":923
 *                 ch = next_char(self)
 *             elif ch >= 'A' and ch <= 'Z':
 *                 ch = next_char(self)             # <<<<<<<<<<<<<<
 *             elif ch == '+' or ch == '/':
 *                 ch = next_char(self)
 */
      __pyx_v_ch = next_char(__pyx_v_self);
      goto __pyx_L5;
    }

    /* "axon/_loader.py":924
 *             elif ch >= 'A' and ch <= 'Z':
 *                 ch = next_char(self)
 *             elif ch == '+' or ch == '/':             # <<<<<<<<<<<<<<
 *                 ch = next_char(self)
 *             elif ch <= ' ':
 */
    switch (__pyx_v_ch) {
      case 43:
      case 47:
      __pyx_t_2 = 1;
      break;
      default:
      __pyx_t_2 = 0;
      break;
    }
    if (__pyx_t_2) {

      /* "axon/_loader.py":925
 *                 ch = next_char(self)
 *             elif ch == '+' or ch == '/':
 *                 ch = next_char(self)             # <<<<<<<<<<<<<<
 *             elif ch <= ' ':
 *                 if text is None:
 */
      __pyx_v_ch = next_char(__pyx_v_self);
      goto __pyx_L5;
    }

    /* "axon/_loader.py":926
 *             elif ch == '+' or ch == '/':
 *                 ch = next_char(self)
 *             elif ch <= ' ':             # <<<<<<<<<<<<<<
 *                 if text is None:
 *                     text = get_token(self, pos0)
 */
    __pyx_t_2 = ((__pyx_v_ch <= 32) != 0);
    if (__pyx_t_2) {

      /* "axon/_loader.py":927
 *                 ch = next_char(self)
 *             elif ch <= ' ':
 *                 if text is None:             # <<<<<<<<<<<<<<
 *                     text = get_token(self, pos0)
 *                 else:
 */
      __pyx_t_2 = (__pyx_v_text == ((PyObject*)Py_None));
      __pyx_t_3 = (__pyx_t_2 != 0);
      if (__pyx_t_3) {

        /* "axon/_loader.py":928
 *             elif ch <= ' ':
 *                 if text is None:
 *                     text = get_token(self, pos0)             # <<<<<<<<<<<<<<
 *                 else:
 *                     text += get_token(self, pos0)
 */
        __pyx_t_5 = ((PyObject *)get_token(__pyx_v_self, __pyx_v_pos0)); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 928; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(((PyObject *)__pyx_v_text));
        __pyx_v_text = ((PyObject*)__pyx_t_5);
        __pyx_t_5 = 0;
        goto __pyx_L6;
      }
      /*else*/ {

        /* "axon/_loader.py":930
 *                     text = get_token(self, pos0)
 *                 else:
 *                     text += get_token(self, pos0)             # <<<<<<<<<<<<<<
 *                 self.skip_spaces()
 *                 if self.eof:
 */
        __pyx_t_5 = ((PyObject *)get_token(__pyx_v_self, __pyx_v_pos0)); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 930; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_5);
        __pyx_t_6 = PyNumber_InPlaceAdd(((PyObject *)__pyx_v_text), __pyx_t_5); if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 930; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(((PyObject *)__pyx_t_6));
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_DECREF(((PyObject *)__pyx_v_text));
        __pyx_v_text = ((PyObject*)__pyx_t_6);
        __pyx_t_6 = 0;
      }
      __pyx_L6:;

      /* "axon/_loader.py":931
 *                 else:
 *                     text += get_token(self, pos0)
 *                 self.skip_spaces()             # <<<<<<<<<<<<<<
 *                 if self.eof:
 *                     errors.error(self, 'MIME Base64 string is not finished')
 */
      __pyx_f_4axon_7_loader_6Loader_skip_spaces(__pyx_v_self);

      /* "axon/_loader.py":932
 *                     text += get_token(self, pos0)
 *                 self.skip_spaces()
 *                 if self.eof:             # <<<<<<<<<<<<<<
 *                     errors.error(self, 'MIME Base64 string is not finished')
 *                 pos0 = self.pos
 */
      __pyx_t_3 = (__pyx_v_self->eof != 0);
      if (__pyx_t_3) {

        /* "axon/_loader.py":933
 *                 self.skip_spaces()
 *                 if self.eof:
 *                     errors.error(self, 'MIME Base64 string is not finished')             # <<<<<<<<<<<<<<
 *                 pos0 = self.pos
 *                 ch = self.line[pos0]
 */
        __pyx_t_6 = __Pyx_GetModuleGlobalName(__pyx_n_s__errors); if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 933; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_6);
        __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s__error); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 933; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        __pyx_t_6 = PyTuple_New(2); if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 933; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_INCREF(((PyObject *)__pyx_v_self));
        PyTuple_SET_ITEM(__pyx_t_6, 0, ((PyObject *)__pyx_v_self));
        __Pyx_GIVEREF(((PyObject *)__pyx_v_self));
        __Pyx_INCREF(((PyObject *)__pyx_kp_u_33));
        PyTuple_SET_ITEM(__pyx_t_6, 1, ((PyObject *)__pyx_kp_u_33));
        __Pyx_GIVEREF(((PyObject *)__pyx_kp_u_33));
        __pyx_t_7 = PyObject_Call(__pyx_t_5, ((PyObject *)__pyx_t_6), NULL); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 933; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_DECREF(((PyObject *)__pyx_t_6)); __pyx_t_6 = 0;
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        goto __pyx_L7;
      }
      __pyx_L7:;

      /* "axon/_loader.py":934
 *                 if self.eof:
 *                     errors.error(self, 'MIME Base64 string is not finished')
 *                 pos0 = self.pos             # <<<<<<<<<<<<<<
 *                 ch = self.line[pos0]
 *             elif ch == '=':
 */
      __pyx_t_1 = __pyx_v_self->pos;
      __pyx_v_pos0 = __pyx_t_1;

      /* "axon/_loader.py":935
 *                     errors.error(self, 'MIME Base64 string is not finished')
 *                 pos0 = self.pos
 *                 ch = self.line[pos0]             # <<<<<<<<<<<<<<
 *             elif ch == '=':
 *                 ch = next_char(self)
 */
      __pyx_t_8 = __Pyx_GetItemInt_Unicode(((PyObject *)__pyx_v_self->line), __pyx_v_pos0, sizeof(int), PyInt_FromLong, 0, 0, 0); if (unlikely(__pyx_t_8 == (Py_UCS4)-1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 935; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
      __pyx_v_ch = __pyx_t_8;
      goto __pyx_L5;
    }

    /* "axon/_loader.py":936
 *                 pos0 = self.pos
 *                 ch = self.line[pos0]
 *             elif ch == '=':             # <<<<<<<<<<<<<<
 *                 ch = next_char(self)
 *                 if ch == '=':
 */
    __pyx_t_3 = ((__pyx_v_ch == 61) != 0);
    if (__pyx_t_3) {

      /* "axon/_loader.py":937
 *                 ch = self.line[pos0]
 *             elif ch == '=':
 *                 ch = next_char(self)             # <<<<<<<<<<<<<<
 *                 if ch == '=':
 *                     ch = next_char(self)
 */
      __pyx_v_ch = next_char(__pyx_v_self);

      /* "axon/_loader.py":938
 *             elif ch == '=':
 *                 ch = next_char(self)
 *                 if ch == '=':             # <<<<<<<<<<<<<<
 *                     ch = next_char(self)
 * 
 */
      __pyx_t_3 = ((__pyx_v_ch == 61) != 0);
      if (__pyx_t_3) {

        /* "axon/_loader.py":939
 *                 ch = next_char(self)
 *                 if ch == '=':
 *                     ch = next_char(self)             # <<<<<<<<<<<<<<
 * 
 *                 if text is None:
 */
        __pyx_v_ch = next_char(__pyx_v_self);
        goto __pyx_L8;
      }
      __pyx_L8:;

      /* "axon/_loader.py":941
 *                     ch = next_char(self)
 * 
 *                 if text is None:             # <<<<<<<<<<<<<<
 *                     text = get_token(self, pos0)
 *                 else:
 */
      __pyx_t_3 = (__pyx_v_text == ((PyObject*)Py_None));
      __pyx_t_2 = (__pyx_t_3 != 0);
      if (__pyx_t_2) {

        /* "axon/_loader.py":942
 * 
 *                 if text is None:
 *                     text = get_token(self, pos0)             # <<<<<<<<<<<<<<
 *                 else:
 *                     text += get_token(self, pos0)
 */
        __pyx_t_7 = ((PyObject *)get_token(__pyx_v_self, __pyx_v_pos0)); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 942; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_DECREF(((PyObject *)__pyx_v_text));
        __pyx_v_text = ((PyObject*)__pyx_t_7);
        __pyx_t_7 = 0;
        goto __pyx_L9;
      }
      /*else*/ {

        /* "axon/_loader.py":944
 *                     text = get_token(self, pos0)
 *                 else:
 *                     text += get_token(self, pos0)             # <<<<<<<<<<<<<<
 *                 return decodebytes(text.encode('ascii'))
 *             else:
 */
        __pyx_t_7 = ((PyObject *)get_token(__pyx_v_self, __pyx_v_pos0)); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 944; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_7);
        __pyx_t_6 = PyNumber_InPlaceAdd(((PyObject *)__pyx_v_text), __pyx_t_7); if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 944; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(((PyObject *)__pyx_t_6));
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        __Pyx_DECREF(((PyObject *)__pyx_v_text));
        __pyx_v_text = ((PyObject*)__pyx_t_6);
        __pyx_t_6 = 0;
      }
      __pyx_L9:;

      /* "axon/_loader.py":945
 *                 else:
 *                     text += get_token(self, pos0)
 *                 return decodebytes(text.encode('ascii'))             # <<<<<<<<<<<<<<
 *             else:
 *                 raise errors.error(self, 'Invalid character %r in MIME Base64 string' % ch)
 */
      __Pyx_XDECREF(__pyx_r);
      __pyx_t_6 = __Pyx_GetModuleGlobalName(__pyx_n_s__decodebytes); if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 945; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_6);
      if (unlikely(((PyObject *)__pyx_v_text) == Py_None)) {
        PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%s'", "encode");
        {__pyx_filename = __pyx_f[0]; __pyx_lineno = 945; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      }
      __pyx_t_7 = ((PyObject *)PyUnicode_AsASCIIString(__pyx_v_text)); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 945; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(((PyObject *)__pyx_t_7));
      __pyx_t_5 = PyTuple_New(1); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 945; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_5);
      PyTuple_SET_ITEM(__pyx_t_5, 0, ((PyObject *)__pyx_t_7));
      __Pyx_GIVEREF(((PyObject *)__pyx_t_7));
      __pyx_t_7 = 0;
      __pyx_t_7 = PyObject_Call(__pyx_t_6, ((PyObject *)__pyx_t_5), NULL); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 945; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_DECREF(((PyObject *)__pyx_t_5)); __pyx_t_5 = 0;
      __pyx_r = __pyx_t_7;
      __pyx_t_7 = 0;
      goto __pyx_L0;
      goto __pyx_L5;
    }
    /*else*/ {

      /* "axon/_loader.py":947
 *                 return decodebytes(text.encode('ascii'))
 *             else:
 *                 raise errors.error(self, 'Invalid character %r in MIME Base64 string' % ch)             # <<<<<<<<<<<<<<
 *     #
 *     def skip_comment(self):
 */
      __pyx_t_7 = __Pyx_GetModuleGlobalName(__pyx_n_s__errors); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 947; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s__error); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 947; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_t_7 = PyUnicode_FromOrdinal(__pyx_v_ch); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 947; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(((PyObject *)__pyx_t_7));
      __pyx_t_6 = PyNumber_Remainder(((PyObject *)__pyx_kp_u_34), ((PyObject *)__pyx_t_7)); if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 947; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(((PyObject *)__pyx_t_6));
      __Pyx_DECREF(((PyObject *)__pyx_t_7)); __pyx_t_7 = 0;
      __pyx_t_7 = PyTuple_New(2); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 947; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_INCREF(((PyObject *)__pyx_v_self));
      PyTuple_SET_ITEM(__pyx_t_7, 0, ((PyObject *)__pyx_v_self));
      __Pyx_GIVEREF(((PyObject *)__pyx_v_self));
      PyTuple_SET_ITEM(__pyx_t_7, 1, ((PyObject *)__pyx_t_6));
      __Pyx_GIVEREF(((PyObject *)__pyx_t_6));
      __pyx_t_6 = 0;
      __pyx_t_6 = PyObject_Call(__pyx_t_5, ((PyObject *)__pyx_t_7), NULL); if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 947; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(((PyObject *)__pyx_t_7)); __pyx_t_7 = 0;
      __Pyx_Raise(__pyx_t_6, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      {__pyx_filename = __pyx_f[0]; __pyx_lineno = 947; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    }
    __pyx_L5:;
  }

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("axon._loader.Loader.get_base64", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_text);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_loader.py":949
 *                 raise errors.error(self, 'Invalid character %r in MIME Base64 string' % ch)
 *     #
 *     def skip_comment(self):             # <<<<<<<<<<<<<<
 *         ch = next_char(self)
 *         while 1:
 */

static void __pyx_f_4axon_7_loader_6Loader_skip_comment(struct __pyx_obj_4axon_7_loader_Loader *__pyx_v_self) {
  Py_UCS4 __pyx_v_ch;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("skip_comment", 0);

  /* "axon/_loader.py":950
 *     #
 *     def skip_comment(self):
 *         ch = next_char(self)             # <<<<<<<<<<<<<<
 *         while 1:
 *             if ch == '\n' or ch == '\r':
 */
  __pyx_v_ch = next_char(__pyx_v_self);

  /* "axon/_loader.py":951
 *     def skip_comment(self):
 *         ch = next_char(self)
 *         while 1:             # <<<<<<<<<<<<<<
 *             if ch == '\n' or ch == '\r':
 *                 self.next_line()
 */
  while (1) {
    if (!1) break;

    /* "axon/_loader.py":952
 *         ch = next_char(self)
 *         while 1:
 *             if ch == '\n' or ch == '\r':             # <<<<<<<<<<<<<<
 *                 self.next_line()
 *                 return
 */
    switch (__pyx_v_ch) {
      case 10:
      case 13:

      /* "axon/_loader.py":953
 *         while 1:
 *             if ch == '\n' or ch == '\r':
 *                 self.next_line()             # <<<<<<<<<<<<<<
 *                 return
 *             else:
 */
      __pyx_f_4axon_7_loader_6Loader_next_line(__pyx_v_self);

      /* "axon/_loader.py":954
 *             if ch == '\n' or ch == '\r':
 *                 self.next_line()
 *                 return             # <<<<<<<<<<<<<<
 *             else:
 *                 ch = next_char(self)
 */
      goto __pyx_L0;
      break;
      default:

      /* "axon/_loader.py":956
 *                 return
 *             else:
 *                 ch = next_char(self)             # <<<<<<<<<<<<<<
 *     #
 *     def skip_comments(self):
 */
      __pyx_v_ch = next_char(__pyx_v_self);
      break;
    }
  }

  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
}

/* "axon/_loader.py":958
 *                 ch = next_char(self)
 *     #
 *     def skip_comments(self):             # <<<<<<<<<<<<<<
 *         while 1:
 *             self.skip_comment()
 */

static void __pyx_f_4axon_7_loader_6Loader_skip_comments(struct __pyx_obj_4axon_7_loader_Loader *__pyx_v_self) {
  Py_UCS4 __pyx_v_ch;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  __Pyx_RefNannySetupContext("skip_comments", 0);

  /* "axon/_loader.py":959
 *     #
 *     def skip_comments(self):
 *         while 1:             # <<<<<<<<<<<<<<
 *             self.skip_comment()
 * 
 */
  while (1) {
    if (!1) break;

    /* "axon/_loader.py":960
 *     def skip_comments(self):
 *         while 1:
 *             self.skip_comment()             # <<<<<<<<<<<<<<
 * 
 *             ch = self.skip_spaces()
 */
    __pyx_f_4axon_7_loader_6Loader_skip_comment(__pyx_v_self);

    /* "axon/_loader.py":962
 *             self.skip_comment()
 * 
 *             ch = self.skip_spaces()             # <<<<<<<<<<<<<<
 *             if self.eof:
 *                 break
 */
    __pyx_v_ch = __pyx_f_4axon_7_loader_6Loader_skip_spaces(__pyx_v_self);

    /* "axon/_loader.py":963
 * 
 *             ch = self.skip_spaces()
 *             if self.eof:             # <<<<<<<<<<<<<<
 *                 break
 * 
 */
    __pyx_t_1 = (__pyx_v_self->eof != 0);
    if (__pyx_t_1) {

      /* "axon/_loader.py":964
 *             ch = self.skip_spaces()
 *             if self.eof:
 *                 break             # <<<<<<<<<<<<<<
 * 
 *             if ch == '#':
 */
      goto __pyx_L4_break;
      goto __pyx_L5;
    }
    __pyx_L5:;

    /* "axon/_loader.py":966
 *                 break
 * 
 *             if ch == '#':             # <<<<<<<<<<<<<<
 *                 skip_char(self)
 *             else:
 */
    __pyx_t_1 = ((__pyx_v_ch == 35) != 0);
    if (__pyx_t_1) {

      /* "axon/_loader.py":967
 * 
 *             if ch == '#':
 *                 skip_char(self)             # <<<<<<<<<<<<<<
 *             else:
 *                 break
 */
      skip_char(__pyx_v_self);
      goto __pyx_L6;
    }
    /*else*/ {

      /* "axon/_loader.py":969
 *                 skip_char(self)
 *             else:
 *                 break             # <<<<<<<<<<<<<<
 *     #
 *     def get_constant_or_string(self, name):
 */
      goto __pyx_L4_break;
    }
    __pyx_L6:;
  }
  __pyx_L4_break:;

  __Pyx_RefNannyFinishContext();
}

/* "axon/_loader.py":971
 *                 break
 *     #
 *     def get_constant_or_string(self, name):             # <<<<<<<<<<<<<<
 *         name2 = self.c_constants.get(name, c_undefined)
 *         if name2 is c_undefined:
 */

static PyObject *__pyx_f_4axon_7_loader_6Loader_get_constant_or_string(struct __pyx_obj_4axon_7_loader_Loader *__pyx_v_self, PyObject *__pyx_v_name) {
  PyObject *__pyx_v_name2 = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_constant_or_string", 0);

  /* "axon/_loader.py":972
 *     #
 *     def get_constant_or_string(self, name):
 *         name2 = self.c_constants.get(name, c_undefined)             # <<<<<<<<<<<<<<
 *         if name2 is c_undefined:
 *             return name
 */
  if (unlikely(((PyObject *)__pyx_v_self->c_constants) == Py_None)) {
    PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%s'", "get");
    {__pyx_filename = __pyx_f[0]; __pyx_lineno = 972; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }
  __pyx_t_1 = __Pyx_PyDict_GetItemDefault(((PyObject *)__pyx_v_self->c_constants), ((PyObject *)__pyx_v_name), __pyx_v_4axon_8_objects_c_undefined); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 972; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_name2 = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "axon/_loader.py":973
 *     def get_constant_or_string(self, name):
 *         name2 = self.c_constants.get(name, c_undefined)
 *         if name2 is c_undefined:             # <<<<<<<<<<<<<<
 *             return name
 *         else:
 */
  __pyx_t_2 = (__pyx_v_name2 == __pyx_v_4axon_8_objects_c_undefined);
  __pyx_t_3 = (__pyx_t_2 != 0);
  if (__pyx_t_3) {

    /* "axon/_loader.py":974
 *         name2 = self.c_constants.get(name, c_undefined)
 *         if name2 is c_undefined:
 *             return name             # <<<<<<<<<<<<<<
 *         else:
 *             return name2
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(((PyObject *)__pyx_v_name));
    __pyx_r = ((PyObject *)__pyx_v_name);
    goto __pyx_L0;
    goto __pyx_L3;
  }
  /*else*/ {

    /* "axon/_loader.py":976
 *             return name
 *         else:
 *             return name2             # <<<<<<<<<<<<<<
 *     #
 *     def get_negative_constant(self):
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_v_name2);
    __pyx_r = __pyx_v_name2;
    goto __pyx_L0;
  }
  __pyx_L3:;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("axon._loader.Loader.get_constant_or_string", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_name2);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_loader.py":978
 *             return name2
 *     #
 *     def get_negative_constant(self):             # <<<<<<<<<<<<<<
 * 
 *         ch = current_char(self)
 */

static PyObject *__pyx_f_4axon_7_loader_6Loader_get_negative_constant(struct __pyx_obj_4axon_7_loader_Loader *__pyx_v_self) {
  Py_UCS4 __pyx_v_ch;
  PyObject *__pyx_v_name = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_negative_constant", 0);

  /* "axon/_loader.py":980
 *     def get_negative_constant(self):
 * 
 *         ch = current_char(self)             # <<<<<<<<<<<<<<
 *         if ch.isalpha():
 *             name = self.get_name()
 */
  __pyx_v_ch = current_char(__pyx_v_self);

  /* "axon/_loader.py":981
 * 
 *         ch = current_char(self)
 *         if ch.isalpha():             # <<<<<<<<<<<<<<
 *             name = self.get_name()
 *             if name == 'Infinity':
 */
  __pyx_t_1 = Py_UNICODE_ISALPHA(__pyx_v_ch); 
  if ((__pyx_t_1 != 0)) {

    /* "axon/_loader.py":982
 *         ch = current_char(self)
 *         if ch.isalpha():
 *             name = self.get_name()             # <<<<<<<<<<<<<<
 *             if name == 'Infinity':
 *                 return self.sbuilder.create_ninf()
 */
    __pyx_t_2 = __pyx_f_4axon_7_loader_6Loader_get_name(__pyx_v_self); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 982; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_v_name = __pyx_t_2;
    __pyx_t_2 = 0;

    /* "axon/_loader.py":983
 *         if ch.isalpha():
 *             name = self.get_name()
 *             if name == 'Infinity':             # <<<<<<<<<<<<<<
 *                 return self.sbuilder.create_ninf()
 *             else:
 */
    __pyx_t_2 = PyObject_RichCompare(__pyx_v_name, ((PyObject *)__pyx_n_u__Infinity), Py_EQ); __Pyx_XGOTREF(__pyx_t_2); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 983; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely(__pyx_t_1 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 983; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (__pyx_t_1) {

      /* "axon/_loader.py":984
 *             name = self.get_name()
 *             if name == 'Infinity':
 *                 return self.sbuilder.create_ninf()             # <<<<<<<<<<<<<<
 *             else:
 *                 errors.error_invalid_value_with_prefix(self, '-')
 */
      __Pyx_XDECREF(__pyx_r);
      __pyx_t_2 = __pyx_v_self->sbuilder->create_ninf(); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 984; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_r = __pyx_t_2;
      __pyx_t_2 = 0;
      goto __pyx_L0;
      goto __pyx_L4;
    }
    /*else*/ {

      /* "axon/_loader.py":986
 *                 return self.sbuilder.create_ninf()
 *             else:
 *                 errors.error_invalid_value_with_prefix(self, '-')             # <<<<<<<<<<<<<<
 *         elif ch == '':
 *             skip_char(self)
 */
      __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s__errors); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 986; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_35); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 986; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __pyx_t_2 = PyTuple_New(2); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 986; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_INCREF(((PyObject *)__pyx_v_self));
      PyTuple_SET_ITEM(__pyx_t_2, 0, ((PyObject *)__pyx_v_self));
      __Pyx_GIVEREF(((PyObject *)__pyx_v_self));
      __Pyx_INCREF(((PyObject *)__pyx_kp_u_6));
      PyTuple_SET_ITEM(__pyx_t_2, 1, ((PyObject *)__pyx_kp_u_6));
      __Pyx_GIVEREF(((PyObject *)__pyx_kp_u_6));
      __pyx_t_4 = PyObject_Call(__pyx_t_3, ((PyObject *)__pyx_t_2), NULL); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 986; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF(((PyObject *)__pyx_t_2)); __pyx_t_2 = 0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
    __pyx_L4:;
    goto __pyx_L3;
  }

  /* "axon/_loader.py":987
 *             else:
 *                 errors.error_invalid_value_with_prefix(self, '-')
 *         elif ch == '':             # <<<<<<<<<<<<<<
 *             skip_char(self)
 *             return self.sbuilder.create_ninf()
 */
  __pyx_t_1 = ((__pyx_v_ch == 8734) != 0);
  if (__pyx_t_1) {

    /* "axon/_loader.py":988
 *                 errors.error_invalid_value_with_prefix(self, '-')
 *         elif ch == '':
 *             skip_char(self)             # <<<<<<<<<<<<<<
 *             return self.sbuilder.create_ninf()
 *         else:
 */
    skip_char(__pyx_v_self);

    /* "axon/_loader.py":989
 *         elif ch == '':
 *             skip_char(self)
 *             return self.sbuilder.create_ninf()             # <<<<<<<<<<<<<<
 *         else:
 *             errors.error_invalid_value_with_prefix(self, '-')
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_4 = __pyx_v_self->sbuilder->create_ninf(); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 989; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_r = __pyx_t_4;
    __pyx_t_4 = 0;
    goto __pyx_L0;
    goto __pyx_L3;
  }
  /*else*/ {

    /* "axon/_loader.py":991
 *             return self.sbuilder.create_ninf()
 *         else:
 *             errors.error_invalid_value_with_prefix(self, '-')             # <<<<<<<<<<<<<<
 *     #
 *     def get_value(self, idn):
 */
    __pyx_t_4 = __Pyx_GetModuleGlobalName(__pyx_n_s__errors); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 991; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_35); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 991; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = PyTuple_New(2); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 991; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_INCREF(((PyObject *)__pyx_v_self));
    PyTuple_SET_ITEM(__pyx_t_4, 0, ((PyObject *)__pyx_v_self));
    __Pyx_GIVEREF(((PyObject *)__pyx_v_self));
    __Pyx_INCREF(((PyObject *)__pyx_kp_u_6));
    PyTuple_SET_ITEM(__pyx_t_4, 1, ((PyObject *)__pyx_kp_u_6));
    __Pyx_GIVEREF(((PyObject *)__pyx_kp_u_6));
    __pyx_t_3 = PyObject_Call(__pyx_t_2, ((PyObject *)__pyx_t_4), NULL); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 991; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(((PyObject *)__pyx_t_4)); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_L3:;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("axon._loader.Loader.get_negative_constant", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_name);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_loader.py":993
 *             errors.error_invalid_value_with_prefix(self, '-')
 *     #
 *     def get_value(self, idn):             # <<<<<<<<<<<<<<
 * 
 *         ch = current_char(self)
 */

static PyObject *__pyx_f_4axon_7_loader_6Loader_get_value(struct __pyx_obj_4axon_7_loader_Loader *__pyx_v_self, int __pyx_v_idn) {
  Py_UCS4 __pyx_v_ch;
  int __pyx_v_is_multi;
  int __pyx_v_pos0;
  PyObject *__pyx_v_val = 0;
  PyObject *__pyx_v_name = NULL;
  PyObject *__pyx_v_label = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  long __pyx_t_5;
  Py_UCS4 __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  int __pyx_t_9;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_value", 0);

  /* "axon/_loader.py":995
 *     def get_value(self, idn):
 * 
 *         ch = current_char(self)             # <<<<<<<<<<<<<<
 *         if (ch <= '9' and ch >= '0') or ch == '.':
 *             val = self.get_number()
 */
  __pyx_v_ch = current_char(__pyx_v_self);

  /* "axon/_loader.py":996
 * 
 *         ch = current_char(self)
 *         if (ch <= '9' and ch >= '0') or ch == '.':             # <<<<<<<<<<<<<<
 *             val = self.get_number()
 *             return val
 */
  __pyx_t_1 = ((__pyx_v_ch <= 57) != 0);
  if (__pyx_t_1) {
    __pyx_t_2 = ((__pyx_v_ch >= 48) != 0);
    __pyx_t_3 = __pyx_t_2;
  } else {
    __pyx_t_3 = __pyx_t_1;
  }
  if (!__pyx_t_3) {
    __pyx_t_1 = ((__pyx_v_ch == 46) != 0);
    __pyx_t_2 = __pyx_t_1;
  } else {
    __pyx_t_2 = __pyx_t_3;
  }
  if (__pyx_t_2) {

    /* "axon/_loader.py":997
 *         ch = current_char(self)
 *         if (ch <= '9' and ch >= '0') or ch == '.':
 *             val = self.get_number()             # <<<<<<<<<<<<<<
 *             return val
 * 
 */
    __pyx_t_4 = __pyx_f_4axon_7_loader_6Loader_get_number(__pyx_v_self); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 997; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_v_val = __pyx_t_4;
    __pyx_t_4 = 0;

    /* "axon/_loader.py":998
 *         if (ch <= '9' and ch >= '0') or ch == '.':
 *             val = self.get_number()
 *             return val             # <<<<<<<<<<<<<<
 * 
 *         if ch == '-':
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_v_val);
    __pyx_r = __pyx_v_val;
    goto __pyx_L0;
    goto __pyx_L3;
  }
  __pyx_L3:;

  /* "axon/_loader.py":1017
 *             skip_char(self)
 *             val = self.get_list_value()
 *         elif ch == '(':             # <<<<<<<<<<<<<<
 *             self.bq += 1
 *             skip_char(self)
 */
  switch (__pyx_v_ch) {

    /* "axon/_loader.py":1000
 *             return val
 * 
 *         if ch == '-':             # <<<<<<<<<<<<<<
 *             ch = self.line[self.pos+1]
 *             if ch.isdigit():
 */
    case 45:

    /* "axon/_loader.py":1001
 * 
 *         if ch == '-':
 *             ch = self.line[self.pos+1]             # <<<<<<<<<<<<<<
 *             if ch.isdigit():
 *                 val = self.get_number()
 */
    __pyx_t_5 = (__pyx_v_self->pos + 1);
    __pyx_t_6 = __Pyx_GetItemInt_Unicode(((PyObject *)__pyx_v_self->line), __pyx_t_5, sizeof(long), PyInt_FromLong, 0, 0, 0); if (unlikely(__pyx_t_6 == (Py_UCS4)-1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1001; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
    __pyx_v_ch = __pyx_t_6;

    /* "axon/_loader.py":1002
 *         if ch == '-':
 *             ch = self.line[self.pos+1]
 *             if ch.isdigit():             # <<<<<<<<<<<<<<
 *                 val = self.get_number()
 *             else:
 */
    __pyx_t_2 = Py_UNICODE_ISDIGIT(__pyx_v_ch); 
    if ((__pyx_t_2 != 0)) {

      /* "axon/_loader.py":1003
 *             ch = self.line[self.pos+1]
 *             if ch.isdigit():
 *                 val = self.get_number()             # <<<<<<<<<<<<<<
 *             else:
 *                 skip_char(self)
 */
      __pyx_t_4 = __pyx_f_4axon_7_loader_6Loader_get_number(__pyx_v_self); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1003; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_v_val = __pyx_t_4;
      __pyx_t_4 = 0;
      goto __pyx_L4;
    }
    /*else*/ {

      /* "axon/_loader.py":1005
 *                 val = self.get_number()
 *             else:
 *                 skip_char(self)             # <<<<<<<<<<<<<<
 *                 val = self.get_negative_constant()
 *         elif ch == '"':
 */
      skip_char(__pyx_v_self);

      /* "axon/_loader.py":1006
 *             else:
 *                 skip_char(self)
 *                 val = self.get_negative_constant()             # <<<<<<<<<<<<<<
 *         elif ch == '"':
 *             val = self.get_string(ch)
 */
      __pyx_t_4 = __pyx_f_4axon_7_loader_6Loader_get_negative_constant(__pyx_v_self); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1006; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_v_val = __pyx_t_4;
      __pyx_t_4 = 0;
    }
    __pyx_L4:;
    break;

    /* "axon/_loader.py":1007
 *                 skip_char(self)
 *                 val = self.get_negative_constant()
 *         elif ch == '"':             # <<<<<<<<<<<<<<
 *             val = self.get_string(ch)
 *         elif ch == '{':
 */
    case 34:

    /* "axon/_loader.py":1008
 *                 val = self.get_negative_constant()
 *         elif ch == '"':
 *             val = self.get_string(ch)             # <<<<<<<<<<<<<<
 *         elif ch == '{':
 *             self.bc += 1
 */
    __pyx_t_4 = __pyx_f_4axon_7_loader_6Loader_get_string(__pyx_v_self, __pyx_v_ch); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1008; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_v_val = __pyx_t_4;
    __pyx_t_4 = 0;
    break;

    /* "axon/_loader.py":1009
 *         elif ch == '"':
 *             val = self.get_string(ch)
 *         elif ch == '{':             # <<<<<<<<<<<<<<
 *             self.bc += 1
 *             skip_char(self)
 */
    case 123:

    /* "axon/_loader.py":1010
 *             val = self.get_string(ch)
 *         elif ch == '{':
 *             self.bc += 1             # <<<<<<<<<<<<<<
 *             skip_char(self)
 *             val = self.get_dict_value()
 */
    __pyx_v_self->bc = (__pyx_v_self->bc + 1);

    /* "axon/_loader.py":1011
 *         elif ch == '{':
 *             self.bc += 1
 *             skip_char(self)             # <<<<<<<<<<<<<<
 *             val = self.get_dict_value()
 *         elif ch == '[':
 */
    skip_char(__pyx_v_self);

    /* "axon/_loader.py":1012
 *             self.bc += 1
 *             skip_char(self)
 *             val = self.get_dict_value()             # <<<<<<<<<<<<<<
 *         elif ch == '[':
 *             self.bs += 1
 */
    __pyx_t_4 = __pyx_f_4axon_7_loader_6Loader_get_dict_value(__pyx_v_self); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1012; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_v_val = __pyx_t_4;
    __pyx_t_4 = 0;
    break;

    /* "axon/_loader.py":1013
 *             skip_char(self)
 *             val = self.get_dict_value()
 *         elif ch == '[':             # <<<<<<<<<<<<<<
 *             self.bs += 1
 *             skip_char(self)
 */
    case 91:

    /* "axon/_loader.py":1014
 *             val = self.get_dict_value()
 *         elif ch == '[':
 *             self.bs += 1             # <<<<<<<<<<<<<<
 *             skip_char(self)
 *             val = self.get_list_value()
 */
    __pyx_v_self->bs = (__pyx_v_self->bs + 1);

    /* "axon/_loader.py":1015
 *         elif ch == '[':
 *             self.bs += 1
 *             skip_char(self)             # <<<<<<<<<<<<<<
 *             val = self.get_list_value()
 *         elif ch == '(':
 */
    skip_char(__pyx_v_self);

    /* "axon/_loader.py":1016
 *             self.bs += 1
 *             skip_char(self)
 *             val = self.get_list_value()             # <<<<<<<<<<<<<<
 *         elif ch == '(':
 *             self.bq += 1
 */
    __pyx_t_4 = __pyx_f_4axon_7_loader_6Loader_get_list_value(__pyx_v_self); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1016; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_v_val = __pyx_t_4;
    __pyx_t_4 = 0;
    break;

    /* "axon/_loader.py":1017
 *             skip_char(self)
 *             val = self.get_list_value()
 *         elif ch == '(':             # <<<<<<<<<<<<<<
 *             self.bq += 1
 *             skip_char(self)
 */
    case 40:

    /* "axon/_loader.py":1018
 *             val = self.get_list_value()
 *         elif ch == '(':
 *             self.bq += 1             # <<<<<<<<<<<<<<
 *             skip_char(self)
 *             val = self.get_tuple_value()
 */
    __pyx_v_self->bq = (__pyx_v_self->bq + 1);

    /* "axon/_loader.py":1019
 *         elif ch == '(':
 *             self.bq += 1
 *             skip_char(self)             # <<<<<<<<<<<<<<
 *             val = self.get_tuple_value()
 *         else:
 */
    skip_char(__pyx_v_self);

    /* "axon/_loader.py":1020
 *             self.bq += 1
 *             skip_char(self)
 *             val = self.get_tuple_value()             # <<<<<<<<<<<<<<
 *         else:
 *             name = self.try_get_name()
 */
    __pyx_t_4 = __pyx_f_4axon_7_loader_6Loader_get_tuple_value(__pyx_v_self); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1020; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_v_val = __pyx_t_4;
    __pyx_t_4 = 0;
    break;
    default:

    /* "axon/_loader.py":1022
 *             val = self.get_tuple_value()
 *         else:
 *             name = self.try_get_name()             # <<<<<<<<<<<<<<
 *             if name is not None:
 *                 ch = current_char(self)
 */
    __pyx_t_4 = __pyx_f_4axon_7_loader_6Loader_try_get_name(__pyx_v_self); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1022; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_v_name = __pyx_t_4;
    __pyx_t_4 = 0;

    /* "axon/_loader.py":1023
 *         else:
 *             name = self.try_get_name()
 *             if name is not None:             # <<<<<<<<<<<<<<
 *                 ch = current_char(self)
 * 
 */
    __pyx_t_2 = (__pyx_v_name != Py_None);
    __pyx_t_3 = (__pyx_t_2 != 0);
    if (__pyx_t_3) {

      /* "axon/_loader.py":1024
 *             name = self.try_get_name()
 *             if name is not None:
 *                 ch = current_char(self)             # <<<<<<<<<<<<<<
 * 
 *                 if ch == '*':
 */
      __pyx_v_ch = current_char(__pyx_v_self);

      /* "axon/_loader.py":1026
 *                 ch = current_char(self)
 * 
 *                 if ch == '*':             # <<<<<<<<<<<<<<
 *                     ch = next_char(self)
 *                     is_multi = 1
 */
      __pyx_t_3 = ((__pyx_v_ch == 42) != 0);
      if (__pyx_t_3) {

        /* "axon/_loader.py":1027
 * 
 *                 if ch == '*':
 *                     ch = next_char(self)             # <<<<<<<<<<<<<<
 *                     is_multi = 1
 *                 else:
 */
        __pyx_v_ch = next_char(__pyx_v_self);

        /* "axon/_loader.py":1028
 *                 if ch == '*':
 *                     ch = next_char(self)
 *                     is_multi = 1             # <<<<<<<<<<<<<<
 *                 else:
 *                     is_multi = 0
 */
        __pyx_v_is_multi = 1;
        goto __pyx_L6;
      }
      /*else*/ {

        /* "axon/_loader.py":1030
 *                     is_multi = 1
 *                 else:
 *                     is_multi = 0             # <<<<<<<<<<<<<<
 * 
 *                 ch = self.skip_spaces()
 */
        __pyx_v_is_multi = 0;
      }
      __pyx_L6:;

      /* "axon/_loader.py":1032
 *                     is_multi = 0
 * 
 *                 ch = self.skip_spaces()             # <<<<<<<<<<<<<<
 *                 if ch == '{':
 *                     self.bc += 1
 */
      __pyx_v_ch = __pyx_f_4axon_7_loader_6Loader_skip_spaces(__pyx_v_self);

      /* "axon/_loader.py":1033
 * 
 *                 ch = self.skip_spaces()
 *                 if ch == '{':             # <<<<<<<<<<<<<<
 *                     self.bc += 1
 *                     skip_char(self)
 */
      __pyx_t_3 = ((__pyx_v_ch == 123) != 0);
      if (__pyx_t_3) {

        /* "axon/_loader.py":1034
 *                 ch = self.skip_spaces()
 *                 if ch == '{':
 *                     self.bc += 1             # <<<<<<<<<<<<<<
 *                     skip_char(self)
 *                     self.moveto_next_token()
 */
        __pyx_v_self->bc = (__pyx_v_self->bc + 1);

        /* "axon/_loader.py":1035
 *                 if ch == '{':
 *                     self.bc += 1
 *                     skip_char(self)             # <<<<<<<<<<<<<<
 *                     self.moveto_next_token()
 * 
 */
        skip_char(__pyx_v_self);

        /* "axon/_loader.py":1036
 *                     self.bc += 1
 *                     skip_char(self)
 *                     self.moveto_next_token()             # <<<<<<<<<<<<<<
 * 
 *                     if is_multi:
 */
        __pyx_t_6 = __pyx_f_4axon_7_loader_6Loader_moveto_next_token(__pyx_v_self); if (unlikely(__pyx_t_6 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1036; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

        /* "axon/_loader.py":1038
 *                     self.moveto_next_token()
 * 
 *                     if is_multi:             # <<<<<<<<<<<<<<
 *                         val = self.get_collection(name, 0)
 *                     else:
 */
        __pyx_t_3 = (__pyx_v_is_multi != 0);
        if (__pyx_t_3) {

          /* "axon/_loader.py":1039
 * 
 *                     if is_multi:
 *                         val = self.get_collection(name, 0)             # <<<<<<<<<<<<<<
 *                     else:
 *                         val = self.get_complex_value(name, 0)
 */
          __pyx_t_4 = __pyx_f_4axon_7_loader_6Loader_get_collection(__pyx_v_self, __pyx_v_name, 0); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1039; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
          __Pyx_GOTREF(__pyx_t_4);
          __pyx_v_val = __pyx_t_4;
          __pyx_t_4 = 0;
          goto __pyx_L8;
        }
        /*else*/ {

          /* "axon/_loader.py":1041
 *                         val = self.get_collection(name, 0)
 *                     else:
 *                         val = self.get_complex_value(name, 0)             # <<<<<<<<<<<<<<
 *                 elif ch == ':':
 *                     skip_char(self)
 */
          __pyx_t_4 = __pyx_f_4axon_7_loader_6Loader_get_complex_value(__pyx_v_self, __pyx_v_name, 0); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1041; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
          __Pyx_GOTREF(__pyx_t_4);
          __pyx_v_val = __pyx_t_4;
          __pyx_t_4 = 0;
        }
        __pyx_L8:;
        goto __pyx_L7;
      }

      /* "axon/_loader.py":1042
 *                     else:
 *                         val = self.get_complex_value(name, 0)
 *                 elif ch == ':':             # <<<<<<<<<<<<<<
 *                     skip_char(self)
 *                     ch = self.moveto_next_token()
 */
      __pyx_t_3 = ((__pyx_v_ch == 58) != 0);
      if (__pyx_t_3) {

        /* "axon/_loader.py":1043
 *                         val = self.get_complex_value(name, 0)
 *                 elif ch == ':':
 *                     skip_char(self)             # <<<<<<<<<<<<<<
 *                     ch = self.moveto_next_token()
 * 
 */
        skip_char(__pyx_v_self);

        /* "axon/_loader.py":1044
 *                 elif ch == ':':
 *                     skip_char(self)
 *                     ch = self.moveto_next_token()             # <<<<<<<<<<<<<<
 * 
 *                     if ch == '.':
 */
        __pyx_t_6 = __pyx_f_4axon_7_loader_6Loader_moveto_next_token(__pyx_v_self); if (unlikely(__pyx_t_6 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1044; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __pyx_v_ch = __pyx_t_6;

        /* "axon/_loader.py":1046
 *                     ch = self.moveto_next_token()
 * 
 *                     if ch == '.':             # <<<<<<<<<<<<<<
 *                         if self.get_dots():
 *                             return self.builder.create_empty(name)
 */
        __pyx_t_3 = ((__pyx_v_ch == 46) != 0);
        if (__pyx_t_3) {

          /* "axon/_loader.py":1047
 * 
 *                     if ch == '.':
 *                         if self.get_dots():             # <<<<<<<<<<<<<<
 *                             return self.builder.create_empty(name)
 *                         else:
 */
          __pyx_t_3 = (__pyx_f_4axon_7_loader_6Loader_get_dots(__pyx_v_self) != 0);
          if (__pyx_t_3) {

            /* "axon/_loader.py":1048
 *                     if ch == '.':
 *                         if self.get_dots():
 *                             return self.builder.create_empty(name)             # <<<<<<<<<<<<<<
 *                         else:
 *                             errors.invalid_value(self)
 */
            __Pyx_XDECREF(__pyx_r);
            __pyx_t_4 = __pyx_v_self->builder->create_empty(__pyx_v_name); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1048; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
            __Pyx_GOTREF(__pyx_t_4);
            __pyx_r = __pyx_t_4;
            __pyx_t_4 = 0;
            goto __pyx_L0;
            goto __pyx_L10;
          }
          /*else*/ {

            /* "axon/_loader.py":1050
 *                             return self.builder.create_empty(name)
 *                         else:
 *                             errors.invalid_value(self)             # <<<<<<<<<<<<<<
 * 
 *                     if self.is_nl:
 */
            __pyx_t_4 = __Pyx_GetModuleGlobalName(__pyx_n_s__errors); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1050; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
            __Pyx_GOTREF(__pyx_t_4);
            __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s__invalid_value); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1050; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
            __Pyx_GOTREF(__pyx_t_7);
            __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
            __pyx_t_4 = PyTuple_New(1); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1050; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
            __Pyx_GOTREF(__pyx_t_4);
            __Pyx_INCREF(((PyObject *)__pyx_v_self));
            PyTuple_SET_ITEM(__pyx_t_4, 0, ((PyObject *)__pyx_v_self));
            __Pyx_GIVEREF(((PyObject *)__pyx_v_self));
            __pyx_t_8 = PyObject_Call(__pyx_t_7, ((PyObject *)__pyx_t_4), NULL); if (unlikely(!__pyx_t_8)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1050; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
            __Pyx_GOTREF(__pyx_t_8);
            __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
            __Pyx_DECREF(((PyObject *)__pyx_t_4)); __pyx_t_4 = 0;
            __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
          }
          __pyx_L10:;
          goto __pyx_L9;
        }
        __pyx_L9:;

        /* "axon/_loader.py":1052
 *                             errors.invalid_value(self)
 * 
 *                     if self.is_nl:             # <<<<<<<<<<<<<<
 *                         if self.pos > idn:
 *                             if is_multi:
 */
        __pyx_t_3 = (__pyx_v_self->is_nl != 0);
        if (__pyx_t_3) {

          /* "axon/_loader.py":1053
 * 
 *                     if self.is_nl:
 *                         if self.pos > idn:             # <<<<<<<<<<<<<<
 *                             if is_multi:
 *                                 val = self.get_collection(name, self.pos)
 */
          __pyx_t_3 = ((__pyx_v_self->pos > __pyx_v_idn) != 0);
          if (__pyx_t_3) {

            /* "axon/_loader.py":1054
 *                     if self.is_nl:
 *                         if self.pos > idn:
 *                             if is_multi:             # <<<<<<<<<<<<<<
 *                                 val = self.get_collection(name, self.pos)
 *                             else:
 */
            __pyx_t_3 = (__pyx_v_is_multi != 0);
            if (__pyx_t_3) {

              /* "axon/_loader.py":1055
 *                         if self.pos > idn:
 *                             if is_multi:
 *                                 val = self.get_collection(name, self.pos)             # <<<<<<<<<<<<<<
 *                             else:
 *                                 val = self.get_complex_value(name, self.pos)
 */
              __pyx_t_8 = __pyx_f_4axon_7_loader_6Loader_get_collection(__pyx_v_self, __pyx_v_name, __pyx_v_self->pos); if (unlikely(!__pyx_t_8)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1055; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
              __Pyx_GOTREF(__pyx_t_8);
              __pyx_v_val = __pyx_t_8;
              __pyx_t_8 = 0;
              goto __pyx_L13;
            }
            /*else*/ {

              /* "axon/_loader.py":1057
 *                                 val = self.get_collection(name, self.pos)
 *                             else:
 *                                 val = self.get_complex_value(name, self.pos)             # <<<<<<<<<<<<<<
 *                         else:
 *                             errors.error_indentation(self, idn)
 */
              __pyx_t_8 = __pyx_f_4axon_7_loader_6Loader_get_complex_value(__pyx_v_self, __pyx_v_name, __pyx_v_self->pos); if (unlikely(!__pyx_t_8)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1057; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
              __Pyx_GOTREF(__pyx_t_8);
              __pyx_v_val = __pyx_t_8;
              __pyx_t_8 = 0;
            }
            __pyx_L13:;
            goto __pyx_L12;
          }
          /*else*/ {

            /* "axon/_loader.py":1059
 *                                 val = self.get_complex_value(name, self.pos)
 *                         else:
 *                             errors.error_indentation(self, idn)             # <<<<<<<<<<<<<<
 *                     else:
 *                         errors.error_unexpected_attribute(self, name)
 */
            __pyx_t_8 = __Pyx_GetModuleGlobalName(__pyx_n_s__errors); if (unlikely(!__pyx_t_8)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1059; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
            __Pyx_GOTREF(__pyx_t_8);
            __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_8, __pyx_n_s__error_indentation); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1059; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
            __Pyx_GOTREF(__pyx_t_4);
            __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
            __pyx_t_8 = PyInt_FromLong(__pyx_v_idn); if (unlikely(!__pyx_t_8)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1059; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
            __Pyx_GOTREF(__pyx_t_8);
            __pyx_t_7 = PyTuple_New(2); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1059; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
            __Pyx_GOTREF(__pyx_t_7);
            __Pyx_INCREF(((PyObject *)__pyx_v_self));
            PyTuple_SET_ITEM(__pyx_t_7, 0, ((PyObject *)__pyx_v_self));
            __Pyx_GIVEREF(((PyObject *)__pyx_v_self));
            PyTuple_SET_ITEM(__pyx_t_7, 1, __pyx_t_8);
            __Pyx_GIVEREF(__pyx_t_8);
            __pyx_t_8 = 0;
            __pyx_t_8 = PyObject_Call(__pyx_t_4, ((PyObject *)__pyx_t_7), NULL); if (unlikely(!__pyx_t_8)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1059; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
            __Pyx_GOTREF(__pyx_t_8);
            __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
            __Pyx_DECREF(((PyObject *)__pyx_t_7)); __pyx_t_7 = 0;
            __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
          }
          __pyx_L12:;
          goto __pyx_L11;
        }
        /*else*/ {

          /* "axon/_loader.py":1061
 *                             errors.error_indentation(self, idn)
 *                     else:
 *                         errors.error_unexpected_attribute(self, name)             # <<<<<<<<<<<<<<
 *                 else:
 *                     val = self.get_constant_or_string(name)
 */
          __pyx_t_8 = __Pyx_GetModuleGlobalName(__pyx_n_s__errors); if (unlikely(!__pyx_t_8)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1061; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
          __Pyx_GOTREF(__pyx_t_8);
          __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_8, __pyx_n_s_36); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1061; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
          __Pyx_GOTREF(__pyx_t_7);
          __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
          __pyx_t_8 = PyTuple_New(2); if (unlikely(!__pyx_t_8)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1061; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
          __Pyx_GOTREF(__pyx_t_8);
          __Pyx_INCREF(((PyObject *)__pyx_v_self));
          PyTuple_SET_ITEM(__pyx_t_8, 0, ((PyObject *)__pyx_v_self));
          __Pyx_GIVEREF(((PyObject *)__pyx_v_self));
          __Pyx_INCREF(__pyx_v_name);
          PyTuple_SET_ITEM(__pyx_t_8, 1, __pyx_v_name);
          __Pyx_GIVEREF(__pyx_v_name);
          __pyx_t_4 = PyObject_Call(__pyx_t_7, ((PyObject *)__pyx_t_8), NULL); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1061; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
          __Pyx_GOTREF(__pyx_t_4);
          __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
          __Pyx_DECREF(((PyObject *)__pyx_t_8)); __pyx_t_8 = 0;
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        }
        __pyx_L11:;
        goto __pyx_L7;
      }
      /*else*/ {

        /* "axon/_loader.py":1063
 *                         errors.error_unexpected_attribute(self, name)
 *                 else:
 *                     val = self.get_constant_or_string(name)             # <<<<<<<<<<<<<<
 *             elif ch == '|':
 *                 val = self.get_base64()
 */
        if (!(likely(PyUnicode_CheckExact(__pyx_v_name))||((__pyx_v_name) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected unicode, got %.200s", Py_TYPE(__pyx_v_name)->tp_name), 0))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1063; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __pyx_t_4 = __pyx_f_4axon_7_loader_6Loader_get_constant_or_string(__pyx_v_self, ((PyObject*)__pyx_v_name)); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1063; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_4);
        __pyx_v_val = __pyx_t_4;
        __pyx_t_4 = 0;
      }
      __pyx_L7:;
      goto __pyx_L5;
    }

    /* "axon/_loader.py":1064
 *                 else:
 *                     val = self.get_constant_or_string(name)
 *             elif ch == '|':             # <<<<<<<<<<<<<<
 *                 val = self.get_base64()
 *             elif ch == '': # \U221E
 */
    __pyx_t_3 = ((__pyx_v_ch == 124) != 0);
    if (__pyx_t_3) {

      /* "axon/_loader.py":1065
 *                     val = self.get_constant_or_string(name)
 *             elif ch == '|':
 *                 val = self.get_base64()             # <<<<<<<<<<<<<<
 *             elif ch == '': # \U221E
 *                 skip_char(self)
 */
      __pyx_t_4 = __pyx_f_4axon_7_loader_6Loader_get_base64(__pyx_v_self); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1065; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_v_val = __pyx_t_4;
      __pyx_t_4 = 0;
      goto __pyx_L5;
    }

    /* "axon/_loader.py":1066
 *             elif ch == '|':
 *                 val = self.get_base64()
 *             elif ch == '': # \U221E             # <<<<<<<<<<<<<<
 *                 skip_char(self)
 *                 val = self.sbuilder.create_inf()
 */
    __pyx_t_3 = ((__pyx_v_ch == 8734) != 0);
    if (__pyx_t_3) {

      /* "axon/_loader.py":1067
 *                 val = self.get_base64()
 *             elif ch == '': # \U221E
 *                 skip_char(self)             # <<<<<<<<<<<<<<
 *                 val = self.sbuilder.create_inf()
 *             elif ch == '?':
 */
      skip_char(__pyx_v_self);

      /* "axon/_loader.py":1068
 *             elif ch == '': # \U221E
 *                 skip_char(self)
 *                 val = self.sbuilder.create_inf()             # <<<<<<<<<<<<<<
 *             elif ch == '?':
 *                 skip_char(self)
 */
      __pyx_t_4 = __pyx_v_self->sbuilder->create_inf(); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1068; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_v_val = __pyx_t_4;
      __pyx_t_4 = 0;
      goto __pyx_L5;
    }

    /* "axon/_loader.py":1069
 *                 skip_char(self)
 *                 val = self.sbuilder.create_inf()
 *             elif ch == '?':             # <<<<<<<<<<<<<<
 *                 skip_char(self)
 *                 if current_char(self) == '?':
 */
    __pyx_t_3 = ((__pyx_v_ch == 63) != 0);
    if (__pyx_t_3) {

      /* "axon/_loader.py":1070
 *                 val = self.sbuilder.create_inf()
 *             elif ch == '?':
 *                 skip_char(self)             # <<<<<<<<<<<<<<
 *                 if current_char(self) == '?':
 *                     skip_char(self)
 */
      skip_char(__pyx_v_self);

      /* "axon/_loader.py":1071
 *             elif ch == '?':
 *                 skip_char(self)
 *                 if current_char(self) == '?':             # <<<<<<<<<<<<<<
 *                     skip_char(self)
 *                     val = c_undefined
 */
      __pyx_t_3 = ((current_char(__pyx_v_self) == 63) != 0);
      if (__pyx_t_3) {

        /* "axon/_loader.py":1072
 *                 skip_char(self)
 *                 if current_char(self) == '?':
 *                     skip_char(self)             # <<<<<<<<<<<<<<
 *                     val = c_undefined
 *                 else:
 */
        skip_char(__pyx_v_self);

        /* "axon/_loader.py":1073
 *                 if current_char(self) == '?':
 *                     skip_char(self)
 *                     val = c_undefined             # <<<<<<<<<<<<<<
 *                 else:
 *                     val = self.sbuilder.create_nan()
 */
        __Pyx_INCREF(__pyx_v_4axon_8_objects_c_undefined);
        __pyx_v_val = __pyx_v_4axon_8_objects_c_undefined;
        goto __pyx_L14;
      }
      /*else*/ {

        /* "axon/_loader.py":1075
 *                     val = c_undefined
 *                 else:
 *                     val = self.sbuilder.create_nan()             # <<<<<<<<<<<<<<
 *             elif ch == '': # \U22A4
 *                 skip_char(self)
 */
        __pyx_t_4 = __pyx_v_self->sbuilder->create_nan(); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1075; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_4);
        __pyx_v_val = __pyx_t_4;
        __pyx_t_4 = 0;
      }
      __pyx_L14:;
      goto __pyx_L5;
    }

    /* "axon/_loader.py":1076
 *                 else:
 *                     val = self.sbuilder.create_nan()
 *             elif ch == '': # \U22A4             # <<<<<<<<<<<<<<
 *                 skip_char(self)
 *                 val = True
 */
    __pyx_t_3 = ((__pyx_v_ch == 8868) != 0);
    if (__pyx_t_3) {

      /* "axon/_loader.py":1077
 *                     val = self.sbuilder.create_nan()
 *             elif ch == '': # \U22A4
 *                 skip_char(self)             # <<<<<<<<<<<<<<
 *                 val = True
 *             elif ch == '': # \U22A5
 */
      skip_char(__pyx_v_self);

      /* "axon/_loader.py":1078
 *             elif ch == '': # \U22A4
 *                 skip_char(self)
 *                 val = True             # <<<<<<<<<<<<<<
 *             elif ch == '': # \U22A5
 *                 skip_char(self)
 */
      __pyx_t_4 = __Pyx_PyBool_FromLong(1); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1078; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_v_val = __pyx_t_4;
      __pyx_t_4 = 0;
      goto __pyx_L5;
    }

    /* "axon/_loader.py":1079
 *                 skip_char(self)
 *                 val = True
 *             elif ch == '': # \U22A5             # <<<<<<<<<<<<<<
 *                 skip_char(self)
 *                 val = False
 */
    __pyx_t_3 = ((__pyx_v_ch == 8869) != 0);
    if (__pyx_t_3) {

      /* "axon/_loader.py":1080
 *                 val = True
 *             elif ch == '': # \U22A5
 *                 skip_char(self)             # <<<<<<<<<<<<<<
 *                 val = False
 *             elif ch == '*':
 */
      skip_char(__pyx_v_self);

      /* "axon/_loader.py":1081
 *             elif ch == '': # \U22A5
 *                 skip_char(self)
 *                 val = False             # <<<<<<<<<<<<<<
 *             elif ch == '*':
 *                 skip_char(self)
 */
      __pyx_t_4 = __Pyx_PyBool_FromLong(0); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1081; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_v_val = __pyx_t_4;
      __pyx_t_4 = 0;
      goto __pyx_L5;
    }

    /* "axon/_loader.py":1082
 *                 skip_char(self)
 *                 val = False
 *             elif ch == '*':             # <<<<<<<<<<<<<<
 *                 skip_char(self)
 *                 label = self.try_get_label()
 */
    __pyx_t_3 = ((__pyx_v_ch == 42) != 0);
    if (__pyx_t_3) {

      /* "axon/_loader.py":1083
 *                 val = False
 *             elif ch == '*':
 *                 skip_char(self)             # <<<<<<<<<<<<<<
 *                 label = self.try_get_label()
 *                 if self.eof:
 */
      skip_char(__pyx_v_self);

      /* "axon/_loader.py":1084
 *             elif ch == '*':
 *                 skip_char(self)
 *                 label = self.try_get_label()             # <<<<<<<<<<<<<<
 *                 if self.eof:
 *                     errors.error_unexpected_end(self)
 */
      __pyx_t_4 = __pyx_f_4axon_7_loader_6Loader_try_get_label(__pyx_v_self); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1084; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_v_label = __pyx_t_4;
      __pyx_t_4 = 0;

      /* "axon/_loader.py":1085
 *                 skip_char(self)
 *                 label = self.try_get_label()
 *                 if self.eof:             # <<<<<<<<<<<<<<
 *                     errors.error_unexpected_end(self)
 *                 if label is not None:
 */
      __pyx_t_3 = (__pyx_v_self->eof != 0);
      if (__pyx_t_3) {

        /* "axon/_loader.py":1086
 *                 label = self.try_get_label()
 *                 if self.eof:
 *                     errors.error_unexpected_end(self)             # <<<<<<<<<<<<<<
 *                 if label is not None:
 *                     val = self.labeled_objects.get(label, c_undefined)
 */
        __pyx_t_4 = __Pyx_GetModuleGlobalName(__pyx_n_s__errors); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1086; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_4);
        __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_23); if (unlikely(!__pyx_t_8)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1086; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __pyx_t_4 = PyTuple_New(1); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1086; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_INCREF(((PyObject *)__pyx_v_self));
        PyTuple_SET_ITEM(__pyx_t_4, 0, ((PyObject *)__pyx_v_self));
        __Pyx_GIVEREF(((PyObject *)__pyx_v_self));
        __pyx_t_7 = PyObject_Call(__pyx_t_8, ((PyObject *)__pyx_t_4), NULL); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1086; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        __Pyx_DECREF(((PyObject *)__pyx_t_4)); __pyx_t_4 = 0;
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        goto __pyx_L15;
      }
      __pyx_L15:;

      /* "axon/_loader.py":1087
 *                 if self.eof:
 *                     errors.error_unexpected_end(self)
 *                 if label is not None:             # <<<<<<<<<<<<<<
 *                     val = self.labeled_objects.get(label, c_undefined)
 *                 else:
 */
      __pyx_t_3 = (__pyx_v_label != Py_None);
      __pyx_t_2 = (__pyx_t_3 != 0);
      if (__pyx_t_2) {

        /* "axon/_loader.py":1088
 *                     errors.error_unexpected_end(self)
 *                 if label is not None:
 *                     val = self.labeled_objects.get(label, c_undefined)             # <<<<<<<<<<<<<<
 *                 else:
 *                     val = c_undefined
 */
        if (unlikely(((PyObject *)__pyx_v_self->labeled_objects) == Py_None)) {
          PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%s'", "get");
          {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1088; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        }
        __pyx_t_7 = __Pyx_PyDict_GetItemDefault(((PyObject *)__pyx_v_self->labeled_objects), __pyx_v_label, __pyx_v_4axon_8_objects_c_undefined); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1088; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_7);
        __pyx_v_val = __pyx_t_7;
        __pyx_t_7 = 0;
        goto __pyx_L16;
      }
      /*else*/ {

        /* "axon/_loader.py":1090
 *                     val = self.labeled_objects.get(label, c_undefined)
 *                 else:
 *                     val = c_undefined             # <<<<<<<<<<<<<<
 *             elif ch == '&':
 *                 pos0 = self.pos
 */
        __Pyx_INCREF(__pyx_v_4axon_8_objects_c_undefined);
        __pyx_v_val = __pyx_v_4axon_8_objects_c_undefined;
      }
      __pyx_L16:;
      goto __pyx_L5;
    }

    /* "axon/_loader.py":1091
 *                 else:
 *                     val = c_undefined
 *             elif ch == '&':             # <<<<<<<<<<<<<<
 *                 pos0 = self.pos
 *                 skip_char(self)
 */
    __pyx_t_2 = ((__pyx_v_ch == 38) != 0);
    if (__pyx_t_2) {

      /* "axon/_loader.py":1092
 *                     val = c_undefined
 *             elif ch == '&':
 *                 pos0 = self.pos             # <<<<<<<<<<<<<<
 *                 skip_char(self)
 *                 label = self.try_get_label()
 */
      __pyx_t_9 = __pyx_v_self->pos;
      __pyx_v_pos0 = __pyx_t_9;

      /* "axon/_loader.py":1093
 *             elif ch == '&':
 *                 pos0 = self.pos
 *                 skip_char(self)             # <<<<<<<<<<<<<<
 *                 label = self.try_get_label()
 * 
 */
      skip_char(__pyx_v_self);

      /* "axon/_loader.py":1094
 *                 pos0 = self.pos
 *                 skip_char(self)
 *                 label = self.try_get_label()             # <<<<<<<<<<<<<<
 * 
 *                 self.moveto_next_token()
 */
      __pyx_t_7 = __pyx_f_4axon_7_loader_6Loader_try_get_label(__pyx_v_self); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1094; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_v_label = __pyx_t_7;
      __pyx_t_7 = 0;

      /* "axon/_loader.py":1096
 *                 label = self.try_get_label()
 * 
 *                 self.moveto_next_token()             # <<<<<<<<<<<<<<
 * 
 *                 val = self.get_value(pos0)
 */
      __pyx_t_6 = __pyx_f_4axon_7_loader_6Loader_moveto_next_token(__pyx_v_self); if (unlikely(__pyx_t_6 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1096; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

      /* "axon/_loader.py":1098
 *                 self.moveto_next_token()
 * 
 *                 val = self.get_value(pos0)             # <<<<<<<<<<<<<<
 *                 self.labeled_objects[label] = val
 *             elif ch == '#':
 */
      __pyx_t_7 = __pyx_f_4axon_7_loader_6Loader_get_value(__pyx_v_self, __pyx_v_pos0); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1098; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_v_val = __pyx_t_7;
      __pyx_t_7 = 0;

      /* "axon/_loader.py":1099
 * 
 *                 val = self.get_value(pos0)
 *                 self.labeled_objects[label] = val             # <<<<<<<<<<<<<<
 *             elif ch == '#':
 *                 self.skip_comments()
 */
      if (unlikely(((PyObject *)__pyx_v_self->labeled_objects) == Py_None)) {
        PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
        {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1099; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      }
      if (PyDict_SetItem(((PyObject *)__pyx_v_self->labeled_objects), __pyx_v_label, __pyx_v_val) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1099; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      goto __pyx_L5;
    }

    /* "axon/_loader.py":1100
 *                 val = self.get_value(pos0)
 *                 self.labeled_objects[label] = val
 *             elif ch == '#':             # <<<<<<<<<<<<<<
 *                 self.skip_comments()
 *                 if self.eof:
 */
    __pyx_t_2 = ((__pyx_v_ch == 35) != 0);
    if (__pyx_t_2) {

      /* "axon/_loader.py":1101
 *                 self.labeled_objects[label] = val
 *             elif ch == '#':
 *                 self.skip_comments()             # <<<<<<<<<<<<<<
 *                 if self.eof:
 *                     errors.error_unexpected_end(self)
 */
      __pyx_f_4axon_7_loader_6Loader_skip_comments(__pyx_v_self);

      /* "axon/_loader.py":1102
 *             elif ch == '#':
 *                 self.skip_comments()
 *                 if self.eof:             # <<<<<<<<<<<<<<
 *                     errors.error_unexpected_end(self)
 *                 val = self.get_value(idn)
 */
      __pyx_t_2 = (__pyx_v_self->eof != 0);
      if (__pyx_t_2) {

        /* "axon/_loader.py":1103
 *                 self.skip_comments()
 *                 if self.eof:
 *                     errors.error_unexpected_end(self)             # <<<<<<<<<<<<<<
 *                 val = self.get_value(idn)
 *             else:
 */
        __pyx_t_7 = __Pyx_GetModuleGlobalName(__pyx_n_s__errors); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1103; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_7);
        __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_23); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1103; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        __pyx_t_7 = PyTuple_New(1); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1103; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_INCREF(((PyObject *)__pyx_v_self));
        PyTuple_SET_ITEM(__pyx_t_7, 0, ((PyObject *)__pyx_v_self));
        __Pyx_GIVEREF(((PyObject *)__pyx_v_self));
        __pyx_t_8 = PyObject_Call(__pyx_t_4, ((PyObject *)__pyx_t_7), NULL); if (unlikely(!__pyx_t_8)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1103; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_DECREF(((PyObject *)__pyx_t_7)); __pyx_t_7 = 0;
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        goto __pyx_L17;
      }
      __pyx_L17:;

      /* "axon/_loader.py":1104
 *                 if self.eof:
 *                     errors.error_unexpected_end(self)
 *                 val = self.get_value(idn)             # <<<<<<<<<<<<<<
 *             else:
 *                 errors.error_unexpected_value(self, 'expected named complex value')
 */
      __pyx_t_8 = __pyx_f_4axon_7_loader_6Loader_get_value(__pyx_v_self, __pyx_v_idn); if (unlikely(!__pyx_t_8)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1104; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_8);
      __pyx_v_val = __pyx_t_8;
      __pyx_t_8 = 0;
      goto __pyx_L5;
    }
    /*else*/ {

      /* "axon/_loader.py":1106
 *                 val = self.get_value(idn)
 *             else:
 *                 errors.error_unexpected_value(self, 'expected named complex value')             # <<<<<<<<<<<<<<
 * 
 *         #if not valid_end_item(self):
 */
      __pyx_t_8 = __Pyx_GetModuleGlobalName(__pyx_n_s__errors); if (unlikely(!__pyx_t_8)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1106; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_8);
      __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_8, __pyx_n_s_25); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1106; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_t_8 = PyTuple_New(2); if (unlikely(!__pyx_t_8)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1106; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_INCREF(((PyObject *)__pyx_v_self));
      PyTuple_SET_ITEM(__pyx_t_8, 0, ((PyObject *)__pyx_v_self));
      __Pyx_GIVEREF(((PyObject *)__pyx_v_self));
      __Pyx_INCREF(((PyObject *)__pyx_kp_u_37));
      PyTuple_SET_ITEM(__pyx_t_8, 1, ((PyObject *)__pyx_kp_u_37));
      __Pyx_GIVEREF(((PyObject *)__pyx_kp_u_37));
      __pyx_t_4 = PyObject_Call(__pyx_t_7, ((PyObject *)__pyx_t_8), NULL); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1106; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_DECREF(((PyObject *)__pyx_t_8)); __pyx_t_8 = 0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
    __pyx_L5:;
    break;
  }

  /* "axon/_loader.py":1111
 *         #    errors.error_end_item(self)
 * 
 *         return val             # <<<<<<<<<<<<<<
 *     #
 *     def get_collection(self, name, idn):
 */
  __Pyx_XDECREF(__pyx_r);
  if (unlikely(!__pyx_v_val)) { __Pyx_RaiseUnboundLocalError("val"); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1111; __pyx_clineno = __LINE__; goto __pyx_L1_error;} }
  __Pyx_INCREF(__pyx_v_val);
  __pyx_r = __pyx_v_val;
  goto __pyx_L0;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("axon._loader.Loader.get_value", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_val);
  __Pyx_XDECREF(__pyx_v_name);
  __Pyx_XDECREF(__pyx_v_label);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_loader.py":1113
 *         return val
 *     #
 *     def get_collection(self, name, idn):             # <<<<<<<<<<<<<<
 *         values = []
 *         while 1:
 */

static PyObject *__pyx_f_4axon_7_loader_6Loader_get_collection(struct __pyx_obj_4axon_7_loader_Loader *__pyx_v_self, PyObject *__pyx_v_name, int __pyx_v_idn) {
  Py_UCS4 __pyx_v_ch;
  PyObject *__pyx_v_values = 0;
  PyObject *__pyx_v_val = 0;
  PyObject *__pyx_v_label = NULL;
  int __pyx_v_pos0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  Py_UCS4 __pyx_t_3;
  int __pyx_t_4;
  int __pyx_t_5;
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  int __pyx_t_9;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_collection", 0);

  /* "axon/_loader.py":1114
 *     #
 *     def get_collection(self, name, idn):
 *         values = []             # <<<<<<<<<<<<<<
 *         while 1:
 *             ch = current_char(self)
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1114; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_values = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "axon/_loader.py":1115
 *     def get_collection(self, name, idn):
 *         values = []
 *         while 1:             # <<<<<<<<<<<<<<
 *             ch = current_char(self)
 * 
 */
  while (1) {
    if (!1) break;

    /* "axon/_loader.py":1116
 *         values = []
 *         while 1:
 *             ch = current_char(self)             # <<<<<<<<<<<<<<
 * 
 *             label = None
 */
    __pyx_v_ch = current_char(__pyx_v_self);

    /* "axon/_loader.py":1118
 *             ch = current_char(self)
 * 
 *             label = None             # <<<<<<<<<<<<<<
 *             if ch == '&':
 *                 skip_char(self)
 */
    __Pyx_INCREF(Py_None);
    __Pyx_XDECREF(__pyx_v_label);
    __pyx_v_label = Py_None;

    /* "axon/_loader.py":1119
 * 
 *             label = None
 *             if ch == '&':             # <<<<<<<<<<<<<<
 *                 skip_char(self)
 * 
 */
    __pyx_t_2 = ((__pyx_v_ch == 38) != 0);
    if (__pyx_t_2) {

      /* "axon/_loader.py":1120
 *             label = None
 *             if ch == '&':
 *                 skip_char(self)             # <<<<<<<<<<<<<<
 * 
 *                 label = self.try_get_label()
 */
      skip_char(__pyx_v_self);

      /* "axon/_loader.py":1122
 *                 skip_char(self)
 * 
 *                 label = self.try_get_label()             # <<<<<<<<<<<<<<
 * 
 *                 ch = self.moveto_next_token()
 */
      __pyx_t_1 = __pyx_f_4axon_7_loader_6Loader_try_get_label(__pyx_v_self); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1122; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_v_label);
      __pyx_v_label = __pyx_t_1;
      __pyx_t_1 = 0;

      /* "axon/_loader.py":1124
 *                 label = self.try_get_label()
 * 
 *                 ch = self.moveto_next_token()             # <<<<<<<<<<<<<<
 * 
 *             if idn:
 */
      __pyx_t_3 = __pyx_f_4axon_7_loader_6Loader_moveto_next_token(__pyx_v_self); if (unlikely(__pyx_t_3 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1124; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __pyx_v_ch = __pyx_t_3;
      goto __pyx_L5;
    }
    __pyx_L5:;

    /* "axon/_loader.py":1126
 *                 ch = self.moveto_next_token()
 * 
 *             if idn:             # <<<<<<<<<<<<<<
 *                 if self.pos == idn:
 *                     pass
 */
    __pyx_t_2 = (__pyx_v_idn != 0);
    if (__pyx_t_2) {

      /* "axon/_loader.py":1127
 * 
 *             if idn:
 *                 if self.pos == idn:             # <<<<<<<<<<<<<<
 *                     pass
 *                 elif self.pos < idn or self.eof or ch == '}' or ch == ']' or ch == ')':
 */
      __pyx_t_2 = ((__pyx_v_self->pos == __pyx_v_idn) != 0);
      if (__pyx_t_2) {
        goto __pyx_L7;
      }

      /* "axon/_loader.py":1129
 *                 if self.pos == idn:
 *                     pass
 *                 elif self.pos < idn or self.eof or ch == '}' or ch == ']' or ch == ')':             # <<<<<<<<<<<<<<
 *                     return c_new_collection(name, values)
 *                 #elif self.pos > idn and self.is_nl:
 */
      __pyx_t_2 = ((__pyx_v_self->pos < __pyx_v_idn) != 0);
      if (!__pyx_t_2) {
        if (!(__pyx_v_self->eof != 0)) {
          switch (__pyx_v_ch) {
            case 125:
            case 93:
            case 41:
            __pyx_t_4 = 1;
            break;
            default:
            __pyx_t_4 = 0;
            break;
          }
          __pyx_t_5 = __pyx_t_4;
        } else {
          __pyx_t_5 = (__pyx_v_self->eof != 0);
        }
        __pyx_t_4 = __pyx_t_5;
      } else {
        __pyx_t_4 = __pyx_t_2;
      }
      if (__pyx_t_4) {

        /* "axon/_loader.py":1130
 *                     pass
 *                 elif self.pos < idn or self.eof or ch == '}' or ch == ']' or ch == ')':
 *                     return c_new_collection(name, values)             # <<<<<<<<<<<<<<
 *                 #elif self.pos > idn and self.is_nl:
 *                 #    errors.error_indentation(self, idn)
 */
        __Pyx_XDECREF(__pyx_r);
        __pyx_t_1 = __pyx_f_4axon_8_objects_c_new_collection(__pyx_v_name, __pyx_v_values); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1130; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_1);
        __pyx_r = __pyx_t_1;
        __pyx_t_1 = 0;
        goto __pyx_L0;
        goto __pyx_L7;
      }
      __pyx_L7:;
      goto __pyx_L6;
    }
    __pyx_L6:;

    /* "axon/_loader.py":1168
 * 
 *                 values.append(val)
 *             elif ch == '}':             # <<<<<<<<<<<<<<
 *                 self.bc -= 1
 *                 skip_char(self)
 */
    switch (__pyx_v_ch) {

      /* "axon/_loader.py":1134
 *                 #    errors.error_indentation(self, idn)
 * 
 *             if ch == '{':             # <<<<<<<<<<<<<<
 *                 self.bc += 1
 *                 skip_char(self)
 */
      case 123:

      /* "axon/_loader.py":1135
 * 
 *             if ch == '{':
 *                 self.bc += 1             # <<<<<<<<<<<<<<
 *                 skip_char(self)
 *                 self.moveto_next_token()
 */
      __pyx_v_self->bc = (__pyx_v_self->bc + 1);

      /* "axon/_loader.py":1136
 *             if ch == '{':
 *                 self.bc += 1
 *                 skip_char(self)             # <<<<<<<<<<<<<<
 *                 self.moveto_next_token()
 * 
 */
      skip_char(__pyx_v_self);

      /* "axon/_loader.py":1137
 *                 self.bc += 1
 *                 skip_char(self)
 *                 self.moveto_next_token()             # <<<<<<<<<<<<<<
 * 
 *                 val = self.get_complex_value(name, 0)
 */
      __pyx_t_3 = __pyx_f_4axon_7_loader_6Loader_moveto_next_token(__pyx_v_self); if (unlikely(__pyx_t_3 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1137; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

      /* "axon/_loader.py":1139
 *                 self.moveto_next_token()
 * 
 *                 val = self.get_complex_value(name, 0)             # <<<<<<<<<<<<<<
 * 
 *                 if label:
 */
      __pyx_t_1 = __pyx_f_4axon_7_loader_6Loader_get_complex_value(__pyx_v_self, __pyx_v_name, 0); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1139; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_XDECREF(__pyx_v_val);
      __pyx_v_val = __pyx_t_1;
      __pyx_t_1 = 0;

      /* "axon/_loader.py":1141
 *                 val = self.get_complex_value(name, 0)
 * 
 *                 if label:             # <<<<<<<<<<<<<<
 *                     self.labeled_objects[label] = val
 * 
 */
      __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_v_label); if (unlikely(__pyx_t_4 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1141; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      if (__pyx_t_4) {

        /* "axon/_loader.py":1142
 * 
 *                 if label:
 *                     self.labeled_objects[label] = val             # <<<<<<<<<<<<<<
 * 
 *                 values.append(val)
 */
        if (unlikely(((PyObject *)__pyx_v_self->labeled_objects) == Py_None)) {
          PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
          {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1142; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        }
        if (PyDict_SetItem(((PyObject *)__pyx_v_self->labeled_objects), __pyx_v_label, __pyx_v_val) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1142; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        goto __pyx_L8;
      }
      __pyx_L8:;

      /* "axon/_loader.py":1144
 *                     self.labeled_objects[label] = val
 * 
 *                 values.append(val)             # <<<<<<<<<<<<<<
 *             elif ch == ':':
 *                 skip_char(self)
 */
      __pyx_t_6 = __Pyx_PyList_Append(__pyx_v_values, __pyx_v_val); if (unlikely(__pyx_t_6 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1144; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      break;

      /* "axon/_loader.py":1145
 * 
 *                 values.append(val)
 *             elif ch == ':':             # <<<<<<<<<<<<<<
 *                 skip_char(self)
 *                 ch = self.moveto_next_token()
 */
      case 58:

      /* "axon/_loader.py":1146
 *                 values.append(val)
 *             elif ch == ':':
 *                 skip_char(self)             # <<<<<<<<<<<<<<
 *                 ch = self.moveto_next_token()
 * 
 */
      skip_char(__pyx_v_self);

      /* "axon/_loader.py":1147
 *             elif ch == ':':
 *                 skip_char(self)
 *                 ch = self.moveto_next_token()             # <<<<<<<<<<<<<<
 * 
 *                 if ch == '.':
 */
      __pyx_t_3 = __pyx_f_4axon_7_loader_6Loader_moveto_next_token(__pyx_v_self); if (unlikely(__pyx_t_3 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1147; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __pyx_v_ch = __pyx_t_3;

      /* "axon/_loader.py":1149
 *                 ch = self.moveto_next_token()
 * 
 *                 if ch == '.':             # <<<<<<<<<<<<<<
 *                     if self.get_dots():
 *                         return self.builder.create_empty(name)
 */
      __pyx_t_4 = ((__pyx_v_ch == 46) != 0);
      if (__pyx_t_4) {

        /* "axon/_loader.py":1150
 * 
 *                 if ch == '.':
 *                     if self.get_dots():             # <<<<<<<<<<<<<<
 *                         return self.builder.create_empty(name)
 *                     else:
 */
        __pyx_t_4 = (__pyx_f_4axon_7_loader_6Loader_get_dots(__pyx_v_self) != 0);
        if (__pyx_t_4) {

          /* "axon/_loader.py":1151
 *                 if ch == '.':
 *                     if self.get_dots():
 *                         return self.builder.create_empty(name)             # <<<<<<<<<<<<<<
 *                     else:
 *                         errors.invalid_value(self)
 */
          __Pyx_XDECREF(__pyx_r);
          __pyx_t_1 = __pyx_v_self->builder->create_empty(__pyx_v_name); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1151; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
          __Pyx_GOTREF(__pyx_t_1);
          __pyx_r = __pyx_t_1;
          __pyx_t_1 = 0;
          goto __pyx_L0;
          goto __pyx_L10;
        }
        /*else*/ {

          /* "axon/_loader.py":1153
 *                         return self.builder.create_empty(name)
 *                     else:
 *                         errors.invalid_value(self)             # <<<<<<<<<<<<<<
 * 
 *                 if self.is_nl:
 */
          __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s__errors); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1153; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
          __Pyx_GOTREF(__pyx_t_1);
          __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s__invalid_value); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1153; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
          __Pyx_GOTREF(__pyx_t_7);
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
          __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1153; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
          __Pyx_GOTREF(__pyx_t_1);
          __Pyx_INCREF(((PyObject *)__pyx_v_self));
          PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self));
          __Pyx_GIVEREF(((PyObject *)__pyx_v_self));
          __pyx_t_8 = PyObject_Call(__pyx_t_7, ((PyObject *)__pyx_t_1), NULL); if (unlikely(!__pyx_t_8)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1153; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
          __Pyx_GOTREF(__pyx_t_8);
          __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
          __Pyx_DECREF(((PyObject *)__pyx_t_1)); __pyx_t_1 = 0;
          __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        }
        __pyx_L10:;
        goto __pyx_L9;
      }
      __pyx_L9:;

      /* "axon/_loader.py":1155
 *                         errors.invalid_value(self)
 * 
 *                 if self.is_nl:             # <<<<<<<<<<<<<<
 *                     if self.pos > idn:
 *                         pos0 = self.pos
 */
      __pyx_t_4 = (__pyx_v_self->is_nl != 0);
      if (__pyx_t_4) {

        /* "axon/_loader.py":1156
 * 
 *                 if self.is_nl:
 *                     if self.pos > idn:             # <<<<<<<<<<<<<<
 *                         pos0 = self.pos
 *                         val = self.get_complex_value(name, pos0)
 */
        __pyx_t_4 = ((__pyx_v_self->pos > __pyx_v_idn) != 0);
        if (__pyx_t_4) {

          /* "axon/_loader.py":1157
 *                 if self.is_nl:
 *                     if self.pos > idn:
 *                         pos0 = self.pos             # <<<<<<<<<<<<<<
 *                         val = self.get_complex_value(name, pos0)
 *                     else:
 */
          __pyx_t_9 = __pyx_v_self->pos;
          __pyx_v_pos0 = __pyx_t_9;

          /* "axon/_loader.py":1158
 *                     if self.pos > idn:
 *                         pos0 = self.pos
 *                         val = self.get_complex_value(name, pos0)             # <<<<<<<<<<<<<<
 *                     else:
 *                         errors.error_indentation(self, idn)
 */
          __pyx_t_8 = __pyx_f_4axon_7_loader_6Loader_get_complex_value(__pyx_v_self, __pyx_v_name, __pyx_v_pos0); if (unlikely(!__pyx_t_8)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1158; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
          __Pyx_GOTREF(__pyx_t_8);
          __Pyx_XDECREF(__pyx_v_val);
          __pyx_v_val = __pyx_t_8;
          __pyx_t_8 = 0;
          goto __pyx_L12;
        }
        /*else*/ {

          /* "axon/_loader.py":1160
 *                         val = self.get_complex_value(name, pos0)
 *                     else:
 *                         errors.error_indentation(self, idn)             # <<<<<<<<<<<<<<
 *                 else:
 *                     errors.error_unexpected_attribute(self, name)
 */
          __pyx_t_8 = __Pyx_GetModuleGlobalName(__pyx_n_s__errors); if (unlikely(!__pyx_t_8)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1160; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
          __Pyx_GOTREF(__pyx_t_8);
          __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_8, __pyx_n_s__error_indentation); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1160; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
          __Pyx_GOTREF(__pyx_t_1);
          __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
          __pyx_t_8 = PyInt_FromLong(__pyx_v_idn); if (unlikely(!__pyx_t_8)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1160; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
          __Pyx_GOTREF(__pyx_t_8);
          __pyx_t_7 = PyTuple_New(2); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1160; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
          __Pyx_GOTREF(__pyx_t_7);
          __Pyx_INCREF(((PyObject *)__pyx_v_self));
          PyTuple_SET_ITEM(__pyx_t_7, 0, ((PyObject *)__pyx_v_self));
          __Pyx_GIVEREF(((PyObject *)__pyx_v_self));
          PyTuple_SET_ITEM(__pyx_t_7, 1, __pyx_t_8);
          __Pyx_GIVEREF(__pyx_t_8);
          __pyx_t_8 = 0;
          __pyx_t_8 = PyObject_Call(__pyx_t_1, ((PyObject *)__pyx_t_7), NULL); if (unlikely(!__pyx_t_8)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1160; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
          __Pyx_GOTREF(__pyx_t_8);
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
          __Pyx_DECREF(((PyObject *)__pyx_t_7)); __pyx_t_7 = 0;
          __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        }
        __pyx_L12:;
        goto __pyx_L11;
      }
      /*else*/ {

        /* "axon/_loader.py":1162
 *                         errors.error_indentation(self, idn)
 *                 else:
 *                     errors.error_unexpected_attribute(self, name)             # <<<<<<<<<<<<<<
 * 
 *                 if label:
 */
        __pyx_t_8 = __Pyx_GetModuleGlobalName(__pyx_n_s__errors); if (unlikely(!__pyx_t_8)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1162; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_8);
        __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_8, __pyx_n_s_36); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1162; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        __pyx_t_8 = PyTuple_New(2); if (unlikely(!__pyx_t_8)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1162; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_INCREF(((PyObject *)__pyx_v_self));
        PyTuple_SET_ITEM(__pyx_t_8, 0, ((PyObject *)__pyx_v_self));
        __Pyx_GIVEREF(((PyObject *)__pyx_v_self));
        __Pyx_INCREF(__pyx_v_name);
        PyTuple_SET_ITEM(__pyx_t_8, 1, __pyx_v_name);
        __Pyx_GIVEREF(__pyx_v_name);
        __pyx_t_1 = PyObject_Call(__pyx_t_7, ((PyObject *)__pyx_t_8), NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1162; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        __Pyx_DECREF(((PyObject *)__pyx_t_8)); __pyx_t_8 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      }
      __pyx_L11:;

      /* "axon/_loader.py":1164
 *                     errors.error_unexpected_attribute(self, name)
 * 
 *                 if label:             # <<<<<<<<<<<<<<
 *                     self.labeled_objects[label] = val
 * 
 */
      __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_v_label); if (unlikely(__pyx_t_4 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1164; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      if (__pyx_t_4) {

        /* "axon/_loader.py":1165
 * 
 *                 if label:
 *                     self.labeled_objects[label] = val             # <<<<<<<<<<<<<<
 * 
 *                 values.append(val)
 */
        if (unlikely(!__pyx_v_val)) { __Pyx_RaiseUnboundLocalError("val"); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1165; __pyx_clineno = __LINE__; goto __pyx_L1_error;} }
        if (unlikely(((PyObject *)__pyx_v_self->labeled_objects) == Py_None)) {
          PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
          {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1165; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        }
        if (PyDict_SetItem(((PyObject *)__pyx_v_self->labeled_objects), __pyx_v_label, __pyx_v_val) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1165; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        goto __pyx_L13;
      }
      __pyx_L13:;

      /* "axon/_loader.py":1167
 *                     self.labeled_objects[label] = val
 * 
 *                 values.append(val)             # <<<<<<<<<<<<<<
 *             elif ch == '}':
 *                 self.bc -= 1
 */
      if (unlikely(!__pyx_v_val)) { __Pyx_RaiseUnboundLocalError("val"); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1167; __pyx_clineno = __LINE__; goto __pyx_L1_error;} }
      __pyx_t_6 = __Pyx_PyList_Append(__pyx_v_values, __pyx_v_val); if (unlikely(__pyx_t_6 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1167; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      break;

      /* "axon/_loader.py":1168
 * 
 *                 values.append(val)
 *             elif ch == '}':             # <<<<<<<<<<<<<<
 *                 self.bc -= 1
 *                 skip_char(self)
 */
      case 125:

      /* "axon/_loader.py":1169
 *                 values.append(val)
 *             elif ch == '}':
 *                 self.bc -= 1             # <<<<<<<<<<<<<<
 *                 skip_char(self)
 * 
 */
      __pyx_v_self->bc = (__pyx_v_self->bc - 1);

      /* "axon/_loader.py":1170
 *             elif ch == '}':
 *                 self.bc -= 1
 *                 skip_char(self)             # <<<<<<<<<<<<<<
 * 
 *                 return c_new_collection(name, values)
 */
      skip_char(__pyx_v_self);

      /* "axon/_loader.py":1172
 *                 skip_char(self)
 * 
 *                 return c_new_collection(name, values)             # <<<<<<<<<<<<<<
 * 
 *             else:
 */
      __Pyx_XDECREF(__pyx_r);
      __pyx_t_1 = __pyx_f_4axon_8_objects_c_new_collection(__pyx_v_name, __pyx_v_values); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1172; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_r = __pyx_t_1;
      __pyx_t_1 = 0;
      goto __pyx_L0;
      break;
      default:

      /* "axon/_loader.py":1175
 * 
 *             else:
 *                 errors.error(self, "Expected '{' or ':' here")             # <<<<<<<<<<<<<<
 * 
 *             ch = self.skip_spaces()
 */
      __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s__errors); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1175; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s__error); if (unlikely(!__pyx_t_8)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1175; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_1 = PyTuple_New(2); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1175; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_INCREF(((PyObject *)__pyx_v_self));
      PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self));
      __Pyx_GIVEREF(((PyObject *)__pyx_v_self));
      __Pyx_INCREF(((PyObject *)__pyx_kp_u_38));
      PyTuple_SET_ITEM(__pyx_t_1, 1, ((PyObject *)__pyx_kp_u_38));
      __Pyx_GIVEREF(((PyObject *)__pyx_kp_u_38));
      __pyx_t_7 = PyObject_Call(__pyx_t_8, ((PyObject *)__pyx_t_1), NULL); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1175; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_DECREF(((PyObject *)__pyx_t_1)); __pyx_t_1 = 0;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      break;
    }

    /* "axon/_loader.py":1177
 *                 errors.error(self, "Expected '{' or ':' here")
 * 
 *             ch = self.skip_spaces()             # <<<<<<<<<<<<<<
 * 
 *     #
 */
    __pyx_v_ch = __pyx_f_4axon_7_loader_6Loader_skip_spaces(__pyx_v_self);
  }

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("axon._loader.Loader.get_collection", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_values);
  __Pyx_XDECREF(__pyx_v_val);
  __Pyx_XDECREF(__pyx_v_label);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_loader.py":1180
 * 
 *     #
 *     def get_complex_value(self, name, idn):             # <<<<<<<<<<<<<<
 *         ch = current_char(self)
 *         if ch == '#':
 */

static PyObject *__pyx_f_4axon_7_loader_6Loader_get_complex_value(struct __pyx_obj_4axon_7_loader_Loader *__pyx_v_self, PyObject *__pyx_v_name, int __pyx_v_idn) {
  Py_UCS4 __pyx_v_ch;
  PyObject *__pyx_v_val = 0;
  PyObject *__pyx_v_sequence = 0;
  PyObject *__pyx_v_mapping = 0;
  int __pyx_v_is_multi;
  PyObject *__pyx_v_aname = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  Py_UCS4 __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_complex_value", 0);

  /* "axon/_loader.py":1181
 *     #
 *     def get_complex_value(self, name, idn):
 *         ch = current_char(self)             # <<<<<<<<<<<<<<
 *         if ch == '#':
 *             self.skip_comments()
 */
  __pyx_v_ch = current_char(__pyx_v_self);

  /* "axon/_loader.py":1182
 *     def get_complex_value(self, name, idn):
 *         ch = current_char(self)
 *         if ch == '#':             # <<<<<<<<<<<<<<
 *             self.skip_comments()
 * 
 */
  __pyx_t_1 = ((__pyx_v_ch == 35) != 0);
  if (__pyx_t_1) {

    /* "axon/_loader.py":1183
 *         ch = current_char(self)
 *         if ch == '#':
 *             self.skip_comments()             # <<<<<<<<<<<<<<
 * 
 *         ch = current_char(self)
 */
    __pyx_f_4axon_7_loader_6Loader_skip_comments(__pyx_v_self);
    goto __pyx_L3;
  }
  __pyx_L3:;

  /* "axon/_loader.py":1185
 *             self.skip_comments()
 * 
 *         ch = current_char(self)             # <<<<<<<<<<<<<<
 *         if ch == '.':
 *             if self.get_dots():
 */
  __pyx_v_ch = current_char(__pyx_v_self);

  /* "axon/_loader.py":1186
 * 
 *         ch = current_char(self)
 *         if ch == '.':             # <<<<<<<<<<<<<<
 *             if self.get_dots():
 *                 return self.builder.create_empty(name)
 */
  __pyx_t_1 = ((__pyx_v_ch == 46) != 0);
  if (__pyx_t_1) {

    /* "axon/_loader.py":1187
 *         ch = current_char(self)
 *         if ch == '.':
 *             if self.get_dots():             # <<<<<<<<<<<<<<
 *                 return self.builder.create_empty(name)
 *             else:
 */
    __pyx_t_1 = (__pyx_f_4axon_7_loader_6Loader_get_dots(__pyx_v_self) != 0);
    if (__pyx_t_1) {

      /* "axon/_loader.py":1188
 *         if ch == '.':
 *             if self.get_dots():
 *                 return self.builder.create_empty(name)             # <<<<<<<<<<<<<<
 *             else:
 *                 errors.invalid_value(self)
 */
      __Pyx_XDECREF(__pyx_r);
      __pyx_t_2 = __pyx_v_self->builder->create_empty(__pyx_v_name); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1188; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_r = __pyx_t_2;
      __pyx_t_2 = 0;
      goto __pyx_L0;
      goto __pyx_L5;
    }
    /*else*/ {

      /* "axon/_loader.py":1190
 *                 return self.builder.create_empty(name)
 *             else:
 *                 errors.invalid_value(self)             # <<<<<<<<<<<<<<
 * 
 *         aname = self.try_get_name()
 */
      __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s__errors); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1190; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s__invalid_value); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1190; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1190; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_INCREF(((PyObject *)__pyx_v_self));
      PyTuple_SET_ITEM(__pyx_t_2, 0, ((PyObject *)__pyx_v_self));
      __Pyx_GIVEREF(((PyObject *)__pyx_v_self));
      __pyx_t_4 = PyObject_Call(__pyx_t_3, ((PyObject *)__pyx_t_2), NULL); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1190; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF(((PyObject *)__pyx_t_2)); __pyx_t_2 = 0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
    __pyx_L5:;
    goto __pyx_L4;
  }
  __pyx_L4:;

  /* "axon/_loader.py":1192
 *                 errors.invalid_value(self)
 * 
 *         aname = self.try_get_name()             # <<<<<<<<<<<<<<
 * 
 *         if aname is not None:
 */
  __pyx_t_4 = __pyx_f_4axon_7_loader_6Loader_try_get_name(__pyx_v_self); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1192; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_v_aname = __pyx_t_4;
  __pyx_t_4 = 0;

  /* "axon/_loader.py":1194
 *         aname = self.try_get_name()
 * 
 *         if aname is not None:             # <<<<<<<<<<<<<<
 * 
 *             ch = current_char(self)
 */
  __pyx_t_1 = (__pyx_v_aname != Py_None);
  __pyx_t_5 = (__pyx_t_1 != 0);
  if (__pyx_t_5) {

    /* "axon/_loader.py":1196
 *         if aname is not None:
 * 
 *             ch = current_char(self)             # <<<<<<<<<<<<<<
 *             if ch == '*':
 *                 ch = next_char(self)
 */
    __pyx_v_ch = current_char(__pyx_v_self);

    /* "axon/_loader.py":1197
 * 
 *             ch = current_char(self)
 *             if ch == '*':             # <<<<<<<<<<<<<<
 *                 ch = next_char(self)
 *                 is_multi = 1
 */
    __pyx_t_5 = ((__pyx_v_ch == 42) != 0);
    if (__pyx_t_5) {

      /* "axon/_loader.py":1198
 *             ch = current_char(self)
 *             if ch == '*':
 *                 ch = next_char(self)             # <<<<<<<<<<<<<<
 *                 is_multi = 1
 *             else:
 */
      __pyx_v_ch = next_char(__pyx_v_self);

      /* "axon/_loader.py":1199
 *             if ch == '*':
 *                 ch = next_char(self)
 *                 is_multi = 1             # <<<<<<<<<<<<<<
 *             else:
 *                 is_multi = 0
 */
      __pyx_v_is_multi = 1;
      goto __pyx_L7;
    }
    /*else*/ {

      /* "axon/_loader.py":1201
 *                 is_multi = 1
 *             else:
 *                 is_multi = 0             # <<<<<<<<<<<<<<
 * 
 *             ch = self.moveto_next_token()
 */
      __pyx_v_is_multi = 0;
    }
    __pyx_L7:;

    /* "axon/_loader.py":1203
 *                 is_multi = 0
 * 
 *             ch = self.moveto_next_token()             # <<<<<<<<<<<<<<
 * 
 *             if ch == ':':
 */
    __pyx_t_6 = __pyx_f_4axon_7_loader_6Loader_moveto_next_token(__pyx_v_self); if (unlikely(__pyx_t_6 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1203; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __pyx_v_ch = __pyx_t_6;

    /* "axon/_loader.py":1222
 *                     mapping = {aname: self.get_value(idn)}
 *                     val = self.get_mapping_sequence(name, mapping, idn)
 *             elif ch == '{':             # <<<<<<<<<<<<<<
 *                 self.bc += 1
 *                 skip_char(self)
 */
    switch (__pyx_v_ch) {

      /* "axon/_loader.py":1205
 *             ch = self.moveto_next_token()
 * 
 *             if ch == ':':             # <<<<<<<<<<<<<<
 *                 skip_char(self)
 *                 self.moveto_next_token()
 */
      case 58:

      /* "axon/_loader.py":1206
 * 
 *             if ch == ':':
 *                 skip_char(self)             # <<<<<<<<<<<<<<
 *                 self.moveto_next_token()
 * 
 */
      skip_char(__pyx_v_self);

      /* "axon/_loader.py":1207
 *             if ch == ':':
 *                 skip_char(self)
 *                 self.moveto_next_token()             # <<<<<<<<<<<<<<
 * 
 *                 if self.is_nl:
 */
      __pyx_t_6 = __pyx_f_4axon_7_loader_6Loader_moveto_next_token(__pyx_v_self); if (unlikely(__pyx_t_6 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1207; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

      /* "axon/_loader.py":1209
 *                 self.moveto_next_token()
 * 
 *                 if self.is_nl:             # <<<<<<<<<<<<<<
 *                     if self.pos > idn:
 *                         if is_multi:
 */
      __pyx_t_5 = (__pyx_v_self->is_nl != 0);
      if (__pyx_t_5) {

        /* "axon/_loader.py":1210
 * 
 *                 if self.is_nl:
 *                     if self.pos > idn:             # <<<<<<<<<<<<<<
 *                         if is_multi:
 *                             sequence =  [self.get_collection(aname, self.pos)]
 */
        __pyx_t_5 = ((__pyx_v_self->pos > __pyx_v_idn) != 0);
        if (__pyx_t_5) {

          /* "axon/_loader.py":1211
 *                 if self.is_nl:
 *                     if self.pos > idn:
 *                         if is_multi:             # <<<<<<<<<<<<<<
 *                             sequence =  [self.get_collection(aname, self.pos)]
 *                         else:
 */
          __pyx_t_5 = (__pyx_v_is_multi != 0);
          if (__pyx_t_5) {

            /* "axon/_loader.py":1212
 *                     if self.pos > idn:
 *                         if is_multi:
 *                             sequence =  [self.get_collection(aname, self.pos)]             # <<<<<<<<<<<<<<
 *                         else:
 *                             sequence = [self.get_complex_value(aname, self.pos)]
 */
            __pyx_t_4 = __pyx_f_4axon_7_loader_6Loader_get_collection(__pyx_v_self, __pyx_v_aname, __pyx_v_self->pos); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1212; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
            __Pyx_GOTREF(__pyx_t_4);
            __pyx_t_2 = PyList_New(1); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1212; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
            __Pyx_GOTREF(__pyx_t_2);
            PyList_SET_ITEM(__pyx_t_2, 0, __pyx_t_4);
            __Pyx_GIVEREF(__pyx_t_4);
            __pyx_t_4 = 0;
            __pyx_v_sequence = ((PyObject*)__pyx_t_2);
            __pyx_t_2 = 0;
            goto __pyx_L10;
          }
          /*else*/ {

            /* "axon/_loader.py":1214
 *                             sequence =  [self.get_collection(aname, self.pos)]
 *                         else:
 *                             sequence = [self.get_complex_value(aname, self.pos)]             # <<<<<<<<<<<<<<
 * 
 *                         val = self.get_sequence_mapping(name, sequence, idn)
 */
            __pyx_t_2 = __pyx_f_4axon_7_loader_6Loader_get_complex_value(__pyx_v_self, __pyx_v_aname, __pyx_v_self->pos); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1214; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
            __Pyx_GOTREF(__pyx_t_2);
            __pyx_t_4 = PyList_New(1); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1214; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
            __Pyx_GOTREF(__pyx_t_4);
            PyList_SET_ITEM(__pyx_t_4, 0, __pyx_t_2);
            __Pyx_GIVEREF(__pyx_t_2);
            __pyx_t_2 = 0;
            __pyx_v_sequence = ((PyObject*)__pyx_t_4);
            __pyx_t_4 = 0;
          }
          __pyx_L10:;

          /* "axon/_loader.py":1216
 *                             sequence = [self.get_complex_value(aname, self.pos)]
 * 
 *                         val = self.get_sequence_mapping(name, sequence, idn)             # <<<<<<<<<<<<<<
 *                     else:
 *                         errors.error_indentation(self, idn)
 */
          __pyx_t_4 = __pyx_f_4axon_7_loader_6Loader_get_sequence_mapping(__pyx_v_self, __pyx_v_name, __pyx_v_sequence, __pyx_v_idn); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1216; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
          __Pyx_GOTREF(__pyx_t_4);
          __pyx_v_val = __pyx_t_4;
          __pyx_t_4 = 0;
          goto __pyx_L9;
        }
        /*else*/ {

          /* "axon/_loader.py":1218
 *                         val = self.get_sequence_mapping(name, sequence, idn)
 *                     else:
 *                         errors.error_indentation(self, idn)             # <<<<<<<<<<<<<<
 *                 else:
 *                     mapping = {aname: self.get_value(idn)}
 */
          __pyx_t_4 = __Pyx_GetModuleGlobalName(__pyx_n_s__errors); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1218; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
          __Pyx_GOTREF(__pyx_t_4);
          __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s__error_indentation); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1218; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          __pyx_t_4 = PyInt_FromLong(__pyx_v_idn); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1218; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
          __Pyx_GOTREF(__pyx_t_4);
          __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1218; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
          __Pyx_GOTREF(__pyx_t_3);
          __Pyx_INCREF(((PyObject *)__pyx_v_self));
          PyTuple_SET_ITEM(__pyx_t_3, 0, ((PyObject *)__pyx_v_self));
          __Pyx_GIVEREF(((PyObject *)__pyx_v_self));
          PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_t_4);
          __Pyx_GIVEREF(__pyx_t_4);
          __pyx_t_4 = 0;
          __pyx_t_4 = PyObject_Call(__pyx_t_2, ((PyObject *)__pyx_t_3), NULL); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1218; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
          __Pyx_GOTREF(__pyx_t_4);
          __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
          __Pyx_DECREF(((PyObject *)__pyx_t_3)); __pyx_t_3 = 0;
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        }
        __pyx_L9:;
        goto __pyx_L8;
      }
      /*else*/ {

        /* "axon/_loader.py":1220
 *                         errors.error_indentation(self, idn)
 *                 else:
 *                     mapping = {aname: self.get_value(idn)}             # <<<<<<<<<<<<<<
 *                     val = self.get_mapping_sequence(name, mapping, idn)
 *             elif ch == '{':
 */
        __pyx_t_4 = PyDict_New(); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1220; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(((PyObject *)__pyx_t_4));
        __pyx_t_3 = __pyx_f_4axon_7_loader_6Loader_get_value(__pyx_v_self, __pyx_v_idn); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1220; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_3);
        if (PyDict_SetItem(__pyx_t_4, __pyx_v_aname, __pyx_t_3) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1220; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __pyx_v_mapping = ((PyObject*)__pyx_t_4);
        __pyx_t_4 = 0;

        /* "axon/_loader.py":1221
 *                 else:
 *                     mapping = {aname: self.get_value(idn)}
 *                     val = self.get_mapping_sequence(name, mapping, idn)             # <<<<<<<<<<<<<<
 *             elif ch == '{':
 *                 self.bc += 1
 */
        __pyx_t_4 = __pyx_f_4axon_7_loader_6Loader_get_mapping_sequence(__pyx_v_self, __pyx_v_name, __pyx_v_mapping, __pyx_v_idn); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1221; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_4);
        __pyx_v_val = __pyx_t_4;
        __pyx_t_4 = 0;
      }
      __pyx_L8:;
      break;

      /* "axon/_loader.py":1222
 *                     mapping = {aname: self.get_value(idn)}
 *                     val = self.get_mapping_sequence(name, mapping, idn)
 *             elif ch == '{':             # <<<<<<<<<<<<<<
 *                 self.bc += 1
 *                 skip_char(self)
 */
      case 123:

      /* "axon/_loader.py":1223
 *                     val = self.get_mapping_sequence(name, mapping, idn)
 *             elif ch == '{':
 *                 self.bc += 1             # <<<<<<<<<<<<<<
 *                 skip_char(self)
 * 
 */
      __pyx_v_self->bc = (__pyx_v_self->bc + 1);

      /* "axon/_loader.py":1224
 *             elif ch == '{':
 *                 self.bc += 1
 *                 skip_char(self)             # <<<<<<<<<<<<<<
 * 
 *                 ch = self.moveto_next_token()
 */
      skip_char(__pyx_v_self);

      /* "axon/_loader.py":1226
 *                 skip_char(self)
 * 
 *                 ch = self.moveto_next_token()             # <<<<<<<<<<<<<<
 * 
 *                 if is_multi:
 */
      __pyx_t_6 = __pyx_f_4axon_7_loader_6Loader_moveto_next_token(__pyx_v_self); if (unlikely(__pyx_t_6 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1226; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __pyx_v_ch = __pyx_t_6;

      /* "axon/_loader.py":1228
 *                 ch = self.moveto_next_token()
 * 
 *                 if is_multi:             # <<<<<<<<<<<<<<
 *                     sequence = [self.get_collection(aname, 0)]
 *                 else:
 */
      __pyx_t_5 = (__pyx_v_is_multi != 0);
      if (__pyx_t_5) {

        /* "axon/_loader.py":1229
 * 
 *                 if is_multi:
 *                     sequence = [self.get_collection(aname, 0)]             # <<<<<<<<<<<<<<
 *                 else:
 *                     sequence = [self.get_complex_value(aname, 0)]
 */
        __pyx_t_4 = __pyx_f_4axon_7_loader_6Loader_get_collection(__pyx_v_self, __pyx_v_aname, 0); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1229; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_4);
        __pyx_t_3 = PyList_New(1); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1229; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_3);
        PyList_SET_ITEM(__pyx_t_3, 0, __pyx_t_4);
        __Pyx_GIVEREF(__pyx_t_4);
        __pyx_t_4 = 0;
        __pyx_v_sequence = ((PyObject*)__pyx_t_3);
        __pyx_t_3 = 0;
        goto __pyx_L11;
      }
      /*else*/ {

        /* "axon/_loader.py":1231
 *                     sequence = [self.get_collection(aname, 0)]
 *                 else:
 *                     sequence = [self.get_complex_value(aname, 0)]             # <<<<<<<<<<<<<<
 * 
 *                 val = self.get_sequence_mapping(name, sequence, idn)
 */
        __pyx_t_3 = __pyx_f_4axon_7_loader_6Loader_get_complex_value(__pyx_v_self, __pyx_v_aname, 0); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1231; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_3);
        __pyx_t_4 = PyList_New(1); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1231; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_4);
        PyList_SET_ITEM(__pyx_t_4, 0, __pyx_t_3);
        __Pyx_GIVEREF(__pyx_t_3);
        __pyx_t_3 = 0;
        __pyx_v_sequence = ((PyObject*)__pyx_t_4);
        __pyx_t_4 = 0;
      }
      __pyx_L11:;

      /* "axon/_loader.py":1233
 *                     sequence = [self.get_complex_value(aname, 0)]
 * 
 *                 val = self.get_sequence_mapping(name, sequence, idn)             # <<<<<<<<<<<<<<
 *             else:
 *                 sequence = [self.get_constant_or_string(aname)]
 */
      __pyx_t_4 = __pyx_f_4axon_7_loader_6Loader_get_sequence_mapping(__pyx_v_self, __pyx_v_name, __pyx_v_sequence, __pyx_v_idn); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1233; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_v_val = __pyx_t_4;
      __pyx_t_4 = 0;
      break;
      default:

      /* "axon/_loader.py":1235
 *                 val = self.get_sequence_mapping(name, sequence, idn)
 *             else:
 *                 sequence = [self.get_constant_or_string(aname)]             # <<<<<<<<<<<<<<
 *                 val = self.get_sequence_mapping(name, sequence, idn)
 * 
 */
      if (!(likely(PyUnicode_CheckExact(__pyx_v_aname))||((__pyx_v_aname) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected unicode, got %.200s", Py_TYPE(__pyx_v_aname)->tp_name), 0))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1235; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __pyx_t_4 = __pyx_f_4axon_7_loader_6Loader_get_constant_or_string(__pyx_v_self, ((PyObject*)__pyx_v_aname)); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1235; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_3 = PyList_New(1); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1235; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_3);
      PyList_SET_ITEM(__pyx_t_3, 0, __pyx_t_4);
      __Pyx_GIVEREF(__pyx_t_4);
      __pyx_t_4 = 0;
      __pyx_v_sequence = ((PyObject*)__pyx_t_3);
      __pyx_t_3 = 0;

      /* "axon/_loader.py":1236
 *             else:
 *                 sequence = [self.get_constant_or_string(aname)]
 *                 val = self.get_sequence_mapping(name, sequence, idn)             # <<<<<<<<<<<<<<
 * 
 *         else:
 */
      __pyx_t_3 = __pyx_f_4axon_7_loader_6Loader_get_sequence_mapping(__pyx_v_self, __pyx_v_name, __pyx_v_sequence, __pyx_v_idn); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1236; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_v_val = __pyx_t_3;
      __pyx_t_3 = 0;
      break;
    }
    goto __pyx_L6;
  }
  /*else*/ {

    /* "axon/_loader.py":1239
 * 
 *         else:
 *             ch = self.moveto_next_token()             # <<<<<<<<<<<<<<
 * 
 *             if ch == '}':
 */
    __pyx_t_6 = __pyx_f_4axon_7_loader_6Loader_moveto_next_token(__pyx_v_self); if (unlikely(__pyx_t_6 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1239; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __pyx_v_ch = __pyx_t_6;

    /* "axon/_loader.py":1241
 *             ch = self.moveto_next_token()
 * 
 *             if ch == '}':             # <<<<<<<<<<<<<<
 *                 self.bc -= 1
 *                 skip_char(self)
 */
    __pyx_t_5 = ((__pyx_v_ch == 125) != 0);
    if (__pyx_t_5) {

      /* "axon/_loader.py":1242
 * 
 *             if ch == '}':
 *                 self.bc -= 1             # <<<<<<<<<<<<<<
 *                 skip_char(self)
 * 
 */
      __pyx_v_self->bc = (__pyx_v_self->bc - 1);

      /* "axon/_loader.py":1243
 *             if ch == '}':
 *                 self.bc -= 1
 *                 skip_char(self)             # <<<<<<<<<<<<<<
 * 
 *                 val = self.builder.create_empty(name)
 */
      skip_char(__pyx_v_self);

      /* "axon/_loader.py":1245
 *                 skip_char(self)
 * 
 *                 val = self.builder.create_empty(name)             # <<<<<<<<<<<<<<
 *             else:
 *                 sequence = [self.get_value(idn)]
 */
      __pyx_t_3 = __pyx_v_self->builder->create_empty(__pyx_v_name); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1245; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_v_val = __pyx_t_3;
      __pyx_t_3 = 0;
      goto __pyx_L12;
    }
    /*else*/ {

      /* "axon/_loader.py":1247
 *                 val = self.builder.create_empty(name)
 *             else:
 *                 sequence = [self.get_value(idn)]             # <<<<<<<<<<<<<<
 *                 val = self.get_sequence_mapping(name, sequence, idn)
 * 
 */
      __pyx_t_3 = __pyx_f_4axon_7_loader_6Loader_get_value(__pyx_v_self, __pyx_v_idn); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1247; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_4 = PyList_New(1); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1247; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_4);
      PyList_SET_ITEM(__pyx_t_4, 0, __pyx_t_3);
      __Pyx_GIVEREF(__pyx_t_3);
      __pyx_t_3 = 0;
      __pyx_v_sequence = ((PyObject*)__pyx_t_4);
      __pyx_t_4 = 0;

      /* "axon/_loader.py":1248
 *             else:
 *                 sequence = [self.get_value(idn)]
 *                 val = self.get_sequence_mapping(name, sequence, idn)             # <<<<<<<<<<<<<<
 * 
 *         return val
 */
      __pyx_t_4 = __pyx_f_4axon_7_loader_6Loader_get_sequence_mapping(__pyx_v_self, __pyx_v_name, __pyx_v_sequence, __pyx_v_idn); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1248; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_v_val = __pyx_t_4;
      __pyx_t_4 = 0;
    }
    __pyx_L12:;
  }
  __pyx_L6:;

  /* "axon/_loader.py":1250
 *                 val = self.get_sequence_mapping(name, sequence, idn)
 * 
 *         return val             # <<<<<<<<<<<<<<
 *     #
 *     def get_sequence_mapping(self, name, sequence, idn):
 */
  __Pyx_XDECREF(__pyx_r);
  if (unlikely(!__pyx_v_val)) { __Pyx_RaiseUnboundLocalError("val"); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1250; __pyx_clineno = __LINE__; goto __pyx_L1_error;} }
  __Pyx_INCREF(__pyx_v_val);
  __pyx_r = __pyx_v_val;
  goto __pyx_L0;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("axon._loader.Loader.get_complex_value", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_val);
  __Pyx_XDECREF(__pyx_v_sequence);
  __Pyx_XDECREF(__pyx_v_mapping);
  __Pyx_XDECREF(__pyx_v_aname);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_loader.py":1252
 *         return val
 *     #
 *     def get_sequence_mapping(self, name, sequence, idn):             # <<<<<<<<<<<<<<
 *         mapping = {}
 *         v = self.get_sequence_part(sequence, mapping, idn)
 */

static PyObject *__pyx_f_4axon_7_loader_6Loader_get_sequence_mapping(struct __pyx_obj_4axon_7_loader_Loader *__pyx_v_self, PyObject *__pyx_v_name, PyObject *__pyx_v_sequence, int __pyx_v_idn) {
  PyObject *__pyx_v_mapping = 0;
  PyObject *__pyx_v_val = 0;
  int __pyx_v_v;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_sequence_mapping", 0);

  /* "axon/_loader.py":1253
 *     #
 *     def get_sequence_mapping(self, name, sequence, idn):
 *         mapping = {}             # <<<<<<<<<<<<<<
 *         v = self.get_sequence_part(sequence, mapping, idn)
 *         if v:
 */
  __pyx_t_1 = PyDict_New(); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1253; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(((PyObject *)__pyx_t_1));
  __pyx_v_mapping = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "axon/_loader.py":1254
 *     def get_sequence_mapping(self, name, sequence, idn):
 *         mapping = {}
 *         v = self.get_sequence_part(sequence, mapping, idn)             # <<<<<<<<<<<<<<
 *         if v:
 *             v = self.get_mapping_part(mapping, None, idn)
 */
  __pyx_t_2 = __pyx_f_4axon_7_loader_6Loader_get_sequence_part(__pyx_v_self, __pyx_v_sequence, __pyx_v_mapping, __pyx_v_idn); if (unlikely(__pyx_t_2 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1254; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_v_v = __pyx_t_2;

  /* "axon/_loader.py":1255
 *         mapping = {}
 *         v = self.get_sequence_part(sequence, mapping, idn)
 *         if v:             # <<<<<<<<<<<<<<
 *             v = self.get_mapping_part(mapping, None, idn)
 *             if v:
 */
  __pyx_t_2 = (__pyx_v_v != 0);
  if (__pyx_t_2) {

    /* "axon/_loader.py":1256
 *         v = self.get_sequence_part(sequence, mapping, idn)
 *         if v:
 *             v = self.get_mapping_part(mapping, None, idn)             # <<<<<<<<<<<<<<
 *             if v:
 *                 errors.error_unexpected_value(self, 'in named sequence-like structure')
 */
    __pyx_t_2 = __pyx_f_4axon_7_loader_6Loader_get_mapping_part(__pyx_v_self, __pyx_v_mapping, ((PyObject*)Py_None), __pyx_v_idn); if (unlikely(__pyx_t_2 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1256; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __pyx_v_v = __pyx_t_2;

    /* "axon/_loader.py":1257
 *         if v:
 *             v = self.get_mapping_part(mapping, None, idn)
 *             if v:             # <<<<<<<<<<<<<<
 *                 errors.error_unexpected_value(self, 'in named sequence-like structure')
 * 
 */
    __pyx_t_2 = (__pyx_v_v != 0);
    if (__pyx_t_2) {

      /* "axon/_loader.py":1258
 *             v = self.get_mapping_part(mapping, None, idn)
 *             if v:
 *                 errors.error_unexpected_value(self, 'in named sequence-like structure')             # <<<<<<<<<<<<<<
 * 
 *             val = self.builder.create_instance(name, c_as_tuple(sequence), mapping)
 */
      __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s__errors); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1258; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_25); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1258; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_1 = PyTuple_New(2); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1258; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_INCREF(((PyObject *)__pyx_v_self));
      PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self));
      __Pyx_GIVEREF(((PyObject *)__pyx_v_self));
      __Pyx_INCREF(((PyObject *)__pyx_kp_u_39));
      PyTuple_SET_ITEM(__pyx_t_1, 1, ((PyObject *)__pyx_kp_u_39));
      __Pyx_GIVEREF(((PyObject *)__pyx_kp_u_39));
      __pyx_t_4 = PyObject_Call(__pyx_t_3, ((PyObject *)__pyx_t_1), NULL); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1258; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF(((PyObject *)__pyx_t_1)); __pyx_t_1 = 0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      goto __pyx_L4;
    }
    __pyx_L4:;

    /* "axon/_loader.py":1260
 *                 errors.error_unexpected_value(self, 'in named sequence-like structure')
 * 
 *             val = self.builder.create_instance(name, c_as_tuple(sequence), mapping)             # <<<<<<<<<<<<<<
 *         else:
 *             val = self.builder.create_sequence(name, sequence)
 */
    __pyx_t_4 = ((PyObject *)__pyx_f_4axon_8_objects_c_as_tuple(((PyObject *)__pyx_v_sequence))); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1260; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_1 = __pyx_v_self->builder->create_instance(__pyx_v_name, ((PyObject*)__pyx_t_4), __pyx_v_mapping); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1260; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_v_val = __pyx_t_1;
    __pyx_t_1 = 0;
    goto __pyx_L3;
  }
  /*else*/ {

    /* "axon/_loader.py":1262
 *             val = self.builder.create_instance(name, c_as_tuple(sequence), mapping)
 *         else:
 *             val = self.builder.create_sequence(name, sequence)             # <<<<<<<<<<<<<<
 * 
 *         return val
 */
    __pyx_t_1 = __pyx_v_self->builder->create_sequence(__pyx_v_name, __pyx_v_sequence); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1262; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_v_val = __pyx_t_1;
    __pyx_t_1 = 0;
  }
  __pyx_L3:;

  /* "axon/_loader.py":1264
 *             val = self.builder.create_sequence(name, sequence)
 * 
 *         return val             # <<<<<<<<<<<<<<
 *     #
 *     def get_empty_sequence(self, name, sequence, idn):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_val);
  __pyx_r = __pyx_v_val;
  goto __pyx_L0;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("axon._loader.Loader.get_sequence_mapping", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_mapping);
  __Pyx_XDECREF(__pyx_v_val);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_4axon_7_loader_6Loader_11get_empty_sequence(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyObject *__pyx_pw_4axon_7_loader_6Loader_11get_empty_sequence(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_name = 0;
  PyObject *__pyx_v_sequence = 0;
  PyObject *__pyx_v_idn = 0;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_empty_sequence (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s__name,&__pyx_n_s__sequence,&__pyx_n_s__idn,0};
    PyObject* values[3] = {0,0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s__name)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s__sequence)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("get_empty_sequence", 1, 3, 3, 1); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1266; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
        }
        case  2:
        if (likely((values[2] = PyDict_GetItem(__pyx_kwds, __pyx_n_s__idn)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("get_empty_sequence", 1, 3, 3, 2); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1266; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "get_empty_sequence") < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1266; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 3) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
      values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
    }
    __pyx_v_name = values[0];
    __pyx_v_sequence = values[1];
    __pyx_v_idn = values[2];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_empty_sequence", 1, 3, 3, PyTuple_GET_SIZE(__pyx_args)); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1266; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  __pyx_L3_error:;
  __Pyx_AddTraceback("axon._loader.Loader.get_empty_sequence", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_4axon_7_loader_6Loader_10get_empty_sequence(((struct __pyx_obj_4axon_7_loader_Loader *)__pyx_v_self), __pyx_v_name, __pyx_v_sequence, __pyx_v_idn);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_loader.py":1266
 *         return val
 *     #
 *     def get_empty_sequence(self, name, sequence, idn):             # <<<<<<<<<<<<<<
 *         mapping = {}
 *         v = self.get_mapping_part(mapping, None, idn)
 */

static PyObject *__pyx_pf_4axon_7_loader_6Loader_10get_empty_sequence(struct __pyx_obj_4axon_7_loader_Loader *__pyx_v_self, PyObject *__pyx_v_name, PyObject *__pyx_v_sequence, PyObject *__pyx_v_idn) {
  PyObject *__pyx_v_mapping = NULL;
  int __pyx_v_v;
  PyObject *__pyx_v_val = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_empty_sequence", 0);

  /* "axon/_loader.py":1267
 *     #
 *     def get_empty_sequence(self, name, sequence, idn):
 *         mapping = {}             # <<<<<<<<<<<<<<
 *         v = self.get_mapping_part(mapping, None, idn)
 *         if v:
 */
  __pyx_t_1 = PyDict_New(); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1267; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(((PyObject *)__pyx_t_1));
  __pyx_v_mapping = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "axon/_loader.py":1268
 *     def get_empty_sequence(self, name, sequence, idn):
 *         mapping = {}
 *         v = self.get_mapping_part(mapping, None, idn)             # <<<<<<<<<<<<<<
 *         if v:
 *             errors.error_unexpected_value(self, 'in named element-like structure')
 */
  __pyx_t_2 = __Pyx_PyInt_AsInt(__pyx_v_idn); if (unlikely((__pyx_t_2 == (int)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1268; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_t_3 = __pyx_f_4axon_7_loader_6Loader_get_mapping_part(__pyx_v_self, __pyx_v_mapping, ((PyObject*)Py_None), __pyx_t_2); if (unlikely(__pyx_t_3 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1268; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_v_v = __pyx_t_3;

  /* "axon/_loader.py":1269
 *         mapping = {}
 *         v = self.get_mapping_part(mapping, None, idn)
 *         if v:             # <<<<<<<<<<<<<<
 *             errors.error_unexpected_value(self, 'in named element-like structure')
 * 
 */
  __pyx_t_3 = (__pyx_v_v != 0);
  if (__pyx_t_3) {

    /* "axon/_loader.py":1270
 *         v = self.get_mapping_part(mapping, None, idn)
 *         if v:
 *             errors.error_unexpected_value(self, 'in named element-like structure')             # <<<<<<<<<<<<<<
 * 
 *         val = self.builder.create_element(name, {}, sequence)
 */
    __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s__errors); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1270; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_25); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1270; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = PyTuple_New(2); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1270; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(((PyObject *)__pyx_v_self));
    PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self));
    __Pyx_GIVEREF(((PyObject *)__pyx_v_self));
    __Pyx_INCREF(((PyObject *)__pyx_kp_u_40));
    PyTuple_SET_ITEM(__pyx_t_1, 1, ((PyObject *)__pyx_kp_u_40));
    __Pyx_GIVEREF(((PyObject *)__pyx_kp_u_40));
    __pyx_t_5 = PyObject_Call(__pyx_t_4, ((PyObject *)__pyx_t_1), NULL); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1270; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(((PyObject *)__pyx_t_1)); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    goto __pyx_L3;
  }
  __pyx_L3:;

  /* "axon/_loader.py":1272
 *             errors.error_unexpected_value(self, 'in named element-like structure')
 * 
 *         val = self.builder.create_element(name, {}, sequence)             # <<<<<<<<<<<<<<
 * 
 *         return val
 */
  __pyx_t_5 = PyDict_New(); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1272; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(((PyObject *)__pyx_t_5));
  if (!(likely(PyList_CheckExact(__pyx_v_sequence))||((__pyx_v_sequence) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected list, got %.200s", Py_TYPE(__pyx_v_sequence)->tp_name), 0))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1272; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_t_1 = __pyx_v_self->builder->create_element(__pyx_v_name, ((PyObject*)__pyx_t_5), ((PyObject*)__pyx_v_sequence)); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1272; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(((PyObject *)__pyx_t_5)); __pyx_t_5 = 0;
  __pyx_v_val = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "axon/_loader.py":1274
 *         val = self.builder.create_element(name, {}, sequence)
 * 
 *         return val             # <<<<<<<<<<<<<<
 *     #
 *     def get_mapping_sequence(self, name, mapping, idn):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_val);
  __pyx_r = __pyx_v_val;
  goto __pyx_L0;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("axon._loader.Loader.get_empty_sequence", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_mapping);
  __Pyx_XDECREF(__pyx_v_val);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_loader.py":1276
 *         return val
 *     #
 *     def get_mapping_sequence(self, name, mapping, idn):             # <<<<<<<<<<<<<<
 *         sequence = []
 *         v = self.get_mapping_part(mapping, sequence, idn)
 */

static PyObject *__pyx_f_4axon_7_loader_6Loader_get_mapping_sequence(struct __pyx_obj_4axon_7_loader_Loader *__pyx_v_self, PyObject *__pyx_v_name, PyObject *__pyx_v_mapping, int __pyx_v_idn) {
  PyObject *__pyx_v_sequence = 0;
  PyObject *__pyx_v_val = 0;
  int __pyx_v_v;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_mapping_sequence", 0);

  /* "axon/_loader.py":1277
 *     #
 *     def get_mapping_sequence(self, name, mapping, idn):
 *         sequence = []             # <<<<<<<<<<<<<<
 *         v = self.get_mapping_part(mapping, sequence, idn)
 *         if v:
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1277; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_sequence = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "axon/_loader.py":1278
 *     def get_mapping_sequence(self, name, mapping, idn):
 *         sequence = []
 *         v = self.get_mapping_part(mapping, sequence, idn)             # <<<<<<<<<<<<<<
 *         if v:
 *             v = self.get_sequence_part(sequence, None, idn)
 */
  __pyx_t_2 = __pyx_f_4axon_7_loader_6Loader_get_mapping_part(__pyx_v_self, __pyx_v_mapping, __pyx_v_sequence, __pyx_v_idn); if (unlikely(__pyx_t_2 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1278; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_v_v = __pyx_t_2;

  /* "axon/_loader.py":1279
 *         sequence = []
 *         v = self.get_mapping_part(mapping, sequence, idn)
 *         if v:             # <<<<<<<<<<<<<<
 *             v = self.get_sequence_part(sequence, None, idn)
 *             if v:
 */
  __pyx_t_2 = (__pyx_v_v != 0);
  if (__pyx_t_2) {

    /* "axon/_loader.py":1280
 *         v = self.get_mapping_part(mapping, sequence, idn)
 *         if v:
 *             v = self.get_sequence_part(sequence, None, idn)             # <<<<<<<<<<<<<<
 *             if v:
 *                 errors.error_unexpected_value(self, 'in named mapping-like structure')
 */
    __pyx_t_2 = __pyx_f_4axon_7_loader_6Loader_get_sequence_part(__pyx_v_self, __pyx_v_sequence, ((PyObject*)Py_None), __pyx_v_idn); if (unlikely(__pyx_t_2 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1280; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __pyx_v_v = __pyx_t_2;

    /* "axon/_loader.py":1281
 *         if v:
 *             v = self.get_sequence_part(sequence, None, idn)
 *             if v:             # <<<<<<<<<<<<<<
 *                 errors.error_unexpected_value(self, 'in named mapping-like structure')
 * 
 */
    __pyx_t_2 = (__pyx_v_v != 0);
    if (__pyx_t_2) {

      /* "axon/_loader.py":1282
 *             v = self.get_sequence_part(sequence, None, idn)
 *             if v:
 *                 errors.error_unexpected_value(self, 'in named mapping-like structure')             # <<<<<<<<<<<<<<
 * 
 *             val = self.builder.create_element(name, mapping, sequence)
 */
      __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s__errors); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1282; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_25); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1282; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_1 = PyTuple_New(2); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1282; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_INCREF(((PyObject *)__pyx_v_self));
      PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self));
      __Pyx_GIVEREF(((PyObject *)__pyx_v_self));
      __Pyx_INCREF(((PyObject *)__pyx_kp_u_41));
      PyTuple_SET_ITEM(__pyx_t_1, 1, ((PyObject *)__pyx_kp_u_41));
      __Pyx_GIVEREF(((PyObject *)__pyx_kp_u_41));
      __pyx_t_4 = PyObject_Call(__pyx_t_3, ((PyObject *)__pyx_t_1), NULL); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1282; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF(((PyObject *)__pyx_t_1)); __pyx_t_1 = 0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      goto __pyx_L4;
    }
    __pyx_L4:;

    /* "axon/_loader.py":1284
 *                 errors.error_unexpected_value(self, 'in named mapping-like structure')
 * 
 *             val = self.builder.create_element(name, mapping, sequence)             # <<<<<<<<<<<<<<
 *         else:
 *             val = self.builder.create_mapping(name, mapping)
 */
    __pyx_t_4 = __pyx_v_self->builder->create_element(__pyx_v_name, __pyx_v_mapping, __pyx_v_sequence); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1284; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_v_val = __pyx_t_4;
    __pyx_t_4 = 0;
    goto __pyx_L3;
  }
  /*else*/ {

    /* "axon/_loader.py":1286
 *             val = self.builder.create_element(name, mapping, sequence)
 *         else:
 *             val = self.builder.create_mapping(name, mapping)             # <<<<<<<<<<<<<<
 * 
 *         return val
 */
    __pyx_t_4 = __pyx_v_self->builder->create_mapping(__pyx_v_name, __pyx_v_mapping); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1286; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_v_val = __pyx_t_4;
    __pyx_t_4 = 0;
  }
  __pyx_L3:;

  /* "axon/_loader.py":1288
 *             val = self.builder.create_mapping(name, mapping)
 * 
 *         return val             # <<<<<<<<<<<<<<
 *     #
 *     def get_empty_mapping(self, name, mapping, idn):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_val);
  __pyx_r = __pyx_v_val;
  goto __pyx_L0;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("axon._loader.Loader.get_mapping_sequence", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_sequence);
  __Pyx_XDECREF(__pyx_v_val);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_4axon_7_loader_6Loader_13get_empty_mapping(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyObject *__pyx_pw_4axon_7_loader_6Loader_13get_empty_mapping(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_name = 0;
  PyObject *__pyx_v_mapping = 0;
  PyObject *__pyx_v_idn = 0;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_empty_mapping (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s__name,&__pyx_n_s__mapping,&__pyx_n_s__idn,0};
    PyObject* values[3] = {0,0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s__name)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s__mapping)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("get_empty_mapping", 1, 3, 3, 1); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1290; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
        }
        case  2:
        if (likely((values[2] = PyDict_GetItem(__pyx_kwds, __pyx_n_s__idn)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("get_empty_mapping", 1, 3, 3, 2); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1290; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "get_empty_mapping") < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1290; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 3) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
      values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
    }
    __pyx_v_name = values[0];
    __pyx_v_mapping = values[1];
    __pyx_v_idn = values[2];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_empty_mapping", 1, 3, 3, PyTuple_GET_SIZE(__pyx_args)); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1290; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  __pyx_L3_error:;
  __Pyx_AddTraceback("axon._loader.Loader.get_empty_mapping", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_4axon_7_loader_6Loader_12get_empty_mapping(((struct __pyx_obj_4axon_7_loader_Loader *)__pyx_v_self), __pyx_v_name, __pyx_v_mapping, __pyx_v_idn);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_loader.py":1290
 *         return val
 *     #
 *     def get_empty_mapping(self, name, mapping, idn):             # <<<<<<<<<<<<<<
 *         sequence = []
 *         v = self.get_sequence_part(sequence, None, idn)
 */

static PyObject *__pyx_pf_4axon_7_loader_6Loader_12get_empty_mapping(struct __pyx_obj_4axon_7_loader_Loader *__pyx_v_self, PyObject *__pyx_v_name, PyObject *__pyx_v_mapping, PyObject *__pyx_v_idn) {
  PyObject *__pyx_v_sequence = NULL;
  int __pyx_v_v;
  PyObject *__pyx_v_val = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_empty_mapping", 0);

  /* "axon/_loader.py":1291
 *     #
 *     def get_empty_mapping(self, name, mapping, idn):
 *         sequence = []             # <<<<<<<<<<<<<<
 *         v = self.get_sequence_part(sequence, None, idn)
 *         if v:
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1291; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_sequence = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "axon/_loader.py":1292
 *     def get_empty_mapping(self, name, mapping, idn):
 *         sequence = []
 *         v = self.get_sequence_part(sequence, None, idn)             # <<<<<<<<<<<<<<
 *         if v:
 *             errors.error_unexpected_value(self, 'in named instance-like structure')
 */
  __pyx_t_2 = __Pyx_PyInt_AsInt(__pyx_v_idn); if (unlikely((__pyx_t_2 == (int)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1292; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_t_3 = __pyx_f_4axon_7_loader_6Loader_get_sequence_part(__pyx_v_self, __pyx_v_sequence, ((PyObject*)Py_None), __pyx_t_2); if (unlikely(__pyx_t_3 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1292; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_v_v = __pyx_t_3;

  /* "axon/_loader.py":1293
 *         sequence = []
 *         v = self.get_sequence_part(sequence, None, idn)
 *         if v:             # <<<<<<<<<<<<<<
 *             errors.error_unexpected_value(self, 'in named instance-like structure')
 * 
 */
  __pyx_t_3 = (__pyx_v_v != 0);
  if (__pyx_t_3) {

    /* "axon/_loader.py":1294
 *         v = self.get_sequence_part(sequence, None, idn)
 *         if v:
 *             errors.error_unexpected_value(self, 'in named instance-like structure')             # <<<<<<<<<<<<<<
 * 
 *         val = self.builder.create_instance(name, (), mapping)
 */
    __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s__errors); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1294; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_25); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1294; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = PyTuple_New(2); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1294; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(((PyObject *)__pyx_v_self));
    PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self));
    __Pyx_GIVEREF(((PyObject *)__pyx_v_self));
    __Pyx_INCREF(((PyObject *)__pyx_kp_u_42));
    PyTuple_SET_ITEM(__pyx_t_1, 1, ((PyObject *)__pyx_kp_u_42));
    __Pyx_GIVEREF(((PyObject *)__pyx_kp_u_42));
    __pyx_t_5 = PyObject_Call(__pyx_t_4, ((PyObject *)__pyx_t_1), NULL); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1294; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(((PyObject *)__pyx_t_1)); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    goto __pyx_L3;
  }
  __pyx_L3:;

  /* "axon/_loader.py":1296
 *             errors.error_unexpected_value(self, 'in named instance-like structure')
 * 
 *         val = self.builder.create_instance(name, (), mapping)             # <<<<<<<<<<<<<<
 * 
 *         return val
 */
  if (!(likely(PyDict_CheckExact(__pyx_v_mapping))||((__pyx_v_mapping) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected dict, got %.200s", Py_TYPE(__pyx_v_mapping)->tp_name), 0))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1296; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_t_5 = __pyx_v_self->builder->create_instance(__pyx_v_name, __pyx_empty_tuple, ((PyObject*)__pyx_v_mapping)); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1296; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_v_val = __pyx_t_5;
  __pyx_t_5 = 0;

  /* "axon/_loader.py":1298
 *         val = self.builder.create_instance(name, (), mapping)
 * 
 *         return val             # <<<<<<<<<<<<<<
 * 
 *     def get_list_value(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_val);
  __pyx_r = __pyx_v_val;
  goto __pyx_L0;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("axon._loader.Loader.get_empty_mapping", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_sequence);
  __Pyx_XDECREF(__pyx_v_val);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_loader.py":1300
 *         return val
 * 
 *     def get_list_value(self):             # <<<<<<<<<<<<<<
 * 
 *         sequence = []
 */

static PyObject *__pyx_f_4axon_7_loader_6Loader_get_list_value(struct __pyx_obj_4axon_7_loader_Loader *__pyx_v_self) {
  Py_UCS4 __pyx_v_ch;
  PyObject *__pyx_v_val = 0;
  PyObject *__pyx_v_sequence = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  Py_UCS4 __pyx_t_2;
  int __pyx_t_3;
  int __pyx_t_4;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_list_value", 0);

  /* "axon/_loader.py":1302
 *     def get_list_value(self):
 * 
 *         sequence = []             # <<<<<<<<<<<<<<
 * 
 *         self.moveto_next_token()
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1302; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_sequence = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "axon/_loader.py":1304
 *         sequence = []
 * 
 *         self.moveto_next_token()             # <<<<<<<<<<<<<<
 * 
 *         while 1:
 */
  __pyx_t_2 = __pyx_f_4axon_7_loader_6Loader_moveto_next_token(__pyx_v_self); if (unlikely(__pyx_t_2 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1304; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

  /* "axon/_loader.py":1306
 *         self.moveto_next_token()
 * 
 *         while 1:             # <<<<<<<<<<<<<<
 *             ch = current_char(self)
 *             if ch == ']':
 */
  while (1) {
    if (!1) break;

    /* "axon/_loader.py":1307
 * 
 *         while 1:
 *             ch = current_char(self)             # <<<<<<<<<<<<<<
 *             if ch == ']':
 *                 skip_char(self)
 */
    __pyx_v_ch = current_char(__pyx_v_self);

    /* "axon/_loader.py":1308
 *         while 1:
 *             ch = current_char(self)
 *             if ch == ']':             # <<<<<<<<<<<<<<
 *                 skip_char(self)
 *                 self.bs -= 1
 */
    __pyx_t_3 = ((__pyx_v_ch == 93) != 0);
    if (__pyx_t_3) {

      /* "axon/_loader.py":1309
 *             ch = current_char(self)
 *             if ch == ']':
 *                 skip_char(self)             # <<<<<<<<<<<<<<
 *                 self.bs -= 1
 *                 return sequence
 */
      skip_char(__pyx_v_self);

      /* "axon/_loader.py":1310
 *             if ch == ']':
 *                 skip_char(self)
 *                 self.bs -= 1             # <<<<<<<<<<<<<<
 *                 return sequence
 * 
 */
      __pyx_v_self->bs = (__pyx_v_self->bs - 1);

      /* "axon/_loader.py":1311
 *                 skip_char(self)
 *                 self.bs -= 1
 *                 return sequence             # <<<<<<<<<<<<<<
 * 
 *             val = self.get_value(0)
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(((PyObject *)__pyx_v_sequence));
      __pyx_r = ((PyObject *)__pyx_v_sequence);
      goto __pyx_L0;
      goto __pyx_L5;
    }
    __pyx_L5:;

    /* "axon/_loader.py":1313
 *                 return sequence
 * 
 *             val = self.get_value(0)             # <<<<<<<<<<<<<<
 *             sequence.append(val)
 * 
 */
    __pyx_t_1 = __pyx_f_4axon_7_loader_6Loader_get_value(__pyx_v_self, 0); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1313; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_XDECREF(__pyx_v_val);
    __pyx_v_val = __pyx_t_1;
    __pyx_t_1 = 0;

    /* "axon/_loader.py":1314
 * 
 *             val = self.get_value(0)
 *             sequence.append(val)             # <<<<<<<<<<<<<<
 * 
 *             self.moveto_next_token()
 */
    __pyx_t_4 = __Pyx_PyList_Append(__pyx_v_sequence, __pyx_v_val); if (unlikely(__pyx_t_4 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1314; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

    /* "axon/_loader.py":1316
 *             sequence.append(val)
 * 
 *             self.moveto_next_token()             # <<<<<<<<<<<<<<
 * 
 *             if self.json:
 */
    __pyx_t_2 = __pyx_f_4axon_7_loader_6Loader_moveto_next_token(__pyx_v_self); if (unlikely(__pyx_t_2 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1316; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

    /* "axon/_loader.py":1318
 *             self.moveto_next_token()
 * 
 *             if self.json:             # <<<<<<<<<<<<<<
 *                 ch = current_char(self)
 *                 if ch == ',':
 */
    __pyx_t_3 = (__pyx_v_self->json != 0);
    if (__pyx_t_3) {

      /* "axon/_loader.py":1319
 * 
 *             if self.json:
 *                 ch = current_char(self)             # <<<<<<<<<<<<<<
 *                 if ch == ',':
 *                     skip_char(self)
 */
      __pyx_v_ch = current_char(__pyx_v_self);

      /* "axon/_loader.py":1320
 *             if self.json:
 *                 ch = current_char(self)
 *                 if ch == ',':             # <<<<<<<<<<<<<<
 *                     skip_char(self)
 *                     self.moveto_next_token()
 */
      __pyx_t_3 = ((__pyx_v_ch == 44) != 0);
      if (__pyx_t_3) {

        /* "axon/_loader.py":1321
 *                 ch = current_char(self)
 *                 if ch == ',':
 *                     skip_char(self)             # <<<<<<<<<<<<<<
 *                     self.moveto_next_token()
 *     #
 */
        skip_char(__pyx_v_self);

        /* "axon/_loader.py":1322
 *                 if ch == ',':
 *                     skip_char(self)
 *                     self.moveto_next_token()             # <<<<<<<<<<<<<<
 *     #
 *     def get_tuple_value(self):
 */
        __pyx_t_2 = __pyx_f_4axon_7_loader_6Loader_moveto_next_token(__pyx_v_self); if (unlikely(__pyx_t_2 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1322; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        goto __pyx_L7;
      }
      __pyx_L7:;
      goto __pyx_L6;
    }
    __pyx_L6:;
  }

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("axon._loader.Loader.get_list_value", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_val);
  __Pyx_XDECREF(__pyx_v_sequence);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_loader.py":1324
 *                     self.moveto_next_token()
 *     #
 *     def get_tuple_value(self):             # <<<<<<<<<<<<<<
 * 
 *         sequence = []
 */

static PyObject *__pyx_f_4axon_7_loader_6Loader_get_tuple_value(struct __pyx_obj_4axon_7_loader_Loader *__pyx_v_self) {
  PyObject *__pyx_v_sequence = 0;
  Py_UCS4 __pyx_v_ch;
  PyObject *__pyx_v_val = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  Py_UCS4 __pyx_t_2;
  int __pyx_t_3;
  int __pyx_t_4;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_tuple_value", 0);

  /* "axon/_loader.py":1326
 *     def get_tuple_value(self):
 * 
 *         sequence = []             # <<<<<<<<<<<<<<
 * 
 *         ch = self.moveto_next_token()
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1326; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_sequence = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "axon/_loader.py":1328
 *         sequence = []
 * 
 *         ch = self.moveto_next_token()             # <<<<<<<<<<<<<<
 * 
 *         while 1:
 */
  __pyx_t_2 = __pyx_f_4axon_7_loader_6Loader_moveto_next_token(__pyx_v_self); if (unlikely(__pyx_t_2 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1328; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_v_ch = __pyx_t_2;

  /* "axon/_loader.py":1330
 *         ch = self.moveto_next_token()
 * 
 *         while 1:             # <<<<<<<<<<<<<<
 * 
 *             #ch = current_char(self)
 */
  while (1) {
    if (!1) break;

    /* "axon/_loader.py":1333
 * 
 *             #ch = current_char(self)
 *             if ch == ')':             # <<<<<<<<<<<<<<
 *                 skip_char(self)
 *                 self.bq -= 1
 */
    __pyx_t_3 = ((__pyx_v_ch == 41) != 0);
    if (__pyx_t_3) {

      /* "axon/_loader.py":1334
 *             #ch = current_char(self)
 *             if ch == ')':
 *                 skip_char(self)             # <<<<<<<<<<<<<<
 *                 self.bq -= 1
 *                 return tuple(sequence)
 */
      skip_char(__pyx_v_self);

      /* "axon/_loader.py":1335
 *             if ch == ')':
 *                 skip_char(self)
 *                 self.bq -= 1             # <<<<<<<<<<<<<<
 *                 return tuple(sequence)
 * 
 */
      __pyx_v_self->bq = (__pyx_v_self->bq - 1);

      /* "axon/_loader.py":1336
 *                 skip_char(self)
 *                 self.bq -= 1
 *                 return tuple(sequence)             # <<<<<<<<<<<<<<
 * 
 *             val = self.get_value(0)
 */
      __Pyx_XDECREF(__pyx_r);
      __pyx_t_1 = ((PyObject *)PyList_AsTuple(__pyx_v_sequence)); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1336; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(((PyObject *)__pyx_t_1));
      __pyx_r = ((PyObject *)__pyx_t_1);
      __pyx_t_1 = 0;
      goto __pyx_L0;
      goto __pyx_L5;
    }
    __pyx_L5:;

    /* "axon/_loader.py":1338
 *                 return tuple(sequence)
 * 
 *             val = self.get_value(0)             # <<<<<<<<<<<<<<
 *             sequence.append(val)
 * 
 */
    __pyx_t_1 = __pyx_f_4axon_7_loader_6Loader_get_value(__pyx_v_self, 0); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1338; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_XDECREF(__pyx_v_val);
    __pyx_v_val = __pyx_t_1;
    __pyx_t_1 = 0;

    /* "axon/_loader.py":1339
 * 
 *             val = self.get_value(0)
 *             sequence.append(val)             # <<<<<<<<<<<<<<
 * 
 *             ch = self.moveto_next_token()
 */
    __pyx_t_4 = __Pyx_PyList_Append(__pyx_v_sequence, __pyx_v_val); if (unlikely(__pyx_t_4 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1339; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

    /* "axon/_loader.py":1341
 *             sequence.append(val)
 * 
 *             ch = self.moveto_next_token()             # <<<<<<<<<<<<<<
 *     #
 *     def get_dict_value(self):
 */
    __pyx_t_2 = __pyx_f_4axon_7_loader_6Loader_moveto_next_token(__pyx_v_self); if (unlikely(__pyx_t_2 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1341; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __pyx_v_ch = __pyx_t_2;
  }

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("axon._loader.Loader.get_tuple_value", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_sequence);
  __Pyx_XDECREF(__pyx_v_val);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_loader.py":1343
 *             ch = self.moveto_next_token()
 *     #
 *     def get_dict_value(self):             # <<<<<<<<<<<<<<
 *         mapping = {}
 * 
 */

static PyObject *__pyx_f_4axon_7_loader_6Loader_get_dict_value(struct __pyx_obj_4axon_7_loader_Loader *__pyx_v_self) {
  Py_UCS4 __pyx_v_ch;
  PyObject *__pyx_v_mapping = 0;
  PyObject *__pyx_v_key = NULL;
  PyObject *__pyx_v_val = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  Py_UCS4 __pyx_t_2;
  int __pyx_t_3;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_dict_value", 0);

  /* "axon/_loader.py":1344
 *     #
 *     def get_dict_value(self):
 *         mapping = {}             # <<<<<<<<<<<<<<
 * 
 *         self.moveto_next_token()
 */
  __pyx_t_1 = PyDict_New(); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1344; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(((PyObject *)__pyx_t_1));
  __pyx_v_mapping = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "axon/_loader.py":1346
 *         mapping = {}
 * 
 *         self.moveto_next_token()             # <<<<<<<<<<<<<<
 * 
 *         while 1:
 */
  __pyx_t_2 = __pyx_f_4axon_7_loader_6Loader_moveto_next_token(__pyx_v_self); if (unlikely(__pyx_t_2 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1346; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

  /* "axon/_loader.py":1348
 *         self.moveto_next_token()
 * 
 *         while 1:             # <<<<<<<<<<<<<<
 * 
 *             key = self.try_get_key()
 */
  while (1) {
    if (!1) break;

    /* "axon/_loader.py":1350
 *         while 1:
 * 
 *             key = self.try_get_key()             # <<<<<<<<<<<<<<
 * 
 *             ch = self.skip_spaces()
 */
    __pyx_t_1 = __pyx_f_4axon_7_loader_6Loader_try_get_key(__pyx_v_self); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1350; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_XDECREF(__pyx_v_key);
    __pyx_v_key = __pyx_t_1;
    __pyx_t_1 = 0;

    /* "axon/_loader.py":1352
 *             key = self.try_get_key()
 * 
 *             ch = self.skip_spaces()             # <<<<<<<<<<<<<<
 * 
 *             if key is not None:
 */
    __pyx_v_ch = __pyx_f_4axon_7_loader_6Loader_skip_spaces(__pyx_v_self);

    /* "axon/_loader.py":1354
 *             ch = self.skip_spaces()
 * 
 *             if key is not None:             # <<<<<<<<<<<<<<
 *                 if ch == ':':
 *                     skip_char(self)
 */
    __pyx_t_3 = (__pyx_v_key != Py_None);
    __pyx_t_4 = (__pyx_t_3 != 0);
    if (__pyx_t_4) {

      /* "axon/_loader.py":1355
 * 
 *             if key is not None:
 *                 if ch == ':':             # <<<<<<<<<<<<<<
 *                     skip_char(self)
 *                     self.moveto_next_token()
 */
      __pyx_t_4 = ((__pyx_v_ch == 58) != 0);
      if (__pyx_t_4) {

        /* "axon/_loader.py":1356
 *             if key is not None:
 *                 if ch == ':':
 *                     skip_char(self)             # <<<<<<<<<<<<<<
 *                     self.moveto_next_token()
 * 
 */
        skip_char(__pyx_v_self);

        /* "axon/_loader.py":1357
 *                 if ch == ':':
 *                     skip_char(self)
 *                     self.moveto_next_token()             # <<<<<<<<<<<<<<
 * 
 *                     val = self.get_value(0)
 */
        __pyx_t_2 = __pyx_f_4axon_7_loader_6Loader_moveto_next_token(__pyx_v_self); if (unlikely(__pyx_t_2 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1357; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

        /* "axon/_loader.py":1359
 *                     self.moveto_next_token()
 * 
 *                     val = self.get_value(0)             # <<<<<<<<<<<<<<
 *                     mapping[key] = val
 *                 else:
 */
        __pyx_t_1 = __pyx_f_4axon_7_loader_6Loader_get_value(__pyx_v_self, 0); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1359; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_XDECREF(__pyx_v_val);
        __pyx_v_val = __pyx_t_1;
        __pyx_t_1 = 0;

        /* "axon/_loader.py":1360
 * 
 *                     val = self.get_value(0)
 *                     mapping[key] = val             # <<<<<<<<<<<<<<
 *                 else:
 *                     errors.error_dict_value(self)
 */
        if (PyDict_SetItem(((PyObject *)__pyx_v_mapping), __pyx_v_key, __pyx_v_val) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1360; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        goto __pyx_L6;
      }
      /*else*/ {

        /* "axon/_loader.py":1362
 *                     mapping[key] = val
 *                 else:
 *                     errors.error_dict_value(self)             # <<<<<<<<<<<<<<
 *             else:
 *                 if ch == '}':
 */
        __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s__errors); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1362; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_1);
        __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s__error_dict_value); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1362; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1362; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_INCREF(((PyObject *)__pyx_v_self));
        PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self));
        __Pyx_GIVEREF(((PyObject *)__pyx_v_self));
        __pyx_t_6 = PyObject_Call(__pyx_t_5, ((PyObject *)__pyx_t_1), NULL); if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1362; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_DECREF(((PyObject *)__pyx_t_1)); __pyx_t_1 = 0;
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      }
      __pyx_L6:;
      goto __pyx_L5;
    }
    /*else*/ {

      /* "axon/_loader.py":1364
 *                     errors.error_dict_value(self)
 *             else:
 *                 if ch == '}':             # <<<<<<<<<<<<<<
 *                     skip_char(self)
 *                     self.bc -= 1
 */
      __pyx_t_4 = ((__pyx_v_ch == 125) != 0);
      if (__pyx_t_4) {

        /* "axon/_loader.py":1365
 *             else:
 *                 if ch == '}':
 *                     skip_char(self)             # <<<<<<<<<<<<<<
 *                     self.bc -= 1
 *                     return mapping
 */
        skip_char(__pyx_v_self);

        /* "axon/_loader.py":1366
 *                 if ch == '}':
 *                     skip_char(self)
 *                     self.bc -= 1             # <<<<<<<<<<<<<<
 *                     return mapping
 *                 else:
 */
        __pyx_v_self->bc = (__pyx_v_self->bc - 1);

        /* "axon/_loader.py":1367
 *                     skip_char(self)
 *                     self.bc -= 1
 *                     return mapping             # <<<<<<<<<<<<<<
 *                 else:
 *                     errors.error_dict_value(self)
 */
        __Pyx_XDECREF(__pyx_r);
        __Pyx_INCREF(((PyObject *)__pyx_v_mapping));
        __pyx_r = ((PyObject *)__pyx_v_mapping);
        goto __pyx_L0;
        goto __pyx_L7;
      }
      /*else*/ {

        /* "axon/_loader.py":1369
 *                     return mapping
 *                 else:
 *                     errors.error_dict_value(self)             # <<<<<<<<<<<<<<
 * 
 *             self.moveto_next_token()
 */
        __pyx_t_6 = __Pyx_GetModuleGlobalName(__pyx_n_s__errors); if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1369; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_6);
        __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s__error_dict_value); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1369; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        __pyx_t_6 = PyTuple_New(1); if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1369; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_INCREF(((PyObject *)__pyx_v_self));
        PyTuple_SET_ITEM(__pyx_t_6, 0, ((PyObject *)__pyx_v_self));
        __Pyx_GIVEREF(((PyObject *)__pyx_v_self));
        __pyx_t_5 = PyObject_Call(__pyx_t_1, ((PyObject *)__pyx_t_6), NULL); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1369; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        __Pyx_DECREF(((PyObject *)__pyx_t_6)); __pyx_t_6 = 0;
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      }
      __pyx_L7:;
    }
    __pyx_L5:;

    /* "axon/_loader.py":1371
 *                     errors.error_dict_value(self)
 * 
 *             self.moveto_next_token()             # <<<<<<<<<<<<<<
 * 
 *             if self.json:
 */
    __pyx_t_2 = __pyx_f_4axon_7_loader_6Loader_moveto_next_token(__pyx_v_self); if (unlikely(__pyx_t_2 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1371; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

    /* "axon/_loader.py":1373
 *             self.moveto_next_token()
 * 
 *             if self.json:             # <<<<<<<<<<<<<<
 *                 ch = current_char(self)
 *                 if ch == ',':
 */
    __pyx_t_4 = (__pyx_v_self->json != 0);
    if (__pyx_t_4) {

      /* "axon/_loader.py":1374
 * 
 *             if self.json:
 *                 ch = current_char(self)             # <<<<<<<<<<<<<<
 *                 if ch == ',':
 *                     skip_char(self)
 */
      __pyx_v_ch = current_char(__pyx_v_self);

      /* "axon/_loader.py":1375
 *             if self.json:
 *                 ch = current_char(self)
 *                 if ch == ',':             # <<<<<<<<<<<<<<
 *                     skip_char(self)
 *                     self.moveto_next_token()
 */
      __pyx_t_4 = ((__pyx_v_ch == 44) != 0);
      if (__pyx_t_4) {

        /* "axon/_loader.py":1376
 *                 ch = current_char(self)
 *                 if ch == ',':
 *                     skip_char(self)             # <<<<<<<<<<<<<<
 *                     self.moveto_next_token()
 *     #
 */
        skip_char(__pyx_v_self);

        /* "axon/_loader.py":1377
 *                 if ch == ',':
 *                     skip_char(self)
 *                     self.moveto_next_token()             # <<<<<<<<<<<<<<
 *     #
 *     def get_mapping_part(self, mapping, sequence, idn):
 */
        __pyx_t_2 = __pyx_f_4axon_7_loader_6Loader_moveto_next_token(__pyx_v_self); if (unlikely(__pyx_t_2 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1377; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        goto __pyx_L9;
      }
      __pyx_L9:;
      goto __pyx_L8;
    }
    __pyx_L8:;
  }

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("axon._loader.Loader.get_dict_value", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_mapping);
  __Pyx_XDECREF(__pyx_v_key);
  __Pyx_XDECREF(__pyx_v_val);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_loader.py":1379
 *                     self.moveto_next_token()
 *     #
 *     def get_mapping_part(self, mapping, sequence, idn):             # <<<<<<<<<<<<<<
 * 
 *         while 1:
 */

static int __pyx_f_4axon_7_loader_6Loader_get_mapping_part(struct __pyx_obj_4axon_7_loader_Loader *__pyx_v_self, PyObject *__pyx_v_mapping, PyObject *__pyx_v_sequence, int __pyx_v_idn) {
  Py_UCS4 __pyx_v_ch;
  int __pyx_v_is_multi;
  PyObject *__pyx_v_name = NULL;
  PyObject *__pyx_v_val = NULL;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  Py_UCS4 __pyx_t_7;
  int __pyx_t_8;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_mapping_part", 0);

  /* "axon/_loader.py":1381
 *     def get_mapping_part(self, mapping, sequence, idn):
 * 
 *         while 1:             # <<<<<<<<<<<<<<
 *             ch = self.skip_spaces()
 * 
 */
  while (1) {
    if (!1) break;

    /* "axon/_loader.py":1382
 * 
 *         while 1:
 *             ch = self.skip_spaces()             # <<<<<<<<<<<<<<
 * 
 *             if idn:
 */
    __pyx_v_ch = __pyx_f_4axon_7_loader_6Loader_skip_spaces(__pyx_v_self);

    /* "axon/_loader.py":1384
 *             ch = self.skip_spaces()
 * 
 *             if idn:             # <<<<<<<<<<<<<<
 *                 if self.pos == idn:
 *                     pass
 */
    __pyx_t_1 = (__pyx_v_idn != 0);
    if (__pyx_t_1) {

      /* "axon/_loader.py":1385
 * 
 *             if idn:
 *                 if self.pos == idn:             # <<<<<<<<<<<<<<
 *                     pass
 *                 elif self.pos < idn or self.eof or ch == '}' or ch == ']':
 */
      __pyx_t_1 = ((__pyx_v_self->pos == __pyx_v_idn) != 0);
      if (__pyx_t_1) {
        goto __pyx_L6;
      }

      /* "axon/_loader.py":1387
 *                 if self.pos == idn:
 *                     pass
 *                 elif self.pos < idn or self.eof or ch == '}' or ch == ']':             # <<<<<<<<<<<<<<
 *                     return 0
 *                 #elif self.pos > idn and self.is_nl:
 */
      __pyx_t_1 = ((__pyx_v_self->pos < __pyx_v_idn) != 0);
      if (!__pyx_t_1) {
        if (!(__pyx_v_self->eof != 0)) {
          switch (__pyx_v_ch) {
            case 125:
            case 93:
            __pyx_t_2 = 1;
            break;
            default:
            __pyx_t_2 = 0;
            break;
          }
          __pyx_t_3 = __pyx_t_2;
        } else {
          __pyx_t_3 = (__pyx_v_self->eof != 0);
        }
        __pyx_t_2 = __pyx_t_3;
      } else {
        __pyx_t_2 = __pyx_t_1;
      }
      if (__pyx_t_2) {

        /* "axon/_loader.py":1388
 *                     pass
 *                 elif self.pos < idn or self.eof or ch == '}' or ch == ']':
 *                     return 0             # <<<<<<<<<<<<<<
 *                 #elif self.pos > idn and self.is_nl:
 *                 #    errors.error_indentation(self, idn)
 */
        __pyx_r = 0;
        goto __pyx_L0;
        goto __pyx_L6;
      }
      __pyx_L6:;
      goto __pyx_L5;
    }

    /* "axon/_loader.py":1391
 *                 #elif self.pos > idn and self.is_nl:
 *                 #    errors.error_indentation(self, idn)
 *             elif self.eof:             # <<<<<<<<<<<<<<
 *                 errors.error_unexpected_end(self)
 * 
 */
    __pyx_t_2 = (__pyx_v_self->eof != 0);
    if (__pyx_t_2) {

      /* "axon/_loader.py":1392
 *                 #    errors.error_indentation(self, idn)
 *             elif self.eof:
 *                 errors.error_unexpected_end(self)             # <<<<<<<<<<<<<<
 * 
 *             name = self.try_get_name()
 */
      __pyx_t_4 = __Pyx_GetModuleGlobalName(__pyx_n_s__errors); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1392; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_23); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1392; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_4 = PyTuple_New(1); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1392; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_INCREF(((PyObject *)__pyx_v_self));
      PyTuple_SET_ITEM(__pyx_t_4, 0, ((PyObject *)__pyx_v_self));
      __Pyx_GIVEREF(((PyObject *)__pyx_v_self));
      __pyx_t_6 = PyObject_Call(__pyx_t_5, ((PyObject *)__pyx_t_4), NULL); if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1392; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(((PyObject *)__pyx_t_4)); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      goto __pyx_L5;
    }
    __pyx_L5:;

    /* "axon/_loader.py":1394
 *                 errors.error_unexpected_end(self)
 * 
 *             name = self.try_get_name()             # <<<<<<<<<<<<<<
 * 
 *             if name is not None:
 */
    __pyx_t_6 = __pyx_f_4axon_7_loader_6Loader_try_get_name(__pyx_v_self); if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1394; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_XDECREF(__pyx_v_name);
    __pyx_v_name = __pyx_t_6;
    __pyx_t_6 = 0;

    /* "axon/_loader.py":1396
 *             name = self.try_get_name()
 * 
 *             if name is not None:             # <<<<<<<<<<<<<<
 * 
 *                 ch = current_char(self)
 */
    __pyx_t_2 = (__pyx_v_name != Py_None);
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (__pyx_t_1) {

      /* "axon/_loader.py":1398
 *             if name is not None:
 * 
 *                 ch = current_char(self)             # <<<<<<<<<<<<<<
 *                 if ch == '*':
 *                     ch = next_char(self)
 */
      __pyx_v_ch = current_char(__pyx_v_self);

      /* "axon/_loader.py":1399
 * 
 *                 ch = current_char(self)
 *                 if ch == '*':             # <<<<<<<<<<<<<<
 *                     ch = next_char(self)
 *                     is_multi = 1
 */
      __pyx_t_1 = ((__pyx_v_ch == 42) != 0);
      if (__pyx_t_1) {

        /* "axon/_loader.py":1400
 *                 ch = current_char(self)
 *                 if ch == '*':
 *                     ch = next_char(self)             # <<<<<<<<<<<<<<
 *                     is_multi = 1
 *                 else:
 */
        __pyx_v_ch = next_char(__pyx_v_self);

        /* "axon/_loader.py":1401
 *                 if ch == '*':
 *                     ch = next_char(self)
 *                     is_multi = 1             # <<<<<<<<<<<<<<
 *                 else:
 *                     is_multi = 0
 */
        __pyx_v_is_multi = 1;
        goto __pyx_L8;
      }
      /*else*/ {

        /* "axon/_loader.py":1403
 *                     is_multi = 1
 *                 else:
 *                     is_multi = 0             # <<<<<<<<<<<<<<
 * 
 *                 ch = self.skip_spaces()
 */
        __pyx_v_is_multi = 0;
      }
      __pyx_L8:;

      /* "axon/_loader.py":1405
 *                     is_multi = 0
 * 
 *                 ch = self.skip_spaces()             # <<<<<<<<<<<<<<
 * 
 *                 if ch == ':':
 */
      __pyx_v_ch = __pyx_f_4axon_7_loader_6Loader_skip_spaces(__pyx_v_self);

      /* "axon/_loader.py":1424
 *                     val = self.get_value(idn)
 *                     mapping[name] = val
 *                 elif ch == '{':             # <<<<<<<<<<<<<<
 *                     self.bc += 1
 *                     skip_char(self)
 */
      switch (__pyx_v_ch) {

        /* "axon/_loader.py":1407
 *                 ch = self.skip_spaces()
 * 
 *                 if ch == ':':             # <<<<<<<<<<<<<<
 *                     skip_char(self)
 * 
 */
        case 58:

        /* "axon/_loader.py":1408
 * 
 *                 if ch == ':':
 *                     skip_char(self)             # <<<<<<<<<<<<<<
 * 
 *                     self.moveto_next_token()
 */
        skip_char(__pyx_v_self);

        /* "axon/_loader.py":1410
 *                     skip_char(self)
 * 
 *                     self.moveto_next_token()             # <<<<<<<<<<<<<<
 * 
 *                     if self.is_nl and self.pos > idn:
 */
        __pyx_t_7 = __pyx_f_4axon_7_loader_6Loader_moveto_next_token(__pyx_v_self); if (unlikely(__pyx_t_7 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1410; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

        /* "axon/_loader.py":1412
 *                     self.moveto_next_token()
 * 
 *                     if self.is_nl and self.pos > idn:             # <<<<<<<<<<<<<<
 *                         if sequence is not None:
 *                             if is_multi:
 */
        if ((__pyx_v_self->is_nl != 0)) {
          __pyx_t_1 = ((__pyx_v_self->pos > __pyx_v_idn) != 0);
          __pyx_t_2 = __pyx_t_1;
        } else {
          __pyx_t_2 = (__pyx_v_self->is_nl != 0);
        }
        if (__pyx_t_2) {

          /* "axon/_loader.py":1413
 * 
 *                     if self.is_nl and self.pos > idn:
 *                         if sequence is not None:             # <<<<<<<<<<<<<<
 *                             if is_multi:
 *                                 val =  self.get_collection(name, self.pos)
 */
          __pyx_t_2 = (__pyx_v_sequence != ((PyObject*)Py_None));
          __pyx_t_1 = (__pyx_t_2 != 0);
          if (__pyx_t_1) {

            /* "axon/_loader.py":1414
 *                     if self.is_nl and self.pos > idn:
 *                         if sequence is not None:
 *                             if is_multi:             # <<<<<<<<<<<<<<
 *                                 val =  self.get_collection(name, self.pos)
 *                             else:
 */
            __pyx_t_1 = (__pyx_v_is_multi != 0);
            if (__pyx_t_1) {

              /* "axon/_loader.py":1415
 *                         if sequence is not None:
 *                             if is_multi:
 *                                 val =  self.get_collection(name, self.pos)             # <<<<<<<<<<<<<<
 *                             else:
 *                                 val = self.get_complex_value(name, self.pos)
 */
              __pyx_t_6 = __pyx_f_4axon_7_loader_6Loader_get_collection(__pyx_v_self, __pyx_v_name, __pyx_v_self->pos); if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1415; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
              __Pyx_GOTREF(__pyx_t_6);
              __Pyx_XDECREF(__pyx_v_val);
              __pyx_v_val = __pyx_t_6;
              __pyx_t_6 = 0;
              goto __pyx_L11;
            }
            /*else*/ {

              /* "axon/_loader.py":1417
 *                                 val =  self.get_collection(name, self.pos)
 *                             else:
 *                                 val = self.get_complex_value(name, self.pos)             # <<<<<<<<<<<<<<
 * 
 *                             sequence.append(val)
 */
              __pyx_t_6 = __pyx_f_4axon_7_loader_6Loader_get_complex_value(__pyx_v_self, __pyx_v_name, __pyx_v_self->pos); if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1417; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
              __Pyx_GOTREF(__pyx_t_6);
              __Pyx_XDECREF(__pyx_v_val);
              __pyx_v_val = __pyx_t_6;
              __pyx_t_6 = 0;
            }
            __pyx_L11:;

            /* "axon/_loader.py":1419
 *                                 val = self.get_complex_value(name, self.pos)
 * 
 *                             sequence.append(val)             # <<<<<<<<<<<<<<
 *                         return 1
 * 
 */
            if (unlikely(((PyObject *)__pyx_v_sequence) == Py_None)) {
              PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%s'", "append");
              {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1419; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
            }
            __pyx_t_8 = __Pyx_PyList_Append(__pyx_v_sequence, __pyx_v_val); if (unlikely(__pyx_t_8 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1419; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
            goto __pyx_L10;
          }
          __pyx_L10:;

          /* "axon/_loader.py":1420
 * 
 *                             sequence.append(val)
 *                         return 1             # <<<<<<<<<<<<<<
 * 
 *                     val = self.get_value(idn)
 */
          __pyx_r = 1;
          goto __pyx_L0;
          goto __pyx_L9;
        }
        __pyx_L9:;

        /* "axon/_loader.py":1422
 *                         return 1
 * 
 *                     val = self.get_value(idn)             # <<<<<<<<<<<<<<
 *                     mapping[name] = val
 *                 elif ch == '{':
 */
        __pyx_t_6 = __pyx_f_4axon_7_loader_6Loader_get_value(__pyx_v_self, __pyx_v_idn); if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1422; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_XDECREF(__pyx_v_val);
        __pyx_v_val = __pyx_t_6;
        __pyx_t_6 = 0;

        /* "axon/_loader.py":1423
 * 
 *                     val = self.get_value(idn)
 *                     mapping[name] = val             # <<<<<<<<<<<<<<
 *                 elif ch == '{':
 *                     self.bc += 1
 */
        if (unlikely(((PyObject *)__pyx_v_mapping) == Py_None)) {
          PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
          {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1423; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        }
        if (PyDict_SetItem(((PyObject *)__pyx_v_mapping), __pyx_v_name, __pyx_v_val) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1423; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        break;

        /* "axon/_loader.py":1424
 *                     val = self.get_value(idn)
 *                     mapping[name] = val
 *                 elif ch == '{':             # <<<<<<<<<<<<<<
 *                     self.bc += 1
 *                     skip_char(self)
 */
        case 123:

        /* "axon/_loader.py":1425
 *                     mapping[name] = val
 *                 elif ch == '{':
 *                     self.bc += 1             # <<<<<<<<<<<<<<
 *                     skip_char(self)
 * 
 */
        __pyx_v_self->bc = (__pyx_v_self->bc + 1);

        /* "axon/_loader.py":1426
 *                 elif ch == '{':
 *                     self.bc += 1
 *                     skip_char(self)             # <<<<<<<<<<<<<<
 * 
 *                     self.moveto_next_token()
 */
        skip_char(__pyx_v_self);

        /* "axon/_loader.py":1428
 *                     skip_char(self)
 * 
 *                     self.moveto_next_token()             # <<<<<<<<<<<<<<
 * 
 *                     if sequence is not None:
 */
        __pyx_t_7 = __pyx_f_4axon_7_loader_6Loader_moveto_next_token(__pyx_v_self); if (unlikely(__pyx_t_7 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1428; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

        /* "axon/_loader.py":1430
 *                     self.moveto_next_token()
 * 
 *                     if sequence is not None:             # <<<<<<<<<<<<<<
 *                         if is_multi:
 *                             val = self.get_collection(name, 0)
 */
        __pyx_t_1 = (__pyx_v_sequence != ((PyObject*)Py_None));
        __pyx_t_2 = (__pyx_t_1 != 0);
        if (__pyx_t_2) {

          /* "axon/_loader.py":1431
 * 
 *                     if sequence is not None:
 *                         if is_multi:             # <<<<<<<<<<<<<<
 *                             val = self.get_collection(name, 0)
 *                         else:
 */
          __pyx_t_2 = (__pyx_v_is_multi != 0);
          if (__pyx_t_2) {

            /* "axon/_loader.py":1432
 *                     if sequence is not None:
 *                         if is_multi:
 *                             val = self.get_collection(name, 0)             # <<<<<<<<<<<<<<
 *                         else:
 *                             val = self.get_complex_value(name, 0)
 */
            __pyx_t_6 = __pyx_f_4axon_7_loader_6Loader_get_collection(__pyx_v_self, __pyx_v_name, 0); if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1432; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
            __Pyx_GOTREF(__pyx_t_6);
            __Pyx_XDECREF(__pyx_v_val);
            __pyx_v_val = __pyx_t_6;
            __pyx_t_6 = 0;
            goto __pyx_L13;
          }
          /*else*/ {

            /* "axon/_loader.py":1434
 *                             val = self.get_collection(name, 0)
 *                         else:
 *                             val = self.get_complex_value(name, 0)             # <<<<<<<<<<<<<<
 *                         sequence.append(val)
 * 
 */
            __pyx_t_6 = __pyx_f_4axon_7_loader_6Loader_get_complex_value(__pyx_v_self, __pyx_v_name, 0); if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1434; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
            __Pyx_GOTREF(__pyx_t_6);
            __Pyx_XDECREF(__pyx_v_val);
            __pyx_v_val = __pyx_t_6;
            __pyx_t_6 = 0;
          }
          __pyx_L13:;

          /* "axon/_loader.py":1435
 *                         else:
 *                             val = self.get_complex_value(name, 0)
 *                         sequence.append(val)             # <<<<<<<<<<<<<<
 * 
 *                     return 1
 */
          if (unlikely(((PyObject *)__pyx_v_sequence) == Py_None)) {
            PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%s'", "append");
            {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1435; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
          }
          __pyx_t_8 = __Pyx_PyList_Append(__pyx_v_sequence, __pyx_v_val); if (unlikely(__pyx_t_8 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1435; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
          goto __pyx_L12;
        }
        __pyx_L12:;

        /* "axon/_loader.py":1437
 *                         sequence.append(val)
 * 
 *                     return 1             # <<<<<<<<<<<<<<
 *                 else:
 *                     if sequence is not None:
 */
        __pyx_r = 1;
        goto __pyx_L0;
        break;
        default:

        /* "axon/_loader.py":1439
 *                     return 1
 *                 else:
 *                     if sequence is not None:             # <<<<<<<<<<<<<<
 *                         val = self.get_constant_or_string(name)
 *                         sequence.append(val)
 */
        __pyx_t_2 = (__pyx_v_sequence != ((PyObject*)Py_None));
        __pyx_t_1 = (__pyx_t_2 != 0);
        if (__pyx_t_1) {

          /* "axon/_loader.py":1440
 *                 else:
 *                     if sequence is not None:
 *                         val = self.get_constant_or_string(name)             # <<<<<<<<<<<<<<
 *                         sequence.append(val)
 *                     return 1
 */
          if (!(likely(PyUnicode_CheckExact(__pyx_v_name))||((__pyx_v_name) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected unicode, got %.200s", Py_TYPE(__pyx_v_name)->tp_name), 0))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1440; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
          __pyx_t_6 = __pyx_f_4axon_7_loader_6Loader_get_constant_or_string(__pyx_v_self, ((PyObject*)__pyx_v_name)); if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1440; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
          __Pyx_GOTREF(__pyx_t_6);
          __Pyx_XDECREF(__pyx_v_val);
          __pyx_v_val = __pyx_t_6;
          __pyx_t_6 = 0;

          /* "axon/_loader.py":1441
 *                     if sequence is not None:
 *                         val = self.get_constant_or_string(name)
 *                         sequence.append(val)             # <<<<<<<<<<<<<<
 *                     return 1
 *             else:
 */
          if (unlikely(((PyObject *)__pyx_v_sequence) == Py_None)) {
            PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%s'", "append");
            {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1441; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
          }
          __pyx_t_8 = __Pyx_PyList_Append(__pyx_v_sequence, __pyx_v_val); if (unlikely(__pyx_t_8 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1441; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
          goto __pyx_L14;
        }
        __pyx_L14:;

        /* "axon/_loader.py":1442
 *                         val = self.get_constant_or_string(name)
 *                         sequence.append(val)
 *                     return 1             # <<<<<<<<<<<<<<
 *             else:
 *                 ch = current_char(self)
 */
        __pyx_r = 1;
        goto __pyx_L0;
        break;
      }
      goto __pyx_L7;
    }
    /*else*/ {

      /* "axon/_loader.py":1444
 *                     return 1
 *             else:
 *                 ch = current_char(self)             # <<<<<<<<<<<<<<
 *                 if ch == '}':
 *                     skip_char(self)
 */
      __pyx_v_ch = current_char(__pyx_v_self);

      /* "axon/_loader.py":1445
 *             else:
 *                 ch = current_char(self)
 *                 if ch == '}':             # <<<<<<<<<<<<<<
 *                     skip_char(self)
 *                     self.bc -= 1
 */
      __pyx_t_1 = ((__pyx_v_ch == 125) != 0);
      if (__pyx_t_1) {

        /* "axon/_loader.py":1446
 *                 ch = current_char(self)
 *                 if ch == '}':
 *                     skip_char(self)             # <<<<<<<<<<<<<<
 *                     self.bc -= 1
 *                     return 0
 */
        skip_char(__pyx_v_self);

        /* "axon/_loader.py":1447
 *                 if ch == '}':
 *                     skip_char(self)
 *                     self.bc -= 1             # <<<<<<<<<<<<<<
 *                     return 0
 *                 else:
 */
        __pyx_v_self->bc = (__pyx_v_self->bc - 1);

        /* "axon/_loader.py":1448
 *                     skip_char(self)
 *                     self.bc -= 1
 *                     return 0             # <<<<<<<<<<<<<<
 *                 else:
 *                     if sequence is not None:
 */
        __pyx_r = 0;
        goto __pyx_L0;
        goto __pyx_L15;
      }
      /*else*/ {

        /* "axon/_loader.py":1450
 *                     return 0
 *                 else:
 *                     if sequence is not None:             # <<<<<<<<<<<<<<
 *                         val = self.get_value(idn)
 *                         sequence.append(val)
 */
        __pyx_t_1 = (__pyx_v_sequence != ((PyObject*)Py_None));
        __pyx_t_2 = (__pyx_t_1 != 0);
        if (__pyx_t_2) {

          /* "axon/_loader.py":1451
 *                 else:
 *                     if sequence is not None:
 *                         val = self.get_value(idn)             # <<<<<<<<<<<<<<
 *                         sequence.append(val)
 *                     return 1
 */
          __pyx_t_6 = __pyx_f_4axon_7_loader_6Loader_get_value(__pyx_v_self, __pyx_v_idn); if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1451; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
          __Pyx_GOTREF(__pyx_t_6);
          __Pyx_XDECREF(__pyx_v_val);
          __pyx_v_val = __pyx_t_6;
          __pyx_t_6 = 0;

          /* "axon/_loader.py":1452
 *                     if sequence is not None:
 *                         val = self.get_value(idn)
 *                         sequence.append(val)             # <<<<<<<<<<<<<<
 *                     return 1
 *     #
 */
          if (unlikely(((PyObject *)__pyx_v_sequence) == Py_None)) {
            PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%s'", "append");
            {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1452; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
          }
          __pyx_t_8 = __Pyx_PyList_Append(__pyx_v_sequence, __pyx_v_val); if (unlikely(__pyx_t_8 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1452; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
          goto __pyx_L16;
        }
        __pyx_L16:;

        /* "axon/_loader.py":1453
 *                         val = self.get_value(idn)
 *                         sequence.append(val)
 *                     return 1             # <<<<<<<<<<<<<<
 *     #
 *     def get_sequence_part(self, sequence, mapping, idn):
 */
        __pyx_r = 1;
        goto __pyx_L0;
      }
      __pyx_L15:;
    }
    __pyx_L7:;
  }

  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("axon._loader.Loader.get_mapping_part", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_name);
  __Pyx_XDECREF(__pyx_v_val);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_loader.py":1455
 *                     return 1
 *     #
 *     def get_sequence_part(self, sequence, mapping, idn):             # <<<<<<<<<<<<<<
 * 
 *         while 1:
 */

static int __pyx_f_4axon_7_loader_6Loader_get_sequence_part(struct __pyx_obj_4axon_7_loader_Loader *__pyx_v_self, PyObject *__pyx_v_sequence, PyObject *__pyx_v_mapping, int __pyx_v_idn) {
  Py_UCS4 __pyx_v_ch;
  int __pyx_v_is_multi;
  PyObject *__pyx_v_name = NULL;
  PyObject *__pyx_v_val = NULL;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  Py_UCS4 __pyx_t_7;
  int __pyx_t_8;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_sequence_part", 0);

  /* "axon/_loader.py":1457
 *     def get_sequence_part(self, sequence, mapping, idn):
 * 
 *         while 1:             # <<<<<<<<<<<<<<
 *             ch = self.skip_spaces()
 * 
 */
  while (1) {
    if (!1) break;

    /* "axon/_loader.py":1458
 * 
 *         while 1:
 *             ch = self.skip_spaces()             # <<<<<<<<<<<<<<
 * 
 *             if idn:
 */
    __pyx_v_ch = __pyx_f_4axon_7_loader_6Loader_skip_spaces(__pyx_v_self);

    /* "axon/_loader.py":1460
 *             ch = self.skip_spaces()
 * 
 *             if idn:             # <<<<<<<<<<<<<<
 *                 if self.pos == idn:
 *                     pass
 */
    __pyx_t_1 = (__pyx_v_idn != 0);
    if (__pyx_t_1) {

      /* "axon/_loader.py":1461
 * 
 *             if idn:
 *                 if self.pos == idn:             # <<<<<<<<<<<<<<
 *                     pass
 *                 elif self.pos < idn or self.eof or ch == '}' or ch == ']':
 */
      __pyx_t_1 = ((__pyx_v_self->pos == __pyx_v_idn) != 0);
      if (__pyx_t_1) {
        goto __pyx_L6;
      }

      /* "axon/_loader.py":1463
 *                 if self.pos == idn:
 *                     pass
 *                 elif self.pos < idn or self.eof or ch == '}' or ch == ']':             # <<<<<<<<<<<<<<
 *                     return 0
 *                 elif self.pos > idn and self.is_nl:
 */
      __pyx_t_1 = ((__pyx_v_self->pos < __pyx_v_idn) != 0);
      if (!__pyx_t_1) {
        if (!(__pyx_v_self->eof != 0)) {
          switch (__pyx_v_ch) {
            case 125:
            case 93:
            __pyx_t_2 = 1;
            break;
            default:
            __pyx_t_2 = 0;
            break;
          }
          __pyx_t_3 = __pyx_t_2;
        } else {
          __pyx_t_3 = (__pyx_v_self->eof != 0);
        }
        __pyx_t_2 = __pyx_t_3;
      } else {
        __pyx_t_2 = __pyx_t_1;
      }
      if (__pyx_t_2) {

        /* "axon/_loader.py":1464
 *                     pass
 *                 elif self.pos < idn or self.eof or ch == '}' or ch == ']':
 *                     return 0             # <<<<<<<<<<<<<<
 *                 elif self.pos > idn and self.is_nl:
 *                     errors.error_indentation(self, idn)
 */
        __pyx_r = 0;
        goto __pyx_L0;
        goto __pyx_L6;
      }

      /* "axon/_loader.py":1465
 *                 elif self.pos < idn or self.eof or ch == '}' or ch == ']':
 *                     return 0
 *                 elif self.pos > idn and self.is_nl:             # <<<<<<<<<<<<<<
 *                     errors.error_indentation(self, idn)
 *             elif self.eof:
 */
      __pyx_t_2 = ((__pyx_v_self->pos > __pyx_v_idn) != 0);
      if (__pyx_t_2) {
        __pyx_t_1 = (__pyx_v_self->is_nl != 0);
      } else {
        __pyx_t_1 = __pyx_t_2;
      }
      if (__pyx_t_1) {

        /* "axon/_loader.py":1466
 *                     return 0
 *                 elif self.pos > idn and self.is_nl:
 *                     errors.error_indentation(self, idn)             # <<<<<<<<<<<<<<
 *             elif self.eof:
 *                 errors.error_unexpected_end(self)
 */
        __pyx_t_4 = __Pyx_GetModuleGlobalName(__pyx_n_s__errors); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1466; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_4);
        __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s__error_indentation); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1466; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __pyx_t_4 = PyInt_FromLong(__pyx_v_idn); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1466; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_4);
        __pyx_t_6 = PyTuple_New(2); if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1466; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_INCREF(((PyObject *)__pyx_v_self));
        PyTuple_SET_ITEM(__pyx_t_6, 0, ((PyObject *)__pyx_v_self));
        __Pyx_GIVEREF(((PyObject *)__pyx_v_self));
        PyTuple_SET_ITEM(__pyx_t_6, 1, __pyx_t_4);
        __Pyx_GIVEREF(__pyx_t_4);
        __pyx_t_4 = 0;
        __pyx_t_4 = PyObject_Call(__pyx_t_5, ((PyObject *)__pyx_t_6), NULL); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1466; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_DECREF(((PyObject *)__pyx_t_6)); __pyx_t_6 = 0;
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        goto __pyx_L6;
      }
      __pyx_L6:;
      goto __pyx_L5;
    }

    /* "axon/_loader.py":1467
 *                 elif self.pos > idn and self.is_nl:
 *                     errors.error_indentation(self, idn)
 *             elif self.eof:             # <<<<<<<<<<<<<<
 *                 errors.error_unexpected_end(self)
 * 
 */
    __pyx_t_1 = (__pyx_v_self->eof != 0);
    if (__pyx_t_1) {

      /* "axon/_loader.py":1468
 *                     errors.error_indentation(self, idn)
 *             elif self.eof:
 *                 errors.error_unexpected_end(self)             # <<<<<<<<<<<<<<
 * 
 *             name = self.try_get_name()
 */
      __pyx_t_4 = __Pyx_GetModuleGlobalName(__pyx_n_s__errors); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1468; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_23); if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1468; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_4 = PyTuple_New(1); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1468; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_INCREF(((PyObject *)__pyx_v_self));
      PyTuple_SET_ITEM(__pyx_t_4, 0, ((PyObject *)__pyx_v_self));
      __Pyx_GIVEREF(((PyObject *)__pyx_v_self));
      __pyx_t_5 = PyObject_Call(__pyx_t_6, ((PyObject *)__pyx_t_4), NULL); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1468; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_DECREF(((PyObject *)__pyx_t_4)); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      goto __pyx_L5;
    }
    __pyx_L5:;

    /* "axon/_loader.py":1470
 *                 errors.error_unexpected_end(self)
 * 
 *             name = self.try_get_name()             # <<<<<<<<<<<<<<
 * 
 *             if name is not None:
 */
    __pyx_t_5 = __pyx_f_4axon_7_loader_6Loader_try_get_name(__pyx_v_self); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1470; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_XDECREF(__pyx_v_name);
    __pyx_v_name = __pyx_t_5;
    __pyx_t_5 = 0;

    /* "axon/_loader.py":1472
 *             name = self.try_get_name()
 * 
 *             if name is not None:             # <<<<<<<<<<<<<<
 * 
 *                 ch = current_char(self)
 */
    __pyx_t_1 = (__pyx_v_name != Py_None);
    __pyx_t_2 = (__pyx_t_1 != 0);
    if (__pyx_t_2) {

      /* "axon/_loader.py":1474
 *             if name is not None:
 * 
 *                 ch = current_char(self)             # <<<<<<<<<<<<<<
 *                 if ch == '*':
 *                     skip_char(self)
 */
      __pyx_v_ch = current_char(__pyx_v_self);

      /* "axon/_loader.py":1475
 * 
 *                 ch = current_char(self)
 *                 if ch == '*':             # <<<<<<<<<<<<<<
 *                     skip_char(self)
 *                     is_multi = 1
 */
      __pyx_t_2 = ((__pyx_v_ch == 42) != 0);
      if (__pyx_t_2) {

        /* "axon/_loader.py":1476
 *                 ch = current_char(self)
 *                 if ch == '*':
 *                     skip_char(self)             # <<<<<<<<<<<<<<
 *                     is_multi = 1
 *                 else:
 */
        skip_char(__pyx_v_self);

        /* "axon/_loader.py":1477
 *                 if ch == '*':
 *                     skip_char(self)
 *                     is_multi = 1             # <<<<<<<<<<<<<<
 *                 else:
 *                     is_multi = 0
 */
        __pyx_v_is_multi = 1;
        goto __pyx_L8;
      }
      /*else*/ {

        /* "axon/_loader.py":1479
 *                     is_multi = 1
 *                 else:
 *                     is_multi = 0             # <<<<<<<<<<<<<<
 * 
 *                 ch = self.skip_spaces()
 */
        __pyx_v_is_multi = 0;
      }
      __pyx_L8:;

      /* "axon/_loader.py":1481
 *                     is_multi = 0
 * 
 *                 ch = self.skip_spaces()             # <<<<<<<<<<<<<<
 * 
 *                 if ch == ':':
 */
      __pyx_v_ch = __pyx_f_4axon_7_loader_6Loader_skip_spaces(__pyx_v_self);

      /* "axon/_loader.py":1501
 *                         mapping[name] = val
 *                     return 1
 *                 elif ch == '{':             # <<<<<<<<<<<<<<
 *                     skip_char(self)
 *                     self.bc += 1
 */
      switch (__pyx_v_ch) {

        /* "axon/_loader.py":1483
 *                 ch = self.skip_spaces()
 * 
 *                 if ch == ':':             # <<<<<<<<<<<<<<
 *                     skip_char(self)
 * 
 */
        case 58:

        /* "axon/_loader.py":1484
 * 
 *                 if ch == ':':
 *                     skip_char(self)             # <<<<<<<<<<<<<<
 * 
 *                     self.moveto_next_token()
 */
        skip_char(__pyx_v_self);

        /* "axon/_loader.py":1486
 *                     skip_char(self)
 * 
 *                     self.moveto_next_token()             # <<<<<<<<<<<<<<
 * 
 *                     if self.is_nl and self.pos > idn:
 */
        __pyx_t_7 = __pyx_f_4axon_7_loader_6Loader_moveto_next_token(__pyx_v_self); if (unlikely(__pyx_t_7 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1486; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

        /* "axon/_loader.py":1488
 *                     self.moveto_next_token()
 * 
 *                     if self.is_nl and self.pos > idn:             # <<<<<<<<<<<<<<
 *                         if is_multi:
 *                             val =  self.get_collection(name, self.pos)
 */
        if ((__pyx_v_self->is_nl != 0)) {
          __pyx_t_2 = ((__pyx_v_self->pos > __pyx_v_idn) != 0);
          __pyx_t_1 = __pyx_t_2;
        } else {
          __pyx_t_1 = (__pyx_v_self->is_nl != 0);
        }
        if (__pyx_t_1) {

          /* "axon/_loader.py":1489
 * 
 *                     if self.is_nl and self.pos > idn:
 *                         if is_multi:             # <<<<<<<<<<<<<<
 *                             val =  self.get_collection(name, self.pos)
 *                         else:
 */
          __pyx_t_1 = (__pyx_v_is_multi != 0);
          if (__pyx_t_1) {

            /* "axon/_loader.py":1490
 *                     if self.is_nl and self.pos > idn:
 *                         if is_multi:
 *                             val =  self.get_collection(name, self.pos)             # <<<<<<<<<<<<<<
 *                         else:
 *                             val = self.get_complex_value(name, self.pos)
 */
            __pyx_t_5 = __pyx_f_4axon_7_loader_6Loader_get_collection(__pyx_v_self, __pyx_v_name, __pyx_v_self->pos); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1490; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
            __Pyx_GOTREF(__pyx_t_5);
            __Pyx_XDECREF(__pyx_v_val);
            __pyx_v_val = __pyx_t_5;
            __pyx_t_5 = 0;
            goto __pyx_L10;
          }
          /*else*/ {

            /* "axon/_loader.py":1492
 *                             val =  self.get_collection(name, self.pos)
 *                         else:
 *                             val = self.get_complex_value(name, self.pos)             # <<<<<<<<<<<<<<
 * 
 *                         sequence.append(val)
 */
            __pyx_t_5 = __pyx_f_4axon_7_loader_6Loader_get_complex_value(__pyx_v_self, __pyx_v_name, __pyx_v_self->pos); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1492; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
            __Pyx_GOTREF(__pyx_t_5);
            __Pyx_XDECREF(__pyx_v_val);
            __pyx_v_val = __pyx_t_5;
            __pyx_t_5 = 0;
          }
          __pyx_L10:;

          /* "axon/_loader.py":1494
 *                             val = self.get_complex_value(name, self.pos)
 * 
 *                         sequence.append(val)             # <<<<<<<<<<<<<<
 *                         continue
 * 
 */
          if (unlikely(((PyObject *)__pyx_v_sequence) == Py_None)) {
            PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%s'", "append");
            {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1494; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
          }
          __pyx_t_8 = __Pyx_PyList_Append(__pyx_v_sequence, __pyx_v_val); if (unlikely(__pyx_t_8 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1494; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

          /* "axon/_loader.py":1495
 * 
 *                         sequence.append(val)
 *                         continue             # <<<<<<<<<<<<<<
 * 
 *                     if mapping is not None:
 */
          goto __pyx_L3_continue;
          goto __pyx_L9;
        }
        __pyx_L9:;

        /* "axon/_loader.py":1497
 *                         continue
 * 
 *                     if mapping is not None:             # <<<<<<<<<<<<<<
 *                         val = self.get_value(idn)
 *                         mapping[name] = val
 */
        __pyx_t_1 = (__pyx_v_mapping != ((PyObject*)Py_None));
        __pyx_t_2 = (__pyx_t_1 != 0);
        if (__pyx_t_2) {

          /* "axon/_loader.py":1498
 * 
 *                     if mapping is not None:
 *                         val = self.get_value(idn)             # <<<<<<<<<<<<<<
 *                         mapping[name] = val
 *                     return 1
 */
          __pyx_t_5 = __pyx_f_4axon_7_loader_6Loader_get_value(__pyx_v_self, __pyx_v_idn); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1498; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
          __Pyx_GOTREF(__pyx_t_5);
          __Pyx_XDECREF(__pyx_v_val);
          __pyx_v_val = __pyx_t_5;
          __pyx_t_5 = 0;

          /* "axon/_loader.py":1499
 *                     if mapping is not None:
 *                         val = self.get_value(idn)
 *                         mapping[name] = val             # <<<<<<<<<<<<<<
 *                     return 1
 *                 elif ch == '{':
 */
          if (unlikely(((PyObject *)__pyx_v_mapping) == Py_None)) {
            PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
            {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1499; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
          }
          if (PyDict_SetItem(((PyObject *)__pyx_v_mapping), __pyx_v_name, __pyx_v_val) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1499; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
          goto __pyx_L11;
        }
        __pyx_L11:;

        /* "axon/_loader.py":1500
 *                         val = self.get_value(idn)
 *                         mapping[name] = val
 *                     return 1             # <<<<<<<<<<<<<<
 *                 elif ch == '{':
 *                     skip_char(self)
 */
        __pyx_r = 1;
        goto __pyx_L0;
        break;

        /* "axon/_loader.py":1501
 *                         mapping[name] = val
 *                     return 1
 *                 elif ch == '{':             # <<<<<<<<<<<<<<
 *                     skip_char(self)
 *                     self.bc += 1
 */
        case 123:

        /* "axon/_loader.py":1502
 *                     return 1
 *                 elif ch == '{':
 *                     skip_char(self)             # <<<<<<<<<<<<<<
 *                     self.bc += 1
 * 
 */
        skip_char(__pyx_v_self);

        /* "axon/_loader.py":1503
 *                 elif ch == '{':
 *                     skip_char(self)
 *                     self.bc += 1             # <<<<<<<<<<<<<<
 * 
 *                     self.moveto_next_token()
 */
        __pyx_v_self->bc = (__pyx_v_self->bc + 1);

        /* "axon/_loader.py":1505
 *                     self.bc += 1
 * 
 *                     self.moveto_next_token()             # <<<<<<<<<<<<<<
 * 
 *                     if is_multi:
 */
        __pyx_t_7 = __pyx_f_4axon_7_loader_6Loader_moveto_next_token(__pyx_v_self); if (unlikely(__pyx_t_7 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1505; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

        /* "axon/_loader.py":1507
 *                     self.moveto_next_token()
 * 
 *                     if is_multi:             # <<<<<<<<<<<<<<
 *                         val = self.get_collection(name, 0)
 *                     else:
 */
        __pyx_t_2 = (__pyx_v_is_multi != 0);
        if (__pyx_t_2) {

          /* "axon/_loader.py":1508
 * 
 *                     if is_multi:
 *                         val = self.get_collection(name, 0)             # <<<<<<<<<<<<<<
 *                     else:
 *                         val = self.get_complex_value(name, 0)
 */
          __pyx_t_5 = __pyx_f_4axon_7_loader_6Loader_get_collection(__pyx_v_self, __pyx_v_name, 0); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1508; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
          __Pyx_GOTREF(__pyx_t_5);
          __Pyx_XDECREF(__pyx_v_val);
          __pyx_v_val = __pyx_t_5;
          __pyx_t_5 = 0;
          goto __pyx_L12;
        }
        /*else*/ {

          /* "axon/_loader.py":1510
 *                         val = self.get_collection(name, 0)
 *                     else:
 *                         val = self.get_complex_value(name, 0)             # <<<<<<<<<<<<<<
 * 
 *                     sequence.append(val)
 */
          __pyx_t_5 = __pyx_f_4axon_7_loader_6Loader_get_complex_value(__pyx_v_self, __pyx_v_name, 0); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1510; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
          __Pyx_GOTREF(__pyx_t_5);
          __Pyx_XDECREF(__pyx_v_val);
          __pyx_v_val = __pyx_t_5;
          __pyx_t_5 = 0;
        }
        __pyx_L12:;

        /* "axon/_loader.py":1512
 *                         val = self.get_complex_value(name, 0)
 * 
 *                     sequence.append(val)             # <<<<<<<<<<<<<<
 *                 else:
 *                     val = self.get_constant_or_string(name)
 */
        if (unlikely(((PyObject *)__pyx_v_sequence) == Py_None)) {
          PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%s'", "append");
          {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1512; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        }
        __pyx_t_8 = __Pyx_PyList_Append(__pyx_v_sequence, __pyx_v_val); if (unlikely(__pyx_t_8 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1512; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        break;
        default:

        /* "axon/_loader.py":1514
 *                     sequence.append(val)
 *                 else:
 *                     val = self.get_constant_or_string(name)             # <<<<<<<<<<<<<<
 *                     sequence.append(val)
 *             else:
 */
        if (!(likely(PyUnicode_CheckExact(__pyx_v_name))||((__pyx_v_name) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected unicode, got %.200s", Py_TYPE(__pyx_v_name)->tp_name), 0))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1514; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __pyx_t_5 = __pyx_f_4axon_7_loader_6Loader_get_constant_or_string(__pyx_v_self, ((PyObject*)__pyx_v_name)); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1514; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_XDECREF(__pyx_v_val);
        __pyx_v_val = __pyx_t_5;
        __pyx_t_5 = 0;

        /* "axon/_loader.py":1515
 *                 else:
 *                     val = self.get_constant_or_string(name)
 *                     sequence.append(val)             # <<<<<<<<<<<<<<
 *             else:
 *                 ch = current_char(self)
 */
        if (unlikely(((PyObject *)__pyx_v_sequence) == Py_None)) {
          PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%s'", "append");
          {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1515; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        }
        __pyx_t_8 = __Pyx_PyList_Append(__pyx_v_sequence, __pyx_v_val); if (unlikely(__pyx_t_8 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1515; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        break;
      }
      goto __pyx_L7;
    }
    /*else*/ {

      /* "axon/_loader.py":1517
 *                     sequence.append(val)
 *             else:
 *                 ch = current_char(self)             # <<<<<<<<<<<<<<
 *                 if ch == '}':
 *                     skip_char(self)
 */
      __pyx_v_ch = current_char(__pyx_v_self);

      /* "axon/_loader.py":1518
 *             else:
 *                 ch = current_char(self)
 *                 if ch == '}':             # <<<<<<<<<<<<<<
 *                     skip_char(self)
 *                     self.bc -= 1
 */
      __pyx_t_2 = ((__pyx_v_ch == 125) != 0);
      if (__pyx_t_2) {

        /* "axon/_loader.py":1519
 *                 ch = current_char(self)
 *                 if ch == '}':
 *                     skip_char(self)             # <<<<<<<<<<<<<<
 *                     self.bc -= 1
 *                     return 0
 */
        skip_char(__pyx_v_self);

        /* "axon/_loader.py":1520
 *                 if ch == '}':
 *                     skip_char(self)
 *                     self.bc -= 1             # <<<<<<<<<<<<<<
 *                     return 0
 *                 else:
 */
        __pyx_v_self->bc = (__pyx_v_self->bc - 1);

        /* "axon/_loader.py":1521
 *                     skip_char(self)
 *                     self.bc -= 1
 *                     return 0             # <<<<<<<<<<<<<<
 *                 else:
 *                     val = self.get_value(idn)
 */
        __pyx_r = 0;
        goto __pyx_L0;
        goto __pyx_L13;
      }
      /*else*/ {

        /* "axon/_loader.py":1523
 *                     return 0
 *                 else:
 *                     val = self.get_value(idn)             # <<<<<<<<<<<<<<
 *                     sequence.append(val)
 * 
 */
        __pyx_t_5 = __pyx_f_4axon_7_loader_6Loader_get_value(__pyx_v_self, __pyx_v_idn); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1523; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_XDECREF(__pyx_v_val);
        __pyx_v_val = __pyx_t_5;
        __pyx_t_5 = 0;

        /* "axon/_loader.py":1524
 *                 else:
 *                     val = self.get_value(idn)
 *                     sequence.append(val)             # <<<<<<<<<<<<<<
 * 
 */
        if (unlikely(((PyObject *)__pyx_v_sequence) == Py_None)) {
          PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%s'", "append");
          {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1524; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        }
        __pyx_t_8 = __Pyx_PyList_Append(__pyx_v_sequence, __pyx_v_val); if (unlikely(__pyx_t_8 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1524; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      }
      __pyx_L13:;
    }
    __pyx_L7:;
    __pyx_L3_continue:;
  }

  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("axon._loader.Loader.get_sequence_part", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_name);
  __Pyx_XDECREF(__pyx_v_val);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_4axon_7_loader_6Loader_4line_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_4axon_7_loader_6Loader_4line_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_4axon_7_loader_6Loader_4line___get__(((struct __pyx_obj_4axon_7_loader_Loader *)__pyx_v_self));
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_loader.pxd":187
 *     cdef object encoding
 * 
 *     cdef public unicode line             # <<<<<<<<<<<<<<
 *     cdef bint eof
 *     cdef public int pos
 */

static PyObject *__pyx_pf_4axon_7_loader_6Loader_4line___get__(struct __pyx_obj_4axon_7_loader_Loader *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(((PyObject *)__pyx_v_self->line));
  __pyx_r = ((PyObject *)__pyx_v_self->line);
  goto __pyx_L0;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_4axon_7_loader_6Loader_4line_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_4axon_7_loader_6Loader_4line_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_r = __pyx_pf_4axon_7_loader_6Loader_4line_2__set__(((struct __pyx_obj_4axon_7_loader_Loader *)__pyx_v_self), ((PyObject *)__pyx_v_value));
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_4axon_7_loader_6Loader_4line_2__set__(struct __pyx_obj_4axon_7_loader_Loader *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__set__", 0);
  if (!(likely(PyUnicode_CheckExact(__pyx_v_value))||((__pyx_v_value) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected unicode, got %.200s", Py_TYPE(__pyx_v_value)->tp_name), 0))) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 187; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_INCREF(__pyx_v_value);
  __Pyx_GIVEREF(__pyx_v_value);
  __Pyx_GOTREF(__pyx_v_self->line);
  __Pyx_DECREF(((PyObject *)__pyx_v_self->line));
  __pyx_v_self->line = ((PyObject*)__pyx_v_value);

  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("axon._loader.Loader.line.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_4axon_7_loader_6Loader_4line_5__del__(PyObject *__pyx_v_self); /*proto*/
static int __pyx_pw_4axon_7_loader_6Loader_4line_5__del__(PyObject *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__ (wrapper)", 0);
  __pyx_r = __pyx_pf_4axon_7_loader_6Loader_4line_4__del__(((struct __pyx_obj_4axon_7_loader_Loader *)__pyx_v_self));
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_4axon_7_loader_6Loader_4line_4__del__(struct __pyx_obj_4axon_7_loader_Loader *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__", 0);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->line);
  __Pyx_DECREF(((PyObject *)__pyx_v_self->line));
  __pyx_v_self->line = ((PyObject*)Py_None);

  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_4axon_7_loader_6Loader_3pos_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_4axon_7_loader_6Loader_3pos_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_4axon_7_loader_6Loader_3pos___get__(((struct __pyx_obj_4axon_7_loader_Loader *)__pyx_v_self));
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_loader.pxd":189
 *     cdef public unicode line
 *     cdef bint eof
 *     cdef public int pos             # <<<<<<<<<<<<<<
 *     cdef public int lnum
 *     cdef public object errto
 */

static PyObject *__pyx_pf_4axon_7_loader_6Loader_3pos___get__(struct __pyx_obj_4axon_7_loader_Loader *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyInt_FromLong(__pyx_v_self->pos); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 189; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("axon._loader.Loader.pos.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_4axon_7_loader_6Loader_3pos_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_4axon_7_loader_6Loader_3pos_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_r = __pyx_pf_4axon_7_loader_6Loader_3pos_2__set__(((struct __pyx_obj_4axon_7_loader_Loader *)__pyx_v_self), ((PyObject *)__pyx_v_value));
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_4axon_7_loader_6Loader_3pos_2__set__(struct __pyx_obj_4axon_7_loader_Loader *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__set__", 0);
  __pyx_t_1 = __Pyx_PyInt_AsInt(__pyx_v_value); if (unlikely((__pyx_t_1 == (int)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 189; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_v_self->pos = __pyx_t_1;

  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("axon._loader.Loader.pos.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_4axon_7_loader_6Loader_4lnum_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_4axon_7_loader_6Loader_4lnum_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_4axon_7_loader_6Loader_4lnum___get__(((struct __pyx_obj_4axon_7_loader_Loader *)__pyx_v_self));
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_loader.pxd":190
 *     cdef bint eof
 *     cdef public int pos
 *     cdef public int lnum             # <<<<<<<<<<<<<<
 *     cdef public object errto
 * 
 */

static PyObject *__pyx_pf_4axon_7_loader_6Loader_4lnum___get__(struct __pyx_obj_4axon_7_loader_Loader *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyInt_FromLong(__pyx_v_self->lnum); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 190; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("axon._loader.Loader.lnum.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_4axon_7_loader_6Loader_4lnum_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_4axon_7_loader_6Loader_4lnum_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_r = __pyx_pf_4axon_7_loader_6Loader_4lnum_2__set__(((struct __pyx_obj_4axon_7_loader_Loader *)__pyx_v_self), ((PyObject *)__pyx_v_value));
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_4axon_7_loader_6Loader_4lnum_2__set__(struct __pyx_obj_4axon_7_loader_Loader *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__set__", 0);
  __pyx_t_1 = __Pyx_PyInt_AsInt(__pyx_v_value); if (unlikely((__pyx_t_1 == (int)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 190; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_v_self->lnum = __pyx_t_1;

  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("axon._loader.Loader.lnum.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_4axon_7_loader_6Loader_5errto_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_4axon_7_loader_6Loader_5errto_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_4axon_7_loader_6Loader_5errto___get__(((struct __pyx_obj_4axon_7_loader_Loader *)__pyx_v_self));
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_loader.pxd":191
 *     cdef public int pos
 *     cdef public int lnum
 *     cdef public object errto             # <<<<<<<<<<<<<<
 * 
 *     cdef int bc
 */

static PyObject *__pyx_pf_4axon_7_loader_6Loader_5errto___get__(struct __pyx_obj_4axon_7_loader_Loader *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->errto);
  __pyx_r = __pyx_v_self->errto;
  goto __pyx_L0;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_4axon_7_loader_6Loader_5errto_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_4axon_7_loader_6Loader_5errto_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_r = __pyx_pf_4axon_7_loader_6Loader_5errto_2__set__(((struct __pyx_obj_4axon_7_loader_Loader *)__pyx_v_self), ((PyObject *)__pyx_v_value));
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_4axon_7_loader_6Loader_5errto_2__set__(struct __pyx_obj_4axon_7_loader_Loader *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__", 0);
  __Pyx_INCREF(__pyx_v_value);
  __Pyx_GIVEREF(__pyx_v_value);
  __Pyx_GOTREF(__pyx_v_self->errto);
  __Pyx_DECREF(__pyx_v_self->errto);
  __pyx_v_self->errto = __pyx_v_value;

  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_4axon_7_loader_6Loader_5errto_5__del__(PyObject *__pyx_v_self); /*proto*/
static int __pyx_pw_4axon_7_loader_6Loader_5errto_5__del__(PyObject *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__ (wrapper)", 0);
  __pyx_r = __pyx_pf_4axon_7_loader_6Loader_5errto_4__del__(((struct __pyx_obj_4axon_7_loader_Loader *)__pyx_v_self));
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_4axon_7_loader_6Loader_5errto_4__del__(struct __pyx_obj_4axon_7_loader_Loader *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__", 0);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->errto);
  __Pyx_DECREF(__pyx_v_self->errto);
  __pyx_v_self->errto = Py_None;

  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_4axon_7_loader_6Loader_3idn_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_4axon_7_loader_6Loader_3idn_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_4axon_7_loader_6Loader_3idn___get__(((struct __pyx_obj_4axon_7_loader_Loader *)__pyx_v_self));
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_loader.pxd":211
 *     cdef bint is_nl
 *     cdef list idn_stack
 *     cdef public int idn             # <<<<<<<<<<<<<<
 * 
 *     cpdef _check_pairs(Loader self)
 */

static PyObject *__pyx_pf_4axon_7_loader_6Loader_3idn___get__(struct __pyx_obj_4axon_7_loader_Loader *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyInt_FromLong(__pyx_v_self->idn); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 211; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("axon._loader.Loader.idn.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_4axon_7_loader_6Loader_3idn_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_4axon_7_loader_6Loader_3idn_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_r = __pyx_pf_4axon_7_loader_6Loader_3idn_2__set__(((struct __pyx_obj_4axon_7_loader_Loader *)__pyx_v_self), ((PyObject *)__pyx_v_value));
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_4axon_7_loader_6Loader_3idn_2__set__(struct __pyx_obj_4axon_7_loader_Loader *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__set__", 0);
  __pyx_t_1 = __Pyx_PyInt_AsInt(__pyx_v_value); if (unlikely((__pyx_t_1 == (int)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 211; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_v_self->idn = __pyx_t_1;

  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("axon._loader.Loader.idn.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static CYTHON_UNUSED int __pyx_pw_7cpython_5array_5array_1__getbuffer__(PyObject *__pyx_v_self, Py_buffer *__pyx_v_info, int __pyx_v_flags); /*proto*/
static CYTHON_UNUSED int __pyx_pw_7cpython_5array_5array_1__getbuffer__(PyObject *__pyx_v_self, Py_buffer *__pyx_v_info, int __pyx_v_flags) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__getbuffer__ (wrapper)", 0);
  __pyx_r = __pyx_pf_7cpython_5array_5array___getbuffer__(((arrayobject *)__pyx_v_self), ((Py_buffer *)__pyx_v_info), ((int)__pyx_v_flags));
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cpython/array.pxd":91
 *             __data_union data
 * 
 *         def __getbuffer__(array self, Py_buffer* info, int flags):             # <<<<<<<<<<<<<<
 *             # This implementation of getbuffer is geared towards Cython
 *             # requirements, and does not yet fullfill the PEP.
 */

static int __pyx_pf_7cpython_5array_5array___getbuffer__(arrayobject *__pyx_v_self, Py_buffer *__pyx_v_info, CYTHON_UNUSED int __pyx_v_flags) {
  CYTHON_UNUSED unsigned int __pyx_v_itemsize;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  char *__pyx_t_1;
  Py_ssize_t __pyx_t_2;
  int __pyx_t_3;
  __Pyx_RefNannySetupContext("__getbuffer__", 0);
  if (__pyx_v_info != NULL) {
    __pyx_v_info->obj = Py_None; __Pyx_INCREF(Py_None);
    __Pyx_GIVEREF(__pyx_v_info->obj);
  }

  /* "cpython/array.pxd":98
 *             cdef unsigned rows, columns, itemsize
 * 
 *             info.suboffsets = NULL             # <<<<<<<<<<<<<<
 *             info.buf = self.data.as_chars
 *             info.readonly = 0
 */
  __pyx_v_info->suboffsets = NULL;

  /* "cpython/array.pxd":99
 * 
 *             info.suboffsets = NULL
 *             info.buf = self.data.as_chars             # <<<<<<<<<<<<<<
 *             info.readonly = 0
 *             info.ndim = 1
 */
  __pyx_t_1 = __pyx_v_self->data.as_chars;
  __pyx_v_info->buf = __pyx_t_1;

  /* "cpython/array.pxd":100
 *             info.suboffsets = NULL
 *             info.buf = self.data.as_chars
 *             info.readonly = 0             # <<<<<<<<<<<<<<
 *             info.ndim = 1
 *             info.itemsize = itemsize = self.ob_descr.itemsize   # e.g. sizeof(float)
 */
  __pyx_v_info->readonly = 0;

  /* "cpython/array.pxd":101
 *             info.buf = self.data.as_chars
 *             info.readonly = 0
 *             info.ndim = 1             # <<<<<<<<<<<<<<
 *             info.itemsize = itemsize = self.ob_descr.itemsize   # e.g. sizeof(float)
 * 
 */
  __pyx_v_info->ndim = 1;

  /* "cpython/array.pxd":102
 *             info.readonly = 0
 *             info.ndim = 1
 *             info.itemsize = itemsize = self.ob_descr.itemsize   # e.g. sizeof(float)             # <<<<<<<<<<<<<<
 * 
 *             info.strides = <Py_ssize_t*> \
 */
  __pyx_v_info->itemsize = __pyx_v_self->ob_descr->itemsize;
  __pyx_v_itemsize = __pyx_v_self->ob_descr->itemsize;

  /* "cpython/array.pxd":104
 *             info.itemsize = itemsize = self.ob_descr.itemsize   # e.g. sizeof(float)
 * 
 *             info.strides = <Py_ssize_t*> \             # <<<<<<<<<<<<<<
 *                            stdlib.malloc(sizeof(Py_ssize_t) * info.ndim * 2 + 2)
 *             info.shape = info.strides + 1
 */
  __pyx_v_info->strides = ((Py_ssize_t *)malloc(((((sizeof(Py_ssize_t)) * __pyx_v_info->ndim) * 2) + 2)));

  /* "cpython/array.pxd":106
 *             info.strides = <Py_ssize_t*> \
 *                            stdlib.malloc(sizeof(Py_ssize_t) * info.ndim * 2 + 2)
 *             info.shape = info.strides + 1             # <<<<<<<<<<<<<<
 *             info.shape[0] = Py_SIZE(self)            # number of items
 *             info.strides[0] = info.itemsize
 */
  __pyx_v_info->shape = (__pyx_v_info->strides + 1);

  /* "cpython/array.pxd":107
 *                            stdlib.malloc(sizeof(Py_ssize_t) * info.ndim * 2 + 2)
 *             info.shape = info.strides + 1
 *             info.shape[0] = Py_SIZE(self)            # number of items             # <<<<<<<<<<<<<<
 *             info.strides[0] = info.itemsize
 * 
 */
  (__pyx_v_info->shape[0]) = Py_SIZE(((PyObject *)__pyx_v_self));

  /* "cpython/array.pxd":108
 *             info.shape = info.strides + 1
 *             info.shape[0] = Py_SIZE(self)            # number of items
 *             info.strides[0] = info.itemsize             # <<<<<<<<<<<<<<
 * 
 *             info.format = <char*>(info.strides + 2 * info.ndim)
 */
  __pyx_t_2 = __pyx_v_info->itemsize;
  (__pyx_v_info->strides[0]) = __pyx_t_2;

  /* "cpython/array.pxd":110
 *             info.strides[0] = info.itemsize
 * 
 *             info.format = <char*>(info.strides + 2 * info.ndim)             # <<<<<<<<<<<<<<
 *             info.format[0] = self.ob_descr.typecode
 *             info.format[1] = 0
 */
  __pyx_v_info->format = ((char *)(__pyx_v_info->strides + (2 * __pyx_v_info->ndim)));

  /* "cpython/array.pxd":111
 * 
 *             info.format = <char*>(info.strides + 2 * info.ndim)
 *             info.format[0] = self.ob_descr.typecode             # <<<<<<<<<<<<<<
 *             info.format[1] = 0
 *             info.obj = self
 */
  __pyx_t_3 = __pyx_v_self->ob_descr->typecode;
  (__pyx_v_info->format[0]) = __pyx_t_3;

  /* "cpython/array.pxd":112
 *             info.format = <char*>(info.strides + 2 * info.ndim)
 *             info.format[0] = self.ob_descr.typecode
 *             info.format[1] = 0             # <<<<<<<<<<<<<<
 *             info.obj = self
 * 
 */
  (__pyx_v_info->format[1]) = 0;

  /* "cpython/array.pxd":113
 *             info.format[0] = self.ob_descr.typecode
 *             info.format[1] = 0
 *             info.obj = self             # <<<<<<<<<<<<<<
 * 
 *         def __releasebuffer__(array self, Py_buffer* info):
 */
  __Pyx_INCREF(((PyObject *)__pyx_v_self));
  __Pyx_GIVEREF(((PyObject *)__pyx_v_self));
  __Pyx_GOTREF(__pyx_v_info->obj);
  __Pyx_DECREF(__pyx_v_info->obj);
  __pyx_v_info->obj = ((PyObject *)__pyx_v_self);

  __pyx_r = 0;
  if (__pyx_v_info != NULL && __pyx_v_info->obj == Py_None) {
    __Pyx_GOTREF(Py_None);
    __Pyx_DECREF(Py_None); __pyx_v_info->obj = NULL;
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static CYTHON_UNUSED void __pyx_pw_7cpython_5array_5array_3__releasebuffer__(PyObject *__pyx_v_self, Py_buffer *__pyx_v_info); /*proto*/
static CYTHON_UNUSED void __pyx_pw_7cpython_5array_5array_3__releasebuffer__(PyObject *__pyx_v_self, Py_buffer *__pyx_v_info) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__releasebuffer__ (wrapper)", 0);
  __pyx_pf_7cpython_5array_5array_2__releasebuffer__(((arrayobject *)__pyx_v_self), ((Py_buffer *)__pyx_v_info));
  __Pyx_RefNannyFinishContext();
}

/* "cpython/array.pxd":115
 *             info.obj = self
 * 
 *         def __releasebuffer__(array self, Py_buffer* info):             # <<<<<<<<<<<<<<
 *             #if PyArray_HASFIELDS(self):
 *             #    stdlib.free(info.format)
 */

static void __pyx_pf_7cpython_5array_5array_2__releasebuffer__(CYTHON_UNUSED arrayobject *__pyx_v_self, Py_buffer *__pyx_v_info) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__releasebuffer__", 0);

  /* "cpython/array.pxd":119
 *             #    stdlib.free(info.format)
 *             #if sizeof(npy_intp) != sizeof(Py_ssize_t):
 *             stdlib.free(info.strides)             # <<<<<<<<<<<<<<
 * 
 *     array newarrayobject(PyTypeObject* type, Py_ssize_t size, arraydescr *descr)
 */
  free(__pyx_v_info->strides);

  __Pyx_RefNannyFinishContext();
}

/* "cpython/array.pxd":130
 * 
 * 
 * cdef inline array clone(array template, Py_ssize_t length, bint zero):             # <<<<<<<<<<<<<<
 *     """ fast creation of a new array, given a template array.
 *     type will be same as template.
 */

static CYTHON_INLINE arrayobject *__pyx_f_7cpython_5array_clone(arrayobject *__pyx_v_template, Py_ssize_t __pyx_v_length, int __pyx_v_zero) {
  arrayobject *__pyx_v_op = 0;
  arrayobject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("clone", 0);

  /* "cpython/array.pxd":135
 *     if zero is true, new array will be initialized with zeroes."""
 *     cdef array op
 *     op = newarrayobject(Py_TYPE(template), length, template.ob_descr)             # <<<<<<<<<<<<<<
 *     if zero and op is not None:
 *         memset(op.data.as_chars, 0, length * op.ob_descr.itemsize)
 */
  __pyx_t_1 = ((PyObject *)newarrayobject(Py_TYPE(((PyObject *)__pyx_v_template)), __pyx_v_length, __pyx_v_template->ob_descr)); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[2]; __pyx_lineno = 135; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_op = ((arrayobject *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "cpython/array.pxd":136
 *     cdef array op
 *     op = newarrayobject(Py_TYPE(template), length, template.ob_descr)
 *     if zero and op is not None:             # <<<<<<<<<<<<<<
 *         memset(op.data.as_chars, 0, length * op.ob_descr.itemsize)
 *     return op
 */
  if ((__pyx_v_zero != 0)) {
    __pyx_t_2 = (((PyObject *)__pyx_v_op) != Py_None);
    __pyx_t_3 = (__pyx_t_2 != 0);
  } else {
    __pyx_t_3 = (__pyx_v_zero != 0);
  }
  if (__pyx_t_3) {

    /* "cpython/array.pxd":137
 *     op = newarrayobject(Py_TYPE(template), length, template.ob_descr)
 *     if zero and op is not None:
 *         memset(op.data.as_chars, 0, length * op.ob_descr.itemsize)             # <<<<<<<<<<<<<<
 *     return op
 * 
 */
    memset(__pyx_v_op->data.as_chars, 0, (__pyx_v_length * __pyx_v_op->ob_descr->itemsize));
    goto __pyx_L3;
  }
  __pyx_L3:;

  /* "cpython/array.pxd":138
 *     if zero and op is not None:
 *         memset(op.data.as_chars, 0, length * op.ob_descr.itemsize)
 *     return op             # <<<<<<<<<<<<<<
 * 
 * cdef inline array copy(array self):
 */
  __Pyx_XDECREF(((PyObject *)__pyx_r));
  __Pyx_INCREF(((PyObject *)__pyx_v_op));
  __pyx_r = __pyx_v_op;
  goto __pyx_L0;

  __pyx_r = ((arrayobject *)Py_None); __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("cpython.array.clone", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_op);
  __Pyx_XGIVEREF((PyObject *)__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cpython/array.pxd":140
 *     return op
 * 
 * cdef inline array copy(array self):             # <<<<<<<<<<<<<<
 *     """ make a copy of an array. """
 *     cdef array op
 */

static CYTHON_INLINE arrayobject *__pyx_f_7cpython_5array_copy(arrayobject *__pyx_v_self) {
  arrayobject *__pyx_v_op = 0;
  arrayobject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("copy", 0);

  /* "cpython/array.pxd":143
 *     """ make a copy of an array. """
 *     cdef array op
 *     op = newarrayobject(Py_TYPE(self), Py_SIZE(self), self.ob_descr)             # <<<<<<<<<<<<<<
 *     memcpy(op.data.as_chars, self.data.as_chars, Py_SIZE(op) * op.ob_descr.itemsize)
 *     return op
 */
  __pyx_t_1 = ((PyObject *)newarrayobject(Py_TYPE(((PyObject *)__pyx_v_self)), Py_SIZE(((PyObject *)__pyx_v_self)), __pyx_v_self->ob_descr)); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[2]; __pyx_lineno = 143; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_op = ((arrayobject *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "cpython/array.pxd":144
 *     cdef array op
 *     op = newarrayobject(Py_TYPE(self), Py_SIZE(self), self.ob_descr)
 *     memcpy(op.data.as_chars, self.data.as_chars, Py_SIZE(op) * op.ob_descr.itemsize)             # <<<<<<<<<<<<<<
 *     return op
 * 
 */
  memcpy(__pyx_v_op->data.as_chars, __pyx_v_self->data.as_chars, (Py_SIZE(((PyObject *)__pyx_v_op)) * __pyx_v_op->ob_descr->itemsize));

  /* "cpython/array.pxd":145
 *     op = newarrayobject(Py_TYPE(self), Py_SIZE(self), self.ob_descr)
 *     memcpy(op.data.as_chars, self.data.as_chars, Py_SIZE(op) * op.ob_descr.itemsize)
 *     return op             # <<<<<<<<<<<<<<
 * 
 * cdef inline int extend_buffer(array self, char* stuff, Py_ssize_t n):
 */
  __Pyx_XDECREF(((PyObject *)__pyx_r));
  __Pyx_INCREF(((PyObject *)__pyx_v_op));
  __pyx_r = __pyx_v_op;
  goto __pyx_L0;

  __pyx_r = ((arrayobject *)Py_None); __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("cpython.array.copy", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_op);
  __Pyx_XGIVEREF((PyObject *)__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cpython/array.pxd":147
 *     return op
 * 
 * cdef inline int extend_buffer(array self, char* stuff, Py_ssize_t n):             # <<<<<<<<<<<<<<
 *     """ efficent appending of new stuff of same type
 *     (e.g. of same array type)
 */

static CYTHON_INLINE int __pyx_f_7cpython_5array_extend_buffer(arrayobject *__pyx_v_self, char *__pyx_v_stuff, Py_ssize_t __pyx_v_n) {
  Py_ssize_t __pyx_v_itemsize;
  Py_ssize_t __pyx_v_orgsize;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  __Pyx_RefNannySetupContext("extend_buffer", 0);

  /* "cpython/array.pxd":151
 *     (e.g. of same array type)
 *     n: number of elements (not number of bytes!) """
 *     cdef Py_ssize_t itemsize = self.ob_descr.itemsize             # <<<<<<<<<<<<<<
 *     cdef Py_ssize_t orgsize = Py_SIZE(self)
 *     if resize_smart(self, orgsize + n) == -1:
 */
  __pyx_t_1 = __pyx_v_self->ob_descr->itemsize;
  __pyx_v_itemsize = __pyx_t_1;

  /* "cpython/array.pxd":152
 *     n: number of elements (not number of bytes!) """
 *     cdef Py_ssize_t itemsize = self.ob_descr.itemsize
 *     cdef Py_ssize_t orgsize = Py_SIZE(self)             # <<<<<<<<<<<<<<
 *     if resize_smart(self, orgsize + n) == -1:
 *         return -1
 */
  __pyx_v_orgsize = Py_SIZE(((PyObject *)__pyx_v_self));

  /* "cpython/array.pxd":153
 *     cdef Py_ssize_t itemsize = self.ob_descr.itemsize
 *     cdef Py_ssize_t orgsize = Py_SIZE(self)
 *     if resize_smart(self, orgsize + n) == -1:             # <<<<<<<<<<<<<<
 *         return -1
 *     memcpy(self.data.as_chars + orgsize * itemsize, stuff, n * itemsize)
 */
  __pyx_t_2 = ((resize_smart(__pyx_v_self, (__pyx_v_orgsize + __pyx_v_n)) == -1) != 0);
  if (__pyx_t_2) {

    /* "cpython/array.pxd":154
 *     cdef Py_ssize_t orgsize = Py_SIZE(self)
 *     if resize_smart(self, orgsize + n) == -1:
 *         return -1             # <<<<<<<<<<<<<<
 *     memcpy(self.data.as_chars + orgsize * itemsize, stuff, n * itemsize)
 * 
 */
    __pyx_r = -1;
    goto __pyx_L0;
    goto __pyx_L3;
  }
  __pyx_L3:;

  /* "cpython/array.pxd":155
 *     if resize_smart(self, orgsize + n) == -1:
 *         return -1
 *     memcpy(self.data.as_chars + orgsize * itemsize, stuff, n * itemsize)             # <<<<<<<<<<<<<<
 * 
 * cdef inline int extend(array self, array other):
 */
  memcpy((__pyx_v_self->data.as_chars + (__pyx_v_orgsize * __pyx_v_itemsize)), __pyx_v_stuff, (__pyx_v_n * __pyx_v_itemsize));

  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cpython/array.pxd":157
 *     memcpy(self.data.as_chars + orgsize * itemsize, stuff, n * itemsize)
 * 
 * cdef inline int extend(array self, array other):             # <<<<<<<<<<<<<<
 *     """ extend array with data from another array; types must match. """
 *     if self.ob_descr.typecode != self.ob_descr.typecode:
 */

static CYTHON_INLINE int __pyx_f_7cpython_5array_extend(arrayobject *__pyx_v_self, arrayobject *__pyx_v_other) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("extend", 0);

  /* "cpython/array.pxd":159
 * cdef inline int extend(array self, array other):
 *     """ extend array with data from another array; types must match. """
 *     if self.ob_descr.typecode != self.ob_descr.typecode:             # <<<<<<<<<<<<<<
 *         PyErr_BadArgument()
 *         return -1
 */
  __pyx_t_1 = ((__pyx_v_self->ob_descr->typecode != __pyx_v_self->ob_descr->typecode) != 0);
  if (__pyx_t_1) {

    /* "cpython/array.pxd":160
 *     """ extend array with data from another array; types must match. """
 *     if self.ob_descr.typecode != self.ob_descr.typecode:
 *         PyErr_BadArgument()             # <<<<<<<<<<<<<<
 *         return -1
 *     return extend_buffer(self, other.data.as_chars, Py_SIZE(other))
 */
    __pyx_t_2 = PyErr_BadArgument(); if (unlikely(__pyx_t_2 == 0)) {__pyx_filename = __pyx_f[2]; __pyx_lineno = 160; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

    /* "cpython/array.pxd":161
 *     if self.ob_descr.typecode != self.ob_descr.typecode:
 *         PyErr_BadArgument()
 *         return -1             # <<<<<<<<<<<<<<
 *     return extend_buffer(self, other.data.as_chars, Py_SIZE(other))
 * 
 */
    __pyx_r = -1;
    goto __pyx_L0;
    goto __pyx_L3;
  }
  __pyx_L3:;

  /* "cpython/array.pxd":162
 *         PyErr_BadArgument()
 *         return -1
 *     return extend_buffer(self, other.data.as_chars, Py_SIZE(other))             # <<<<<<<<<<<<<<
 * 
 * cdef inline void zero(array op):
 */
  __pyx_r = __pyx_f_7cpython_5array_extend_buffer(__pyx_v_self, __pyx_v_other->data.as_chars, Py_SIZE(((PyObject *)__pyx_v_other)));
  goto __pyx_L0;

  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_WriteUnraisable("cpython.array.extend", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cpython/array.pxd":164
 *     return extend_buffer(self, other.data.as_chars, Py_SIZE(other))
 * 
 * cdef inline void zero(array op):             # <<<<<<<<<<<<<<
 *     """ set all elements of array to zero. """
 *     memset(op.data.as_chars, 0, Py_SIZE(op) * op.ob_descr.itemsize)
 */

static CYTHON_INLINE void __pyx_f_7cpython_5array_zero(arrayobject *__pyx_v_op) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("zero", 0);

  /* "cpython/array.pxd":166
 * cdef inline void zero(array op):
 *     """ set all elements of array to zero. """
 *     memset(op.data.as_chars, 0, Py_SIZE(op) * op.ob_descr.itemsize)             # <<<<<<<<<<<<<<
 */
  memset(__pyx_v_op->data.as_chars, 0, (Py_SIZE(((PyObject *)__pyx_v_op)) * __pyx_v_op->ob_descr->itemsize));

  __Pyx_RefNannyFinishContext();
}

/* "axon/_loader.pxd":59
 * cdef dict c_factory_dict
 * 
 * cdef inline object dict_get(object op, object key, object default):             # <<<<<<<<<<<<<<
 *     cdef PyObject* val = <PyObject*>PyDict_GetItem(op, key)
 *     if val == NULL:
 */

static CYTHON_INLINE PyObject *__pyx_f_4axon_7_loader_dict_get(PyObject *__pyx_v_op, PyObject *__pyx_v_key, PyObject *__pyx_v_default) {
  PyObject *__pyx_v_val;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  __Pyx_RefNannySetupContext("dict_get", 0);

  /* "axon/_loader.pxd":60
 * 
 * cdef inline object dict_get(object op, object key, object default):
 *     cdef PyObject* val = <PyObject*>PyDict_GetItem(op, key)             # <<<<<<<<<<<<<<
 *     if val == NULL:
 *         return default
 */
  __pyx_v_val = ((PyObject *)PyDict_GetItem(__pyx_v_op, __pyx_v_key));

  /* "axon/_loader.pxd":61
 * cdef inline object dict_get(object op, object key, object default):
 *     cdef PyObject* val = <PyObject*>PyDict_GetItem(op, key)
 *     if val == NULL:             # <<<<<<<<<<<<<<
 *         return default
 *     else:
 */
  __pyx_t_1 = ((__pyx_v_val == NULL) != 0);
  if (__pyx_t_1) {

    /* "axon/_loader.pxd":62
 *     cdef PyObject* val = <PyObject*>PyDict_GetItem(op, key)
 *     if val == NULL:
 *         return default             # <<<<<<<<<<<<<<
 *     else:
 *         return <object>val
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_v_default);
    __pyx_r = __pyx_v_default;
    goto __pyx_L0;
    goto __pyx_L3;
  }
  /*else*/ {

    /* "axon/_loader.pxd":64
 *         return default
 *     else:
 *         return <object>val             # <<<<<<<<<<<<<<
 * 
 * # cdef inline unicode _as_name(object name):
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(((PyObject *)__pyx_v_val));
    __pyx_r = ((PyObject *)__pyx_v_val);
    goto __pyx_L0;
  }
  __pyx_L3:;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cpython/datetime.pxd":104
 * # Datetime C API initialization function.
 * # You have to call it before any usage of DateTime CAPI functions.
 * cdef inline void import_datetime():             # <<<<<<<<<<<<<<
 *     PyDateTime_IMPORT
 * 
 */

static CYTHON_INLINE void __pyx_f_7cpython_8datetime_import_datetime(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("import_datetime", 0);

  /* "cpython/datetime.pxd":105
 * # You have to call it before any usage of DateTime CAPI functions.
 * cdef inline void import_datetime():
 *     PyDateTime_IMPORT             # <<<<<<<<<<<<<<
 * 
 * # Create date object using DateTime CAPI factory function.
 */
  PyDateTime_IMPORT;

  __Pyx_RefNannyFinishContext();
}

/* "cpython/datetime.pxd":109
 * # Create date object using DateTime CAPI factory function.
 * # Note, there are no range checks for any of the arguments.
 * cdef inline object date_new(int year, int month, int day):             # <<<<<<<<<<<<<<
 *     return PyDateTimeAPI.Date_FromDate(year, month, day, PyDateTimeAPI.DateType)
 * 
 */

static CYTHON_INLINE PyObject *__pyx_f_7cpython_8datetime_date_new(int __pyx_v_year, int __pyx_v_month, int __pyx_v_day) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("date_new", 0);

  /* "cpython/datetime.pxd":110
 * # Note, there are no range checks for any of the arguments.
 * cdef inline object date_new(int year, int month, int day):
 *     return PyDateTimeAPI.Date_FromDate(year, month, day, PyDateTimeAPI.DateType)             # <<<<<<<<<<<<<<
 * 
 * # Create time object using DateTime CAPI factory function
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyDateTimeAPI->Date_FromDate(__pyx_v_year, __pyx_v_month, __pyx_v_day, PyDateTimeAPI->DateType); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[3]; __pyx_lineno = 110; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("cpython.datetime.date_new", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cpython/datetime.pxd":114
 * # Create time object using DateTime CAPI factory function
 * # Note, there are no range checks for any of the arguments.
 * cdef inline object time_new(int hour, int minute, int second, int microsecond, object tz):             # <<<<<<<<<<<<<<
 *     return PyDateTimeAPI.Time_FromTime(hour, minute, second, microsecond, tz, PyDateTimeAPI.TimeType)
 * 
 */

static CYTHON_INLINE PyObject *__pyx_f_7cpython_8datetime_time_new(int __pyx_v_hour, int __pyx_v_minute, int __pyx_v_second, int __pyx_v_microsecond, PyObject *__pyx_v_tz) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("time_new", 0);

  /* "cpython/datetime.pxd":115
 * # Note, there are no range checks for any of the arguments.
 * cdef inline object time_new(int hour, int minute, int second, int microsecond, object tz):
 *     return PyDateTimeAPI.Time_FromTime(hour, minute, second, microsecond, tz, PyDateTimeAPI.TimeType)             # <<<<<<<<<<<<<<
 * 
 * # Create datetime object using DateTime CAPI factory function.
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyDateTimeAPI->Time_FromTime(__pyx_v_hour, __pyx_v_minute, __pyx_v_second, __pyx_v_microsecond, __pyx_v_tz, PyDateTimeAPI->TimeType); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[3]; __pyx_lineno = 115; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("cpython.datetime.time_new", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cpython/datetime.pxd":119
 * # Create datetime object using DateTime CAPI factory function.
 * # Note, there are no range checks for any of the arguments.
 * cdef inline object datetime_new(int year, int month, int day, int hour, int minute, int second, int microsecond, object tz):             # <<<<<<<<<<<<<<
 *     return PyDateTimeAPI.DateTime_FromDateAndTime(year, month, day, hour, minute, second, microsecond, tz, PyDateTimeAPI.DateTimeType)
 * 
 */

static CYTHON_INLINE PyObject *__pyx_f_7cpython_8datetime_datetime_new(int __pyx_v_year, int __pyx_v_month, int __pyx_v_day, int __pyx_v_hour, int __pyx_v_minute, int __pyx_v_second, int __pyx_v_microsecond, PyObject *__pyx_v_tz) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("datetime_new", 0);

  /* "cpython/datetime.pxd":120
 * # Note, there are no range checks for any of the arguments.
 * cdef inline object datetime_new(int year, int month, int day, int hour, int minute, int second, int microsecond, object tz):
 *     return PyDateTimeAPI.DateTime_FromDateAndTime(year, month, day, hour, minute, second, microsecond, tz, PyDateTimeAPI.DateTimeType)             # <<<<<<<<<<<<<<
 * 
 * # Create timedelta object using DateTime CAPI factory function.
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyDateTimeAPI->DateTime_FromDateAndTime(__pyx_v_year, __pyx_v_month, __pyx_v_day, __pyx_v_hour, __pyx_v_minute, __pyx_v_second, __pyx_v_microsecond, __pyx_v_tz, PyDateTimeAPI->DateTimeType); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[3]; __pyx_lineno = 120; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("cpython.datetime.datetime_new", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cpython/datetime.pxd":124
 * # Create timedelta object using DateTime CAPI factory function.
 * # Note, there are no range checks for any of the arguments.
 * cdef inline object timedelta_new(int days, int seconds, int useconds):             # <<<<<<<<<<<<<<
 *     return PyDateTimeAPI.Delta_FromDelta(days, seconds, useconds, 1, PyDateTimeAPI.DeltaType)
 * 
 */

static CYTHON_INLINE PyObject *__pyx_f_7cpython_8datetime_timedelta_new(int __pyx_v_days, int __pyx_v_seconds, int __pyx_v_useconds) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("timedelta_new", 0);

  /* "cpython/datetime.pxd":125
 * # Note, there are no range checks for any of the arguments.
 * cdef inline object timedelta_new(int days, int seconds, int useconds):
 *     return PyDateTimeAPI.Delta_FromDelta(days, seconds, useconds, 1, PyDateTimeAPI.DeltaType)             # <<<<<<<<<<<<<<
 * 
 * # More recognizable getters for date/time/datetime/timedelta.
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyDateTimeAPI->Delta_FromDelta(__pyx_v_days, __pyx_v_seconds, __pyx_v_useconds, 1, PyDateTimeAPI->DeltaType); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[3]; __pyx_lineno = 125; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("cpython.datetime.timedelta_new", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cpython/datetime.pxd":133
 * 
 * # Get tzinfo of time
 * cdef inline object time_tzinfo(object o):             # <<<<<<<<<<<<<<
 *     if (<PyDateTime_Time*>o).hastzinfo:
 *         return <object>(<PyDateTime_Time*>o).tzinfo
 */

static CYTHON_INLINE PyObject *__pyx_f_7cpython_8datetime_time_tzinfo(PyObject *__pyx_v_o) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  __Pyx_RefNannySetupContext("time_tzinfo", 0);

  /* "cpython/datetime.pxd":134
 * # Get tzinfo of time
 * cdef inline object time_tzinfo(object o):
 *     if (<PyDateTime_Time*>o).hastzinfo:             # <<<<<<<<<<<<<<
 *         return <object>(<PyDateTime_Time*>o).tzinfo
 *     else:
 */
  __pyx_t_1 = (((PyDateTime_Time *)__pyx_v_o)->hastzinfo != 0);
  if (__pyx_t_1) {

    /* "cpython/datetime.pxd":135
 * cdef inline object time_tzinfo(object o):
 *     if (<PyDateTime_Time*>o).hastzinfo:
 *         return <object>(<PyDateTime_Time*>o).tzinfo             # <<<<<<<<<<<<<<
 *     else:
 *         return None
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(((PyObject *)((PyDateTime_Time *)__pyx_v_o)->tzinfo));
    __pyx_r = ((PyObject *)((PyDateTime_Time *)__pyx_v_o)->tzinfo);
    goto __pyx_L0;
    goto __pyx_L3;
  }
  /*else*/ {

    /* "cpython/datetime.pxd":137
 *         return <object>(<PyDateTime_Time*>o).tzinfo
 *     else:
 *         return None             # <<<<<<<<<<<<<<
 * 
 * # Get tzinfo of datetime
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(Py_None);
    __pyx_r = Py_None;
    goto __pyx_L0;
  }
  __pyx_L3:;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cpython/datetime.pxd":140
 * 
 * # Get tzinfo of datetime
 * cdef inline object datetime_tzinfo(object o):             # <<<<<<<<<<<<<<
 *     if (<PyDateTime_DateTime*>o).hastzinfo:
 *         return <object>(<PyDateTime_DateTime*>o).tzinfo
 */

static CYTHON_INLINE PyObject *__pyx_f_7cpython_8datetime_datetime_tzinfo(PyObject *__pyx_v_o) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  __Pyx_RefNannySetupContext("datetime_tzinfo", 0);

  /* "cpython/datetime.pxd":141
 * # Get tzinfo of datetime
 * cdef inline object datetime_tzinfo(object o):
 *     if (<PyDateTime_DateTime*>o).hastzinfo:             # <<<<<<<<<<<<<<
 *         return <object>(<PyDateTime_DateTime*>o).tzinfo
 *     else:
 */
  __pyx_t_1 = (((PyDateTime_DateTime *)__pyx_v_o)->hastzinfo != 0);
  if (__pyx_t_1) {

    /* "cpython/datetime.pxd":142
 * cdef inline object datetime_tzinfo(object o):
 *     if (<PyDateTime_DateTime*>o).hastzinfo:
 *         return <object>(<PyDateTime_DateTime*>o).tzinfo             # <<<<<<<<<<<<<<
 *     else:
 *         return None
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(((PyObject *)((PyDateTime_DateTime *)__pyx_v_o)->tzinfo));
    __pyx_r = ((PyObject *)((PyDateTime_DateTime *)__pyx_v_o)->tzinfo);
    goto __pyx_L0;
    goto __pyx_L3;
  }
  /*else*/ {

    /* "cpython/datetime.pxd":144
 *         return <object>(<PyDateTime_DateTime*>o).tzinfo
 *     else:
 *         return None             # <<<<<<<<<<<<<<
 * 
 * # Get year of date
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(Py_None);
    __pyx_r = Py_None;
    goto __pyx_L0;
  }
  __pyx_L3:;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cpython/datetime.pxd":147
 * 
 * # Get year of date
 * cdef inline int date_year(object o):             # <<<<<<<<<<<<<<
 *     return PyDateTime_GET_YEAR(o)
 * 
 */

static CYTHON_INLINE int __pyx_f_7cpython_8datetime_date_year(PyObject *__pyx_v_o) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("date_year", 0);

  /* "cpython/datetime.pxd":148
 * # Get year of date
 * cdef inline int date_year(object o):
 *     return PyDateTime_GET_YEAR(o)             # <<<<<<<<<<<<<<
 * 
 * # Get month of date
 */
  __pyx_r = PyDateTime_GET_YEAR(__pyx_v_o);
  goto __pyx_L0;

  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cpython/datetime.pxd":151
 * 
 * # Get month of date
 * cdef inline int date_month(object o):             # <<<<<<<<<<<<<<
 *     return PyDateTime_GET_MONTH(o)
 * 
 */

static CYTHON_INLINE int __pyx_f_7cpython_8datetime_date_month(PyObject *__pyx_v_o) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("date_month", 0);

  /* "cpython/datetime.pxd":152
 * # Get month of date
 * cdef inline int date_month(object o):
 *     return PyDateTime_GET_MONTH(o)             # <<<<<<<<<<<<<<
 * 
 * # Get day of date
 */
  __pyx_r = PyDateTime_GET_MONTH(__pyx_v_o);
  goto __pyx_L0;

  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cpython/datetime.pxd":155
 * 
 * # Get day of date
 * cdef inline int date_day(object o):             # <<<<<<<<<<<<<<
 *     return PyDateTime_GET_DAY(o)
 * 
 */

static CYTHON_INLINE int __pyx_f_7cpython_8datetime_date_day(PyObject *__pyx_v_o) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("date_day", 0);

  /* "cpython/datetime.pxd":156
 * # Get day of date
 * cdef inline int date_day(object o):
 *     return PyDateTime_GET_DAY(o)             # <<<<<<<<<<<<<<
 * 
 * # Get year of datetime
 */
  __pyx_r = PyDateTime_GET_DAY(__pyx_v_o);
  goto __pyx_L0;

  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cpython/datetime.pxd":159
 * 
 * # Get year of datetime
 * cdef inline int datetime_year(object o):             # <<<<<<<<<<<<<<
 *     return PyDateTime_GET_YEAR(o)
 * 
 */

static CYTHON_INLINE int __pyx_f_7cpython_8datetime_datetime_year(PyObject *__pyx_v_o) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("datetime_year", 0);

  /* "cpython/datetime.pxd":160
 * # Get year of datetime
 * cdef inline int datetime_year(object o):
 *     return PyDateTime_GET_YEAR(o)             # <<<<<<<<<<<<<<
 * 
 * # Get month of datetime
 */
  __pyx_r = PyDateTime_GET_YEAR(__pyx_v_o);
  goto __pyx_L0;

  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cpython/datetime.pxd":163
 * 
 * # Get month of datetime
 * cdef inline int datetime_month(object o):             # <<<<<<<<<<<<<<
 *     return PyDateTime_GET_MONTH(o)
 * 
 */

static CYTHON_INLINE int __pyx_f_7cpython_8datetime_datetime_month(PyObject *__pyx_v_o) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("datetime_month", 0);

  /* "cpython/datetime.pxd":164
 * # Get month of datetime
 * cdef inline int datetime_month(object o):
 *     return PyDateTime_GET_MONTH(o)             # <<<<<<<<<<<<<<
 * 
 * # Get day of datetime
 */
  __pyx_r = PyDateTime_GET_MONTH(__pyx_v_o);
  goto __pyx_L0;

  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cpython/datetime.pxd":167
 * 
 * # Get day of datetime
 * cdef inline int datetime_day(object o):             # <<<<<<<<<<<<<<
 *     return PyDateTime_GET_DAY(o)
 * 
 */

static CYTHON_INLINE int __pyx_f_7cpython_8datetime_datetime_day(PyObject *__pyx_v_o) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("datetime_day", 0);

  /* "cpython/datetime.pxd":168
 * # Get day of datetime
 * cdef inline int datetime_day(object o):
 *     return PyDateTime_GET_DAY(o)             # <<<<<<<<<<<<<<
 * 
 * # Get hour of time
 */
  __pyx_r = PyDateTime_GET_DAY(__pyx_v_o);
  goto __pyx_L0;

  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cpython/datetime.pxd":171
 * 
 * # Get hour of time
 * cdef inline int time_hour(object o):             # <<<<<<<<<<<<<<
 *     return PyDateTime_TIME_GET_HOUR(o)
 * 
 */

static CYTHON_INLINE int __pyx_f_7cpython_8datetime_time_hour(PyObject *__pyx_v_o) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("time_hour", 0);

  /* "cpython/datetime.pxd":172
 * # Get hour of time
 * cdef inline int time_hour(object o):
 *     return PyDateTime_TIME_GET_HOUR(o)             # <<<<<<<<<<<<<<
 * 
 * # Get minute of time
 */
  __pyx_r = PyDateTime_TIME_GET_HOUR(__pyx_v_o);
  goto __pyx_L0;

  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cpython/datetime.pxd":175
 * 
 * # Get minute of time
 * cdef inline int time_minute(object o):             # <<<<<<<<<<<<<<
 *     return PyDateTime_TIME_GET_MINUTE(o)
 * 
 */

static CYTHON_INLINE int __pyx_f_7cpython_8datetime_time_minute(PyObject *__pyx_v_o) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("time_minute", 0);

  /* "cpython/datetime.pxd":176
 * # Get minute of time
 * cdef inline int time_minute(object o):
 *     return PyDateTime_TIME_GET_MINUTE(o)             # <<<<<<<<<<<<<<
 * 
 * # Get second of time
 */
  __pyx_r = PyDateTime_TIME_GET_MINUTE(__pyx_v_o);
  goto __pyx_L0;

  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cpython/datetime.pxd":179
 * 
 * # Get second of time
 * cdef inline int time_second(object o):             # <<<<<<<<<<<<<<
 *     return PyDateTime_TIME_GET_SECOND(o)
 * 
 */

static CYTHON_INLINE int __pyx_f_7cpython_8datetime_time_second(PyObject *__pyx_v_o) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("time_second", 0);

  /* "cpython/datetime.pxd":180
 * # Get second of time
 * cdef inline int time_second(object o):
 *     return PyDateTime_TIME_GET_SECOND(o)             # <<<<<<<<<<<<<<
 * 
 * # Get microsecond of time
 */
  __pyx_r = PyDateTime_TIME_GET_SECOND(__pyx_v_o);
  goto __pyx_L0;

  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cpython/datetime.pxd":183
 * 
 * # Get microsecond of time
 * cdef inline int time_microsecond(object o):             # <<<<<<<<<<<<<<
 *     return PyDateTime_TIME_GET_MICROSECOND(o)
 * 
 */

static CYTHON_INLINE int __pyx_f_7cpython_8datetime_time_microsecond(PyObject *__pyx_v_o) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("time_microsecond", 0);

  /* "cpython/datetime.pxd":184
 * # Get microsecond of time
 * cdef inline int time_microsecond(object o):
 *     return PyDateTime_TIME_GET_MICROSECOND(o)             # <<<<<<<<<<<<<<
 * 
 * # Get hour of datetime
 */
  __pyx_r = PyDateTime_TIME_GET_MICROSECOND(__pyx_v_o);
  goto __pyx_L0;

  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cpython/datetime.pxd":187
 * 
 * # Get hour of datetime
 * cdef inline int datetime_hour(object o):             # <<<<<<<<<<<<<<
 *     return PyDateTime_DATE_GET_HOUR(o)
 * 
 */

static CYTHON_INLINE int __pyx_f_7cpython_8datetime_datetime_hour(PyObject *__pyx_v_o) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("datetime_hour", 0);

  /* "cpython/datetime.pxd":188
 * # Get hour of datetime
 * cdef inline int datetime_hour(object o):
 *     return PyDateTime_DATE_GET_HOUR(o)             # <<<<<<<<<<<<<<
 * 
 * # Get minute of datetime
 */
  __pyx_r = PyDateTime_DATE_GET_HOUR(__pyx_v_o);
  goto __pyx_L0;

  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cpython/datetime.pxd":191
 * 
 * # Get minute of datetime
 * cdef inline int datetime_minute(object o):             # <<<<<<<<<<<<<<
 *     return PyDateTime_DATE_GET_MINUTE(o)
 * 
 */

static CYTHON_INLINE int __pyx_f_7cpython_8datetime_datetime_minute(PyObject *__pyx_v_o) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("datetime_minute", 0);

  /* "cpython/datetime.pxd":192
 * # Get minute of datetime
 * cdef inline int datetime_minute(object o):
 *     return PyDateTime_DATE_GET_MINUTE(o)             # <<<<<<<<<<<<<<
 * 
 * # Get second of datetime
 */
  __pyx_r = PyDateTime_DATE_GET_MINUTE(__pyx_v_o);
  goto __pyx_L0;

  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cpython/datetime.pxd":195
 * 
 * # Get second of datetime
 * cdef inline int datetime_second(object o):             # <<<<<<<<<<<<<<
 *     return PyDateTime_DATE_GET_SECOND(o)
 * 
 */

static CYTHON_INLINE int __pyx_f_7cpython_8datetime_datetime_second(PyObject *__pyx_v_o) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("datetime_second", 0);

  /* "cpython/datetime.pxd":196
 * # Get second of datetime
 * cdef inline int datetime_second(object o):
 *     return PyDateTime_DATE_GET_SECOND(o)             # <<<<<<<<<<<<<<
 * 
 * # Get microsecond of datetime
 */
  __pyx_r = PyDateTime_DATE_GET_SECOND(__pyx_v_o);
  goto __pyx_L0;

  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cpython/datetime.pxd":199
 * 
 * # Get microsecond of datetime
 * cdef inline int datetime_microsecond(object o):             # <<<<<<<<<<<<<<
 *     return PyDateTime_DATE_GET_MICROSECOND(o)
 * 
 */

static CYTHON_INLINE int __pyx_f_7cpython_8datetime_datetime_microsecond(PyObject *__pyx_v_o) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("datetime_microsecond", 0);

  /* "cpython/datetime.pxd":200
 * # Get microsecond of datetime
 * cdef inline int datetime_microsecond(object o):
 *     return PyDateTime_DATE_GET_MICROSECOND(o)             # <<<<<<<<<<<<<<
 * 
 * # Get days of timedelta
 */
  __pyx_r = PyDateTime_DATE_GET_MICROSECOND(__pyx_v_o);
  goto __pyx_L0;

  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cpython/datetime.pxd":203
 * 
 * # Get days of timedelta
 * cdef inline int timedelta_days(object o):             # <<<<<<<<<<<<<<
 *     return (<PyDateTime_Delta*>o).days
 * 
 */

static CYTHON_INLINE int __pyx_f_7cpython_8datetime_timedelta_days(PyObject *__pyx_v_o) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("timedelta_days", 0);

  /* "cpython/datetime.pxd":204
 * # Get days of timedelta
 * cdef inline int timedelta_days(object o):
 *     return (<PyDateTime_Delta*>o).days             # <<<<<<<<<<<<<<
 * 
 * # Get seconds of timedelta
 */
  __pyx_r = ((PyDateTime_Delta *)__pyx_v_o)->days;
  goto __pyx_L0;

  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cpython/datetime.pxd":207
 * 
 * # Get seconds of timedelta
 * cdef inline int timedelta_seconds(object o):             # <<<<<<<<<<<<<<
 *     return (<PyDateTime_Delta*>o).seconds
 * 
 */

static CYTHON_INLINE int __pyx_f_7cpython_8datetime_timedelta_seconds(PyObject *__pyx_v_o) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("timedelta_seconds", 0);

  /* "cpython/datetime.pxd":208
 * # Get seconds of timedelta
 * cdef inline int timedelta_seconds(object o):
 *     return (<PyDateTime_Delta*>o).seconds             # <<<<<<<<<<<<<<
 * 
 * # Get microseconds of timedelta
 */
  __pyx_r = ((PyDateTime_Delta *)__pyx_v_o)->seconds;
  goto __pyx_L0;

  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cpython/datetime.pxd":211
 * 
 * # Get microseconds of timedelta
 * cdef inline int timedelta_microseconds(object o):             # <<<<<<<<<<<<<<
 *     return (<PyDateTime_Delta*>o).microseconds
 */

static CYTHON_INLINE int __pyx_f_7cpython_8datetime_timedelta_microseconds(PyObject *__pyx_v_o) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("timedelta_microseconds", 0);

  /* "cpython/datetime.pxd":212
 * # Get microseconds of timedelta
 * cdef inline int timedelta_microseconds(object o):
 *     return (<PyDateTime_Delta*>o).microseconds             # <<<<<<<<<<<<<<
 */
  __pyx_r = ((PyDateTime_Delta *)__pyx_v_o)->microseconds;
  goto __pyx_L0;

  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_objects.pxd":34
 * #        return <object>val
 * 
 * cdef inline dict c_as_dict(object ob):             # <<<<<<<<<<<<<<
 *     if type(ob) is dict:
 *         return <dict>ob
 */

static CYTHON_INLINE PyObject *__pyx_f_4axon_8_objects_c_as_dict(PyObject *__pyx_v_ob) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("c_as_dict", 0);

  /* "axon/_objects.pxd":35
 * 
 * cdef inline dict c_as_dict(object ob):
 *     if type(ob) is dict:             # <<<<<<<<<<<<<<
 *         return <dict>ob
 *     elif ob is None:
 */
  __pyx_t_1 = (((PyObject *)Py_TYPE(__pyx_v_ob)) == ((PyObject *)((PyObject*)(&PyDict_Type))));
  __pyx_t_2 = (__pyx_t_1 != 0);
  if (__pyx_t_2) {

    /* "axon/_objects.pxd":36
 * cdef inline dict c_as_dict(object ob):
 *     if type(ob) is dict:
 *         return <dict>ob             # <<<<<<<<<<<<<<
 *     elif ob is None:
 *         return {}
 */
    __Pyx_XDECREF(((PyObject *)__pyx_r));
    __Pyx_INCREF(((PyObject *)((PyObject*)__pyx_v_ob)));
    __pyx_r = ((PyObject*)__pyx_v_ob);
    goto __pyx_L0;
    goto __pyx_L3;
  }

  /* "axon/_objects.pxd":37
 *     if type(ob) is dict:
 *         return <dict>ob
 *     elif ob is None:             # <<<<<<<<<<<<<<
 *         return {}
 *     else:
 */
  __pyx_t_2 = (__pyx_v_ob == Py_None);
  __pyx_t_1 = (__pyx_t_2 != 0);
  if (__pyx_t_1) {

    /* "axon/_objects.pxd":38
 *         return <dict>ob
 *     elif ob is None:
 *         return {}             # <<<<<<<<<<<<<<
 *     else:
 *         return dict(ob)
 */
    __Pyx_XDECREF(((PyObject *)__pyx_r));
    __pyx_t_3 = PyDict_New(); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[4]; __pyx_lineno = 38; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(((PyObject *)__pyx_t_3));
    __pyx_r = ((PyObject*)__pyx_t_3);
    __pyx_t_3 = 0;
    goto __pyx_L0;
    goto __pyx_L3;
  }
  /*else*/ {

    /* "axon/_objects.pxd":40
 *         return {}
 *     else:
 *         return dict(ob)             # <<<<<<<<<<<<<<
 * 
 * cdef inline list c_as_list(object ob):
 */
    __Pyx_XDECREF(((PyObject *)__pyx_r));
    __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[4]; __pyx_lineno = 40; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_INCREF(__pyx_v_ob);
    PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_v_ob);
    __Pyx_GIVEREF(__pyx_v_ob);
    __pyx_t_4 = PyObject_Call(((PyObject *)((PyObject*)(&PyDict_Type))), ((PyObject *)__pyx_t_3), NULL); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[4]; __pyx_lineno = 40; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(((PyObject *)__pyx_t_3)); __pyx_t_3 = 0;
    __pyx_r = ((PyObject*)__pyx_t_4);
    __pyx_t_4 = 0;
    goto __pyx_L0;
  }
  __pyx_L3:;

  __pyx_r = ((PyObject*)Py_None); __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("axon._objects.c_as_dict", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_objects.pxd":42
 *         return dict(ob)
 * 
 * cdef inline list c_as_list(object ob):             # <<<<<<<<<<<<<<
 *     if type(ob) is list:
 *         return <list>ob
 */

static CYTHON_INLINE PyObject *__pyx_f_4axon_8_objects_c_as_list(PyObject *__pyx_v_ob) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("c_as_list", 0);

  /* "axon/_objects.pxd":43
 * 
 * cdef inline list c_as_list(object ob):
 *     if type(ob) is list:             # <<<<<<<<<<<<<<
 *         return <list>ob
 *     elif ob is None:
 */
  __pyx_t_1 = (((PyObject *)Py_TYPE(__pyx_v_ob)) == ((PyObject *)((PyObject*)(&PyList_Type))));
  __pyx_t_2 = (__pyx_t_1 != 0);
  if (__pyx_t_2) {

    /* "axon/_objects.pxd":44
 * cdef inline list c_as_list(object ob):
 *     if type(ob) is list:
 *         return <list>ob             # <<<<<<<<<<<<<<
 *     elif ob is None:
 *         return []
 */
    __Pyx_XDECREF(((PyObject *)__pyx_r));
    __Pyx_INCREF(((PyObject *)((PyObject*)__pyx_v_ob)));
    __pyx_r = ((PyObject*)__pyx_v_ob);
    goto __pyx_L0;
    goto __pyx_L3;
  }

  /* "axon/_objects.pxd":45
 *     if type(ob) is list:
 *         return <list>ob
 *     elif ob is None:             # <<<<<<<<<<<<<<
 *         return []
 *     else:
 */
  __pyx_t_2 = (__pyx_v_ob == Py_None);
  __pyx_t_1 = (__pyx_t_2 != 0);
  if (__pyx_t_1) {

    /* "axon/_objects.pxd":46
 *         return <list>ob
 *     elif ob is None:
 *         return []             # <<<<<<<<<<<<<<
 *     else:
 *         return list(ob)
 */
    __Pyx_XDECREF(((PyObject *)__pyx_r));
    __pyx_t_3 = PyList_New(0); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[4]; __pyx_lineno = 46; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_r = ((PyObject*)__pyx_t_3);
    __pyx_t_3 = 0;
    goto __pyx_L0;
    goto __pyx_L3;
  }
  /*else*/ {

    /* "axon/_objects.pxd":48
 *         return []
 *     else:
 *         return list(ob)             # <<<<<<<<<<<<<<
 * 
 * cdef inline tuple c_as_tuple(object ob):
 */
    __Pyx_XDECREF(((PyObject *)__pyx_r));
    __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[4]; __pyx_lineno = 48; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_INCREF(__pyx_v_ob);
    PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_v_ob);
    __Pyx_GIVEREF(__pyx_v_ob);
    __pyx_t_4 = PyObject_Call(((PyObject *)((PyObject*)(&PyList_Type))), ((PyObject *)__pyx_t_3), NULL); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[4]; __pyx_lineno = 48; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(((PyObject *)__pyx_t_3)); __pyx_t_3 = 0;
    __pyx_r = ((PyObject*)__pyx_t_4);
    __pyx_t_4 = 0;
    goto __pyx_L0;
  }
  __pyx_L3:;

  __pyx_r = ((PyObject*)Py_None); __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("axon._objects.c_as_list", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_objects.pxd":50
 *         return list(ob)
 * 
 * cdef inline tuple c_as_tuple(object ob):             # <<<<<<<<<<<<<<
 *     if type(ob) is tuple:
 *         return <tuple>ob
 */

static CYTHON_INLINE PyObject *__pyx_f_4axon_8_objects_c_as_tuple(PyObject *__pyx_v_ob) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("c_as_tuple", 0);

  /* "axon/_objects.pxd":51
 * 
 * cdef inline tuple c_as_tuple(object ob):
 *     if type(ob) is tuple:             # <<<<<<<<<<<<<<
 *         return <tuple>ob
 *     elif ob is None:
 */
  __pyx_t_1 = (((PyObject *)Py_TYPE(__pyx_v_ob)) == ((PyObject *)((PyObject*)(&PyTuple_Type))));
  __pyx_t_2 = (__pyx_t_1 != 0);
  if (__pyx_t_2) {

    /* "axon/_objects.pxd":52
 * cdef inline tuple c_as_tuple(object ob):
 *     if type(ob) is tuple:
 *         return <tuple>ob             # <<<<<<<<<<<<<<
 *     elif ob is None:
 *         return ()
 */
    __Pyx_XDECREF(((PyObject *)__pyx_r));
    __Pyx_INCREF(((PyObject *)((PyObject*)__pyx_v_ob)));
    __pyx_r = ((PyObject*)__pyx_v_ob);
    goto __pyx_L0;
    goto __pyx_L3;
  }

  /* "axon/_objects.pxd":53
 *     if type(ob) is tuple:
 *         return <tuple>ob
 *     elif ob is None:             # <<<<<<<<<<<<<<
 *         return ()
 *     else:
 */
  __pyx_t_2 = (__pyx_v_ob == Py_None);
  __pyx_t_1 = (__pyx_t_2 != 0);
  if (__pyx_t_1) {

    /* "axon/_objects.pxd":54
 *         return <tuple>ob
 *     elif ob is None:
 *         return ()             # <<<<<<<<<<<<<<
 *     else:
 *         return tuple(ob)
 */
    __Pyx_XDECREF(((PyObject *)__pyx_r));
    __Pyx_INCREF(((PyObject *)__pyx_empty_tuple));
    __pyx_r = __pyx_empty_tuple;
    goto __pyx_L0;
    goto __pyx_L3;
  }
  /*else*/ {

    /* "axon/_objects.pxd":56
 *         return ()
 *     else:
 *         return tuple(ob)             # <<<<<<<<<<<<<<
 * 
 * cdef inline unicode c_as_unicode(object ob):
 */
    __Pyx_XDECREF(((PyObject *)__pyx_r));
    __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[4]; __pyx_lineno = 56; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_INCREF(__pyx_v_ob);
    PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_v_ob);
    __Pyx_GIVEREF(__pyx_v_ob);
    __pyx_t_4 = PyObject_Call(((PyObject *)((PyObject*)(&PyTuple_Type))), ((PyObject *)__pyx_t_3), NULL); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[4]; __pyx_lineno = 56; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(((PyObject *)__pyx_t_3)); __pyx_t_3 = 0;
    __pyx_r = ((PyObject*)__pyx_t_4);
    __pyx_t_4 = 0;
    goto __pyx_L0;
  }
  __pyx_L3:;

  __pyx_r = ((PyObject*)Py_None); __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("axon._objects.c_as_tuple", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_objects.pxd":58
 *         return tuple(ob)
 * 
 * cdef inline unicode c_as_unicode(object ob):             # <<<<<<<<<<<<<<
 *     tp = type(ob)
 *     if tp is unicode:
 */

static CYTHON_INLINE PyObject *__pyx_f_4axon_8_objects_c_as_unicode(PyObject *__pyx_v_ob) {
  PyObject *__pyx_v_tp = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("c_as_unicode", 0);

  /* "axon/_objects.pxd":59
 * 
 * cdef inline unicode c_as_unicode(object ob):
 *     tp = type(ob)             # <<<<<<<<<<<<<<
 *     if tp is unicode:
 *         return <unicode>ob
 */
  __Pyx_INCREF(((PyObject *)Py_TYPE(__pyx_v_ob)));
  __pyx_v_tp = ((PyObject*)((PyObject *)Py_TYPE(__pyx_v_ob)));

  /* "axon/_objects.pxd":60
 * cdef inline unicode c_as_unicode(object ob):
 *     tp = type(ob)
 *     if tp is unicode:             # <<<<<<<<<<<<<<
 *         return <unicode>ob
 *     elif tp == c_str_type:
 */
  __pyx_t_1 = (__pyx_v_tp == ((PyObject*)(&PyUnicode_Type)));
  __pyx_t_2 = (__pyx_t_1 != 0);
  if (__pyx_t_2) {

    /* "axon/_objects.pxd":61
 *     tp = type(ob)
 *     if tp is unicode:
 *         return <unicode>ob             # <<<<<<<<<<<<<<
 *     elif tp == c_str_type:
 *         return unicode(ob)
 */
    __Pyx_XDECREF(((PyObject *)__pyx_r));
    __Pyx_INCREF(((PyObject *)((PyObject*)__pyx_v_ob)));
    __pyx_r = ((PyObject*)__pyx_v_ob);
    goto __pyx_L0;
    goto __pyx_L3;
  }

  /* "axon/_objects.pxd":62
 *     if tp is unicode:
 *         return <unicode>ob
 *     elif tp == c_str_type:             # <<<<<<<<<<<<<<
 *         return unicode(ob)
 *     elif ob is None:
 */
  __pyx_t_3 = PyObject_RichCompare(((PyObject *)__pyx_v_tp), __pyx_v_4axon_8_objects_c_str_type, Py_EQ); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[4]; __pyx_lineno = 62; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely(__pyx_t_2 < 0)) {__pyx_filename = __pyx_f[4]; __pyx_lineno = 62; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (__pyx_t_2) {

    /* "axon/_objects.pxd":63
 *         return <unicode>ob
 *     elif tp == c_str_type:
 *         return unicode(ob)             # <<<<<<<<<<<<<<
 *     elif ob is None:
 *         return unicode('')
 */
    __Pyx_XDECREF(((PyObject *)__pyx_r));
    __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[4]; __pyx_lineno = 63; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_INCREF(__pyx_v_ob);
    PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_v_ob);
    __Pyx_GIVEREF(__pyx_v_ob);
    __pyx_t_4 = PyObject_Call(((PyObject *)((PyObject*)(&PyUnicode_Type))), ((PyObject *)__pyx_t_3), NULL); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[4]; __pyx_lineno = 63; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(((PyObject *)__pyx_t_3)); __pyx_t_3 = 0;
    __pyx_r = ((PyObject*)__pyx_t_4);
    __pyx_t_4 = 0;
    goto __pyx_L0;
    goto __pyx_L3;
  }

  /* "axon/_objects.pxd":64
 *     elif tp == c_str_type:
 *         return unicode(ob)
 *     elif ob is None:             # <<<<<<<<<<<<<<
 *         return unicode('')
 *     else:
 */
  __pyx_t_2 = (__pyx_v_ob == Py_None);
  __pyx_t_1 = (__pyx_t_2 != 0);
  if (__pyx_t_1) {

    /* "axon/_objects.pxd":65
 *         return unicode(ob)
 *     elif ob is None:
 *         return unicode('')             # <<<<<<<<<<<<<<
 *     else:
 *         raise TypeError('This object %r is not unicode compatible' % ob)
 */
    __Pyx_XDECREF(((PyObject *)__pyx_r));
    __pyx_t_4 = PyObject_Call(((PyObject *)((PyObject*)(&PyUnicode_Type))), ((PyObject *)__pyx_k_tuple_43), NULL); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[4]; __pyx_lineno = 65; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_r = ((PyObject*)__pyx_t_4);
    __pyx_t_4 = 0;
    goto __pyx_L0;
    goto __pyx_L3;
  }
  /*else*/ {

    /* "axon/_objects.pxd":67
 *         return unicode('')
 *     else:
 *         raise TypeError('This object %r is not unicode compatible' % ob)             # <<<<<<<<<<<<<<
 * 
 * cdef inline unicode c_as_name(object name):
 */
    __pyx_t_4 = PyNumber_Remainder(((PyObject *)__pyx_kp_u_44), __pyx_v_ob); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[4]; __pyx_lineno = 67; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(((PyObject *)__pyx_t_4));
    __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[4]; __pyx_lineno = 67; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_3, 0, ((PyObject *)__pyx_t_4));
    __Pyx_GIVEREF(((PyObject *)__pyx_t_4));
    __pyx_t_4 = 0;
    __pyx_t_4 = PyObject_Call(__pyx_builtin_TypeError, ((PyObject *)__pyx_t_3), NULL); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[4]; __pyx_lineno = 67; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(((PyObject *)__pyx_t_3)); __pyx_t_3 = 0;
    __Pyx_Raise(__pyx_t_4, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    {__pyx_filename = __pyx_f[4]; __pyx_lineno = 67; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }
  __pyx_L3:;

  __pyx_r = ((PyObject*)Py_None); __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("axon._objects.c_as_unicode", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_tp);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_objects.pxd":69
 *         raise TypeError('This object %r is not unicode compatible' % ob)
 * 
 * cdef inline unicode c_as_name(object name):             # <<<<<<<<<<<<<<
 *     n = name_cache.get(name, None)
 *     if n is None:
 */

static CYTHON_INLINE PyObject *__pyx_f_4axon_8_objects_c_as_name(PyObject *__pyx_v_name) {
  PyObject *__pyx_v_n = NULL;
  PyObject *__pyx_v_uname = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("c_as_name", 0);

  /* "axon/_objects.pxd":70
 * 
 * cdef inline unicode c_as_name(object name):
 *     n = name_cache.get(name, None)             # <<<<<<<<<<<<<<
 *     if n is None:
 *         uname = c_as_unicode(name)
 */
  if (unlikely(((PyObject *)__pyx_v_4axon_8_objects_name_cache) == Py_None)) {
    PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%s'", "get");
    {__pyx_filename = __pyx_f[4]; __pyx_lineno = 70; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }
  __pyx_t_1 = __Pyx_PyDict_GetItemDefault(((PyObject *)__pyx_v_4axon_8_objects_name_cache), __pyx_v_name, Py_None); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[4]; __pyx_lineno = 70; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_n = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "axon/_objects.pxd":71
 * cdef inline unicode c_as_name(object name):
 *     n = name_cache.get(name, None)
 *     if n is None:             # <<<<<<<<<<<<<<
 *         uname = c_as_unicode(name)
 *         name_cache[name] = uname
 */
  __pyx_t_2 = (__pyx_v_n == Py_None);
  __pyx_t_3 = (__pyx_t_2 != 0);
  if (__pyx_t_3) {

    /* "axon/_objects.pxd":72
 *     n = name_cache.get(name, None)
 *     if n is None:
 *         uname = c_as_unicode(name)             # <<<<<<<<<<<<<<
 *         name_cache[name] = uname
 *     elif name is None:
 */
    __pyx_t_1 = ((PyObject *)__pyx_f_4axon_8_objects_c_as_unicode(__pyx_v_name)); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[4]; __pyx_lineno = 72; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_v_uname = __pyx_t_1;
    __pyx_t_1 = 0;

    /* "axon/_objects.pxd":73
 *     if n is None:
 *         uname = c_as_unicode(name)
 *         name_cache[name] = uname             # <<<<<<<<<<<<<<
 *     elif name is None:
 *         uname = empty_name
 */
    if (unlikely(((PyObject *)__pyx_v_4axon_8_objects_name_cache) == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      {__pyx_filename = __pyx_f[4]; __pyx_lineno = 73; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    }
    if (PyDict_SetItem(((PyObject *)__pyx_v_4axon_8_objects_name_cache), __pyx_v_name, __pyx_v_uname) < 0) {__pyx_filename = __pyx_f[4]; __pyx_lineno = 73; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    goto __pyx_L3;
  }

  /* "axon/_objects.pxd":74
 *         uname = c_as_unicode(name)
 *         name_cache[name] = uname
 *     elif name is None:             # <<<<<<<<<<<<<<
 *         uname = empty_name
 *     else:
 */
  __pyx_t_3 = (__pyx_v_name == Py_None);
  __pyx_t_2 = (__pyx_t_3 != 0);
  if (__pyx_t_2) {

    /* "axon/_objects.pxd":75
 *         name_cache[name] = uname
 *     elif name is None:
 *         uname = empty_name             # <<<<<<<<<<<<<<
 *     else:
 *         uname = n
 */
    __Pyx_INCREF(((PyObject *)__pyx_v_4axon_8_objects_empty_name));
    __pyx_v_uname = ((PyObject *)__pyx_v_4axon_8_objects_empty_name);
    goto __pyx_L3;
  }
  /*else*/ {

    /* "axon/_objects.pxd":77
 *         uname = empty_name
 *     else:
 *         uname = n             # <<<<<<<<<<<<<<
 *     return uname
 * 
 */
    __Pyx_INCREF(__pyx_v_n);
    __pyx_v_uname = __pyx_v_n;
  }
  __pyx_L3:;

  /* "axon/_objects.pxd":78
 *     else:
 *         uname = n
 *     return uname             # <<<<<<<<<<<<<<
 * 
 * cdef inline object py_as_name(object name):
 */
  __Pyx_XDECREF(((PyObject *)__pyx_r));
  if (!(likely(PyUnicode_CheckExact(__pyx_v_uname))||((__pyx_v_uname) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected unicode, got %.200s", Py_TYPE(__pyx_v_uname)->tp_name), 0))) {__pyx_filename = __pyx_f[4]; __pyx_lineno = 78; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_INCREF(__pyx_v_uname);
  __pyx_r = ((PyObject*)__pyx_v_uname);
  goto __pyx_L0;

  __pyx_r = ((PyObject*)Py_None); __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("axon._objects.c_as_name", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_n);
  __Pyx_XDECREF(__pyx_v_uname);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_objects.pxd":80
 *     return uname
 * 
 * cdef inline object py_as_name(object name):             # <<<<<<<<<<<<<<
 *     n = name_cache.get(name, None)
 *     if n is None:
 */

static CYTHON_INLINE PyObject *__pyx_f_4axon_8_objects_py_as_name(PyObject *__pyx_v_name) {
  PyObject *__pyx_v_n = NULL;
  PyObject *__pyx_v_uname = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("py_as_name", 0);

  /* "axon/_objects.pxd":81
 * 
 * cdef inline object py_as_name(object name):
 *     n = name_cache.get(name, None)             # <<<<<<<<<<<<<<
 *     if n is None:
 *         uname = c_as_unicode(name)
 */
  if (unlikely(((PyObject *)__pyx_v_4axon_8_objects_name_cache) == Py_None)) {
    PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%s'", "get");
    {__pyx_filename = __pyx_f[4]; __pyx_lineno = 81; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }
  __pyx_t_1 = __Pyx_PyDict_GetItemDefault(((PyObject *)__pyx_v_4axon_8_objects_name_cache), __pyx_v_name, Py_None); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[4]; __pyx_lineno = 81; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_n = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "axon/_objects.pxd":82
 * cdef inline object py_as_name(object name):
 *     n = name_cache.get(name, None)
 *     if n is None:             # <<<<<<<<<<<<<<
 *         uname = c_as_unicode(name)
 *         name_cache[name] = uname
 */
  __pyx_t_2 = (__pyx_v_n == Py_None);
  __pyx_t_3 = (__pyx_t_2 != 0);
  if (__pyx_t_3) {

    /* "axon/_objects.pxd":83
 *     n = name_cache.get(name, None)
 *     if n is None:
 *         uname = c_as_unicode(name)             # <<<<<<<<<<<<<<
 *         name_cache[name] = uname
 *     elif name is None:
 */
    __pyx_t_1 = ((PyObject *)__pyx_f_4axon_8_objects_c_as_unicode(__pyx_v_name)); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[4]; __pyx_lineno = 83; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_v_uname = __pyx_t_1;
    __pyx_t_1 = 0;

    /* "axon/_objects.pxd":84
 *     if n is None:
 *         uname = c_as_unicode(name)
 *         name_cache[name] = uname             # <<<<<<<<<<<<<<
 *     elif name is None:
 *         uname = empty_name
 */
    if (unlikely(((PyObject *)__pyx_v_4axon_8_objects_name_cache) == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      {__pyx_filename = __pyx_f[4]; __pyx_lineno = 84; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    }
    if (PyDict_SetItem(((PyObject *)__pyx_v_4axon_8_objects_name_cache), __pyx_v_name, __pyx_v_uname) < 0) {__pyx_filename = __pyx_f[4]; __pyx_lineno = 84; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    goto __pyx_L3;
  }

  /* "axon/_objects.pxd":85
 *         uname = c_as_unicode(name)
 *         name_cache[name] = uname
 *     elif name is None:             # <<<<<<<<<<<<<<
 *         uname = empty_name
 *     else:
 */
  __pyx_t_3 = (__pyx_v_name == Py_None);
  __pyx_t_2 = (__pyx_t_3 != 0);
  if (__pyx_t_2) {

    /* "axon/_objects.pxd":86
 *         name_cache[name] = uname
 *     elif name is None:
 *         uname = empty_name             # <<<<<<<<<<<<<<
 *     else:
 *         uname = n
 */
    __Pyx_INCREF(((PyObject *)__pyx_v_4axon_8_objects_empty_name));
    __pyx_v_uname = ((PyObject *)__pyx_v_4axon_8_objects_empty_name);
    goto __pyx_L3;
  }
  /*else*/ {

    /* "axon/_objects.pxd":88
 *         uname = empty_name
 *     else:
 *         uname = n             # <<<<<<<<<<<<<<
 *     return uname
 * 
 */
    __Pyx_INCREF(__pyx_v_n);
    __pyx_v_uname = __pyx_v_n;
  }
  __pyx_L3:;

  /* "axon/_objects.pxd":89
 *     else:
 *         uname = n
 *     return uname             # <<<<<<<<<<<<<<
 * 
 * # ----------------------------------------
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_uname);
  __pyx_r = __pyx_v_uname;
  goto __pyx_L0;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("axon._objects.py_as_name", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_n);
  __Pyx_XDECREF(__pyx_v_uname);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static struct __pyx_obj_4axon_7_loader___pyx_scope_struct__factory *__pyx_freelist_4axon_7_loader___pyx_scope_struct__factory[8];
static int __pyx_freecount_4axon_7_loader___pyx_scope_struct__factory = 0;

static PyObject *__pyx_tp_new_4axon_7_loader___pyx_scope_struct__factory(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  struct __pyx_obj_4axon_7_loader___pyx_scope_struct__factory *p;
  PyObject *o;
  if (likely((__pyx_freecount_4axon_7_loader___pyx_scope_struct__factory > 0) & (t->tp_basicsize == sizeof(struct __pyx_obj_4axon_7_loader___pyx_scope_struct__factory)))) {
    o = (PyObject*)__pyx_freelist_4axon_7_loader___pyx_scope_struct__factory[--__pyx_freecount_4axon_7_loader___pyx_scope_struct__factory];
    memset(o, 0, sizeof(struct __pyx_obj_4axon_7_loader___pyx_scope_struct__factory));
    PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  p = ((struct __pyx_obj_4axon_7_loader___pyx_scope_struct__factory *)o);
  p->__pyx_v_name = 0;
  return o;
}

static void __pyx_tp_dealloc_4axon_7_loader___pyx_scope_struct__factory(PyObject *o) {
  struct __pyx_obj_4axon_7_loader___pyx_scope_struct__factory *p = (struct __pyx_obj_4axon_7_loader___pyx_scope_struct__factory *)o;
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_v_name);
  if ((__pyx_freecount_4axon_7_loader___pyx_scope_struct__factory < 8) & (Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_4axon_7_loader___pyx_scope_struct__factory))) {
    __pyx_freelist_4axon_7_loader___pyx_scope_struct__factory[__pyx_freecount_4axon_7_loader___pyx_scope_struct__factory++] = ((struct __pyx_obj_4axon_7_loader___pyx_scope_struct__factory *)o);
  } else {
    (*Py_TYPE(o)->tp_free)(o);
  }
}

static int __pyx_tp_traverse_4axon_7_loader___pyx_scope_struct__factory(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_4axon_7_loader___pyx_scope_struct__factory *p = (struct __pyx_obj_4axon_7_loader___pyx_scope_struct__factory *)o;
  if (p->__pyx_v_name) {
    e = (*v)(p->__pyx_v_name, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_4axon_7_loader___pyx_scope_struct__factory(PyObject *o) {
  struct __pyx_obj_4axon_7_loader___pyx_scope_struct__factory *p = (struct __pyx_obj_4axon_7_loader___pyx_scope_struct__factory *)o;
  PyObject* tmp;
  tmp = ((PyObject*)p->__pyx_v_name);
  p->__pyx_v_name = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyMethodDef __pyx_methods_4axon_7_loader___pyx_scope_struct__factory[] = {
  {0, 0, 0, 0}
};

static PyTypeObject __pyx_type_4axon_7_loader___pyx_scope_struct__factory = {
  PyVarObject_HEAD_INIT(0, 0)
  __Pyx_NAMESTR("axon._loader.__pyx_scope_struct__factory"), /*tp_name*/
  sizeof(struct __pyx_obj_4axon_7_loader___pyx_scope_struct__factory), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_4axon_7_loader___pyx_scope_struct__factory, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #else
  0, /*reserved*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_4axon_7_loader___pyx_scope_struct__factory, /*tp_traverse*/
  __pyx_tp_clear_4axon_7_loader___pyx_scope_struct__factory, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_4axon_7_loader___pyx_scope_struct__factory, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_4axon_7_loader___pyx_scope_struct__factory, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  #if PY_VERSION_HEX >= 0x02060000
  0, /*tp_version_tag*/
  #endif
};

static PyObject *__pyx_tp_new_4axon_7_loader_Builder(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  o = (*t->tp_alloc)(t, 0);
  if (unlikely(!o)) return 0;
  return o;
}

static void __pyx_tp_dealloc_4axon_7_loader_Builder(PyObject *o) {
  (*Py_TYPE(o)->tp_free)(o);
}

static PyMethodDef __pyx_methods_4axon_7_loader_Builder[] = {
  {0, 0, 0, 0}
};

DL_EXPORT(PyTypeObject) BuilderType = {
  PyVarObject_HEAD_INIT(0, 0)
  __Pyx_NAMESTR("axon._loader.Builder"), /*tp_name*/
  sizeof(struct Builder), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_4axon_7_loader_Builder, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #else
  0, /*reserved*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE, /*tp_flags*/
  0, /*tp_doc*/
  0, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_4axon_7_loader_Builder, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_4axon_7_loader_Builder, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  #if PY_VERSION_HEX >= 0x02060000
  0, /*tp_version_tag*/
  #endif
};
static struct __pyx_vtabstruct_4axon_7_loader_FixedOffsetTZ __pyx_vtable_4axon_7_loader_FixedOffsetTZ;

static PyObject *__pyx_tp_new_4axon_7_loader_FixedOffsetTZ(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct FixedOffsetTZObject *p;
  PyObject *o = __pyx_ptype_7cpython_8datetime_tzinfo->tp_new(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct FixedOffsetTZObject *)o);
  p->__pyx_vtab = __pyx_vtabptr_4axon_7_loader_FixedOffsetTZ;
  p->minutes = Py_None; Py_INCREF(Py_None);
  return o;
}

static void __pyx_tp_dealloc_4axon_7_loader_FixedOffsetTZ(PyObject *o) {
  struct FixedOffsetTZObject *p = (struct FixedOffsetTZObject *)o;
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->minutes);
  PyObject_GC_Track(o);
  if (likely(__pyx_ptype_7cpython_8datetime_tzinfo)) __pyx_ptype_7cpython_8datetime_tzinfo->tp_dealloc(o); else __Pyx_call_next_tp_dealloc(o, __pyx_tp_dealloc_4axon_7_loader_FixedOffsetTZ);
}

static int __pyx_tp_traverse_4axon_7_loader_FixedOffsetTZ(PyObject *o, visitproc v, void *a) {
  int e;
  struct FixedOffsetTZObject *p = (struct FixedOffsetTZObject *)o;
  e = ((likely(__pyx_ptype_7cpython_8datetime_tzinfo)) ? ((__pyx_ptype_7cpython_8datetime_tzinfo->tp_traverse) ? __pyx_ptype_7cpython_8datetime_tzinfo->tp_traverse(o, v, a) : 0) : __Pyx_call_next_tp_traverse(o, v, a, __pyx_tp_traverse_4axon_7_loader_FixedOffsetTZ)); if (e) return e;
  if (p->minutes) {
    e = (*v)(p->minutes, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_4axon_7_loader_FixedOffsetTZ(PyObject *o) {
  struct FixedOffsetTZObject *p = (struct FixedOffsetTZObject *)o;
  PyObject* tmp;
  if (likely(__pyx_ptype_7cpython_8datetime_tzinfo)) { if (__pyx_ptype_7cpython_8datetime_tzinfo->tp_clear) __pyx_ptype_7cpython_8datetime_tzinfo->tp_clear(o); } else __Pyx_call_next_tp_clear(o, __pyx_tp_clear_4axon_7_loader_FixedOffsetTZ);
  tmp = ((PyObject*)p->minutes);
  p->minutes = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyObject *__pyx_getprop_4axon_7_loader_13FixedOffsetTZ_minutes(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_4axon_7_loader_13FixedOffsetTZ_7minutes_1__get__(o);
}

static int __pyx_setprop_4axon_7_loader_13FixedOffsetTZ_minutes(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_4axon_7_loader_13FixedOffsetTZ_7minutes_3__set__(o, v);
  }
  else {
    return __pyx_pw_4axon_7_loader_13FixedOffsetTZ_7minutes_5__del__(o);
  }
}

static PyMethodDef __pyx_methods_4axon_7_loader_FixedOffsetTZ[] = {
  {__Pyx_NAMESTR("utcoffset"), (PyCFunction)__pyx_pw_4axon_7_loader_13FixedOffsetTZ_3utcoffset, METH_O, __Pyx_DOCSTR(0)},
  {__Pyx_NAMESTR("tzname"), (PyCFunction)__pyx_pw_4axon_7_loader_13FixedOffsetTZ_5tzname, METH_O, __Pyx_DOCSTR(0)},
  {__Pyx_NAMESTR("dst"), (PyCFunction)__pyx_pw_4axon_7_loader_13FixedOffsetTZ_7dst, METH_O, __Pyx_DOCSTR(0)},
  {0, 0, 0, 0}
};

static struct PyGetSetDef __pyx_getsets_4axon_7_loader_FixedOffsetTZ[] = {
  {(char *)"minutes", __pyx_getprop_4axon_7_loader_13FixedOffsetTZ_minutes, __pyx_setprop_4axon_7_loader_13FixedOffsetTZ_minutes, 0, 0},
  {0, 0, 0, 0, 0}
};

DL_EXPORT(PyTypeObject) FixedOffsetTZType = {
  PyVarObject_HEAD_INIT(0, 0)
  __Pyx_NAMESTR("axon._loader.FixedOffsetTZ"), /*tp_name*/
  sizeof(struct FixedOffsetTZObject), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_4axon_7_loader_FixedOffsetTZ, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #else
  0, /*reserved*/
  #endif
  __pyx_pw_4axon_7_loader_13FixedOffsetTZ_11__repr__, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  __pyx_pw_4axon_7_loader_13FixedOffsetTZ_9__str__, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  __Pyx_DOCSTR("Fixed offset in minutes east from UTC."), /*tp_doc*/
  __pyx_tp_traverse_4axon_7_loader_FixedOffsetTZ, /*tp_traverse*/
  __pyx_tp_clear_4axon_7_loader_FixedOffsetTZ, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_4axon_7_loader_FixedOffsetTZ, /*tp_methods*/
  0, /*tp_members*/
  __pyx_getsets_4axon_7_loader_FixedOffsetTZ, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  __pyx_pw_4axon_7_loader_13FixedOffsetTZ_1__init__, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_4axon_7_loader_FixedOffsetTZ, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  #if PY_VERSION_HEX >= 0x02060000
  0, /*tp_version_tag*/
  #endif
};

static PyObject *__pyx_tp_new_4axon_7_loader_SimpleBuilder(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  o = (*t->tp_alloc)(t, 0);
  if (unlikely(!o)) return 0;
  return o;
}

static void __pyx_tp_dealloc_4axon_7_loader_SimpleBuilder(PyObject *o) {
  (*Py_TYPE(o)->tp_free)(o);
}

static PyMethodDef __pyx_methods_4axon_7_loader_SimpleBuilder[] = {
  {0, 0, 0, 0}
};

DL_EXPORT(PyTypeObject) SimpleBuilderType = {
  PyVarObject_HEAD_INIT(0, 0)
  __Pyx_NAMESTR("axon._loader.SimpleBuilder"), /*tp_name*/
  sizeof(struct SimpleBuilder), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_4axon_7_loader_SimpleBuilder, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #else
  0, /*reserved*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE, /*tp_flags*/
  0, /*tp_doc*/
  0, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_4axon_7_loader_SimpleBuilder, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  __pyx_pw_4axon_7_loader_13SimpleBuilder_1__init__, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_4axon_7_loader_SimpleBuilder, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  #if PY_VERSION_HEX >= 0x02060000
  0, /*tp_version_tag*/
  #endif
};
static struct __pyx_vtabstruct_4axon_7_loader_Loader __pyx_vtable_4axon_7_loader_Loader;

static PyObject *__pyx_tp_new_4axon_7_loader_Loader(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  struct __pyx_obj_4axon_7_loader_Loader *p;
  PyObject *o;
  o = (*t->tp_alloc)(t, 0);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_4axon_7_loader_Loader *)o);
  p->__pyx_vtab = __pyx_vtabptr_4axon_7_loader_Loader;
  p->fd = Py_None; Py_INCREF(Py_None);
  p->readline = Py_None; Py_INCREF(Py_None);
  p->encoding = Py_None; Py_INCREF(Py_None);
  p->line = ((PyObject*)Py_None); Py_INCREF(Py_None);
  p->errto = Py_None; Py_INCREF(Py_None);
  p->builder = ((struct Builder *)Py_None); Py_INCREF(Py_None);
  p->sbuilder = ((struct SimpleBuilder *)Py_None); Py_INCREF(Py_None);
  p->c_constants = ((PyObject*)Py_None); Py_INCREF(Py_None);
  p->labeled_objects = ((PyObject*)Py_None); Py_INCREF(Py_None);
  p->ta = ((PyObject*)Py_None); Py_INCREF(Py_None);
  p->da = ((PyObject*)Py_None); Py_INCREF(Py_None);
  p->to = ((PyObject*)Py_None); Py_INCREF(Py_None);
  p->idn_stack = ((PyObject*)Py_None); Py_INCREF(Py_None);
  return o;
}

static void __pyx_tp_dealloc_4axon_7_loader_Loader(PyObject *o) {
  struct __pyx_obj_4axon_7_loader_Loader *p = (struct __pyx_obj_4axon_7_loader_Loader *)o;
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->fd);
  Py_CLEAR(p->readline);
  Py_CLEAR(p->encoding);
  Py_CLEAR(p->line);
  Py_CLEAR(p->errto);
  Py_CLEAR(p->builder);
  Py_CLEAR(p->sbuilder);
  Py_CLEAR(p->c_constants);
  Py_CLEAR(p->labeled_objects);
  Py_CLEAR(p->ta);
  Py_CLEAR(p->da);
  Py_CLEAR(p->to);
  Py_CLEAR(p->idn_stack);
  (*Py_TYPE(o)->tp_free)(o);
}

static int __pyx_tp_traverse_4axon_7_loader_Loader(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_4axon_7_loader_Loader *p = (struct __pyx_obj_4axon_7_loader_Loader *)o;
  if (p->fd) {
    e = (*v)(p->fd, a); if (e) return e;
  }
  if (p->readline) {
    e = (*v)(p->readline, a); if (e) return e;
  }
  if (p->encoding) {
    e = (*v)(p->encoding, a); if (e) return e;
  }
  if (p->line) {
    e = (*v)(p->line, a); if (e) return e;
  }
  if (p->errto) {
    e = (*v)(p->errto, a); if (e) return e;
  }
  if (p->builder) {
    e = (*v)(((PyObject*)p->builder), a); if (e) return e;
  }
  if (p->sbuilder) {
    e = (*v)(((PyObject*)p->sbuilder), a); if (e) return e;
  }
  if (p->c_constants) {
    e = (*v)(p->c_constants, a); if (e) return e;
  }
  if (p->labeled_objects) {
    e = (*v)(p->labeled_objects, a); if (e) return e;
  }
  if (p->ta) {
    e = (*v)(p->ta, a); if (e) return e;
  }
  if (p->da) {
    e = (*v)(p->da, a); if (e) return e;
  }
  if (p->to) {
    e = (*v)(p->to, a); if (e) return e;
  }
  if (p->idn_stack) {
    e = (*v)(p->idn_stack, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_4axon_7_loader_Loader(PyObject *o) {
  struct __pyx_obj_4axon_7_loader_Loader *p = (struct __pyx_obj_4axon_7_loader_Loader *)o;
  PyObject* tmp;
  tmp = ((PyObject*)p->fd);
  p->fd = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->readline);
  p->readline = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->encoding);
  p->encoding = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->line);
  p->line = ((PyObject*)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->errto);
  p->errto = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->builder);
  p->builder = ((struct Builder *)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->sbuilder);
  p->sbuilder = ((struct SimpleBuilder *)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->c_constants);
  p->c_constants = ((PyObject*)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->labeled_objects);
  p->labeled_objects = ((PyObject*)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->ta);
  p->ta = ((PyObject*)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->da);
  p->da = ((PyObject*)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->to);
  p->to = ((PyObject*)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->idn_stack);
  p->idn_stack = ((PyObject*)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyObject *__pyx_getprop_4axon_7_loader_6Loader_line(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_4axon_7_loader_6Loader_4line_1__get__(o);
}

static int __pyx_setprop_4axon_7_loader_6Loader_line(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_4axon_7_loader_6Loader_4line_3__set__(o, v);
  }
  else {
    return __pyx_pw_4axon_7_loader_6Loader_4line_5__del__(o);
  }
}

static PyObject *__pyx_getprop_4axon_7_loader_6Loader_pos(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_4axon_7_loader_6Loader_3pos_1__get__(o);
}

static int __pyx_setprop_4axon_7_loader_6Loader_pos(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_4axon_7_loader_6Loader_3pos_3__set__(o, v);
  }
  else {
    PyErr_SetString(PyExc_NotImplementedError, "__del__");
    return -1;
  }
}

static PyObject *__pyx_getprop_4axon_7_loader_6Loader_lnum(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_4axon_7_loader_6Loader_4lnum_1__get__(o);
}

static int __pyx_setprop_4axon_7_loader_6Loader_lnum(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_4axon_7_loader_6Loader_4lnum_3__set__(o, v);
  }
  else {
    PyErr_SetString(PyExc_NotImplementedError, "__del__");
    return -1;
  }
}

static PyObject *__pyx_getprop_4axon_7_loader_6Loader_errto(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_4axon_7_loader_6Loader_5errto_1__get__(o);
}

static int __pyx_setprop_4axon_7_loader_6Loader_errto(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_4axon_7_loader_6Loader_5errto_3__set__(o, v);
  }
  else {
    return __pyx_pw_4axon_7_loader_6Loader_5errto_5__del__(o);
  }
}

static PyObject *__pyx_getprop_4axon_7_loader_6Loader_idn(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_4axon_7_loader_6Loader_3idn_1__get__(o);
}

static int __pyx_setprop_4axon_7_loader_6Loader_idn(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_4axon_7_loader_6Loader_3idn_3__set__(o, v);
  }
  else {
    PyErr_SetString(PyExc_NotImplementedError, "__del__");
    return -1;
  }
}

static PyMethodDef __pyx_methods_4axon_7_loader_Loader[] = {
  {__Pyx_NAMESTR("__next__"), (PyCFunction)__pyx_pw_4axon_7_loader_6Loader_3__next__, METH_NOARGS|METH_COEXIST, __Pyx_DOCSTR(__pyx_doc_4axon_7_loader_6Loader_2__next__)},
  {__Pyx_NAMESTR("_check_pairs"), (PyCFunction)__pyx_pw_4axon_7_loader_6Loader_5_check_pairs, METH_NOARGS, __Pyx_DOCSTR(0)},
  {__Pyx_NAMESTR("load"), (PyCFunction)__pyx_pw_4axon_7_loader_6Loader_7load, METH_NOARGS, __Pyx_DOCSTR(__pyx_doc_4axon_7_loader_6Loader_6load)},
  {__Pyx_NAMESTR("get_empty_sequence"), (PyCFunction)__pyx_pw_4axon_7_loader_6Loader_11get_empty_sequence, METH_VARARGS|METH_KEYWORDS, __Pyx_DOCSTR(0)},
  {__Pyx_NAMESTR("get_empty_mapping"), (PyCFunction)__pyx_pw_4axon_7_loader_6Loader_13get_empty_mapping, METH_VARARGS|METH_KEYWORDS, __Pyx_DOCSTR(0)},
  {0, 0, 0, 0}
};

static struct PyGetSetDef __pyx_getsets_4axon_7_loader_Loader[] = {
  {(char *)"line", __pyx_getprop_4axon_7_loader_6Loader_line, __pyx_setprop_4axon_7_loader_6Loader_line, 0, 0},
  {(char *)"pos", __pyx_getprop_4axon_7_loader_6Loader_pos, __pyx_setprop_4axon_7_loader_6Loader_pos, 0, 0},
  {(char *)"lnum", __pyx_getprop_4axon_7_loader_6Loader_lnum, __pyx_setprop_4axon_7_loader_6Loader_lnum, 0, 0},
  {(char *)"errto", __pyx_getprop_4axon_7_loader_6Loader_errto, __pyx_setprop_4axon_7_loader_6Loader_errto, 0, 0},
  {(char *)"idn", __pyx_getprop_4axon_7_loader_6Loader_idn, __pyx_setprop_4axon_7_loader_6Loader_idn, 0, 0},
  {0, 0, 0, 0, 0}
};

static PyTypeObject __pyx_type_4axon_7_loader_Loader = {
  PyVarObject_HEAD_INIT(0, 0)
  __Pyx_NAMESTR("axon._loader.Loader"), /*tp_name*/
  sizeof(struct __pyx_obj_4axon_7_loader_Loader), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_4axon_7_loader_Loader, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #else
  0, /*reserved*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  __Pyx_DOCSTR("\n    Loader from line oriented unicode text inputs.\n\n    .. py:attribute:: line\n\n        Current input unicode line\n\n    .. py:attribute:: pos\n\n        Position of current unicode character\n\n    .. py:attribute:: lnum\n\n        Number of current input unicode line\n\n    .. py:attribute:: errto\n\n        Name of file for reporting errors\n\n    "), /*tp_doc*/
  __pyx_tp_traverse_4axon_7_loader_Loader, /*tp_traverse*/
  __pyx_tp_clear_4axon_7_loader_Loader, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  __pyx_pw_4axon_7_loader_6Loader_9__iter__, /*tp_iter*/
  __pyx_pw_4axon_7_loader_6Loader_3__next__, /*tp_iternext*/
  __pyx_methods_4axon_7_loader_Loader, /*tp_methods*/
  0, /*tp_members*/
  __pyx_getsets_4axon_7_loader_Loader, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  __pyx_pw_4axon_7_loader_6Loader_1__init__, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_4axon_7_loader_Loader, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  #if PY_VERSION_HEX >= 0x02060000
  0, /*tp_version_tag*/
  #endif
};

static PyMethodDef __pyx_methods[] = {
  {0, 0, 0, 0}
};

#if PY_MAJOR_VERSION >= 3
static struct PyModuleDef __pyx_moduledef = {
  #if PY_VERSION_HEX < 0x03020000
    { PyObject_HEAD_INIT(NULL) NULL, 0, NULL },
  #else
    PyModuleDef_HEAD_INIT,
  #endif
    __Pyx_NAMESTR("_loader"),
    0, /* m_doc */
    -1, /* m_size */
    __pyx_methods /* m_methods */,
    NULL, /* m_reload */
    NULL, /* m_traverse */
    NULL, /* m_clear */
    NULL /* m_free */
};
#endif

static __Pyx_StringTabEntry __pyx_string_tab[] = {
  {&__pyx_kp_u_11, __pyx_k_11, sizeof(__pyx_k_11), 0, 1, 0, 0},
  {&__pyx_kp_u_14, __pyx_k_14, sizeof(__pyx_k_14), 0, 1, 0, 0},
  {&__pyx_kp_u_15, __pyx_k_15, sizeof(__pyx_k_15), 0, 1, 0, 0},
  {&__pyx_kp_u_16, __pyx_k_16, sizeof(__pyx_k_16), 0, 1, 0, 0},
  {&__pyx_kp_u_17, __pyx_k_17, sizeof(__pyx_k_17), 0, 1, 0, 0},
  {&__pyx_kp_u_18, __pyx_k_18, sizeof(__pyx_k_18), 0, 1, 0, 0},
  {&__pyx_kp_u_19, __pyx_k_19, sizeof(__pyx_k_19), 0, 1, 0, 0},
  {&__pyx_kp_u_20, __pyx_k_20, sizeof(__pyx_k_20), 0, 1, 0, 0},
  {&__pyx_kp_u_21, __pyx_k_21, sizeof(__pyx_k_21), 0, 1, 0, 0},
  {&__pyx_kp_u_22, __pyx_k_22, sizeof(__pyx_k_22), 0, 1, 0, 0},
  {&__pyx_n_s_23, __pyx_k_23, sizeof(__pyx_k_23), 0, 0, 1, 1},
  {&__pyx_n_s_24, __pyx_k_24, sizeof(__pyx_k_24), 0, 0, 1, 1},
  {&__pyx_n_s_25, __pyx_k_25, sizeof(__pyx_k_25), 0, 0, 1, 1},
  {&__pyx_kp_u_26, __pyx_k_26, sizeof(__pyx_k_26), 0, 1, 0, 0},
  {&__pyx_kp_u_27, __pyx_k_27, sizeof(__pyx_k_27), 0, 1, 0, 0},
  {&__pyx_kp_u_28, __pyx_k_28, sizeof(__pyx_k_28), 0, 1, 0, 0},
  {&__pyx_kp_u_29, __pyx_k_29, sizeof(__pyx_k_29), 0, 1, 0, 0},
  {&__pyx_kp_s_3, __pyx_k_3, sizeof(__pyx_k_3), 0, 0, 1, 0},
  {&__pyx_kp_u_30, __pyx_k_30, sizeof(__pyx_k_30), 0, 1, 0, 0},
  {&__pyx_kp_u_31, __pyx_k_31, sizeof(__pyx_k_31), 0, 1, 0, 0},
  {&__pyx_kp_u_32, __pyx_k_32, sizeof(__pyx_k_32), 0, 1, 0, 0},
  {&__pyx_kp_u_33, __pyx_k_33, sizeof(__pyx_k_33), 0, 1, 0, 0},
  {&__pyx_kp_u_34, __pyx_k_34, sizeof(__pyx_k_34), 0, 1, 0, 0},
  {&__pyx_n_s_35, __pyx_k_35, sizeof(__pyx_k_35), 0, 0, 1, 1},
  {&__pyx_n_s_36, __pyx_k_36, sizeof(__pyx_k_36), 0, 0, 1, 1},
  {&__pyx_kp_u_37, __pyx_k_37, sizeof(__pyx_k_37), 0, 1, 0, 0},
  {&__pyx_kp_u_38, __pyx_k_38, sizeof(__pyx_k_38), 0, 1, 0, 0},
  {&__pyx_kp_u_39, __pyx_k_39, sizeof(__pyx_k_39), 0, 1, 0, 0},
  {&__pyx_n_s_4, __pyx_k_4, sizeof(__pyx_k_4), 0, 0, 1, 1},
  {&__pyx_kp_u_40, __pyx_k_40, sizeof(__pyx_k_40), 0, 1, 0, 0},
  {&__pyx_kp_u_41, __pyx_k_41, sizeof(__pyx_k_41), 0, 1, 0, 0},
  {&__pyx_kp_u_42, __pyx_k_42, sizeof(__pyx_k_42), 0, 1, 0, 0},
  {&__pyx_kp_u_44, __pyx_k_44, sizeof(__pyx_k_44), 0, 1, 0, 0},
  {&__pyx_n_s_45, __pyx_k_45, sizeof(__pyx_k_45), 0, 0, 1, 1},
  {&__pyx_n_s_46, __pyx_k_46, sizeof(__pyx_k_46), 0, 0, 1, 1},
  {&__pyx_n_s_5, __pyx_k_5, sizeof(__pyx_k_5), 0, 0, 1, 1},
  {&__pyx_n_s_54, __pyx_k_54, sizeof(__pyx_k_54), 0, 0, 1, 1},
  {&__pyx_kp_u_55, __pyx_k_55, sizeof(__pyx_k_55), 0, 1, 0, 0},
  {&__pyx_kp_u_6, __pyx_k_6, sizeof(__pyx_k_6), 0, 1, 0, 0},
  {&__pyx_kp_u_7, __pyx_k_7, sizeof(__pyx_k_7), 0, 1, 0, 0},
  {&__pyx_kp_u_8, __pyx_k_8, sizeof(__pyx_k_8), 0, 1, 0, 0},
  {&__pyx_kp_u_9, __pyx_k_9, sizeof(__pyx_k_9), 0, 1, 0, 0},
  {&__pyx_n_u__Infinity, __pyx_k__Infinity, sizeof(__pyx_k__Infinity), 0, 1, 0, 1},
  {&__pyx_n_u__NaN, __pyx_k__NaN, sizeof(__pyx_k__NaN), 0, 1, 0, 1},
  {&__pyx_n_s__StopIteration, __pyx_k__StopIteration, sizeof(__pyx_k__StopIteration), 0, 0, 1, 1},
  {&__pyx_n_s__TypeError, __pyx_k__TypeError, sizeof(__pyx_k__TypeError), 0, 0, 1, 1},
  {&__pyx_n_s__ValueError, __pyx_k__ValueError, sizeof(__pyx_k__ValueError), 0, 0, 1, 1},
  {&__pyx_n_s____import__, __pyx_k____import__, sizeof(__pyx_k____import__), 0, 0, 1, 1},
  {&__pyx_n_s____main__, __pyx_k____main__, sizeof(__pyx_k____main__), 0, 0, 1, 1},
  {&__pyx_n_s____pyx_capi__, __pyx_k____pyx_capi__, sizeof(__pyx_k____pyx_capi__), 0, 0, 1, 1},
  {&__pyx_n_s____pyx_vtable__, __pyx_k____pyx_vtable__, sizeof(__pyx_k____pyx_vtable__), 0, 0, 1, 1},
  {&__pyx_n_s____test__, __pyx_k____test__, sizeof(__pyx_k____test__), 0, 0, 1, 1},
  {&__pyx_n_s___decimal, __pyx_k___decimal, sizeof(__pyx_k___decimal), 0, 0, 1, 1},
  {&__pyx_n_s___decimal2str, __pyx_k___decimal2str, sizeof(__pyx_k___decimal2str), 0, 0, 1, 1},
  {&__pyx_n_s___factory, __pyx_k___factory, sizeof(__pyx_k___factory), 0, 0, 1, 1},
  {&__pyx_n_s___inf, __pyx_k___inf, sizeof(__pyx_k___inf), 0, 0, 1, 1},
  {&__pyx_n_s___nan, __pyx_k___nan, sizeof(__pyx_k___nan), 0, 0, 1, 1},
  {&__pyx_n_s___ninf, __pyx_k___ninf, sizeof(__pyx_k___ninf), 0, 0, 1, 1},
  {&__pyx_n_s___str2decimal, __pyx_k___str2decimal, sizeof(__pyx_k___str2decimal), 0, 0, 1, 1},
  {&__pyx_n_s__as_name, __pyx_k__as_name, sizeof(__pyx_k__as_name), 0, 0, 1, 1},
  {&__pyx_n_s__base64, __pyx_k__base64, sizeof(__pyx_k__base64), 0, 0, 1, 1},
  {&__pyx_n_s__bool_type, __pyx_k__bool_type, sizeof(__pyx_k__bool_type), 0, 0, 1, 1},
  {&__pyx_n_s__bytes_type, __pyx_k__bytes_type, sizeof(__pyx_k__bytes_type), 0, 0, 1, 1},
  {&__pyx_n_s__c_constants, __pyx_k__c_constants, sizeof(__pyx_k__c_constants), 0, 0, 1, 1},
  {&__pyx_n_s__c_factory_dict, __pyx_k__c_factory_dict, sizeof(__pyx_k__c_factory_dict), 0, 0, 1, 1},
  {&__pyx_n_s__cdecimal, __pyx_k__cdecimal, sizeof(__pyx_k__cdecimal), 0, 0, 1, 1},
  {&__pyx_n_s__close, __pyx_k__close, sizeof(__pyx_k__close), 0, 0, 1, 1},
  {&__pyx_n_s__create_decimal, __pyx_k__create_decimal, sizeof(__pyx_k__create_decimal), 0, 0, 1, 1},
  {&__pyx_n_s__datetime, __pyx_k__datetime, sizeof(__pyx_k__datetime), 0, 0, 1, 1},
  {&__pyx_n_s__decimal, __pyx_k__decimal, sizeof(__pyx_k__decimal), 0, 0, 1, 1},
  {&__pyx_n_s__decodebytes, __pyx_k__decodebytes, sizeof(__pyx_k__decodebytes), 0, 0, 1, 1},
  {&__pyx_n_s__decodestring, __pyx_k__decodestring, sizeof(__pyx_k__decodestring), 0, 0, 1, 1},
  {&__pyx_n_s__error, __pyx_k__error, sizeof(__pyx_k__error), 0, 0, 1, 1},
  {&__pyx_n_s__error_dict_value, __pyx_k__error_dict_value, sizeof(__pyx_k__error_dict_value), 0, 0, 1, 1},
  {&__pyx_n_s__error_getnumber, __pyx_k__error_getnumber, sizeof(__pyx_k__error_getnumber), 0, 0, 1, 1},
  {&__pyx_n_s__error_indentation, __pyx_k__error_indentation, sizeof(__pyx_k__error_indentation), 0, 0, 1, 1},
  {&__pyx_n_s__error_invalid_time, __pyx_k__error_invalid_time, sizeof(__pyx_k__error_invalid_time), 0, 0, 1, 1},
  {&__pyx_n_s__errors, __pyx_k__errors, sizeof(__pyx_k__errors), 0, 0, 1, 1},
  {&__pyx_n_s__errto, __pyx_k__errto, sizeof(__pyx_k__errto), 0, 0, 1, 1},
  {&__pyx_n_s__factory, __pyx_k__factory, sizeof(__pyx_k__factory), 0, 0, 1, 1},
  {&__pyx_n_s__factory_func, __pyx_k__factory_func, sizeof(__pyx_k__factory_func), 0, 0, 1, 1},
  {&__pyx_n_u__false, __pyx_k__false, sizeof(__pyx_k__false), 0, 1, 0, 1},
  {&__pyx_n_s__fd, __pyx_k__fd, sizeof(__pyx_k__fd), 0, 0, 1, 1},
  {&__pyx_n_s__float_type, __pyx_k__float_type, sizeof(__pyx_k__float_type), 0, 0, 1, 1},
  {&__pyx_n_s__get, __pyx_k__get, sizeof(__pyx_k__get), 0, 0, 1, 1},
  {&__pyx_n_s__getcontext, __pyx_k__getcontext, sizeof(__pyx_k__getcontext), 0, 0, 1, 1},
  {&__pyx_n_s__idn, __pyx_k__idn, sizeof(__pyx_k__idn), 0, 0, 1, 1},
  {&__pyx_n_u__inf, __pyx_k__inf, sizeof(__pyx_k__inf), 0, 1, 0, 1},
  {&__pyx_n_s__int_type, __pyx_k__int_type, sizeof(__pyx_k__int_type), 0, 0, 1, 1},
  {&__pyx_n_s__invalid_value, __pyx_k__invalid_value, sizeof(__pyx_k__invalid_value), 0, 0, 1, 1},
  {&__pyx_n_s__json, __pyx_k__json, sizeof(__pyx_k__json), 0, 0, 1, 1},
  {&__pyx_n_s__long_type, __pyx_k__long_type, sizeof(__pyx_k__long_type), 0, 0, 1, 1},
  {&__pyx_n_s__mapping, __pyx_k__mapping, sizeof(__pyx_k__mapping), 0, 0, 1, 1},
  {&__pyx_n_s__minutes, __pyx_k__minutes, sizeof(__pyx_k__minutes), 0, 0, 1, 1},
  {&__pyx_n_u__mixed, __pyx_k__mixed, sizeof(__pyx_k__mixed), 0, 1, 0, 1},
  {&__pyx_n_s__mode, __pyx_k__mode, sizeof(__pyx_k__mode), 0, 0, 1, 1},
  {&__pyx_n_s__name, __pyx_k__name, sizeof(__pyx_k__name), 0, 0, 1, 1},
  {&__pyx_n_u__nan, __pyx_k__nan, sizeof(__pyx_k__nan), 0, 1, 0, 1},
  {&__pyx_n_u__null, __pyx_k__null, sizeof(__pyx_k__null), 0, 1, 0, 1},
  {&__pyx_n_s__open, __pyx_k__open, sizeof(__pyx_k__open), 0, 0, 1, 1},
  {&__pyx_n_s__pydatetime, __pyx_k__pydatetime, sizeof(__pyx_k__pydatetime), 0, 0, 1, 1},
  {&__pyx_n_s__range, __pyx_k__range, sizeof(__pyx_k__range), 0, 0, 1, 1},
  {&__pyx_n_s__readline, __pyx_k__readline, sizeof(__pyx_k__readline), 0, 0, 1, 1},
  {&__pyx_n_s__reset_factory, __pyx_k__reset_factory, sizeof(__pyx_k__reset_factory), 0, 0, 1, 1},
  {&__pyx_n_u__safe, __pyx_k__safe, sizeof(__pyx_k__safe), 0, 1, 0, 1},
  {&__pyx_n_s__sequence, __pyx_k__sequence, sizeof(__pyx_k__sequence), 0, 0, 1, 1},
  {&__pyx_n_s__stderr, __pyx_k__stderr, sizeof(__pyx_k__stderr), 0, 0, 1, 1},
  {&__pyx_n_s__str_type, __pyx_k__str_type, sizeof(__pyx_k__str_type), 0, 0, 1, 1},
  {&__pyx_n_u__strict, __pyx_k__strict, sizeof(__pyx_k__strict), 0, 1, 0, 1},
  {&__pyx_n_s__sys, __pyx_k__sys, sizeof(__pyx_k__sys), 0, 0, 1, 1},
  {&__pyx_n_s__timedelta, __pyx_k__timedelta, sizeof(__pyx_k__timedelta), 0, 0, 1, 1},
  {&__pyx_n_s__to_eng_string, __pyx_k__to_eng_string, sizeof(__pyx_k__to_eng_string), 0, 0, 1, 1},
  {&__pyx_n_u__true, __pyx_k__true, sizeof(__pyx_k__true), 0, 1, 0, 1},
  {&__pyx_n_s__tz_dict, __pyx_k__tz_dict, sizeof(__pyx_k__tz_dict), 0, 0, 1, 1},
  {&__pyx_n_s__tzname, __pyx_k__tzname, sizeof(__pyx_k__tzname), 0, 0, 1, 1},
  {&__pyx_n_s__unicode_type, __pyx_k__unicode_type, sizeof(__pyx_k__unicode_type), 0, 0, 1, 1},
  {&__pyx_n_u__wt, __pyx_k__wt, sizeof(__pyx_k__wt), 0, 1, 0, 1},
  {0, 0, 0, 0, 0, 0, 0}
};
static int __Pyx_InitCachedBuiltins(void) {
  __pyx_builtin_range = __Pyx_GetBuiltinName(__pyx_n_s__range); if (!__pyx_builtin_range) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 71; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_builtin_ValueError = __Pyx_GetBuiltinName(__pyx_n_s__ValueError); if (!__pyx_builtin_ValueError) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 342; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_builtin_open = __Pyx_GetBuiltinName(__pyx_n_s__open); if (!__pyx_builtin_open) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 353; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_builtin_StopIteration = __Pyx_GetBuiltinName(__pyx_n_s__StopIteration); if (!__pyx_builtin_StopIteration) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 378; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_builtin_TypeError = __Pyx_GetBuiltinName(__pyx_n_s__TypeError); if (!__pyx_builtin_TypeError) {__pyx_filename = __pyx_f[4]; __pyx_lineno = 67; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  return 0;
  __pyx_L1_error:;
  return -1;
}

static int __Pyx_InitCachedConstants(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_InitCachedConstants", 0);

  /* "axon/_loader.py":36
 *     name = c_as_unicode(name)
 *     if factory_func is None:
 *         def _factory(factory_func):             # <<<<<<<<<<<<<<
 *             c_factory_dict[c_as_name(name)] = factory_func
 *             return factory_func
 */
  __pyx_k_tuple_1 = PyTuple_Pack(1, ((PyObject *)__pyx_n_s__factory_func)); if (unlikely(!__pyx_k_tuple_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 36; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_1);
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_1));
  __pyx_k_codeobj_2 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_k_tuple_1, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_3, __pyx_n_s___factory, 36, __pyx_empty_bytes); if (unlikely(!__pyx_k_codeobj_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 36; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

  /* "axon/_loader.py":224
 * 
 *     def __str__(self):
 *         return self.tzname(None)             # <<<<<<<<<<<<<<
 * 
 *     def __repr__(self):
 */
  __pyx_k_tuple_10 = PyTuple_Pack(1, Py_None); if (unlikely(!__pyx_k_tuple_10)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 224; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_10);
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_10));

  /* "axon/_loader.py":227
 * 
 *     def __repr__(self):
 *         return "<tz:%s>" % self.tzname(None)             # <<<<<<<<<<<<<<
 * 
 * def tzinfo_fromargs(minutes):
 */
  __pyx_k_tuple_12 = PyTuple_Pack(1, Py_None); if (unlikely(!__pyx_k_tuple_12)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 227; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_12);
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_12));

  /* "axon/_objects.pxd":65
 *         return unicode(ob)
 *     elif ob is None:
 *         return unicode('')             # <<<<<<<<<<<<<<
 *     else:
 *         raise TypeError('This object %r is not unicode compatible' % ob)
 */
  __pyx_k_tuple_43 = PyTuple_Pack(1, ((PyObject *)__pyx_kp_u_21)); if (unlikely(!__pyx_k_tuple_43)) {__pyx_filename = __pyx_f[4]; __pyx_lineno = 65; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_43);
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_43));

  /* "axon/_loader.py":30
 * c_factory_dict = {}
 * 
 * def reset_factory():             # <<<<<<<<<<<<<<
 *     c_factory_dict = {}
 * 
 */
  __pyx_k_tuple_47 = PyTuple_Pack(1, ((PyObject *)__pyx_n_s__c_factory_dict)); if (unlikely(!__pyx_k_tuple_47)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 30; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_47);
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_47));
  __pyx_k_codeobj_48 = (PyObject*)__Pyx_PyCode_New(0, 0, 1, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_k_tuple_47, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_3, __pyx_n_s__reset_factory, 30, __pyx_empty_bytes); if (unlikely(!__pyx_k_codeobj_48)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 30; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

  /* "axon/_loader.py":33
 *     c_factory_dict = {}
 * 
 * def factory(name, factory_func=None):             # <<<<<<<<<<<<<<
 *     name = c_as_unicode(name)
 *     if factory_func is None:
 */
  __pyx_k_tuple_49 = PyTuple_Pack(4, ((PyObject *)__pyx_n_s__name), ((PyObject *)__pyx_n_s__factory_func), ((PyObject *)__pyx_n_s___factory), ((PyObject *)__pyx_n_s___factory)); if (unlikely(!__pyx_k_tuple_49)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 33; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_49);
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_49));
  __pyx_k_codeobj_50 = (PyObject*)__Pyx_PyCode_New(2, 0, 4, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_k_tuple_49, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_3, __pyx_n_s__factory, 33, __pyx_empty_bytes); if (unlikely(!__pyx_k_codeobj_50)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 33; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_k_tuple_51 = PyTuple_Pack(1, ((PyObject *)Py_None)); if (unlikely(!__pyx_k_tuple_51)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 33; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_51);
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_51));

  /* "axon/_loader.py":51
 * }
 * 
 * def as_name(name):             # <<<<<<<<<<<<<<
 *     return c_as_name(name)
 * 
 */
  __pyx_k_tuple_52 = PyTuple_Pack(1, ((PyObject *)__pyx_n_s__name)); if (unlikely(!__pyx_k_tuple_52)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 51; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_52);
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_52));
  __pyx_k_codeobj_53 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_k_tuple_52, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_3, __pyx_n_s__as_name, 51, __pyx_empty_bytes); if (unlikely(!__pyx_k_codeobj_53)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 51; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_RefNannyFinishContext();
  return 0;
  __pyx_L1_error:;
  __Pyx_RefNannyFinishContext();
  return -1;
}

static int __Pyx_InitGlobals(void) {
  if (__Pyx_InitStrings(__pyx_string_tab) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  __pyx_int_0 = PyInt_FromLong(0); if (unlikely(!__pyx_int_0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  __pyx_int_60 = PyInt_FromLong(60); if (unlikely(!__pyx_int_60)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  __pyx_int_720 = PyInt_FromLong(720); if (unlikely(!__pyx_int_720)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  __pyx_int_1440 = PyInt_FromLong(1440); if (unlikely(!__pyx_int_1440)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  return 0;
  __pyx_L1_error:;
  return -1;
}

#if PY_MAJOR_VERSION < 3
PyMODINIT_FUNC init_loader(void); /*proto*/
PyMODINIT_FUNC init_loader(void)
#else
PyMODINIT_FUNC PyInit__loader(void); /*proto*/
PyMODINIT_FUNC PyInit__loader(void)
#endif
{
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  double __pyx_t_11;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannyDeclarations
  #if CYTHON_REFNANNY
  __Pyx_RefNanny = __Pyx_RefNannyImportAPI("refnanny");
  if (!__Pyx_RefNanny) {
      PyErr_Clear();
      __Pyx_RefNanny = __Pyx_RefNannyImportAPI("Cython.Runtime.refnanny");
      if (!__Pyx_RefNanny)
          Py_FatalError("failed to import 'refnanny' module");
  }
  #endif
  __Pyx_RefNannySetupContext("PyMODINIT_FUNC PyInit__loader(void)", 0);
  if ( __Pyx_check_binary_version() < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_empty_tuple = PyTuple_New(0); if (unlikely(!__pyx_empty_tuple)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_empty_bytes = PyBytes_FromStringAndSize("", 0); if (unlikely(!__pyx_empty_bytes)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  #ifdef __Pyx_CyFunction_USED
  if (__Pyx_CyFunction_init() < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  #endif
  #ifdef __Pyx_FusedFunction_USED
  if (__pyx_FusedFunction_init() < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  #endif
  #ifdef __Pyx_Generator_USED
  if (__pyx_Generator_init() < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  #endif
  /*--- Library function declarations ---*/
  /*--- Threads initialization code ---*/
  #if defined(__PYX_FORCE_INIT_THREADS) && __PYX_FORCE_INIT_THREADS
  #ifdef WITH_THREAD /* Python build with threading support? */
  PyEval_InitThreads();
  #endif
  #endif
  /*--- Module creation code ---*/
  #if PY_MAJOR_VERSION < 3
  __pyx_m = Py_InitModule4(__Pyx_NAMESTR("_loader"), __pyx_methods, 0, 0, PYTHON_API_VERSION); Py_XINCREF(__pyx_m);
  #else
  __pyx_m = PyModule_Create(&__pyx_moduledef);
  #endif
  if (unlikely(!__pyx_m)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_d = PyModule_GetDict(__pyx_m); if (unlikely(!__pyx_d)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  Py_INCREF(__pyx_d);
  #if PY_MAJOR_VERSION >= 3
  {
    PyObject *modules = PyImport_GetModuleDict(); if (unlikely(!modules)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    if (!PyDict_GetItemString(modules, "axon._loader")) {
      if (unlikely(PyDict_SetItemString(modules, "axon._loader", __pyx_m) < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    }
  }
  #endif
  __pyx_b = PyImport_AddModule(__Pyx_NAMESTR(__Pyx_BUILTIN_MODULE_NAME)); if (unlikely(!__pyx_b)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  #if CYTHON_COMPILING_IN_PYPY
  Py_INCREF(__pyx_b);
  #endif
  if (__Pyx_SetAttrString(__pyx_m, "__builtins__", __pyx_b) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  /*--- Initialize various global constants etc. ---*/
  if (unlikely(__Pyx_InitGlobals() < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  #if PY_MAJOR_VERSION < 3 && (__PYX_DEFAULT_STRING_ENCODING_IS_ASCII || __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT)
  if (__Pyx_init_sys_getdefaultencoding_params() < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  #endif
  if (__pyx_module_is_main_axon___loader) {
    if (__Pyx_SetAttrString(__pyx_m, "__name__", __pyx_n_s____main__) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  }
  /*--- Builtin init code ---*/
  if (unlikely(__Pyx_InitCachedBuiltins() < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  /*--- Constants init code ---*/
  if (unlikely(__Pyx_InitCachedConstants() < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  /*--- Global init code ---*/
  __pyx_v_4axon_7_loader_unicode_type = Py_None; Py_INCREF(Py_None);
  __pyx_v_4axon_7_loader_str_type = Py_None; Py_INCREF(Py_None);
  __pyx_v_4axon_7_loader_int_type = Py_None; Py_INCREF(Py_None);
  __pyx_v_4axon_7_loader_long_type = Py_None; Py_INCREF(Py_None);
  __pyx_v_4axon_7_loader_bool_type = Py_None; Py_INCREF(Py_None);
  __pyx_v_4axon_7_loader_float_type = Py_None; Py_INCREF(Py_None);
  __pyx_v_4axon_7_loader_bytes_type = Py_None; Py_INCREF(Py_None);
  __pyx_v_4axon_7_loader_c_constants = ((PyObject*)Py_None); Py_INCREF(Py_None);
  __pyx_v_4axon_7_loader_c_factory_dict = ((PyObject*)Py_None); Py_INCREF(Py_None);
  __pyx_v_4axon_7_loader__str2decimal = Py_None; Py_INCREF(Py_None);
  __pyx_v_4axon_7_loader__inf = Py_None; Py_INCREF(Py_None);
  __pyx_v_4axon_7_loader__ninf = Py_None; Py_INCREF(Py_None);
  __pyx_v_4axon_7_loader__nan = Py_None; Py_INCREF(Py_None);
  __pyx_v_4axon_7_loader_tz_dict = ((PyObject*)Py_None); Py_INCREF(Py_None);
  /*--- Variable export code ---*/
  if (__Pyx_ExportVoidPtr(__pyx_n_s__unicode_type, (void *)&__pyx_v_4axon_7_loader_unicode_type, "PyObject *") < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__Pyx_ExportVoidPtr(__pyx_n_s__str_type, (void *)&__pyx_v_4axon_7_loader_str_type, "PyObject *") < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__Pyx_ExportVoidPtr(__pyx_n_s__int_type, (void *)&__pyx_v_4axon_7_loader_int_type, "PyObject *") < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__Pyx_ExportVoidPtr(__pyx_n_s__long_type, (void *)&__pyx_v_4axon_7_loader_long_type, "PyObject *") < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__Pyx_ExportVoidPtr(__pyx_n_s__bool_type, (void *)&__pyx_v_4axon_7_loader_bool_type, "PyObject *") < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__Pyx_ExportVoidPtr(__pyx_n_s__float_type, (void *)&__pyx_v_4axon_7_loader_float_type, "PyObject *") < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__Pyx_ExportVoidPtr(__pyx_n_s__bytes_type, (void *)&__pyx_v_4axon_7_loader_bytes_type, "PyObject *") < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__Pyx_ExportVoidPtr(__pyx_n_s__c_constants, (void *)&__pyx_v_4axon_7_loader_c_constants, "PyObject *") < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__Pyx_ExportVoidPtr(__pyx_n_s__c_factory_dict, (void *)&__pyx_v_4axon_7_loader_c_factory_dict, "PyObject *") < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__Pyx_ExportVoidPtr(__pyx_n_s___str2decimal, (void *)&__pyx_v_4axon_7_loader__str2decimal, "PyObject *") < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__Pyx_ExportVoidPtr(__pyx_n_s___inf, (void *)&__pyx_v_4axon_7_loader__inf, "PyObject *") < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__Pyx_ExportVoidPtr(__pyx_n_s___ninf, (void *)&__pyx_v_4axon_7_loader__ninf, "PyObject *") < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__Pyx_ExportVoidPtr(__pyx_n_s___nan, (void *)&__pyx_v_4axon_7_loader__nan, "PyObject *") < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__Pyx_ExportVoidPtr(__pyx_n_s__tz_dict, (void *)&__pyx_v_4axon_7_loader_tz_dict, "PyObject *") < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  /*--- Function export code ---*/
  if (__Pyx_ExportFunction("str2float", (void (*)(void))__pyx_f_4axon_7_loader_str2float, "PyObject *(PyObject *)") < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__Pyx_ExportFunction("str2decimal", (void (*)(void))__pyx_f_4axon_7_loader_str2decimal, "PyObject *(PyObject *)") < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__Pyx_ExportFunction("str2int", (void (*)(void))__pyx_f_4axon_7_loader_str2int, "PyObject *(PyObject *)") < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__Pyx_ExportFunction("time_fromargs", (void (*)(void))__pyx_f_4axon_7_loader_time_fromargs, "PyObject *(int, int, int, int, PyObject *)") < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__Pyx_ExportFunction("timedelta_fromargs", (void (*)(void))__pyx_f_4axon_7_loader_timedelta_fromargs, "PyObject *(int, int, int)") < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__Pyx_ExportFunction("date_fromargs", (void (*)(void))__pyx_f_4axon_7_loader_date_fromargs, "PyObject *(int, int, int)") < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__Pyx_ExportFunction("datetime_fromargs", (void (*)(void))__pyx_f_4axon_7_loader_datetime_fromargs, "PyObject *(int, int, int, int, int, int, int, PyObject *)") < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__Pyx_ExportFunction("float_inf", (void (*)(void))__pyx_f_4axon_7_loader_float_inf, "PyObject *(void)") < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__Pyx_ExportFunction("float_ninf", (void (*)(void))__pyx_f_4axon_7_loader_float_ninf, "PyObject *(void)") < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__Pyx_ExportFunction("float_nan", (void (*)(void))__pyx_f_4axon_7_loader_float_nan, "PyObject *(void)") < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__Pyx_ExportFunction("c_new_mapping_mixed", (void (*)(void))__pyx_f_4axon_7_loader_c_new_mapping_mixed, "PyObject *(PyObject *, PyObject *)") < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__Pyx_ExportFunction("c_new_sequence_mixed", (void (*)(void))__pyx_f_4axon_7_loader_c_new_sequence_mixed, "PyObject *(PyObject *, PyObject *)") < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__Pyx_ExportFunction("c_new_element_mixed", (void (*)(void))__pyx_f_4axon_7_loader_c_new_element_mixed, "PyObject *(PyObject *, PyObject *, PyObject *)") < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__Pyx_ExportFunction("c_new_instance_mixed", (void (*)(void))__pyx_f_4axon_7_loader_c_new_instance_mixed, "PyObject *(PyObject *, PyObject *, PyObject *)") < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__Pyx_ExportFunction("c_new_empty_mixed", (void (*)(void))__pyx_f_4axon_7_loader_c_new_empty_mixed, "PyObject *(PyObject *)") < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__Pyx_ExportFunction("c_new_mapping_strict", (void (*)(void))__pyx_f_4axon_7_loader_c_new_mapping_strict, "PyObject *(PyObject *, PyObject *)") < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__Pyx_ExportFunction("c_new_sequence_strict", (void (*)(void))__pyx_f_4axon_7_loader_c_new_sequence_strict, "PyObject *(PyObject *, PyObject *)") < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__Pyx_ExportFunction("c_new_element_strict", (void (*)(void))__pyx_f_4axon_7_loader_c_new_element_strict, "PyObject *(PyObject *, PyObject *, PyObject *)") < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__Pyx_ExportFunction("c_new_instance_strict", (void (*)(void))__pyx_f_4axon_7_loader_c_new_instance_strict, "PyObject *(PyObject *, PyObject *, PyObject *)") < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__Pyx_ExportFunction("c_new_empty_strict", (void (*)(void))__pyx_f_4axon_7_loader_c_new_empty_strict, "PyObject *(PyObject *)") < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__Pyx_ExportFunction("safe_builder", (void (*)(void))__pyx_f_4axon_7_loader_safe_builder, "struct Builder *(void)") < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__Pyx_ExportFunction("strict_builder", (void (*)(void))__pyx_f_4axon_7_loader_strict_builder, "struct Builder *(void)") < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__Pyx_ExportFunction("mixed_builder", (void (*)(void))__pyx_f_4axon_7_loader_mixed_builder, "struct Builder *(void)") < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__Pyx_ExportFunction("tzinfo_fromargs", (void (*)(void))__pyx_f_4axon_7_loader_tzinfo_fromargs, "PyObject *(int)") < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  /*--- Type init code ---*/
  if (PyType_Ready(&__pyx_type_4axon_7_loader___pyx_scope_struct__factory) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 33; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_ptype_4axon_7_loader___pyx_scope_struct__factory = &__pyx_type_4axon_7_loader___pyx_scope_struct__factory;
  if (PyType_Ready(&BuilderType) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 190; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__Pyx_SetAttrString(__pyx_m, "Builder", (PyObject *)&BuilderType) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 190; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_ptype_4axon_7_loader_Builder = &BuilderType;
  __pyx_ptype_7cpython_8datetime_tzinfo = __Pyx_ImportType("datetime", "tzinfo", sizeof(PyDateTime_TZInfo), 0); if (unlikely(!__pyx_ptype_7cpython_8datetime_tzinfo)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_vtabptr_4axon_7_loader_FixedOffsetTZ = &__pyx_vtable_4axon_7_loader_FixedOffsetTZ;
  __pyx_vtable_4axon_7_loader_FixedOffsetTZ._init = (void (*)(struct FixedOffsetTZObject *, PyObject *))__pyx_f_4axon_7_loader_13FixedOffsetTZ__init;
  FixedOffsetTZType.tp_base = __pyx_ptype_7cpython_8datetime_tzinfo;
  if (PyType_Ready(&FixedOffsetTZType) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 195; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__Pyx_SetVtable(FixedOffsetTZType.tp_dict, __pyx_vtabptr_4axon_7_loader_FixedOffsetTZ) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 195; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__Pyx_SetAttrString(__pyx_m, "FixedOffsetTZ", (PyObject *)&FixedOffsetTZType) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 195; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_ptype_4axon_7_loader_FixedOffsetTZ = &FixedOffsetTZType;
  if (PyType_Ready(&SimpleBuilderType) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 237; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__Pyx_SetAttrString(__pyx_m, "SimpleBuilder", (PyObject *)&SimpleBuilderType) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 237; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_ptype_4axon_7_loader_SimpleBuilder = &SimpleBuilderType;
  __pyx_vtabptr_4axon_7_loader_Loader = &__pyx_vtable_4axon_7_loader_Loader;
  __pyx_vtable_4axon_7_loader_Loader._check_pairs = (PyObject *(*)(struct __pyx_obj_4axon_7_loader_Loader *, int __pyx_skip_dispatch))__pyx_f_4axon_7_loader_6Loader__check_pairs;
  __pyx_vtable_4axon_7_loader_Loader.load = (PyObject *(*)(struct __pyx_obj_4axon_7_loader_Loader *, int __pyx_skip_dispatch))__pyx_f_4axon_7_loader_6Loader_load;
  __pyx_vtable_4axon_7_loader_Loader.moveto_next_token = (Py_UCS4 (*)(struct __pyx_obj_4axon_7_loader_Loader *))__pyx_f_4axon_7_loader_6Loader_moveto_next_token;
  __pyx_vtable_4axon_7_loader_Loader.skip_spaces = (Py_UCS4 (*)(struct __pyx_obj_4axon_7_loader_Loader *))__pyx_f_4axon_7_loader_6Loader_skip_spaces;
  __pyx_vtable_4axon_7_loader_Loader.skip_whitespace = (void (*)(struct __pyx_obj_4axon_7_loader_Loader *))__pyx_f_4axon_7_loader_6Loader_skip_whitespace;
  __pyx_vtable_4axon_7_loader_Loader.next_line = (void (*)(struct __pyx_obj_4axon_7_loader_Loader *))__pyx_f_4axon_7_loader_6Loader_next_line;
  __pyx_vtable_4axon_7_loader_Loader.get_dots = (int (*)(struct __pyx_obj_4axon_7_loader_Loader *))__pyx_f_4axon_7_loader_6Loader_get_dots;
  __pyx_vtable_4axon_7_loader_Loader.try_get_int = (int (*)(struct __pyx_obj_4axon_7_loader_Loader *, int))__pyx_f_4axon_7_loader_6Loader_try_get_int;
  __pyx_vtable_4axon_7_loader_Loader.get_date = (int (*)(struct __pyx_obj_4axon_7_loader_Loader *))__pyx_f_4axon_7_loader_6Loader_get_date;
  __pyx_vtable_4axon_7_loader_Loader.get_time = (int (*)(struct __pyx_obj_4axon_7_loader_Loader *))__pyx_f_4axon_7_loader_6Loader_get_time;
  __pyx_vtable_4axon_7_loader_Loader.get_time_offset = (int (*)(struct __pyx_obj_4axon_7_loader_Loader *))__pyx_f_4axon_7_loader_6Loader_get_time_offset;
  __pyx_vtable_4axon_7_loader_Loader.get_tzinfo = (PyObject *(*)(struct __pyx_obj_4axon_7_loader_Loader *))__pyx_f_4axon_7_loader_6Loader_get_tzinfo;
  __pyx_vtable_4axon_7_loader_Loader.get_number = (PyObject *(*)(struct __pyx_obj_4axon_7_loader_Loader *))__pyx_f_4axon_7_loader_6Loader_get_number;
  __pyx_vtable_4axon_7_loader_Loader.get_name = (PyObject *(*)(struct __pyx_obj_4axon_7_loader_Loader *))__pyx_f_4axon_7_loader_6Loader_get_name;
  __pyx_vtable_4axon_7_loader_Loader.get_key = (PyObject *(*)(struct __pyx_obj_4axon_7_loader_Loader *))__pyx_f_4axon_7_loader_6Loader_get_key;
  __pyx_vtable_4axon_7_loader_Loader.try_get_name = (PyObject *(*)(struct __pyx_obj_4axon_7_loader_Loader *))__pyx_f_4axon_7_loader_6Loader_try_get_name;
  __pyx_vtable_4axon_7_loader_Loader.try_get_key = (PyObject *(*)(struct __pyx_obj_4axon_7_loader_Loader *))__pyx_f_4axon_7_loader_6Loader_try_get_key;
  __pyx_vtable_4axon_7_loader_Loader.try_get_label = (PyObject *(*)(struct __pyx_obj_4axon_7_loader_Loader *))__pyx_f_4axon_7_loader_6Loader_try_get_label;
  __pyx_vtable_4axon_7_loader_Loader.get_unicode_hex = (PyObject *(*)(struct __pyx_obj_4axon_7_loader_Loader *))__pyx_f_4axon_7_loader_6Loader_get_unicode_hex;
  __pyx_vtable_4axon_7_loader_Loader.get_string = (PyObject *(*)(struct __pyx_obj_4axon_7_loader_Loader *, Py_UCS4))__pyx_f_4axon_7_loader_6Loader_get_string;
  __pyx_vtable_4axon_7_loader_Loader.get_base64 = (PyObject *(*)(struct __pyx_obj_4axon_7_loader_Loader *))__pyx_f_4axon_7_loader_6Loader_get_base64;
  __pyx_vtable_4axon_7_loader_Loader.skip_comment = (void (*)(struct __pyx_obj_4axon_7_loader_Loader *))__pyx_f_4axon_7_loader_6Loader_skip_comment;
  __pyx_vtable_4axon_7_loader_Loader.skip_comments = (void (*)(struct __pyx_obj_4axon_7_loader_Loader *))__pyx_f_4axon_7_loader_6Loader_skip_comments;
  __pyx_vtable_4axon_7_loader_Loader.get_constant_or_string = (PyObject *(*)(struct __pyx_obj_4axon_7_loader_Loader *, PyObject *))__pyx_f_4axon_7_loader_6Loader_get_constant_or_string;
  __pyx_vtable_4axon_7_loader_Loader.get_negative_constant = (PyObject *(*)(struct __pyx_obj_4axon_7_loader_Loader *))__pyx_f_4axon_7_loader_6Loader_get_negative_constant;
  __pyx_vtable_4axon_7_loader_Loader.get_value = (PyObject *(*)(struct __pyx_obj_4axon_7_loader_Loader *, int))__pyx_f_4axon_7_loader_6Loader_get_value;
  __pyx_vtable_4axon_7_loader_Loader.get_collection = (PyObject *(*)(struct __pyx_obj_4axon_7_loader_Loader *, PyObject *, int))__pyx_f_4axon_7_loader_6Loader_get_collection;
  __pyx_vtable_4axon_7_loader_Loader.get_complex_value = (PyObject *(*)(struct __pyx_obj_4axon_7_loader_Loader *, PyObject *, int))__pyx_f_4axon_7_loader_6Loader_get_complex_value;
  __pyx_vtable_4axon_7_loader_Loader.get_sequence_mapping = (PyObject *(*)(struct __pyx_obj_4axon_7_loader_Loader *, PyObject *, PyObject *, int))__pyx_f_4axon_7_loader_6Loader_get_sequence_mapping;
  __pyx_vtable_4axon_7_loader_Loader.get_mapping_sequence = (PyObject *(*)(struct __pyx_obj_4axon_7_loader_Loader *, PyObject *, PyObject *, int))__pyx_f_4axon_7_loader_6Loader_get_mapping_sequence;
  __pyx_vtable_4axon_7_loader_Loader.get_list_value = (PyObject *(*)(struct __pyx_obj_4axon_7_loader_Loader *))__pyx_f_4axon_7_loader_6Loader_get_list_value;
  __pyx_vtable_4axon_7_loader_Loader.get_tuple_value = (PyObject *(*)(struct __pyx_obj_4axon_7_loader_Loader *))__pyx_f_4axon_7_loader_6Loader_get_tuple_value;
  __pyx_vtable_4axon_7_loader_Loader.get_dict_value = (PyObject *(*)(struct __pyx_obj_4axon_7_loader_Loader *))__pyx_f_4axon_7_loader_6Loader_get_dict_value;
  __pyx_vtable_4axon_7_loader_Loader.get_mapping_part = (int (*)(struct __pyx_obj_4axon_7_loader_Loader *, PyObject *, PyObject *, int))__pyx_f_4axon_7_loader_6Loader_get_mapping_part;
  __pyx_vtable_4axon_7_loader_Loader.get_sequence_part = (int (*)(struct __pyx_obj_4axon_7_loader_Loader *, PyObject *, PyObject *, int))__pyx_f_4axon_7_loader_6Loader_get_sequence_part;
  if (PyType_Ready(&__pyx_type_4axon_7_loader_Loader) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 284; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  #if CYTHON_COMPILING_IN_CPYTHON
  {
    PyObject *wrapper = __Pyx_GetAttrString((PyObject *)&__pyx_type_4axon_7_loader_Loader, "__init__"); if (unlikely(!wrapper)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 284; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    if (Py_TYPE(wrapper) == &PyWrapperDescr_Type) {
      __pyx_wrapperbase_4axon_7_loader_6Loader___init__ = *((PyWrapperDescrObject *)wrapper)->d_base;
      __pyx_wrapperbase_4axon_7_loader_6Loader___init__.doc = __pyx_doc_4axon_7_loader_6Loader___init__;
      ((PyWrapperDescrObject *)wrapper)->d_base = &__pyx_wrapperbase_4axon_7_loader_6Loader___init__;
    }
  }
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON
  {
    PyObject *wrapper = __Pyx_GetAttrString((PyObject *)&__pyx_type_4axon_7_loader_Loader, "__next__"); if (unlikely(!wrapper)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 284; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    if (Py_TYPE(wrapper) == &PyWrapperDescr_Type) {
      __pyx_wrapperbase_4axon_7_loader_6Loader_2__next__ = *((PyWrapperDescrObject *)wrapper)->d_base;
      __pyx_wrapperbase_4axon_7_loader_6Loader_2__next__.doc = __pyx_doc_4axon_7_loader_6Loader_2__next__;
      ((PyWrapperDescrObject *)wrapper)->d_base = &__pyx_wrapperbase_4axon_7_loader_6Loader_2__next__;
    }
  }
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON
  {
    PyObject *wrapper = __Pyx_GetAttrString((PyObject *)&__pyx_type_4axon_7_loader_Loader, "__iter__"); if (unlikely(!wrapper)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 284; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    if (Py_TYPE(wrapper) == &PyWrapperDescr_Type) {
      __pyx_wrapperbase_4axon_7_loader_6Loader_8__iter__ = *((PyWrapperDescrObject *)wrapper)->d_base;
      __pyx_wrapperbase_4axon_7_loader_6Loader_8__iter__.doc = __pyx_doc_4axon_7_loader_6Loader_8__iter__;
      ((PyWrapperDescrObject *)wrapper)->d_base = &__pyx_wrapperbase_4axon_7_loader_6Loader_8__iter__;
    }
  }
  #endif
  if (__Pyx_SetVtable(__pyx_type_4axon_7_loader_Loader.tp_dict, __pyx_vtabptr_4axon_7_loader_Loader) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 284; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__Pyx_SetAttrString(__pyx_m, "Loader", (PyObject *)&__pyx_type_4axon_7_loader_Loader) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 284; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_ptype_4axon_7_loader_Loader = &__pyx_type_4axon_7_loader_Loader;
  /*--- Type import code ---*/
  __pyx_ptype_7cpython_8datetime_date = __Pyx_ImportType("datetime", "date", sizeof(PyDateTime_Date), 0); if (unlikely(!__pyx_ptype_7cpython_8datetime_date)) {__pyx_filename = __pyx_f[3]; __pyx_lineno = 9; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_ptype_7cpython_8datetime_time = __Pyx_ImportType("datetime", "time", sizeof(PyDateTime_Time), 0); if (unlikely(!__pyx_ptype_7cpython_8datetime_time)) {__pyx_filename = __pyx_f[3]; __pyx_lineno = 12; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_ptype_7cpython_8datetime_datetime = __Pyx_ImportType("datetime", "datetime", sizeof(PyDateTime_DateTime), 0); if (unlikely(!__pyx_ptype_7cpython_8datetime_datetime)) {__pyx_filename = __pyx_f[3]; __pyx_lineno = 15; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_ptype_7cpython_8datetime_timedelta = __Pyx_ImportType("datetime", "timedelta", sizeof(PyDateTime_Delta), 0); if (unlikely(!__pyx_ptype_7cpython_8datetime_timedelta)) {__pyx_filename = __pyx_f[3]; __pyx_lineno = 18; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_ptype_7cpython_5array_array = __Pyx_ImportType("array", "array", sizeof(arrayobject), 0); if (unlikely(!__pyx_ptype_7cpython_5array_array)) {__pyx_filename = __pyx_f[2]; __pyx_lineno = 58; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_ptype_4axon_8_objects_Undefined = __Pyx_ImportType("axon._objects", "Undefined", sizeof(struct UndefinedObject), 1); if (unlikely(!__pyx_ptype_4axon_8_objects_Undefined)) {__pyx_filename = __pyx_f[4]; __pyx_lineno = 107; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_ptype_4axon_8_objects_rdict = __Pyx_ImportType("axon._objects", "rdict", sizeof(struct ReadonlyDict), 1); if (unlikely(!__pyx_ptype_4axon_8_objects_rdict)) {__pyx_filename = __pyx_f[4]; __pyx_lineno = 114; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_ptype_4axon_8_objects_rlist = __Pyx_ImportType("axon._objects", "rlist", sizeof(struct ReadonlyList), 1); if (unlikely(!__pyx_ptype_4axon_8_objects_rlist)) {__pyx_filename = __pyx_f[4]; __pyx_lineno = 121; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_ptype_4axon_8_objects_NamedValue = __Pyx_ImportType("axon._objects", "NamedValue", sizeof(struct __pyx_obj_4axon_8_objects_NamedValue), 1); if (unlikely(!__pyx_ptype_4axon_8_objects_NamedValue)) {__pyx_filename = __pyx_f[4]; __pyx_lineno = 127; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_ptype_4axon_8_objects_Attribute = __Pyx_ImportType("axon._objects", "Attribute", sizeof(struct Attribute), 1); if (unlikely(!__pyx_ptype_4axon_8_objects_Attribute)) {__pyx_filename = __pyx_f[4]; __pyx_lineno = 137; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_ptype_4axon_8_objects_Attrs = __Pyx_ImportType("axon._objects", "Attrs", sizeof(struct __pyx_obj_4axon_8_objects_Attrs), 1); if (unlikely(!__pyx_ptype_4axon_8_objects_Attrs)) {__pyx_filename = __pyx_f[4]; __pyx_lineno = 146; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_ptype_4axon_8_objects_Empty = __Pyx_ImportType("axon._objects", "Empty", sizeof(struct EmptyObject), 1); if (unlikely(!__pyx_ptype_4axon_8_objects_Empty)) {__pyx_filename = __pyx_f[4]; __pyx_lineno = 156; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_ptype_4axon_8_objects_Sequence = __Pyx_ImportType("axon._objects", "Sequence", sizeof(struct SequenceObject), 1); if (unlikely(!__pyx_ptype_4axon_8_objects_Sequence)) {__pyx_filename = __pyx_f[4]; __pyx_lineno = 163; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_ptype_4axon_8_objects_Collection = __Pyx_ImportType("axon._objects", "Collection", sizeof(struct CollectionObject), 1); if (unlikely(!__pyx_ptype_4axon_8_objects_Collection)) {__pyx_filename = __pyx_f[4]; __pyx_lineno = 172; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_ptype_4axon_8_objects_Mapping = __Pyx_ImportType("axon._objects", "Mapping", sizeof(struct MappingObject), 1); if (unlikely(!__pyx_ptype_4axon_8_objects_Mapping)) {__pyx_filename = __pyx_f[4]; __pyx_lineno = 181; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_ptype_4axon_8_objects_Element = __Pyx_ImportType("axon._objects", "Element", sizeof(struct ElementObject), 1); if (unlikely(!__pyx_ptype_4axon_8_objects_Element)) {__pyx_filename = __pyx_f[4]; __pyx_lineno = 190; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_ptype_4axon_8_objects_Instance = __Pyx_ImportType("axon._objects", "Instance", sizeof(struct InstanceObject), 1); if (unlikely(!__pyx_ptype_4axon_8_objects_Instance)) {__pyx_filename = __pyx_f[4]; __pyx_lineno = 199; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_ptype_4axon_8_objects_StringReader = __Pyx_ImportType("axon._objects", "StringReader", sizeof(struct __pyx_obj_4axon_8_objects_StringReader), 1); if (unlikely(!__pyx_ptype_4axon_8_objects_StringReader)) {__pyx_filename = __pyx_f[4]; __pyx_lineno = 227; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_vtabptr_4axon_8_objects_StringReader = (struct __pyx_vtabstruct_4axon_8_objects_StringReader*)__Pyx_GetVtable(__pyx_ptype_4axon_8_objects_StringReader->tp_dict); if (unlikely(!__pyx_vtabptr_4axon_8_objects_StringReader)) {__pyx_filename = __pyx_f[4]; __pyx_lineno = 227; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  /*--- Variable import code ---*/
  __pyx_t_1 = __Pyx_ImportModule("axon._objects"); if (!__pyx_t_1) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__Pyx_ImportVoidPtr(__pyx_t_1, "_decimal2str", (void **)&__pyx_vp_4axon_8_objects__decimal2str, "PyObject *") < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__Pyx_ImportVoidPtr(__pyx_t_1, "empty_name", (void **)&__pyx_vp_4axon_8_objects_empty_name, "PyObject *") < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__Pyx_ImportVoidPtr(__pyx_t_1, "c_undescore", (void **)&__pyx_vp_4axon_8_objects_c_undescore, "PyObject *") < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__Pyx_ImportVoidPtr(__pyx_t_1, "c_undefined", (void **)&__pyx_vp_4axon_8_objects_c_undefined, "PyObject *") < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__Pyx_ImportVoidPtr(__pyx_t_1, "name_cache", (void **)&__pyx_vp_4axon_8_objects_name_cache, "PyObject *") < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__Pyx_ImportVoidPtr(__pyx_t_1, "c_str_type", (void **)&__pyx_vp_4axon_8_objects_c_str_type, "PyObject *") < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__Pyx_ImportVoidPtr(__pyx_t_1, "c_empty_dict", (void **)&__pyx_vp_4axon_8_objects_c_empty_dict, "struct ReadonlyDict *") < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__Pyx_ImportVoidPtr(__pyx_t_1, "c_empty_list", (void **)&__pyx_vp_4axon_8_objects_c_empty_list, "struct ReadonlyList *") < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__Pyx_ImportVoidPtr(__pyx_t_1, "NAME_IS_EMPTY", (void **)&__pyx_vp_4axon_8_objects_NAME_IS_EMPTY, "PyObject *") < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  Py_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  /*--- Function import code ---*/
  __pyx_t_2 = __Pyx_ImportModule("axon._objects"); if (!__pyx_t_2) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__Pyx_ImportFunction(__pyx_t_2, "c_new_sequence", (void (**)(void))&__pyx_f_4axon_8_objects_c_new_sequence, "PyObject *(PyObject *, PyObject *)") < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__Pyx_ImportFunction(__pyx_t_2, "c_new_collection", (void (**)(void))&__pyx_f_4axon_8_objects_c_new_collection, "PyObject *(PyObject *, PyObject *)") < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__Pyx_ImportFunction(__pyx_t_2, "c_new_mapping", (void (**)(void))&__pyx_f_4axon_8_objects_c_new_mapping, "PyObject *(PyObject *, PyObject *)") < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__Pyx_ImportFunction(__pyx_t_2, "c_new_element", (void (**)(void))&__pyx_f_4axon_8_objects_c_new_element, "PyObject *(PyObject *, PyObject *, PyObject *)") < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__Pyx_ImportFunction(__pyx_t_2, "c_new_instance", (void (**)(void))&__pyx_f_4axon_8_objects_c_new_instance, "PyObject *(PyObject *, PyObject *, PyObject *)") < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__Pyx_ImportFunction(__pyx_t_2, "c_new_empty", (void (**)(void))&__pyx_f_4axon_8_objects_c_new_empty, "PyObject *(PyObject *)") < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  Py_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  /*--- Execution code ---*/

  /* "axon/_loader.py":11
 * # {{LICENCE}}
 * 
 * import sys             # <<<<<<<<<<<<<<
 * 
 * try:
 */
  __pyx_t_3 = __Pyx_Import(((PyObject *)__pyx_n_s__sys), 0, 0); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 11; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s__sys, __pyx_t_3) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 11; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "axon/_loader.py":13
 * import sys
 * 
 * try:             # <<<<<<<<<<<<<<
 *     from base64 import decodebytes
 * except:
 */
  {
    __Pyx_ExceptionSave(&__pyx_t_4, &__pyx_t_5, &__pyx_t_6);
    __Pyx_XGOTREF(__pyx_t_4);
    __Pyx_XGOTREF(__pyx_t_5);
    __Pyx_XGOTREF(__pyx_t_6);
    /*try:*/ {

      /* "axon/_loader.py":14
 * 
 * try:
 *     from base64 import decodebytes             # <<<<<<<<<<<<<<
 * except:
 *     from base64 import decodestring as decodebytes
 */
      __pyx_t_3 = PyList_New(1); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 14; __pyx_clineno = __LINE__; goto __pyx_L2_error;}
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_INCREF(((PyObject *)__pyx_n_s__decodebytes));
      PyList_SET_ITEM(__pyx_t_3, 0, ((PyObject *)__pyx_n_s__decodebytes));
      __Pyx_GIVEREF(((PyObject *)__pyx_n_s__decodebytes));
      __pyx_t_7 = __Pyx_Import(((PyObject *)__pyx_n_s__base64), ((PyObject *)__pyx_t_3), 0); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 14; __pyx_clineno = __LINE__; goto __pyx_L2_error;}
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(((PyObject *)__pyx_t_3)); __pyx_t_3 = 0;
      __pyx_t_3 = __Pyx_ImportFrom(__pyx_t_7, __pyx_n_s__decodebytes); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 14; __pyx_clineno = __LINE__; goto __pyx_L2_error;}
      __Pyx_GOTREF(__pyx_t_3);
      if (PyDict_SetItem(__pyx_d, __pyx_n_s__decodebytes, __pyx_t_3) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 14; __pyx_clineno = __LINE__; goto __pyx_L2_error;}
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    }
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    goto __pyx_L9_try_end;
    __pyx_L2_error:;
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;

    /* "axon/_loader.py":15
 * try:
 *     from base64 import decodebytes
 * except:             # <<<<<<<<<<<<<<
 *     from base64 import decodestring as decodebytes
 * 
 */
    /*except:*/ {
      __Pyx_AddTraceback("axon._loader", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_7, &__pyx_t_3, &__pyx_t_8) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 15; __pyx_clineno = __LINE__; goto __pyx_L4_except_error;}
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_GOTREF(__pyx_t_8);

      /* "axon/_loader.py":16
 *     from base64 import decodebytes
 * except:
 *     from base64 import decodestring as decodebytes             # <<<<<<<<<<<<<<
 * 
 * import axon.errors as errors
 */
      __pyx_t_9 = PyList_New(1); if (unlikely(!__pyx_t_9)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 16; __pyx_clineno = __LINE__; goto __pyx_L4_except_error;}
      __Pyx_GOTREF(__pyx_t_9);
      __Pyx_INCREF(((PyObject *)__pyx_n_s__decodestring));
      PyList_SET_ITEM(__pyx_t_9, 0, ((PyObject *)__pyx_n_s__decodestring));
      __Pyx_GIVEREF(((PyObject *)__pyx_n_s__decodestring));
      __pyx_t_10 = __Pyx_Import(((PyObject *)__pyx_n_s__base64), ((PyObject *)__pyx_t_9), 0); if (unlikely(!__pyx_t_10)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 16; __pyx_clineno = __LINE__; goto __pyx_L4_except_error;}
      __Pyx_GOTREF(__pyx_t_10);
      __Pyx_DECREF(((PyObject *)__pyx_t_9)); __pyx_t_9 = 0;
      __pyx_t_9 = __Pyx_ImportFrom(__pyx_t_10, __pyx_n_s__decodestring); if (unlikely(!__pyx_t_9)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 16; __pyx_clineno = __LINE__; goto __pyx_L4_except_error;}
      __Pyx_GOTREF(__pyx_t_9);
      if (PyDict_SetItem(__pyx_d, __pyx_n_s__decodebytes, __pyx_t_9) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 16; __pyx_clineno = __LINE__; goto __pyx_L4_except_error;}
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      goto __pyx_L3_exception_handled;
    }
    __pyx_L4_except_error:;
    __Pyx_XGIVEREF(__pyx_t_4);
    __Pyx_XGIVEREF(__pyx_t_5);
    __Pyx_XGIVEREF(__pyx_t_6);
    __Pyx_ExceptionReset(__pyx_t_4, __pyx_t_5, __pyx_t_6);
    goto __pyx_L1_error;
    __pyx_L3_exception_handled:;
    __Pyx_XGIVEREF(__pyx_t_4);
    __Pyx_XGIVEREF(__pyx_t_5);
    __Pyx_XGIVEREF(__pyx_t_6);
    __Pyx_ExceptionReset(__pyx_t_4, __pyx_t_5, __pyx_t_6);
    __pyx_L9_try_end:;
  }

  /* "axon/_loader.py":18
 *     from base64 import decodestring as decodebytes
 * 
 * import axon.errors as errors             # <<<<<<<<<<<<<<
 * 
 * import datetime as pydatetime
 */
  __pyx_t_8 = PyList_New(1); if (unlikely(!__pyx_t_8)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 18; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_INCREF(((PyObject *)__pyx_n_s_46));
  PyList_SET_ITEM(__pyx_t_8, 0, ((PyObject *)__pyx_n_s_46));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s_46));
  __pyx_t_3 = __Pyx_Import(((PyObject *)__pyx_n_s_45), ((PyObject *)__pyx_t_8), 0); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 18; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(((PyObject *)__pyx_t_8)); __pyx_t_8 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s__errors, __pyx_t_3) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 18; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "axon/_loader.py":20
 * import axon.errors as errors
 * 
 * import datetime as pydatetime             # <<<<<<<<<<<<<<
 * 
 * import_datetime()
 */
  __pyx_t_3 = __Pyx_Import(((PyObject *)__pyx_n_s__datetime), 0, 0); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 20; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s__pydatetime, __pyx_t_3) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 20; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "axon/_loader.py":22
 * import datetime as pydatetime
 * 
 * import_datetime()             # <<<<<<<<<<<<<<
 * 
 * ###
 */
  __pyx_f_7cpython_8datetime_import_datetime();

  /* "axon/_loader.py":28
 * ###
 * 
 * c_factory_dict = {}             # <<<<<<<<<<<<<<
 * 
 * def reset_factory():
 */
  __pyx_t_3 = PyDict_New(); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 28; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(((PyObject *)__pyx_t_3));
  __Pyx_XGOTREF(((PyObject *)__pyx_v_4axon_7_loader_c_factory_dict));
  __Pyx_DECREF(((PyObject *)__pyx_v_4axon_7_loader_c_factory_dict));
  __Pyx_GIVEREF(((PyObject *)__pyx_t_3));
  __pyx_v_4axon_7_loader_c_factory_dict = ((PyObject*)__pyx_t_3);
  __pyx_t_3 = 0;

  /* "axon/_loader.py":30
 * c_factory_dict = {}
 * 
 * def reset_factory():             # <<<<<<<<<<<<<<
 *     c_factory_dict = {}
 * 
 */
  __pyx_t_3 = __Pyx_CyFunction_NewEx(&__pyx_mdef_4axon_7_loader_1reset_factory, 0, __pyx_n_s__reset_factory, NULL, __pyx_n_s_5, ((PyObject *)__pyx_k_codeobj_48)); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 30; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s__reset_factory, __pyx_t_3) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 30; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "axon/_loader.py":33
 *     c_factory_dict = {}
 * 
 * def factory(name, factory_func=None):             # <<<<<<<<<<<<<<
 *     name = c_as_unicode(name)
 *     if factory_func is None:
 */
  __pyx_t_3 = __Pyx_CyFunction_NewEx(&__pyx_mdef_4axon_7_loader_3factory, 0, __pyx_n_s__factory, NULL, __pyx_n_s_5, ((PyObject *)__pyx_k_codeobj_50)); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 33; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_3, ((PyObject *)__pyx_k_tuple_51));
  if (PyDict_SetItem(__pyx_d, __pyx_n_s__factory, __pyx_t_3) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 33; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "axon/_loader.py":43
 *         c_factory_dict[c_as_name(name)] = factory_func
 * 
 * c_constants = {             # <<<<<<<<<<<<<<
 *     c_as_name(c_as_unicode('true')): True,
 *     c_as_name(c_as_unicode('false')): False,
 */
  __pyx_t_3 = PyDict_New(); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 43; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(((PyObject *)__pyx_t_3));

  /* "axon/_loader.py":44
 * 
 * c_constants = {
 *     c_as_name(c_as_unicode('true')): True,             # <<<<<<<<<<<<<<
 *     c_as_name(c_as_unicode('false')): False,
 *     c_as_name(c_as_unicode('null')): None,
 */
  __pyx_t_8 = ((PyObject *)__pyx_f_4axon_8_objects_c_as_unicode(((PyObject *)__pyx_n_u__true))); if (unlikely(!__pyx_t_8)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 44; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_8);
  __pyx_t_7 = ((PyObject *)__pyx_f_4axon_8_objects_c_as_name(__pyx_t_8)); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 44; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  __pyx_t_8 = __Pyx_PyBool_FromLong(1); if (unlikely(!__pyx_t_8)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 44; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_8);
  if (PyDict_SetItem(__pyx_t_3, __pyx_t_7, __pyx_t_8) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 43; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

  /* "axon/_loader.py":45
 * c_constants = {
 *     c_as_name(c_as_unicode('true')): True,
 *     c_as_name(c_as_unicode('false')): False,             # <<<<<<<<<<<<<<
 *     c_as_name(c_as_unicode('null')): None,
 *     #c_as_name(c_as_unicode('NaN')): float('nan'),
 */
  __pyx_t_8 = ((PyObject *)__pyx_f_4axon_8_objects_c_as_unicode(((PyObject *)__pyx_n_u__false))); if (unlikely(!__pyx_t_8)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 45; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_8);
  __pyx_t_7 = ((PyObject *)__pyx_f_4axon_8_objects_c_as_name(__pyx_t_8)); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 45; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  __pyx_t_8 = __Pyx_PyBool_FromLong(0); if (unlikely(!__pyx_t_8)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 45; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_8);
  if (PyDict_SetItem(__pyx_t_3, __pyx_t_7, __pyx_t_8) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 43; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

  /* "axon/_loader.py":46
 *     c_as_name(c_as_unicode('true')): True,
 *     c_as_name(c_as_unicode('false')): False,
 *     c_as_name(c_as_unicode('null')): None,             # <<<<<<<<<<<<<<
 *     #c_as_name(c_as_unicode('NaN')): float('nan'),
 *     #c_as_name(c_as_unicode('Infinity')): float('inf'),
 */
  __pyx_t_8 = ((PyObject *)__pyx_f_4axon_8_objects_c_as_unicode(((PyObject *)__pyx_n_u__null))); if (unlikely(!__pyx_t_8)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 46; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_8);
  __pyx_t_7 = ((PyObject *)__pyx_f_4axon_8_objects_c_as_name(__pyx_t_8)); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 46; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  if (PyDict_SetItem(__pyx_t_3, __pyx_t_7, Py_None) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 43; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_XGOTREF(((PyObject *)__pyx_v_4axon_7_loader_c_constants));
  __Pyx_DECREF(((PyObject *)__pyx_v_4axon_7_loader_c_constants));
  __Pyx_GIVEREF(((PyObject *)__pyx_t_3));
  __pyx_v_4axon_7_loader_c_constants = ((PyObject*)__pyx_t_3);
  __pyx_t_3 = 0;

  /* "axon/_loader.py":51
 * }
 * 
 * def as_name(name):             # <<<<<<<<<<<<<<
 *     return c_as_name(name)
 * 
 */
  __pyx_t_3 = __Pyx_CyFunction_NewEx(&__pyx_mdef_4axon_7_loader_5as_name, 0, __pyx_n_s__as_name, NULL, __pyx_n_s_5, ((PyObject *)__pyx_k_codeobj_53)); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 51; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s__as_name, __pyx_t_3) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 51; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "axon/_loader.py":56
 * import cython
 * 
 * try:             # <<<<<<<<<<<<<<
 *     import cdecimal as _decimal
 * except:
 */
  {
    __Pyx_ExceptionSave(&__pyx_t_6, &__pyx_t_5, &__pyx_t_4);
    __Pyx_XGOTREF(__pyx_t_6);
    __Pyx_XGOTREF(__pyx_t_5);
    __Pyx_XGOTREF(__pyx_t_4);
    /*try:*/ {

      /* "axon/_loader.py":57
 * 
 * try:
 *     import cdecimal as _decimal             # <<<<<<<<<<<<<<
 * except:
 *     import decimal as _decimal
 */
      __pyx_t_3 = __Pyx_Import(((PyObject *)__pyx_n_s__cdecimal), 0, 0); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 57; __pyx_clineno = __LINE__; goto __pyx_L12_error;}
      __Pyx_GOTREF(__pyx_t_3);
      if (PyDict_SetItem(__pyx_d, __pyx_n_s___decimal, __pyx_t_3) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 57; __pyx_clineno = __LINE__; goto __pyx_L12_error;}
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    }
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    goto __pyx_L19_try_end;
    __pyx_L12_error:;
    __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
    __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "axon/_loader.py":58
 * try:
 *     import cdecimal as _decimal
 * except:             # <<<<<<<<<<<<<<
 *     import decimal as _decimal
 * 
 */
    /*except:*/ {
      __Pyx_AddTraceback("axon._loader", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_3, &__pyx_t_7, &__pyx_t_8) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 58; __pyx_clineno = __LINE__; goto __pyx_L14_except_error;}
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_GOTREF(__pyx_t_8);

      /* "axon/_loader.py":59
 *     import cdecimal as _decimal
 * except:
 *     import decimal as _decimal             # <<<<<<<<<<<<<<
 * 
 * default_decimal_context = _decimal.getcontext()
 */
      __pyx_t_10 = __Pyx_Import(((PyObject *)__pyx_n_s__decimal), 0, 0); if (unlikely(!__pyx_t_10)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 59; __pyx_clineno = __LINE__; goto __pyx_L14_except_error;}
      __Pyx_GOTREF(__pyx_t_10);
      if (PyDict_SetItem(__pyx_d, __pyx_n_s___decimal, __pyx_t_10) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 59; __pyx_clineno = __LINE__; goto __pyx_L14_except_error;}
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      goto __pyx_L13_exception_handled;
    }
    __pyx_L14_except_error:;
    __Pyx_XGIVEREF(__pyx_t_6);
    __Pyx_XGIVEREF(__pyx_t_5);
    __Pyx_XGIVEREF(__pyx_t_4);
    __Pyx_ExceptionReset(__pyx_t_6, __pyx_t_5, __pyx_t_4);
    goto __pyx_L1_error;
    __pyx_L13_exception_handled:;
    __Pyx_XGIVEREF(__pyx_t_6);
    __Pyx_XGIVEREF(__pyx_t_5);
    __Pyx_XGIVEREF(__pyx_t_4);
    __Pyx_ExceptionReset(__pyx_t_6, __pyx_t_5, __pyx_t_4);
    __pyx_L19_try_end:;
  }

  /* "axon/_loader.py":61
 *     import decimal as _decimal
 * 
 * default_decimal_context = _decimal.getcontext()             # <<<<<<<<<<<<<<
 * _str2decimal = default_decimal_context.create_decimal
 * _decimal2str = default_decimal_context.to_eng_string
 */
  __pyx_t_8 = __Pyx_GetModuleGlobalName(__pyx_n_s___decimal); if (unlikely(!__pyx_t_8)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 61; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_8);
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_8, __pyx_n_s__getcontext); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 61; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  __pyx_t_8 = PyObject_Call(__pyx_t_7, ((PyObject *)__pyx_empty_tuple), NULL); if (unlikely(!__pyx_t_8)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 61; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_54, __pyx_t_8) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 61; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

  /* "axon/_loader.py":62
 * 
 * default_decimal_context = _decimal.getcontext()
 * _str2decimal = default_decimal_context.create_decimal             # <<<<<<<<<<<<<<
 * _decimal2str = default_decimal_context.to_eng_string
 * 
 */
  __pyx_t_8 = __Pyx_GetModuleGlobalName(__pyx_n_s_54); if (unlikely(!__pyx_t_8)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 62; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_8);
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_8, __pyx_n_s__create_decimal); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 62; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  __Pyx_XGOTREF(__pyx_v_4axon_7_loader__str2decimal);
  __Pyx_DECREF(__pyx_v_4axon_7_loader__str2decimal);
  __Pyx_GIVEREF(__pyx_t_7);
  __pyx_v_4axon_7_loader__str2decimal = __pyx_t_7;
  __pyx_t_7 = 0;

  /* "axon/_loader.py":63
 * default_decimal_context = _decimal.getcontext()
 * _str2decimal = default_decimal_context.create_decimal
 * _decimal2str = default_decimal_context.to_eng_string             # <<<<<<<<<<<<<<
 * 
 * def str2float(text):
 */
  __pyx_t_7 = __Pyx_GetModuleGlobalName(__pyx_n_s_54); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 63; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s__to_eng_string); if (unlikely(!__pyx_t_8)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 63; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s___decimal2str, __pyx_t_8) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 63; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

  /* "axon/_loader.py":104
 *     return datetime_new(y, M, d, h, m, s, ms, tz)
 * 
 * _inf = float('inf')             # <<<<<<<<<<<<<<
 * _ninf = float('-inf')
 * _nan = float('nan')
 */
  __pyx_t_11 = __Pyx_PyObject_AsDouble(((PyObject *)__pyx_n_u__inf)); if (unlikely(__pyx_t_11 == ((double)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 104; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_t_8 = PyFloat_FromDouble(__pyx_t_11); if (unlikely(!__pyx_t_8)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 104; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_XGOTREF(__pyx_v_4axon_7_loader__inf);
  __Pyx_DECREF(__pyx_v_4axon_7_loader__inf);
  __Pyx_GIVEREF(__pyx_t_8);
  __pyx_v_4axon_7_loader__inf = __pyx_t_8;
  __pyx_t_8 = 0;

  /* "axon/_loader.py":105
 * 
 * _inf = float('inf')
 * _ninf = float('-inf')             # <<<<<<<<<<<<<<
 * _nan = float('nan')
 * 
 */
  __pyx_t_11 = __Pyx_PyObject_AsDouble(((PyObject *)__pyx_kp_u_55)); if (unlikely(__pyx_t_11 == ((double)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 105; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_t_8 = PyFloat_FromDouble(__pyx_t_11); if (unlikely(!__pyx_t_8)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 105; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_XGOTREF(__pyx_v_4axon_7_loader__ninf);
  __Pyx_DECREF(__pyx_v_4axon_7_loader__ninf);
  __Pyx_GIVEREF(__pyx_t_8);
  __pyx_v_4axon_7_loader__ninf = __pyx_t_8;
  __pyx_t_8 = 0;

  /* "axon/_loader.py":106
 * _inf = float('inf')
 * _ninf = float('-inf')
 * _nan = float('nan')             # <<<<<<<<<<<<<<
 * 
 * def float_inf():
 */
  __pyx_t_11 = __Pyx_PyObject_AsDouble(((PyObject *)__pyx_n_u__nan)); if (unlikely(__pyx_t_11 == ((double)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 106; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_t_8 = PyFloat_FromDouble(__pyx_t_11); if (unlikely(!__pyx_t_8)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 106; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_XGOTREF(__pyx_v_4axon_7_loader__nan);
  __Pyx_DECREF(__pyx_v_4axon_7_loader__nan);
  __Pyx_GIVEREF(__pyx_t_8);
  __pyx_v_4axon_7_loader__nan = __pyx_t_8;
  __pyx_t_8 = 0;

  /* "axon/_loader.py":193
 *     pass
 * 
 * tz_dict = {}             # <<<<<<<<<<<<<<
 * 
 * class FixedOffsetTZ(tzinfo):
 */
  __pyx_t_8 = PyDict_New(); if (unlikely(!__pyx_t_8)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 193; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(((PyObject *)__pyx_t_8));
  __Pyx_XGOTREF(((PyObject *)__pyx_v_4axon_7_loader_tz_dict));
  __Pyx_DECREF(((PyObject *)__pyx_v_4axon_7_loader_tz_dict));
  __Pyx_GIVEREF(((PyObject *)__pyx_t_8));
  __pyx_v_4axon_7_loader_tz_dict = ((PyObject*)__pyx_t_8);
  __pyx_t_8 = 0;

  /* "axon/_loader.py":307
 *     '''
 *     #
 *     def __init__(self, fd, mode='safe', errto=None, json=False):             # <<<<<<<<<<<<<<
 *         '''
 *         .. py:function:: Loader(fd, readline, builder="safe", sbuilder="default", errto=None)
 */
  __pyx_t_8 = __Pyx_PyBool_FromLong(0); if (unlikely(!__pyx_t_8)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 307; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_8);
  __pyx_k_13 = __pyx_t_8;
  __Pyx_GIVEREF(__pyx_t_8);
  __pyx_t_8 = 0;

  /* "axon/_loader.py":1
 * # coding: utf-8             # <<<<<<<<<<<<<<
 * 
 * #cython: boundscheck=False
 */
  __pyx_t_8 = PyDict_New(); if (unlikely(!__pyx_t_8)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(((PyObject *)__pyx_t_8));
  if (PyDict_SetItem(__pyx_d, __pyx_n_s____test__, ((PyObject *)__pyx_t_8)) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(((PyObject *)__pyx_t_8)); __pyx_t_8 = 0;

  /* "axon/_objects.pxd":80
 *     return uname
 * 
 * cdef inline object py_as_name(object name):             # <<<<<<<<<<<<<<
 *     n = name_cache.get(name, None)
 *     if n is None:
 */
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_10);
  if (__pyx_m) {
    __Pyx_AddTraceback("init axon._loader", __pyx_clineno, __pyx_lineno, __pyx_filename);
    Py_DECREF(__pyx_m); __pyx_m = 0;
  } else if (!PyErr_Occurred()) {
    PyErr_SetString(PyExc_ImportError, "init axon._loader");
  }
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  #if PY_MAJOR_VERSION < 3
  return;
  #else
  return __pyx_m;
  #endif
}

/* Runtime support code */
#if CYTHON_REFNANNY
static __Pyx_RefNannyAPIStruct *__Pyx_RefNannyImportAPI(const char *modname) {
    PyObject *m = NULL, *p = NULL;
    void *r = NULL;
    m = PyImport_ImportModule((char *)modname);
    if (!m) goto end;
    p = PyObject_GetAttrString(m, (char *)"RefNannyAPI");
    if (!p) goto end;
    r = PyLong_AsVoidPtr(p);
end:
    Py_XDECREF(p);
    Py_XDECREF(m);
    return (__Pyx_RefNannyAPIStruct *)r;
}
#endif /* CYTHON_REFNANNY */

static PyObject *__Pyx_GetBuiltinName(PyObject *name) {
    PyObject* result = __Pyx_PyObject_GetAttrStr(__pyx_b, name);
    if (unlikely(!result)) {
        PyErr_Format(PyExc_NameError,
#if PY_MAJOR_VERSION >= 3
            "name '%U' is not defined", name);
#else
            "name '%s' is not defined", PyString_AS_STRING(name));
#endif
    }
    return result;
}

static void __Pyx_RaiseDoubleKeywordsError(
    const char* func_name,
    PyObject* kw_name)
{
    PyErr_Format(PyExc_TypeError,
        #if PY_MAJOR_VERSION >= 3
        "%s() got multiple values for keyword argument '%U'", func_name, kw_name);
        #else
        "%s() got multiple values for keyword argument '%s'", func_name,
        PyString_AsString(kw_name));
        #endif
}

static int __Pyx_ParseOptionalKeywords(
    PyObject *kwds,
    PyObject **argnames[],
    PyObject *kwds2,
    PyObject *values[],
    Py_ssize_t num_pos_args,
    const char* function_name)
{
    PyObject *key = 0, *value = 0;
    Py_ssize_t pos = 0;
    PyObject*** name;
    PyObject*** first_kw_arg = argnames + num_pos_args;
    while (PyDict_Next(kwds, &pos, &key, &value)) {
        name = first_kw_arg;
        while (*name && (**name != key)) name++;
        if (*name) {
            values[name-argnames] = value;
            continue;
        }
        name = first_kw_arg;
        #if PY_MAJOR_VERSION < 3
        if (likely(PyString_CheckExact(key)) || likely(PyString_Check(key))) {
            while (*name) {
                if ((CYTHON_COMPILING_IN_PYPY || PyString_GET_SIZE(**name) == PyString_GET_SIZE(key))
                        && _PyString_Eq(**name, key)) {
                    values[name-argnames] = value;
                    break;
                }
                name++;
            }
            if (*name) continue;
            else {
                PyObject*** argname = argnames;
                while (argname != first_kw_arg) {
                    if ((**argname == key) || (
                            (CYTHON_COMPILING_IN_PYPY || PyString_GET_SIZE(**argname) == PyString_GET_SIZE(key))
                             && _PyString_Eq(**argname, key))) {
                        goto arg_passed_twice;
                    }
                    argname++;
                }
            }
        } else
        #endif
        if (likely(PyUnicode_Check(key))) {
            while (*name) {
                int cmp = (**name == key) ? 0 :
                #if !CYTHON_COMPILING_IN_PYPY && PY_MAJOR_VERSION >= 3
                    (PyUnicode_GET_SIZE(**name) != PyUnicode_GET_SIZE(key)) ? 1 :
                #endif
                    PyUnicode_Compare(**name, key);
                if (cmp < 0 && unlikely(PyErr_Occurred())) goto bad;
                if (cmp == 0) {
                    values[name-argnames] = value;
                    break;
                }
                name++;
            }
            if (*name) continue;
            else {
                PyObject*** argname = argnames;
                while (argname != first_kw_arg) {
                    int cmp = (**argname == key) ? 0 :
                    #if !CYTHON_COMPILING_IN_PYPY && PY_MAJOR_VERSION >= 3
                        (PyUnicode_GET_SIZE(**argname) != PyUnicode_GET_SIZE(key)) ? 1 :
                    #endif
                        PyUnicode_Compare(**argname, key);
                    if (cmp < 0 && unlikely(PyErr_Occurred())) goto bad;
                    if (cmp == 0) goto arg_passed_twice;
                    argname++;
                }
            }
        } else
            goto invalid_keyword_type;
        if (kwds2) {
            if (unlikely(PyDict_SetItem(kwds2, key, value))) goto bad;
        } else {
            goto invalid_keyword;
        }
    }
    return 0;
arg_passed_twice:
    __Pyx_RaiseDoubleKeywordsError(function_name, key);
    goto bad;
invalid_keyword_type:
    PyErr_Format(PyExc_TypeError,
        "%s() keywords must be strings", function_name);
    goto bad;
invalid_keyword:
    PyErr_Format(PyExc_TypeError,
    #if PY_MAJOR_VERSION < 3
        "%s() got an unexpected keyword argument '%s'",
        function_name, PyString_AsString(key));
    #else
        "%s() got an unexpected keyword argument '%U'",
        function_name, key);
    #endif
bad:
    return -1;
}

static void __Pyx_RaiseArgtupleInvalid(
    const char* func_name,
    int exact,
    Py_ssize_t num_min,
    Py_ssize_t num_max,
    Py_ssize_t num_found)
{
    Py_ssize_t num_expected;
    const char *more_or_less;
    if (num_found < num_min) {
        num_expected = num_min;
        more_or_less = "at least";
    } else {
        num_expected = num_max;
        more_or_less = "at most";
    }
    if (exact) {
        more_or_less = "exactly";
    }
    PyErr_Format(PyExc_TypeError,
                 "%s() takes %s %" CYTHON_FORMAT_SSIZE_T "d positional argument%s (%" CYTHON_FORMAT_SSIZE_T "d given)",
                 func_name, more_or_less, num_expected,
                 (num_expected == 1) ? "" : "s", num_found);
}

static CYTHON_INLINE void __Pyx_RaiseClosureNameError(const char *varname) {
    PyErr_Format(PyExc_NameError, "free variable '%s' referenced before assignment in enclosing scope", varname);
}

static PyObject *
__Pyx_CyFunction_get_doc(__pyx_CyFunctionObject *op, CYTHON_UNUSED void *closure)
{
    if (unlikely(op->func_doc == NULL)) {
        if (op->func.m_ml->ml_doc) {
#if PY_MAJOR_VERSION >= 3
            op->func_doc = PyUnicode_FromString(op->func.m_ml->ml_doc);
#else
            op->func_doc = PyString_FromString(op->func.m_ml->ml_doc);
#endif
            if (unlikely(op->func_doc == NULL))
                return NULL;
        } else {
            Py_INCREF(Py_None);
            return Py_None;
        }
    }
    Py_INCREF(op->func_doc);
    return op->func_doc;
}
static int
__Pyx_CyFunction_set_doc(__pyx_CyFunctionObject *op, PyObject *value)
{
    PyObject *tmp = op->func_doc;
    if (value == NULL)
        value = Py_None; /* Mark as deleted */
    Py_INCREF(value);
    op->func_doc = value;
    Py_XDECREF(tmp);
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_name(__pyx_CyFunctionObject *op)
{
    if (unlikely(op->func_name == NULL)) {
#if PY_MAJOR_VERSION >= 3
        op->func_name = PyUnicode_InternFromString(op->func.m_ml->ml_name);
#else
        op->func_name = PyString_InternFromString(op->func.m_ml->ml_name);
#endif
        if (unlikely(op->func_name == NULL))
            return NULL;
    }
    Py_INCREF(op->func_name);
    return op->func_name;
}
static int
__Pyx_CyFunction_set_name(__pyx_CyFunctionObject *op, PyObject *value)
{
    PyObject *tmp;
#if PY_MAJOR_VERSION >= 3
    if (unlikely(value == NULL || !PyUnicode_Check(value))) {
#else
    if (unlikely(value == NULL || !PyString_Check(value))) {
#endif
        PyErr_SetString(PyExc_TypeError,
                        "__name__ must be set to a string object");
        return -1;
    }
    tmp = op->func_name;
    Py_INCREF(value);
    op->func_name = value;
    Py_XDECREF(tmp);
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_qualname(__pyx_CyFunctionObject *op)
{
    Py_INCREF(op->func_qualname);
    return op->func_qualname;
}
static int
__Pyx_CyFunction_set_qualname(__pyx_CyFunctionObject *op, PyObject *value)
{
    PyObject *tmp;
#if PY_MAJOR_VERSION >= 3
    if (unlikely(value == NULL || !PyUnicode_Check(value))) {
#else
    if (unlikely(value == NULL || !PyString_Check(value))) {
#endif
        PyErr_SetString(PyExc_TypeError,
                        "__qualname__ must be set to a string object");
        return -1;
    }
    tmp = op->func_qualname;
    Py_INCREF(value);
    op->func_qualname = value;
    Py_XDECREF(tmp);
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_self(__pyx_CyFunctionObject *m, CYTHON_UNUSED void *closure)
{
    PyObject *self;
    self = m->func_closure;
    if (self == NULL)
        self = Py_None;
    Py_INCREF(self);
    return self;
}
static PyObject *
__Pyx_CyFunction_get_dict(__pyx_CyFunctionObject *op)
{
    if (unlikely(op->func_dict == NULL)) {
        op->func_dict = PyDict_New();
        if (unlikely(op->func_dict == NULL))
            return NULL;
    }
    Py_INCREF(op->func_dict);
    return op->func_dict;
}
static int
__Pyx_CyFunction_set_dict(__pyx_CyFunctionObject *op, PyObject *value)
{
    PyObject *tmp;
    if (unlikely(value == NULL)) {
        PyErr_SetString(PyExc_TypeError,
               "function's dictionary may not be deleted");
        return -1;
    }
    if (unlikely(!PyDict_Check(value))) {
        PyErr_SetString(PyExc_TypeError,
               "setting function's dictionary to a non-dict");
        return -1;
    }
    tmp = op->func_dict;
    Py_INCREF(value);
    op->func_dict = value;
    Py_XDECREF(tmp);
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_globals(CYTHON_UNUSED __pyx_CyFunctionObject *op)
{
    PyObject* dict = PyModule_GetDict(__pyx_m);
    Py_XINCREF(dict);
    return dict;
}
static PyObject *
__Pyx_CyFunction_get_closure(CYTHON_UNUSED __pyx_CyFunctionObject *op)
{
    Py_INCREF(Py_None);
    return Py_None;
}
static PyObject *
__Pyx_CyFunction_get_code(__pyx_CyFunctionObject *op)
{
    PyObject* result = (op->func_code) ? op->func_code : Py_None;
    Py_INCREF(result);
    return result;
}
static int
__Pyx_CyFunction_init_defaults(__pyx_CyFunctionObject *op) {
    PyObject *res = op->defaults_getter((PyObject *) op);
    if (unlikely(!res))
        return -1;
    op->defaults_tuple = PyTuple_GET_ITEM(res, 0);
    Py_INCREF(op->defaults_tuple);
    op->defaults_kwdict = PyTuple_GET_ITEM(res, 1);
    Py_INCREF(op->defaults_kwdict);
    Py_DECREF(res);
    return 0;
}
static int
__Pyx_CyFunction_set_defaults(__pyx_CyFunctionObject *op, PyObject* value) {
    PyObject* tmp;
    if (!value) {
        value = Py_None;
    } else if (value != Py_None && !PyTuple_Check(value)) {
        PyErr_SetString(PyExc_TypeError,
                        "__defaults__ must be set to a tuple object");
        return -1;
    }
    Py_INCREF(value);
    tmp = op->defaults_tuple;
    op->defaults_tuple = value;
    Py_XDECREF(tmp);
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_defaults(__pyx_CyFunctionObject *op) {
    PyObject* result = op->defaults_tuple;
    if (unlikely(!result)) {
        if (op->defaults_getter) {
            if (__Pyx_CyFunction_init_defaults(op) < 0) return NULL;
            result = op->defaults_tuple;
        } else {
            result = Py_None;
        }
    }
    Py_INCREF(result);
    return result;
}
static int
__Pyx_CyFunction_set_kwdefaults(__pyx_CyFunctionObject *op, PyObject* value) {
    PyObject* tmp;
    if (!value) {
        value = Py_None;
    } else if (value != Py_None && !PyDict_Check(value)) {
        PyErr_SetString(PyExc_TypeError,
                        "__kwdefaults__ must be set to a dict object");
        return -1;
    }
    Py_INCREF(value);
    tmp = op->defaults_kwdict;
    op->defaults_kwdict = value;
    Py_XDECREF(tmp);
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_kwdefaults(__pyx_CyFunctionObject *op) {
    PyObject* result = op->defaults_kwdict;
    if (unlikely(!result)) {
        if (op->defaults_getter) {
            if (__Pyx_CyFunction_init_defaults(op) < 0) return NULL;
            result = op->defaults_kwdict;
        } else {
            result = Py_None;
        }
    }
    Py_INCREF(result);
    return result;
}
static int
__Pyx_CyFunction_set_annotations(__pyx_CyFunctionObject *op, PyObject* value) {
    PyObject* tmp;
    if (!value || value == Py_None) {
        value = NULL;
    } else if (!PyDict_Check(value)) {
        PyErr_SetString(PyExc_TypeError,
                        "__annotations__ must be set to a dict object");
        return -1;
    }
    Py_XINCREF(value);
    tmp = op->func_annotations;
    op->func_annotations = value;
    Py_XDECREF(tmp);
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_annotations(__pyx_CyFunctionObject *op) {
    PyObject* result = op->func_annotations;
    if (unlikely(!result)) {
        result = PyDict_New();
        if (unlikely(!result)) return NULL;
        op->func_annotations = result;
    }
    Py_INCREF(result);
    return result;
}
static PyGetSetDef __pyx_CyFunction_getsets[] = {
    {(char *) "func_doc", (getter)__Pyx_CyFunction_get_doc, (setter)__Pyx_CyFunction_set_doc, 0, 0},
    {(char *) "__doc__",  (getter)__Pyx_CyFunction_get_doc, (setter)__Pyx_CyFunction_set_doc, 0, 0},
    {(char *) "func_name", (getter)__Pyx_CyFunction_get_name, (setter)__Pyx_CyFunction_set_name, 0, 0},
    {(char *) "__name__", (getter)__Pyx_CyFunction_get_name, (setter)__Pyx_CyFunction_set_name, 0, 0},
    {(char *) "__qualname__", (getter)__Pyx_CyFunction_get_qualname, (setter)__Pyx_CyFunction_set_qualname, 0, 0},
    {(char *) "__self__", (getter)__Pyx_CyFunction_get_self, 0, 0, 0},
    {(char *) "func_dict", (getter)__Pyx_CyFunction_get_dict, (setter)__Pyx_CyFunction_set_dict, 0, 0},
    {(char *) "__dict__", (getter)__Pyx_CyFunction_get_dict, (setter)__Pyx_CyFunction_set_dict, 0, 0},
    {(char *) "func_globals", (getter)__Pyx_CyFunction_get_globals, 0, 0, 0},
    {(char *) "__globals__", (getter)__Pyx_CyFunction_get_globals, 0, 0, 0},
    {(char *) "func_closure", (getter)__Pyx_CyFunction_get_closure, 0, 0, 0},
    {(char *) "__closure__", (getter)__Pyx_CyFunction_get_closure, 0, 0, 0},
    {(char *) "func_code", (getter)__Pyx_CyFunction_get_code, 0, 0, 0},
    {(char *) "__code__", (getter)__Pyx_CyFunction_get_code, 0, 0, 0},
    {(char *) "func_defaults", (getter)__Pyx_CyFunction_get_defaults, (setter)__Pyx_CyFunction_set_defaults, 0, 0},
    {(char *) "__defaults__", (getter)__Pyx_CyFunction_get_defaults, (setter)__Pyx_CyFunction_set_defaults, 0, 0},
    {(char *) "__kwdefaults__", (getter)__Pyx_CyFunction_get_kwdefaults, (setter)__Pyx_CyFunction_set_kwdefaults, 0, 0},
    {(char *) "__annotations__", (getter)__Pyx_CyFunction_get_annotations, (setter)__Pyx_CyFunction_set_annotations, 0, 0},
    {0, 0, 0, 0, 0}
};
#ifndef PY_WRITE_RESTRICTED /* < Py2.5 */
#define PY_WRITE_RESTRICTED WRITE_RESTRICTED
#endif
static PyMemberDef __pyx_CyFunction_members[] = {
    {(char *) "__module__", T_OBJECT, offsetof(__pyx_CyFunctionObject, func.m_module), PY_WRITE_RESTRICTED, 0},
    {0, 0, 0,  0, 0}
};
static PyObject *
__Pyx_CyFunction_reduce(__pyx_CyFunctionObject *m, CYTHON_UNUSED PyObject *args)
{
#if PY_MAJOR_VERSION >= 3
    return PyUnicode_FromString(m->func.m_ml->ml_name);
#else
    return PyString_FromString(m->func.m_ml->ml_name);
#endif
}
static PyMethodDef __pyx_CyFunction_methods[] = {
    {__Pyx_NAMESTR("__reduce__"), (PyCFunction)__Pyx_CyFunction_reduce, METH_VARARGS, 0},
    {0, 0, 0, 0}
};
static PyObject *__Pyx_CyFunction_New(PyTypeObject *type, PyMethodDef *ml, int flags, PyObject* qualname,
                                      PyObject *closure, PyObject *module, PyObject* code) {
    __pyx_CyFunctionObject *op = PyObject_GC_New(__pyx_CyFunctionObject, type);
    if (op == NULL)
        return NULL;
    op->flags = flags;
    op->func_weakreflist = NULL;
    op->func.m_ml = ml;
    op->func.m_self = (PyObject *) op;
    Py_XINCREF(closure);
    op->func_closure = closure;
    Py_XINCREF(module);
    op->func.m_module = module;
    op->func_dict = NULL;
    op->func_name = NULL;
    Py_INCREF(qualname);
    op->func_qualname = qualname;
    op->func_doc = NULL;
    op->func_classobj = NULL;
    Py_XINCREF(code);
    op->func_code = code;
    op->defaults_pyobjects = 0;
    op->defaults = NULL;
    op->defaults_tuple = NULL;
    op->defaults_kwdict = NULL;
    op->defaults_getter = NULL;
    op->func_annotations = NULL;
    PyObject_GC_Track(op);
    return (PyObject *) op;
}
static int
__Pyx_CyFunction_clear(__pyx_CyFunctionObject *m)
{
    Py_CLEAR(m->func_closure);
    Py_CLEAR(m->func.m_module);
    Py_CLEAR(m->func_dict);
    Py_CLEAR(m->func_name);
    Py_CLEAR(m->func_qualname);
    Py_CLEAR(m->func_doc);
    Py_CLEAR(m->func_code);
    Py_CLEAR(m->func_classobj);
    Py_CLEAR(m->defaults_tuple);
    Py_CLEAR(m->defaults_kwdict);
    Py_CLEAR(m->func_annotations);
    if (m->defaults) {
        PyObject **pydefaults = __Pyx_CyFunction_Defaults(PyObject *, m);
        int i;
        for (i = 0; i < m->defaults_pyobjects; i++)
            Py_XDECREF(pydefaults[i]);
        PyMem_Free(m->defaults);
        m->defaults = NULL;
    }
    return 0;
}
static void __Pyx_CyFunction_dealloc(__pyx_CyFunctionObject *m)
{
    PyObject_GC_UnTrack(m);
    if (m->func_weakreflist != NULL)
        PyObject_ClearWeakRefs((PyObject *) m);
    __Pyx_CyFunction_clear(m);
    PyObject_GC_Del(m);
}
static int __Pyx_CyFunction_traverse(__pyx_CyFunctionObject *m, visitproc visit, void *arg)
{
    Py_VISIT(m->func_closure);
    Py_VISIT(m->func.m_module);
    Py_VISIT(m->func_dict);
    Py_VISIT(m->func_name);
    Py_VISIT(m->func_qualname);
    Py_VISIT(m->func_doc);
    Py_VISIT(m->func_code);
    Py_VISIT(m->func_classobj);
    Py_VISIT(m->defaults_tuple);
    Py_VISIT(m->defaults_kwdict);
    if (m->defaults) {
        PyObject **pydefaults = __Pyx_CyFunction_Defaults(PyObject *, m);
        int i;
        for (i = 0; i < m->defaults_pyobjects; i++)
            Py_VISIT(pydefaults[i]);
    }
    return 0;
}
static PyObject *__Pyx_CyFunction_descr_get(PyObject *func, PyObject *obj, PyObject *type)
{
    __pyx_CyFunctionObject *m = (__pyx_CyFunctionObject *) func;
    if (m->flags & __Pyx_CYFUNCTION_STATICMETHOD) {
        Py_INCREF(func);
        return func;
    }
    if (m->flags & __Pyx_CYFUNCTION_CLASSMETHOD) {
        if (type == NULL)
            type = (PyObject *)(Py_TYPE(obj));
        return PyMethod_New(func,
                            type, (PyObject *)(Py_TYPE(type)));
    }
    if (obj == Py_None)
        obj = NULL;
    return PyMethod_New(func, obj, type);
}
static PyObject*
__Pyx_CyFunction_repr(__pyx_CyFunctionObject *op)
{
#if PY_MAJOR_VERSION >= 3
    return PyUnicode_FromFormat("<cyfunction %U at %p>",
                                op->func_qualname, (void *)op);
#else
    return PyString_FromFormat("<cyfunction %s at %p>",
                               PyString_AsString(op->func_qualname), (void *)op);
#endif
}
#if CYTHON_COMPILING_IN_PYPY
static PyObject * __Pyx_CyFunction_Call(PyObject *func, PyObject *arg, PyObject *kw) {
    PyCFunctionObject* f = (PyCFunctionObject*)func;
    PyCFunction meth = PyCFunction_GET_FUNCTION(func);
    PyObject *self = PyCFunction_GET_SELF(func);
    Py_ssize_t size;
    switch (PyCFunction_GET_FLAGS(func) & ~(METH_CLASS | METH_STATIC | METH_COEXIST)) {
    case METH_VARARGS:
        if (likely(kw == NULL) || PyDict_Size(kw) == 0)
            return (*meth)(self, arg);
        break;
    case METH_VARARGS | METH_KEYWORDS:
        return (*(PyCFunctionWithKeywords)meth)(self, arg, kw);
    case METH_NOARGS:
        if (likely(kw == NULL) || PyDict_Size(kw) == 0) {
            size = PyTuple_GET_SIZE(arg);
            if (size == 0)
                return (*meth)(self, NULL);
            PyErr_Format(PyExc_TypeError,
                "%.200s() takes no arguments (%zd given)",
                f->m_ml->ml_name, size);
            return NULL;
        }
        break;
    case METH_O:
        if (likely(kw == NULL) || PyDict_Size(kw) == 0) {
            size = PyTuple_GET_SIZE(arg);
            if (size == 1)
                return (*meth)(self, PyTuple_GET_ITEM(arg, 0));
            PyErr_Format(PyExc_TypeError,
                "%.200s() takes exactly one argument (%zd given)",
                f->m_ml->ml_name, size);
            return NULL;
        }
        break;
    default:
        PyErr_SetString(PyExc_SystemError, "Bad call flags in "
                        "__Pyx_CyFunction_Call. METH_OLDARGS is no "
                        "longer supported!");
        return NULL;
    }
    PyErr_Format(PyExc_TypeError, "%.200s() takes no keyword arguments",
                 f->m_ml->ml_name);
    return NULL;
}
#else
static PyObject * __Pyx_CyFunction_Call(PyObject *func, PyObject *arg, PyObject *kw) {
	return PyCFunction_Call(func, arg, kw);
}
#endif
static PyTypeObject __pyx_CyFunctionType_type = {
    PyVarObject_HEAD_INIT(0, 0)
    __Pyx_NAMESTR("cython_function_or_method"), /*tp_name*/
    sizeof(__pyx_CyFunctionObject),   /*tp_basicsize*/
    0,                                  /*tp_itemsize*/
    (destructor) __Pyx_CyFunction_dealloc, /*tp_dealloc*/
    0,                                  /*tp_print*/
    0,                                  /*tp_getattr*/
    0,                                  /*tp_setattr*/
#if PY_MAJOR_VERSION < 3
    0,                                  /*tp_compare*/
#else
    0,                                  /*reserved*/
#endif
    (reprfunc) __Pyx_CyFunction_repr,   /*tp_repr*/
    0,                                  /*tp_as_number*/
    0,                                  /*tp_as_sequence*/
    0,                                  /*tp_as_mapping*/
    0,                                  /*tp_hash*/
    __Pyx_CyFunction_Call,              /*tp_call*/
    0,                                  /*tp_str*/
    0,                                  /*tp_getattro*/
    0,                                  /*tp_setattro*/
    0,                                  /*tp_as_buffer*/
    Py_TPFLAGS_DEFAULT | Py_TPFLAGS_HAVE_GC, /* tp_flags*/
    0,                                  /*tp_doc*/
    (traverseproc) __Pyx_CyFunction_traverse,   /*tp_traverse*/
    (inquiry) __Pyx_CyFunction_clear,   /*tp_clear*/
    0,                                  /*tp_richcompare*/
    offsetof(__pyx_CyFunctionObject, func_weakreflist), /* tp_weaklistoffse */
    0,                                  /*tp_iter*/
    0,                                  /*tp_iternext*/
    __pyx_CyFunction_methods,           /*tp_methods*/
    __pyx_CyFunction_members,           /*tp_members*/
    __pyx_CyFunction_getsets,           /*tp_getset*/
    0,                                  /*tp_base*/
    0,                                  /*tp_dict*/
    __Pyx_CyFunction_descr_get,         /*tp_descr_get*/
    0,                                  /*tp_descr_set*/
    offsetof(__pyx_CyFunctionObject, func_dict),/*tp_dictoffset*/
    0,                                  /*tp_init*/
    0,                                  /*tp_alloc*/
    0,                                  /*tp_new*/
    0,                                  /*tp_free*/
    0,                                  /*tp_is_gc*/
    0,                                  /*tp_bases*/
    0,                                  /*tp_mro*/
    0,                                  /*tp_cache*/
    0,                                  /*tp_subclasses*/
    0,                                  /*tp_weaklist*/
    0,                                  /*tp_del*/
#if PY_VERSION_HEX >= 0x02060000
    0,                                  /*tp_version_tag*/
#endif
};
static int __Pyx_CyFunction_init(void) {
#if !CYTHON_COMPILING_IN_PYPY
    __pyx_CyFunctionType_type.tp_call = PyCFunction_Call;
#endif
    if (PyType_Ready(&__pyx_CyFunctionType_type) < 0)
        return -1;
    __pyx_CyFunctionType = &__pyx_CyFunctionType_type;
    return 0;
}
static CYTHON_INLINE void *__Pyx_CyFunction_InitDefaults(PyObject *func, size_t size, int pyobjects) {
    __pyx_CyFunctionObject *m = (__pyx_CyFunctionObject *) func;
    m->defaults = PyMem_Malloc(size);
    if (!m->defaults)
        return PyErr_NoMemory();
    memset(m->defaults, 0, size);
    m->defaults_pyobjects = pyobjects;
    return m->defaults;
}
static CYTHON_INLINE void __Pyx_CyFunction_SetDefaultsTuple(PyObject *func, PyObject *tuple) {
    __pyx_CyFunctionObject *m = (__pyx_CyFunctionObject *) func;
    m->defaults_tuple = tuple;
    Py_INCREF(tuple);
}
static CYTHON_INLINE void __Pyx_CyFunction_SetDefaultsKwDict(PyObject *func, PyObject *dict) {
    __pyx_CyFunctionObject *m = (__pyx_CyFunctionObject *) func;
    m->defaults_kwdict = dict;
    Py_INCREF(dict);
}
static CYTHON_INLINE void __Pyx_CyFunction_SetAnnotationsDict(PyObject *func, PyObject *dict) {
    __pyx_CyFunctionObject *m = (__pyx_CyFunctionObject *) func;
    m->func_annotations = dict;
    Py_INCREF(dict);
}

static PyObject* __Pyx_PyDict_GetItemDefault(PyObject* d, PyObject* key, PyObject* default_value) {
    PyObject* value;
#if PY_MAJOR_VERSION >= 3
    value = PyDict_GetItemWithError(d, key);
    if (unlikely(!value)) {
        if (unlikely(PyErr_Occurred()))
            return NULL;
        value = default_value;
    }
    Py_INCREF(value);
#else
    if (PyString_CheckExact(key) || PyUnicode_CheckExact(key) || PyInt_CheckExact(key)) {
        value = PyDict_GetItem(d, key);
        if (unlikely(!value)) {
            value = default_value;
        }
        Py_INCREF(value);
    } else {
        if (default_value == Py_None)
            default_value = NULL;
        value = PyObject_CallMethodObjArgs(
            d, __pyx_n_s__get, key, default_value, NULL);
    }
#endif
    return value;
}

static CYTHON_INLINE PyObject *__Pyx_GetModuleGlobalName(PyObject *name) {
    PyObject *result;
#if CYTHON_COMPILING_IN_CPYTHON
    result = PyDict_GetItem(__pyx_d, name);
    if (result) {
        Py_INCREF(result);
    } else {
#else
    result = PyObject_GetItem(__pyx_d, name);
    if (!result) {
        PyErr_Clear();
#endif
        result = __Pyx_GetBuiltinName(name);
    }
    return result;
}

static CYTHON_INLINE void __Pyx_RaiseTooManyValuesError(Py_ssize_t expected) {
    PyErr_Format(PyExc_ValueError,
                 "too many values to unpack (expected %" CYTHON_FORMAT_SSIZE_T "d)", expected);
}

static CYTHON_INLINE void __Pyx_RaiseNeedMoreValuesError(Py_ssize_t index) {
    PyErr_Format(PyExc_ValueError,
                 "need more than %" CYTHON_FORMAT_SSIZE_T "d value%s to unpack",
                 index, (index == 1) ? "" : "s");
}

static CYTHON_INLINE int __Pyx_IterFinish(void) {
#if CYTHON_COMPILING_IN_CPYTHON
    PyThreadState *tstate = PyThreadState_GET();
    PyObject* exc_type = tstate->curexc_type;
    if (unlikely(exc_type)) {
        if (likely(exc_type == PyExc_StopIteration) || PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration)) {
            PyObject *exc_value, *exc_tb;
            exc_value = tstate->curexc_value;
            exc_tb = tstate->curexc_traceback;
            tstate->curexc_type = 0;
            tstate->curexc_value = 0;
            tstate->curexc_traceback = 0;
            Py_DECREF(exc_type);
            Py_XDECREF(exc_value);
            Py_XDECREF(exc_tb);
            return 0;
        } else {
            return -1;
        }
    }
    return 0;
#else
    if (unlikely(PyErr_Occurred())) {
        if (likely(PyErr_ExceptionMatches(PyExc_StopIteration))) {
            PyErr_Clear();
            return 0;
        } else {
            return -1;
        }
    }
    return 0;
#endif
}

static int __Pyx_IternextUnpackEndCheck(PyObject *retval, Py_ssize_t expected) {
    if (unlikely(retval)) {
        Py_DECREF(retval);
        __Pyx_RaiseTooManyValuesError(expected);
        return -1;
    } else {
        return __Pyx_IterFinish();
    }
    return 0;
}

static CYTHON_INLINE int __Pyx_SetItemInt_Generic(PyObject *o, PyObject *j, PyObject *v) {
    int r;
    if (!j) return -1;
    r = PyObject_SetItem(o, j, v);
    Py_DECREF(j);
    return r;
}
static CYTHON_INLINE int __Pyx_SetItemInt_Fast(PyObject *o, Py_ssize_t i, PyObject *v,
                                               int is_list, int wraparound, int boundscheck) {
#if CYTHON_COMPILING_IN_CPYTHON
    if (is_list || PyList_CheckExact(o)) {
        Py_ssize_t n = (!wraparound) ? i : ((likely(i >= 0)) ? i : i + PyList_GET_SIZE(o));
        if ((!boundscheck) || likely((n >= 0) & (n < PyList_GET_SIZE(o)))) {
            PyObject* old = PyList_GET_ITEM(o, n);
            Py_INCREF(v);
            PyList_SET_ITEM(o, n, v);
            Py_DECREF(old);
            return 1;
        }
    } else {
        PySequenceMethods *m = Py_TYPE(o)->tp_as_sequence;
        if (likely(m && m->sq_ass_item)) {
            if (wraparound && unlikely(i < 0) && likely(m->sq_length)) {
                Py_ssize_t l = m->sq_length(o);
                if (likely(l >= 0)) {
                    i += l;
                } else {
                    if (PyErr_ExceptionMatches(PyExc_OverflowError))
                        PyErr_Clear();
                    else
                        return -1;
                }
            }
            return m->sq_ass_item(o, i, v);
        }
    }
#else
#if CYTHON_COMPILING_IN_PYPY
    if (is_list || (PySequence_Check(o) && !PyDict_Check(o))) {
#else
    if (is_list || PySequence_Check(o)) {
#endif
        return PySequence_SetItem(o, i, v);
    }
#endif
    return __Pyx_SetItemInt_Generic(o, PyInt_FromSsize_t(i), v);
}

static CYTHON_INLINE int __Pyx_CheckKeywordStrings(
    PyObject *kwdict,
    const char* function_name,
    int kw_allowed)
{
    PyObject* key = 0;
    Py_ssize_t pos = 0;
#if CPYTHON_COMPILING_IN_PYPY
    if (!kw_allowed && PyDict_Next(kwdict, &pos, &key, 0))
        goto invalid_keyword;
    return 1;
#else
    while (PyDict_Next(kwdict, &pos, &key, 0)) {
        #if PY_MAJOR_VERSION < 3
        if (unlikely(!PyString_CheckExact(key)) && unlikely(!PyString_Check(key)))
        #endif
            if (unlikely(!PyUnicode_Check(key)))
                goto invalid_keyword_type;
    }
    if ((!kw_allowed) && unlikely(key))
        goto invalid_keyword;
    return 1;
invalid_keyword_type:
    PyErr_Format(PyExc_TypeError,
        "%s() keywords must be strings", function_name);
    return 0;
#endif
invalid_keyword:
    PyErr_Format(PyExc_TypeError,
    #if PY_MAJOR_VERSION < 3
        "%s() got an unexpected keyword argument '%s'",
        function_name, PyString_AsString(key));
    #else
        "%s() got an unexpected keyword argument '%U'",
        function_name, key);
    #endif
    return 0;
}

static CYTHON_INLINE void __Pyx_ErrRestore(PyObject *type, PyObject *value, PyObject *tb) {
#if CYTHON_COMPILING_IN_CPYTHON
    PyObject *tmp_type, *tmp_value, *tmp_tb;
    PyThreadState *tstate = PyThreadState_GET();
    tmp_type = tstate->curexc_type;
    tmp_value = tstate->curexc_value;
    tmp_tb = tstate->curexc_traceback;
    tstate->curexc_type = type;
    tstate->curexc_value = value;
    tstate->curexc_traceback = tb;
    Py_XDECREF(tmp_type);
    Py_XDECREF(tmp_value);
    Py_XDECREF(tmp_tb);
#else
    PyErr_Restore(type, value, tb);
#endif
}
static CYTHON_INLINE void __Pyx_ErrFetch(PyObject **type, PyObject **value, PyObject **tb) {
#if CYTHON_COMPILING_IN_CPYTHON
    PyThreadState *tstate = PyThreadState_GET();
    *type = tstate->curexc_type;
    *value = tstate->curexc_value;
    *tb = tstate->curexc_traceback;
    tstate->curexc_type = 0;
    tstate->curexc_value = 0;
    tstate->curexc_traceback = 0;
#else
    PyErr_Fetch(type, value, tb);
#endif
}

#if PY_MAJOR_VERSION < 3
static void __Pyx_Raise(PyObject *type, PyObject *value, PyObject *tb,
                        CYTHON_UNUSED PyObject *cause) {
    Py_XINCREF(type);
    if (!value || value == Py_None)
        value = NULL;
    else
        Py_INCREF(value);
    if (!tb || tb == Py_None)
        tb = NULL;
    else {
        Py_INCREF(tb);
        if (!PyTraceBack_Check(tb)) {
            PyErr_SetString(PyExc_TypeError,
                "raise: arg 3 must be a traceback or None");
            goto raise_error;
        }
    }
    #if PY_VERSION_HEX < 0x02050000
    if (PyClass_Check(type)) {
    #else
    if (PyType_Check(type)) {
    #endif
#if CYTHON_COMPILING_IN_PYPY
        if (!value) {
            Py_INCREF(Py_None);
            value = Py_None;
        }
#endif
        PyErr_NormalizeException(&type, &value, &tb);
    } else {
        if (value) {
            PyErr_SetString(PyExc_TypeError,
                "instance exception may not have a separate value");
            goto raise_error;
        }
        value = type;
        #if PY_VERSION_HEX < 0x02050000
        if (PyInstance_Check(type)) {
            type = (PyObject*) ((PyInstanceObject*)type)->in_class;
            Py_INCREF(type);
        } else {
            type = 0;
            PyErr_SetString(PyExc_TypeError,
                "raise: exception must be an old-style class or instance");
            goto raise_error;
        }
        #else
        type = (PyObject*) Py_TYPE(type);
        Py_INCREF(type);
        if (!PyType_IsSubtype((PyTypeObject *)type, (PyTypeObject *)PyExc_BaseException)) {
            PyErr_SetString(PyExc_TypeError,
                "raise: exception class must be a subclass of BaseException");
            goto raise_error;
        }
        #endif
    }
    __Pyx_ErrRestore(type, value, tb);
    return;
raise_error:
    Py_XDECREF(value);
    Py_XDECREF(type);
    Py_XDECREF(tb);
    return;
}
#else /* Python 3+ */
static void __Pyx_Raise(PyObject *type, PyObject *value, PyObject *tb, PyObject *cause) {
    PyObject* owned_instance = NULL;
    if (tb == Py_None) {
        tb = 0;
    } else if (tb && !PyTraceBack_Check(tb)) {
        PyErr_SetString(PyExc_TypeError,
            "raise: arg 3 must be a traceback or None");
        goto bad;
    }
    if (value == Py_None)
        value = 0;
    if (PyExceptionInstance_Check(type)) {
        if (value) {
            PyErr_SetString(PyExc_TypeError,
                "instance exception may not have a separate value");
            goto bad;
        }
        value = type;
        type = (PyObject*) Py_TYPE(value);
    } else if (PyExceptionClass_Check(type)) {
        PyObject *args;
        if (!value)
            args = PyTuple_New(0);
        else if (PyTuple_Check(value)) {
            Py_INCREF(value);
            args = value;
        } else
            args = PyTuple_Pack(1, value);
        if (!args)
            goto bad;
        owned_instance = PyEval_CallObject(type, args);
        Py_DECREF(args);
        if (!owned_instance)
            goto bad;
        value = owned_instance;
        if (!PyExceptionInstance_Check(value)) {
            PyErr_Format(PyExc_TypeError,
                         "calling %R should have returned an instance of "
                         "BaseException, not %R",
                         type, Py_TYPE(value));
            goto bad;
        }
    } else {
        PyErr_SetString(PyExc_TypeError,
            "raise: exception class must be a subclass of BaseException");
        goto bad;
    }
#if PY_VERSION_HEX >= 0x03030000
    if (cause) {
#else
    if (cause && cause != Py_None) {
#endif
        PyObject *fixed_cause;
        if (cause == Py_None) {
            fixed_cause = NULL;
        } else if (PyExceptionClass_Check(cause)) {
            fixed_cause = PyObject_CallObject(cause, NULL);
            if (fixed_cause == NULL)
                goto bad;
        } else if (PyExceptionInstance_Check(cause)) {
            fixed_cause = cause;
            Py_INCREF(fixed_cause);
        } else {
            PyErr_SetString(PyExc_TypeError,
                            "exception causes must derive from "
                            "BaseException");
            goto bad;
        }
        PyException_SetCause(value, fixed_cause);
    }
    PyErr_SetObject(type, value);
    if (tb) {
        PyThreadState *tstate = PyThreadState_GET();
        PyObject* tmp_tb = tstate->curexc_traceback;
        if (tb != tmp_tb) {
            Py_INCREF(tb);
            tstate->curexc_traceback = tb;
            Py_XDECREF(tmp_tb);
        }
    }
bad:
    Py_XDECREF(owned_instance);
    return;
}
#endif

static CYTHON_INLINE int __Pyx_PyUnicode_Equals(PyObject* s1, PyObject* s2, int equals) {
#if CYTHON_COMPILING_IN_PYPY
    return PyObject_RichCompareBool(s1, s2, equals);
#else
    if (s1 == s2) {
        return (equals == Py_EQ);
    } else if (PyUnicode_CheckExact(s1) & PyUnicode_CheckExact(s2)) {
        #if CYTHON_PEP393_ENABLED
        if ((PyUnicode_READY(s1) < 0) || (PyUnicode_READY(s2) < 0))
            return -1;
        if (PyUnicode_GET_LENGTH(s1) != PyUnicode_GET_LENGTH(s2)) {
            return (equals == Py_NE);
        } else if (PyUnicode_GET_LENGTH(s1) == 1) {
            Py_UCS4 ch1 = PyUnicode_READ_CHAR(s1, 0);
            Py_UCS4 ch2 = PyUnicode_READ_CHAR(s2, 0);
            return (equals == Py_EQ) ? (ch1 == ch2) : (ch1 != ch2);
        #else
        if (PyUnicode_GET_SIZE(s1) != PyUnicode_GET_SIZE(s2)) {
            return (equals == Py_NE);
        } else if (PyUnicode_GET_SIZE(s1) == 1) {
            Py_UNICODE ch1 = PyUnicode_AS_UNICODE(s1)[0];
            Py_UNICODE ch2 = PyUnicode_AS_UNICODE(s2)[0];
            return (equals == Py_EQ) ? (ch1 == ch2) : (ch1 != ch2);
        #endif
        } else {
            int result = PyUnicode_Compare(s1, s2);
            if ((result == -1) && unlikely(PyErr_Occurred()))
                return -1;
            return (equals == Py_EQ) ? (result == 0) : (result != 0);
        }
    } else if ((s1 == Py_None) & PyUnicode_CheckExact(s2)) {
        return (equals == Py_NE);
    } else if ((s2 == Py_None) & PyUnicode_CheckExact(s1)) {
        return (equals == Py_NE);
    } else {
        int result;
        PyObject* py_result = PyObject_RichCompare(s1, s2, equals);
        if (!py_result)
            return -1;
        result = __Pyx_PyObject_IsTrue(py_result);
        Py_DECREF(py_result);
        return result;
    }
#endif
}

static CYTHON_INLINE Py_UCS4 __Pyx_GetItemInt_Unicode_Fast(PyObject* ustring, Py_ssize_t i,
                                                           int wraparound, int boundscheck) {
    Py_ssize_t length;
#if CYTHON_PEP393_ENABLED
    if (unlikely(__Pyx_PyUnicode_READY(ustring) < 0)) return (Py_UCS4)-1;
#endif
    if (wraparound | boundscheck) {
        length = __Pyx_PyUnicode_GET_LENGTH(ustring);
        if (wraparound & unlikely(i < 0)) i += length;
        if ((!boundscheck) || likely((0 <= i) & (i < length))) {
            return __Pyx_PyUnicode_READ_CHAR(ustring, i);
        } else {
            PyErr_SetString(PyExc_IndexError, "string index out of range");
            return (Py_UCS4)-1;
        }
    } else {
        return __Pyx_PyUnicode_READ_CHAR(ustring, i);
    }
}
static CYTHON_INLINE Py_UCS4 __Pyx_GetItemInt_Unicode_Generic(PyObject* ustring, PyObject* j) {
    Py_UCS4 uchar;
    PyObject *uchar_string;
    if (!j) return (Py_UCS4)-1;
    uchar_string = PyObject_GetItem(ustring, j);
    Py_DECREF(j);
    if (!uchar_string) return (Py_UCS4)-1;
#if CYTHON_PEP393_ENABLED
    if (unlikely(__Pyx_PyUnicode_READY(uchar_string) < 0)) {
        Py_DECREF(uchar_string);
        return (Py_UCS4)-1;
    }
#endif
    uchar = __Pyx_PyUnicode_READ_CHAR(uchar_string, 0);
    Py_DECREF(uchar_string);
    return uchar;
}

static void __Pyx_WriteUnraisable(const char *name, CYTHON_UNUSED int clineno,
                                  CYTHON_UNUSED int lineno, CYTHON_UNUSED const char *filename) {
    PyObject *old_exc, *old_val, *old_tb;
    PyObject *ctx;
    __Pyx_ErrFetch(&old_exc, &old_val, &old_tb);
    #if PY_MAJOR_VERSION < 3
    ctx = PyString_FromString(name);
    #else
    ctx = PyUnicode_FromString(name);
    #endif
    __Pyx_ErrRestore(old_exc, old_val, old_tb);
    if (!ctx) {
        PyErr_WriteUnraisable(Py_None);
    } else {
        PyErr_WriteUnraisable(ctx);
        Py_DECREF(ctx);
    }
}

static CYTHON_INLINE PyObject* __Pyx_PyUnicode_Substring(
            PyObject* text, Py_ssize_t start, Py_ssize_t stop) {
    Py_ssize_t length;
#if CYTHON_PEP393_ENABLED
    if (unlikely(PyUnicode_READY(text) == -1)) return NULL;
    length = PyUnicode_GET_LENGTH(text);
#else
    length = PyUnicode_GET_SIZE(text);
#endif
    if (start < 0) {
        start += length;
        if (start < 0)
            start = 0;
    }
    if (stop < 0)
        stop += length;
    else if (stop > length)
        stop = length;
    length = stop - start;
    if (length <= 0)
        return PyUnicode_FromUnicode(NULL, 0);
#if CYTHON_PEP393_ENABLED
    return PyUnicode_FromKindAndData(PyUnicode_KIND(text),
        PyUnicode_1BYTE_DATA(text) + start*PyUnicode_KIND(text), stop-start);
#else
    return PyUnicode_FromUnicode(PyUnicode_AS_UNICODE(text)+start, stop-start);
#endif
}

static CYTHON_INLINE void __Pyx_RaiseUnboundLocalError(const char *varname) {
    PyErr_Format(PyExc_UnboundLocalError, "local variable '%s' referenced before assignment", varname);
}

static void __Pyx_call_next_tp_dealloc(PyObject* obj, destructor current_tp_dealloc) {
    PyTypeObject* type = Py_TYPE(obj);
    while (type && type->tp_dealloc != current_tp_dealloc)
        type = type->tp_base;
    while (type && type->tp_dealloc == current_tp_dealloc)
        type = type->tp_base;
    if (type)
        type->tp_dealloc(obj);
}

static int __Pyx_call_next_tp_traverse(PyObject* obj, visitproc v, void *a, traverseproc current_tp_traverse) {
    PyTypeObject* type = Py_TYPE(obj);
    while (type && type->tp_traverse != current_tp_traverse)
        type = type->tp_base;
    while (type && type->tp_traverse == current_tp_traverse)
        type = type->tp_base;
    if (type && type->tp_traverse)
        return type->tp_traverse(obj, v, a);
    return 0;
}

static void __Pyx_call_next_tp_clear(PyObject* obj, inquiry current_tp_clear) {
    PyTypeObject* type = Py_TYPE(obj);
    while (type && type->tp_clear != current_tp_clear)
        type = type->tp_base;
    while (type && type->tp_clear == current_tp_clear)
        type = type->tp_base;
    if (type && type->tp_clear)
        type->tp_clear(obj);
}

static int __Pyx_SetVtable(PyObject *dict, void *vtable) {
#if PY_VERSION_HEX >= 0x02070000 && !(PY_MAJOR_VERSION==3&&PY_MINOR_VERSION==0)
    PyObject *ob = PyCapsule_New(vtable, 0, 0);
#else
    PyObject *ob = PyCObject_FromVoidPtr(vtable, 0);
#endif
    if (!ob)
        goto bad;
    if (PyDict_SetItem(dict, __pyx_n_s____pyx_vtable__, ob) < 0)
        goto bad;
    Py_DECREF(ob);
    return 0;
bad:
    Py_XDECREF(ob);
    return -1;
}

static void* __Pyx_GetVtable(PyObject *dict) {
    void* ptr;
    PyObject *ob = PyObject_GetItem(dict, __pyx_n_s____pyx_vtable__);
    if (!ob)
        goto bad;
#if PY_VERSION_HEX >= 0x02070000 && !(PY_MAJOR_VERSION==3&&PY_MINOR_VERSION==0)
    ptr = PyCapsule_GetPointer(ob, 0);
#else
    ptr = PyCObject_AsVoidPtr(ob);
#endif
    if (!ptr && !PyErr_Occurred())
        PyErr_SetString(PyExc_RuntimeError, "invalid vtable found for imported type");
    Py_DECREF(ob);
    return ptr;
bad:
    Py_XDECREF(ob);
    return NULL;
}

static PyObject* __Pyx_ImportFrom(PyObject* module, PyObject* name) {
    PyObject* value = __Pyx_PyObject_GetAttrStr(module, name);
    if (unlikely(!value) && PyErr_ExceptionMatches(PyExc_AttributeError)) {
        PyErr_Format(PyExc_ImportError,
        #if PY_MAJOR_VERSION < 3
            "cannot import name %.230s", PyString_AS_STRING(name));
        #else
            "cannot import name %S", name);
        #endif
    }
    return value;
}

static int __Pyx_GetException(PyObject **type, PyObject **value, PyObject **tb) {
    PyObject *local_type, *local_value, *local_tb;
#if CYTHON_COMPILING_IN_CPYTHON
    PyObject *tmp_type, *tmp_value, *tmp_tb;
    PyThreadState *tstate = PyThreadState_GET();
    local_type = tstate->curexc_type;
    local_value = tstate->curexc_value;
    local_tb = tstate->curexc_traceback;
    tstate->curexc_type = 0;
    tstate->curexc_value = 0;
    tstate->curexc_traceback = 0;
#else
    PyErr_Fetch(&local_type, &local_value, &local_tb);
#endif
    PyErr_NormalizeException(&local_type, &local_value, &local_tb);
#if CYTHON_COMPILING_IN_CPYTHON
    if (unlikely(tstate->curexc_type))
#else
    if (unlikely(PyErr_Occurred()))
#endif
        goto bad;
    #if PY_MAJOR_VERSION >= 3
    if (unlikely(PyException_SetTraceback(local_value, local_tb) < 0))
        goto bad;
    #endif
    Py_INCREF(local_type);
    Py_INCREF(local_value);
    Py_INCREF(local_tb);
    *type = local_type;
    *value = local_value;
    *tb = local_tb;
#if CYTHON_COMPILING_IN_CPYTHON
    tmp_type = tstate->exc_type;
    tmp_value = tstate->exc_value;
    tmp_tb = tstate->exc_traceback;
    tstate->exc_type = local_type;
    tstate->exc_value = local_value;
    tstate->exc_traceback = local_tb;
    /* Make sure tstate is in a consistent state when we XDECREF
       these objects (DECREF may run arbitrary code). */
    Py_XDECREF(tmp_type);
    Py_XDECREF(tmp_value);
    Py_XDECREF(tmp_tb);
#else
    PyErr_SetExcInfo(local_type, local_value, local_tb);
#endif
    return 0;
bad:
    *type = 0;
    *value = 0;
    *tb = 0;
    Py_XDECREF(local_type);
    Py_XDECREF(local_value);
    Py_XDECREF(local_tb);
    return -1;
}

static double __Pyx__PyObject_AsDouble(PyObject* obj) {
    PyObject* float_value;
#if CYTHON_COMPILING_IN_PYPY
    float_value = PyNumber_Float(obj);
#else
    PyNumberMethods *nb = Py_TYPE(obj)->tp_as_number;
    if (likely(nb) && likely(nb->nb_float)) {
        float_value = nb->nb_float(obj);
        if (likely(float_value) && unlikely(!PyFloat_Check(float_value))) {
            PyErr_Format(PyExc_TypeError,
                "__float__ returned non-float (type %.200s)",
                Py_TYPE(float_value)->tp_name);
            Py_DECREF(float_value);
            goto bad;
        }
    } else if (PyUnicode_CheckExact(obj) || PyBytes_CheckExact(obj)) {
#if PY_MAJOR_VERSION >= 3
        float_value = PyFloat_FromString(obj);
#else
        float_value = PyFloat_FromString(obj, 0);
#endif
    } else {
        PyObject* args = PyTuple_New(1);
        if (unlikely(!args)) goto bad;
        PyTuple_SET_ITEM(args, 0, obj);
        float_value = PyObject_Call((PyObject*)&PyFloat_Type, args, 0);
        PyTuple_SET_ITEM(args, 0, 0);
        Py_DECREF(args);
    }
#endif
    if (likely(float_value)) {
        double value = PyFloat_AS_DOUBLE(float_value);
        Py_DECREF(float_value);
        return value;
    }
bad:
    return (double)-1;
}

static CYTHON_INLINE void __Pyx_ExceptionSave(PyObject **type, PyObject **value, PyObject **tb) {
#if CYTHON_COMPILING_IN_CPYTHON
    PyThreadState *tstate = PyThreadState_GET();
    *type = tstate->exc_type;
    *value = tstate->exc_value;
    *tb = tstate->exc_traceback;
    Py_XINCREF(*type);
    Py_XINCREF(*value);
    Py_XINCREF(*tb);
#else
    PyErr_GetExcInfo(type, value, tb);
#endif
}
static void __Pyx_ExceptionReset(PyObject *type, PyObject *value, PyObject *tb) {
#if CYTHON_COMPILING_IN_CPYTHON
    PyObject *tmp_type, *tmp_value, *tmp_tb;
    PyThreadState *tstate = PyThreadState_GET();
    tmp_type = tstate->exc_type;
    tmp_value = tstate->exc_value;
    tmp_tb = tstate->exc_traceback;
    tstate->exc_type = type;
    tstate->exc_value = value;
    tstate->exc_traceback = tb;
    Py_XDECREF(tmp_type);
    Py_XDECREF(tmp_value);
    Py_XDECREF(tmp_tb);
#else
    PyErr_SetExcInfo(type, value, tb);
#endif
}

static PyObject *__Pyx_Import(PyObject *name, PyObject *from_list, int level) {
    PyObject *empty_list = 0;
    PyObject *module = 0;
    PyObject *global_dict = 0;
    PyObject *empty_dict = 0;
    PyObject *list;
    #if PY_VERSION_HEX < 0x03030000
    PyObject *py_import;
    py_import = __Pyx_PyObject_GetAttrStr(__pyx_b, __pyx_n_s____import__);
    if (!py_import)
        goto bad;
    #endif
    if (from_list)
        list = from_list;
    else {
        empty_list = PyList_New(0);
        if (!empty_list)
            goto bad;
        list = empty_list;
    }
    global_dict = PyModule_GetDict(__pyx_m);
    if (!global_dict)
        goto bad;
    empty_dict = PyDict_New();
    if (!empty_dict)
        goto bad;
    #if PY_VERSION_HEX >= 0x02050000
    {
        #if PY_MAJOR_VERSION >= 3
        if (level == -1) {
            if (strchr(__Pyx_MODULE_NAME, '.')) {
                #if PY_VERSION_HEX < 0x03030000
                PyObject *py_level = PyInt_FromLong(1);
                if (!py_level)
                    goto bad;
                module = PyObject_CallFunctionObjArgs(py_import,
                    name, global_dict, empty_dict, list, py_level, NULL);
                Py_DECREF(py_level);
                #else
                module = PyImport_ImportModuleLevelObject(
                    name, global_dict, empty_dict, list, 1);
                #endif
                if (!module) {
                    if (!PyErr_ExceptionMatches(PyExc_ImportError))
                        goto bad;
                    PyErr_Clear();
                }
            }
            level = 0; /* try absolute import on failure */
        }
        #endif
        if (!module) {
            #if PY_VERSION_HEX < 0x03030000
            PyObject *py_level = PyInt_FromLong(level);
            if (!py_level)
                goto bad;
            module = PyObject_CallFunctionObjArgs(py_import,
                name, global_dict, empty_dict, list, py_level, NULL);
            Py_DECREF(py_level);
            #else
            module = PyImport_ImportModuleLevelObject(
                name, global_dict, empty_dict, list, level);
            #endif
        }
    }
    #else
    if (level>0) {
        PyErr_SetString(PyExc_RuntimeError, "Relative import is not supported for Python <=2.4.");
        goto bad;
    }
    module = PyObject_CallFunctionObjArgs(py_import,
        name, global_dict, empty_dict, list, NULL);
    #endif
bad:
    #if PY_VERSION_HEX < 0x03030000
    Py_XDECREF(py_import);
    #endif
    Py_XDECREF(empty_list);
    Py_XDECREF(empty_dict);
    return module;
}

static CYTHON_INLINE unsigned char __Pyx_PyInt_AsUnsignedChar(PyObject* x) {
    const unsigned char neg_one = (unsigned char)-1, const_zero = 0;
    const int is_unsigned = neg_one > const_zero;
    if (sizeof(unsigned char) < sizeof(long)) {
        long val = __Pyx_PyInt_AsLong(x);
        if (unlikely(val != (long)(unsigned char)val)) {
            if (!unlikely(val == -1 && PyErr_Occurred())) {
                PyErr_SetString(PyExc_OverflowError,
                    (is_unsigned && unlikely(val < 0)) ?
                    "can't convert negative value to unsigned char" :
                    "value too large to convert to unsigned char");
            }
            return (unsigned char)-1;
        }
        return (unsigned char)val;
    }
    return (unsigned char)__Pyx_PyInt_AsUnsignedLong(x);
}

static CYTHON_INLINE unsigned short __Pyx_PyInt_AsUnsignedShort(PyObject* x) {
    const unsigned short neg_one = (unsigned short)-1, const_zero = 0;
    const int is_unsigned = neg_one > const_zero;
    if (sizeof(unsigned short) < sizeof(long)) {
        long val = __Pyx_PyInt_AsLong(x);
        if (unlikely(val != (long)(unsigned short)val)) {
            if (!unlikely(val == -1 && PyErr_Occurred())) {
                PyErr_SetString(PyExc_OverflowError,
                    (is_unsigned && unlikely(val < 0)) ?
                    "can't convert negative value to unsigned short" :
                    "value too large to convert to unsigned short");
            }
            return (unsigned short)-1;
        }
        return (unsigned short)val;
    }
    return (unsigned short)__Pyx_PyInt_AsUnsignedLong(x);
}

static CYTHON_INLINE unsigned int __Pyx_PyInt_AsUnsignedInt(PyObject* x) {
    const unsigned int neg_one = (unsigned int)-1, const_zero = 0;
    const int is_unsigned = neg_one > const_zero;
    if (sizeof(unsigned int) < sizeof(long)) {
        long val = __Pyx_PyInt_AsLong(x);
        if (unlikely(val != (long)(unsigned int)val)) {
            if (!unlikely(val == -1 && PyErr_Occurred())) {
                PyErr_SetString(PyExc_OverflowError,
                    (is_unsigned && unlikely(val < 0)) ?
                    "can't convert negative value to unsigned int" :
                    "value too large to convert to unsigned int");
            }
            return (unsigned int)-1;
        }
        return (unsigned int)val;
    }
    return (unsigned int)__Pyx_PyInt_AsUnsignedLong(x);
}

static CYTHON_INLINE char __Pyx_PyInt_AsChar(PyObject* x) {
    const char neg_one = (char)-1, const_zero = 0;
    const int is_unsigned = neg_one > const_zero;
    if (sizeof(char) < sizeof(long)) {
        long val = __Pyx_PyInt_AsLong(x);
        if (unlikely(val != (long)(char)val)) {
            if (!unlikely(val == -1 && PyErr_Occurred())) {
                PyErr_SetString(PyExc_OverflowError,
                    (is_unsigned && unlikely(val < 0)) ?
                    "can't convert negative value to char" :
                    "value too large to convert to char");
            }
            return (char)-1;
        }
        return (char)val;
    }
    return (char)__Pyx_PyInt_AsLong(x);
}

static CYTHON_INLINE short __Pyx_PyInt_AsShort(PyObject* x) {
    const short neg_one = (short)-1, const_zero = 0;
    const int is_unsigned = neg_one > const_zero;
    if (sizeof(short) < sizeof(long)) {
        long val = __Pyx_PyInt_AsLong(x);
        if (unlikely(val != (long)(short)val)) {
            if (!unlikely(val == -1 && PyErr_Occurred())) {
                PyErr_SetString(PyExc_OverflowError,
                    (is_unsigned && unlikely(val < 0)) ?
                    "can't convert negative value to short" :
                    "value too large to convert to short");
            }
            return (short)-1;
        }
        return (short)val;
    }
    return (short)__Pyx_PyInt_AsLong(x);
}

static CYTHON_INLINE int __Pyx_PyInt_AsInt(PyObject* x) {
    const int neg_one = (int)-1, const_zero = 0;
    const int is_unsigned = neg_one > const_zero;
    if (sizeof(int) < sizeof(long)) {
        long val = __Pyx_PyInt_AsLong(x);
        if (unlikely(val != (long)(int)val)) {
            if (!unlikely(val == -1 && PyErr_Occurred())) {
                PyErr_SetString(PyExc_OverflowError,
                    (is_unsigned && unlikely(val < 0)) ?
                    "can't convert negative value to int" :
                    "value too large to convert to int");
            }
            return (int)-1;
        }
        return (int)val;
    }
    return (int)__Pyx_PyInt_AsLong(x);
}

static CYTHON_INLINE signed char __Pyx_PyInt_AsSignedChar(PyObject* x) {
    const signed char neg_one = (signed char)-1, const_zero = 0;
    const int is_unsigned = neg_one > const_zero;
    if (sizeof(signed char) < sizeof(long)) {
        long val = __Pyx_PyInt_AsLong(x);
        if (unlikely(val != (long)(signed char)val)) {
            if (!unlikely(val == -1 && PyErr_Occurred())) {
                PyErr_SetString(PyExc_OverflowError,
                    (is_unsigned && unlikely(val < 0)) ?
                    "can't convert negative value to signed char" :
                    "value too large to convert to signed char");
            }
            return (signed char)-1;
        }
        return (signed char)val;
    }
    return (signed char)__Pyx_PyInt_AsSignedLong(x);
}

static CYTHON_INLINE signed short __Pyx_PyInt_AsSignedShort(PyObject* x) {
    const signed short neg_one = (signed short)-1, const_zero = 0;
    const int is_unsigned = neg_one > const_zero;
    if (sizeof(signed short) < sizeof(long)) {
        long val = __Pyx_PyInt_AsLong(x);
        if (unlikely(val != (long)(signed short)val)) {
            if (!unlikely(val == -1 && PyErr_Occurred())) {
                PyErr_SetString(PyExc_OverflowError,
                    (is_unsigned && unlikely(val < 0)) ?
                    "can't convert negative value to signed short" :
                    "value too large to convert to signed short");
            }
            return (signed short)-1;
        }
        return (signed short)val;
    }
    return (signed short)__Pyx_PyInt_AsSignedLong(x);
}

static CYTHON_INLINE signed int __Pyx_PyInt_AsSignedInt(PyObject* x) {
    const signed int neg_one = (signed int)-1, const_zero = 0;
    const int is_unsigned = neg_one > const_zero;
    if (sizeof(signed int) < sizeof(long)) {
        long val = __Pyx_PyInt_AsLong(x);
        if (unlikely(val != (long)(signed int)val)) {
            if (!unlikely(val == -1 && PyErr_Occurred())) {
                PyErr_SetString(PyExc_OverflowError,
                    (is_unsigned && unlikely(val < 0)) ?
                    "can't convert negative value to signed int" :
                    "value too large to convert to signed int");
            }
            return (signed int)-1;
        }
        return (signed int)val;
    }
    return (signed int)__Pyx_PyInt_AsSignedLong(x);
}

static CYTHON_INLINE int __Pyx_PyInt_AsLongDouble(PyObject* x) {
    const int neg_one = (int)-1, const_zero = 0;
    const int is_unsigned = neg_one > const_zero;
    if (sizeof(int) < sizeof(long)) {
        long val = __Pyx_PyInt_AsLong(x);
        if (unlikely(val != (long)(int)val)) {
            if (!unlikely(val == -1 && PyErr_Occurred())) {
                PyErr_SetString(PyExc_OverflowError,
                    (is_unsigned && unlikely(val < 0)) ?
                    "can't convert negative value to int" :
                    "value too large to convert to int");
            }
            return (int)-1;
        }
        return (int)val;
    }
    return (int)__Pyx_PyInt_AsLong(x);
}

#if CYTHON_COMPILING_IN_CPYTHON && PY_MAJOR_VERSION >= 3
#if CYTHON_USE_PYLONG_INTERNALS
#include "longintrepr.h"
#endif
#endif
static CYTHON_INLINE unsigned long __Pyx_PyInt_AsUnsignedLong(PyObject* x) {
    const unsigned long neg_one = (unsigned long)-1, const_zero = 0;
    const int is_unsigned = neg_one > const_zero;
#if PY_MAJOR_VERSION < 3
    if (likely(PyInt_Check(x))) {
        long val = PyInt_AS_LONG(x);
        if (is_unsigned && unlikely(val < 0)) {
            PyErr_SetString(PyExc_OverflowError,
                            "can't convert negative value to unsigned long");
            return (unsigned long)-1;
        }
        return (unsigned long)val;
    } else
#endif
    if (likely(PyLong_Check(x))) {
        if (is_unsigned) {
#if CYTHON_COMPILING_IN_CPYTHON && PY_MAJOR_VERSION >= 3
#if CYTHON_USE_PYLONG_INTERNALS
            if (sizeof(digit) <= sizeof(unsigned long)) {
                switch (Py_SIZE(x)) {
                    case  0: return 0;
                    case  1: return (unsigned long) ((PyLongObject*)x)->ob_digit[0];
                }
            }
#endif
#endif
            if (unlikely(Py_SIZE(x) < 0)) {
                PyErr_SetString(PyExc_OverflowError,
                                "can't convert negative value to unsigned long");
                return (unsigned long)-1;
            }
            return (unsigned long)PyLong_AsUnsignedLong(x);
        } else {
#if CYTHON_COMPILING_IN_CPYTHON && PY_MAJOR_VERSION >= 3
#if CYTHON_USE_PYLONG_INTERNALS
            if (sizeof(digit) <= sizeof(unsigned long)) {
                switch (Py_SIZE(x)) {
                    case  0: return 0;
                    case  1: return +(unsigned long) ((PyLongObject*)x)->ob_digit[0];
                    case -1: return -(unsigned long) ((PyLongObject*)x)->ob_digit[0];
                }
            }
#endif
#endif
            return (unsigned long)PyLong_AsLong(x);
        }
    } else {
        unsigned long val;
        PyObject *tmp = __Pyx_PyNumber_Int(x);
        if (!tmp) return (unsigned long)-1;
        val = __Pyx_PyInt_AsUnsignedLong(tmp);
        Py_DECREF(tmp);
        return val;
    }
}

#if CYTHON_COMPILING_IN_CPYTHON && PY_MAJOR_VERSION >= 3
#if CYTHON_USE_PYLONG_INTERNALS
#include "longintrepr.h"
#endif
#endif
static CYTHON_INLINE unsigned PY_LONG_LONG __Pyx_PyInt_AsUnsignedLongLong(PyObject* x) {
    const unsigned PY_LONG_LONG neg_one = (unsigned PY_LONG_LONG)-1, const_zero = 0;
    const int is_unsigned = neg_one > const_zero;
#if PY_MAJOR_VERSION < 3
    if (likely(PyInt_Check(x))) {
        long val = PyInt_AS_LONG(x);
        if (is_unsigned && unlikely(val < 0)) {
            PyErr_SetString(PyExc_OverflowError,
                            "can't convert negative value to unsigned PY_LONG_LONG");
            return (unsigned PY_LONG_LONG)-1;
        }
        return (unsigned PY_LONG_LONG)val;
    } else
#endif
    if (likely(PyLong_Check(x))) {
        if (is_unsigned) {
#if CYTHON_COMPILING_IN_CPYTHON && PY_MAJOR_VERSION >= 3
#if CYTHON_USE_PYLONG_INTERNALS
            if (sizeof(digit) <= sizeof(unsigned PY_LONG_LONG)) {
                switch (Py_SIZE(x)) {
                    case  0: return 0;
                    case  1: return (unsigned PY_LONG_LONG) ((PyLongObject*)x)->ob_digit[0];
                }
            }
#endif
#endif
            if (unlikely(Py_SIZE(x) < 0)) {
                PyErr_SetString(PyExc_OverflowError,
                                "can't convert negative value to unsigned PY_LONG_LONG");
                return (unsigned PY_LONG_LONG)-1;
            }
            return (unsigned PY_LONG_LONG)PyLong_AsUnsignedLongLong(x);
        } else {
#if CYTHON_COMPILING_IN_CPYTHON && PY_MAJOR_VERSION >= 3
#if CYTHON_USE_PYLONG_INTERNALS
            if (sizeof(digit) <= sizeof(unsigned PY_LONG_LONG)) {
                switch (Py_SIZE(x)) {
                    case  0: return 0;
                    case  1: return +(unsigned PY_LONG_LONG) ((PyLongObject*)x)->ob_digit[0];
                    case -1: return -(unsigned PY_LONG_LONG) ((PyLongObject*)x)->ob_digit[0];
                }
            }
#endif
#endif
            return (unsigned PY_LONG_LONG)PyLong_AsLongLong(x);
        }
    } else {
        unsigned PY_LONG_LONG val;
        PyObject *tmp = __Pyx_PyNumber_Int(x);
        if (!tmp) return (unsigned PY_LONG_LONG)-1;
        val = __Pyx_PyInt_AsUnsignedLongLong(tmp);
        Py_DECREF(tmp);
        return val;
    }
}

#if CYTHON_COMPILING_IN_CPYTHON && PY_MAJOR_VERSION >= 3
#if CYTHON_USE_PYLONG_INTERNALS
#include "longintrepr.h"
#endif
#endif
static CYTHON_INLINE long __Pyx_PyInt_AsLong(PyObject* x) {
    const long neg_one = (long)-1, const_zero = 0;
    const int is_unsigned = neg_one > const_zero;
#if PY_MAJOR_VERSION < 3
    if (likely(PyInt_Check(x))) {
        long val = PyInt_AS_LONG(x);
        if (is_unsigned && unlikely(val < 0)) {
            PyErr_SetString(PyExc_OverflowError,
                            "can't convert negative value to long");
            return (long)-1;
        }
        return (long)val;
    } else
#endif
    if (likely(PyLong_Check(x))) {
        if (is_unsigned) {
#if CYTHON_COMPILING_IN_CPYTHON && PY_MAJOR_VERSION >= 3
#if CYTHON_USE_PYLONG_INTERNALS
            if (sizeof(digit) <= sizeof(long)) {
                switch (Py_SIZE(x)) {
                    case  0: return 0;
                    case  1: return (long) ((PyLongObject*)x)->ob_digit[0];
                }
            }
#endif
#endif
            if (unlikely(Py_SIZE(x) < 0)) {
                PyErr_SetString(PyExc_OverflowError,
                                "can't convert negative value to long");
                return (long)-1;
            }
            return (long)PyLong_AsUnsignedLong(x);
        } else {
#if CYTHON_COMPILING_IN_CPYTHON && PY_MAJOR_VERSION >= 3
#if CYTHON_USE_PYLONG_INTERNALS
            if (sizeof(digit) <= sizeof(long)) {
                switch (Py_SIZE(x)) {
                    case  0: return 0;
                    case  1: return +(long) ((PyLongObject*)x)->ob_digit[0];
                    case -1: return -(long) ((PyLongObject*)x)->ob_digit[0];
                }
            }
#endif
#endif
            return (long)PyLong_AsLong(x);
        }
    } else {
        long val;
        PyObject *tmp = __Pyx_PyNumber_Int(x);
        if (!tmp) return (long)-1;
        val = __Pyx_PyInt_AsLong(tmp);
        Py_DECREF(tmp);
        return val;
    }
}

#if CYTHON_COMPILING_IN_CPYTHON && PY_MAJOR_VERSION >= 3
#if CYTHON_USE_PYLONG_INTERNALS
#include "longintrepr.h"
#endif
#endif
static CYTHON_INLINE PY_LONG_LONG __Pyx_PyInt_AsLongLong(PyObject* x) {
    const PY_LONG_LONG neg_one = (PY_LONG_LONG)-1, const_zero = 0;
    const int is_unsigned = neg_one > const_zero;
#if PY_MAJOR_VERSION < 3
    if (likely(PyInt_Check(x))) {
        long val = PyInt_AS_LONG(x);
        if (is_unsigned && unlikely(val < 0)) {
            PyErr_SetString(PyExc_OverflowError,
                            "can't convert negative value to PY_LONG_LONG");
            return (PY_LONG_LONG)-1;
        }
        return (PY_LONG_LONG)val;
    } else
#endif
    if (likely(PyLong_Check(x))) {
        if (is_unsigned) {
#if CYTHON_COMPILING_IN_CPYTHON && PY_MAJOR_VERSION >= 3
#if CYTHON_USE_PYLONG_INTERNALS
            if (sizeof(digit) <= sizeof(PY_LONG_LONG)) {
                switch (Py_SIZE(x)) {
                    case  0: return 0;
                    case  1: return (PY_LONG_LONG) ((PyLongObject*)x)->ob_digit[0];
                }
            }
#endif
#endif
            if (unlikely(Py_SIZE(x) < 0)) {
                PyErr_SetString(PyExc_OverflowError,
                                "can't convert negative value to PY_LONG_LONG");
                return (PY_LONG_LONG)-1;
            }
            return (PY_LONG_LONG)PyLong_AsUnsignedLongLong(x);
        } else {
#if CYTHON_COMPILING_IN_CPYTHON && PY_MAJOR_VERSION >= 3
#if CYTHON_USE_PYLONG_INTERNALS
            if (sizeof(digit) <= sizeof(PY_LONG_LONG)) {
                switch (Py_SIZE(x)) {
                    case  0: return 0;
                    case  1: return +(PY_LONG_LONG) ((PyLongObject*)x)->ob_digit[0];
                    case -1: return -(PY_LONG_LONG) ((PyLongObject*)x)->ob_digit[0];
                }
            }
#endif
#endif
            return (PY_LONG_LONG)PyLong_AsLongLong(x);
        }
    } else {
        PY_LONG_LONG val;
        PyObject *tmp = __Pyx_PyNumber_Int(x);
        if (!tmp) return (PY_LONG_LONG)-1;
        val = __Pyx_PyInt_AsLongLong(tmp);
        Py_DECREF(tmp);
        return val;
    }
}

#if CYTHON_COMPILING_IN_CPYTHON && PY_MAJOR_VERSION >= 3
#if CYTHON_USE_PYLONG_INTERNALS
#include "longintrepr.h"
#endif
#endif
static CYTHON_INLINE signed long __Pyx_PyInt_AsSignedLong(PyObject* x) {
    const signed long neg_one = (signed long)-1, const_zero = 0;
    const int is_unsigned = neg_one > const_zero;
#if PY_MAJOR_VERSION < 3
    if (likely(PyInt_Check(x))) {
        long val = PyInt_AS_LONG(x);
        if (is_unsigned && unlikely(val < 0)) {
            PyErr_SetString(PyExc_OverflowError,
                            "can't convert negative value to signed long");
            return (signed long)-1;
        }
        return (signed long)val;
    } else
#endif
    if (likely(PyLong_Check(x))) {
        if (is_unsigned) {
#if CYTHON_COMPILING_IN_CPYTHON && PY_MAJOR_VERSION >= 3
#if CYTHON_USE_PYLONG_INTERNALS
            if (sizeof(digit) <= sizeof(signed long)) {
                switch (Py_SIZE(x)) {
                    case  0: return 0;
                    case  1: return (signed long) ((PyLongObject*)x)->ob_digit[0];
                }
            }
#endif
#endif
            if (unlikely(Py_SIZE(x) < 0)) {
                PyErr_SetString(PyExc_OverflowError,
                                "can't convert negative value to signed long");
                return (signed long)-1;
            }
            return (signed long)PyLong_AsUnsignedLong(x);
        } else {
#if CYTHON_COMPILING_IN_CPYTHON && PY_MAJOR_VERSION >= 3
#if CYTHON_USE_PYLONG_INTERNALS
            if (sizeof(digit) <= sizeof(signed long)) {
                switch (Py_SIZE(x)) {
                    case  0: return 0;
                    case  1: return +(signed long) ((PyLongObject*)x)->ob_digit[0];
                    case -1: return -(signed long) ((PyLongObject*)x)->ob_digit[0];
                }
            }
#endif
#endif
            return (signed long)PyLong_AsLong(x);
        }
    } else {
        signed long val;
        PyObject *tmp = __Pyx_PyNumber_Int(x);
        if (!tmp) return (signed long)-1;
        val = __Pyx_PyInt_AsSignedLong(tmp);
        Py_DECREF(tmp);
        return val;
    }
}

#if CYTHON_COMPILING_IN_CPYTHON && PY_MAJOR_VERSION >= 3
#if CYTHON_USE_PYLONG_INTERNALS
#include "longintrepr.h"
#endif
#endif
static CYTHON_INLINE signed PY_LONG_LONG __Pyx_PyInt_AsSignedLongLong(PyObject* x) {
    const signed PY_LONG_LONG neg_one = (signed PY_LONG_LONG)-1, const_zero = 0;
    const int is_unsigned = neg_one > const_zero;
#if PY_MAJOR_VERSION < 3
    if (likely(PyInt_Check(x))) {
        long val = PyInt_AS_LONG(x);
        if (is_unsigned && unlikely(val < 0)) {
            PyErr_SetString(PyExc_OverflowError,
                            "can't convert negative value to signed PY_LONG_LONG");
            return (signed PY_LONG_LONG)-1;
        }
        return (signed PY_LONG_LONG)val;
    } else
#endif
    if (likely(PyLong_Check(x))) {
        if (is_unsigned) {
#if CYTHON_COMPILING_IN_CPYTHON && PY_MAJOR_VERSION >= 3
#if CYTHON_USE_PYLONG_INTERNALS
            if (sizeof(digit) <= sizeof(signed PY_LONG_LONG)) {
                switch (Py_SIZE(x)) {
                    case  0: return 0;
                    case  1: return (signed PY_LONG_LONG) ((PyLongObject*)x)->ob_digit[0];
                }
            }
#endif
#endif
            if (unlikely(Py_SIZE(x) < 0)) {
                PyErr_SetString(PyExc_OverflowError,
                                "can't convert negative value to signed PY_LONG_LONG");
                return (signed PY_LONG_LONG)-1;
            }
            return (signed PY_LONG_LONG)PyLong_AsUnsignedLongLong(x);
        } else {
#if CYTHON_COMPILING_IN_CPYTHON && PY_MAJOR_VERSION >= 3
#if CYTHON_USE_PYLONG_INTERNALS
            if (sizeof(digit) <= sizeof(signed PY_LONG_LONG)) {
                switch (Py_SIZE(x)) {
                    case  0: return 0;
                    case  1: return +(signed PY_LONG_LONG) ((PyLongObject*)x)->ob_digit[0];
                    case -1: return -(signed PY_LONG_LONG) ((PyLongObject*)x)->ob_digit[0];
                }
            }
#endif
#endif
            return (signed PY_LONG_LONG)PyLong_AsLongLong(x);
        }
    } else {
        signed PY_LONG_LONG val;
        PyObject *tmp = __Pyx_PyNumber_Int(x);
        if (!tmp) return (signed PY_LONG_LONG)-1;
        val = __Pyx_PyInt_AsSignedLongLong(tmp);
        Py_DECREF(tmp);
        return val;
    }
}

static int __Pyx_check_binary_version(void) {
    char ctversion[4], rtversion[4];
    PyOS_snprintf(ctversion, 4, "%d.%d", PY_MAJOR_VERSION, PY_MINOR_VERSION);
    PyOS_snprintf(rtversion, 4, "%s", Py_GetVersion());
    if (ctversion[0] != rtversion[0] || ctversion[2] != rtversion[2]) {
        char message[200];
        PyOS_snprintf(message, sizeof(message),
                      "compiletime version %s of module '%.100s' "
                      "does not match runtime version %s",
                      ctversion, __Pyx_MODULE_NAME, rtversion);
        #if PY_VERSION_HEX < 0x02050000
        return PyErr_Warn(NULL, message);
        #else
        return PyErr_WarnEx(NULL, message, 1);
        #endif
    }
    return 0;
}

static int __Pyx_ExportVoidPtr(PyObject *name, void *p, const char *sig) {
    PyObject *d;
    PyObject *cobj = 0;
    d = PyDict_GetItem(__pyx_d, __pyx_n_s____pyx_capi__);
    Py_XINCREF(d);
    if (!d) {
        d = PyDict_New();
        if (!d)
            goto bad;
        if (__Pyx_PyObject_SetAttrStr(__pyx_m, __pyx_n_s____pyx_capi__, d) < 0)
            goto bad;
    }
#if PY_VERSION_HEX >= 0x02070000 && !(PY_MAJOR_VERSION==3 && PY_MINOR_VERSION==0)
    cobj = PyCapsule_New(p, sig, 0);
#else
    cobj = PyCObject_FromVoidPtrAndDesc(p, (void *)sig, 0);
#endif
    if (!cobj)
        goto bad;
    if (PyDict_SetItem(d, name, cobj) < 0)
        goto bad;
    Py_DECREF(cobj);
    Py_DECREF(d);
    return 0;
bad:
    Py_XDECREF(cobj);
    Py_XDECREF(d);
    return -1;
}

static int __Pyx_ExportFunction(const char *name, void (*f)(void), const char *sig) {
    PyObject *d = 0;
    PyObject *cobj = 0;
    union {
        void (*fp)(void);
        void *p;
    } tmp;
    d = PyObject_GetAttrString(__pyx_m, (char *)"__pyx_capi__");
    if (!d) {
        PyErr_Clear();
        d = PyDict_New();
        if (!d)
            goto bad;
        Py_INCREF(d);
        if (PyModule_AddObject(__pyx_m, (char *)"__pyx_capi__", d) < 0)
            goto bad;
    }
    tmp.fp = f;
#if PY_VERSION_HEX >= 0x02070000 && !(PY_MAJOR_VERSION==3&&PY_MINOR_VERSION==0)
    cobj = PyCapsule_New(tmp.p, sig, 0);
#else
    cobj = PyCObject_FromVoidPtrAndDesc(tmp.p, (void *)sig, 0);
#endif
    if (!cobj)
        goto bad;
    if (PyDict_SetItemString(d, name, cobj) < 0)
        goto bad;
    Py_DECREF(cobj);
    Py_DECREF(d);
    return 0;
bad:
    Py_XDECREF(cobj);
    Py_XDECREF(d);
    return -1;
}

#ifndef __PYX_HAVE_RT_ImportModule
#define __PYX_HAVE_RT_ImportModule
static PyObject *__Pyx_ImportModule(const char *name) {
    PyObject *py_name = 0;
    PyObject *py_module = 0;
    py_name = __Pyx_PyIdentifier_FromString(name);
    if (!py_name)
        goto bad;
    py_module = PyImport_Import(py_name);
    Py_DECREF(py_name);
    return py_module;
bad:
    Py_XDECREF(py_name);
    return 0;
}
#endif

#ifndef __PYX_HAVE_RT_ImportType
#define __PYX_HAVE_RT_ImportType
static PyTypeObject *__Pyx_ImportType(const char *module_name, const char *class_name,
    size_t size, int strict)
{
    PyObject *py_module = 0;
    PyObject *result = 0;
    PyObject *py_name = 0;
    char warning[200];
    Py_ssize_t basicsize;
#ifdef Py_LIMITED_API
    PyObject *py_basicsize;
#endif
    py_module = __Pyx_ImportModule(module_name);
    if (!py_module)
        goto bad;
    py_name = __Pyx_PyIdentifier_FromString(class_name);
    if (!py_name)
        goto bad;
    result = PyObject_GetAttr(py_module, py_name);
    Py_DECREF(py_name);
    py_name = 0;
    Py_DECREF(py_module);
    py_module = 0;
    if (!result)
        goto bad;
    if (!PyType_Check(result)) {
        PyErr_Format(PyExc_TypeError,
            "%s.%s is not a type object",
            module_name, class_name);
        goto bad;
    }
#ifndef Py_LIMITED_API
    basicsize = ((PyTypeObject *)result)->tp_basicsize;
#else
    py_basicsize = PyObject_GetAttrString(result, "__basicsize__");
    if (!py_basicsize)
        goto bad;
    basicsize = PyLong_AsSsize_t(py_basicsize);
    Py_DECREF(py_basicsize);
    py_basicsize = 0;
    if (basicsize == (Py_ssize_t)-1 && PyErr_Occurred())
        goto bad;
#endif
    if (!strict && (size_t)basicsize > size) {
        PyOS_snprintf(warning, sizeof(warning),
            "%s.%s size changed, may indicate binary incompatibility",
            module_name, class_name);
        #if PY_VERSION_HEX < 0x02050000
        if (PyErr_Warn(NULL, warning) < 0) goto bad;
        #else
        if (PyErr_WarnEx(NULL, warning, 0) < 0) goto bad;
        #endif
    }
    else if ((size_t)basicsize != size) {
        PyErr_Format(PyExc_ValueError,
            "%s.%s has the wrong size, try recompiling",
            module_name, class_name);
        goto bad;
    }
    return (PyTypeObject *)result;
bad:
    Py_XDECREF(py_module);
    Py_XDECREF(result);
    return NULL;
}
#endif

#ifndef __PYX_HAVE_RT_ImportVoidPtr
#define __PYX_HAVE_RT_ImportVoidPtr
static int __Pyx_ImportVoidPtr(PyObject *module, const char *name, void **p, const char *sig) {
    PyObject *d = 0;
    PyObject *cobj = 0;
    d = PyObject_GetAttrString(module, (char *)"__pyx_capi__");
    if (!d)
        goto bad;
    cobj = PyDict_GetItemString(d, name);
    if (!cobj) {
        PyErr_Format(PyExc_ImportError,
            "%s does not export expected C variable %s",
                PyModule_GetName(module), name);
        goto bad;
    }
#if PY_VERSION_HEX >= 0x02070000 && !(PY_MAJOR_VERSION==3 && PY_MINOR_VERSION==0)
    if (!PyCapsule_IsValid(cobj, sig)) {
        PyErr_Format(PyExc_TypeError,
            "C variable %s.%s has wrong signature (expected %s, got %s)",
             PyModule_GetName(module), name, sig, PyCapsule_GetName(cobj));
        goto bad;
    }
    *p = PyCapsule_GetPointer(cobj, sig);
#else
    {const char *desc, *s1, *s2;
    desc = (const char *)PyCObject_GetDesc(cobj);
    if (!desc)
        goto bad;
    s1 = desc; s2 = sig;
    while (*s1 != '\0' && *s1 == *s2) { s1++; s2++; }
    if (*s1 != *s2) {
        PyErr_Format(PyExc_TypeError,
            "C variable %s.%s has wrong signature (expected %s, got %s)",
             PyModule_GetName(module), name, sig, desc);
        goto bad;
    }
    *p = PyCObject_AsVoidPtr(cobj);}
#endif
    if (!(*p))
        goto bad;
    Py_DECREF(d);
    return 0;
bad:
    Py_XDECREF(d);
    return -1;
}
#endif

#ifndef __PYX_HAVE_RT_ImportFunction
#define __PYX_HAVE_RT_ImportFunction
static int __Pyx_ImportFunction(PyObject *module, const char *funcname, void (**f)(void), const char *sig) {
    PyObject *d = 0;
    PyObject *cobj = 0;
    union {
        void (*fp)(void);
        void *p;
    } tmp;
    d = PyObject_GetAttrString(module, (char *)"__pyx_capi__");
    if (!d)
        goto bad;
    cobj = PyDict_GetItemString(d, funcname);
    if (!cobj) {
        PyErr_Format(PyExc_ImportError,
            "%s does not export expected C function %s",
                PyModule_GetName(module), funcname);
        goto bad;
    }
#if PY_VERSION_HEX >= 0x02070000 && !(PY_MAJOR_VERSION==3 && PY_MINOR_VERSION==0)
    if (!PyCapsule_IsValid(cobj, sig)) {
        PyErr_Format(PyExc_TypeError,
            "C function %s.%s has wrong signature (expected %s, got %s)",
             PyModule_GetName(module), funcname, sig, PyCapsule_GetName(cobj));
        goto bad;
    }
    tmp.p = PyCapsule_GetPointer(cobj, sig);
#else
    {const char *desc, *s1, *s2;
    desc = (const char *)PyCObject_GetDesc(cobj);
    if (!desc)
        goto bad;
    s1 = desc; s2 = sig;
    while (*s1 != '\0' && *s1 == *s2) { s1++; s2++; }
    if (*s1 != *s2) {
        PyErr_Format(PyExc_TypeError,
            "C function %s.%s has wrong signature (expected %s, got %s)",
             PyModule_GetName(module), funcname, sig, desc);
        goto bad;
    }
    tmp.p = PyCObject_AsVoidPtr(cobj);}
#endif
    *f = tmp.fp;
    if (!(*f))
        goto bad;
    Py_DECREF(d);
    return 0;
bad:
    Py_XDECREF(d);
    return -1;
}
#endif

static int __pyx_bisect_code_objects(__Pyx_CodeObjectCacheEntry* entries, int count, int code_line) {
    int start = 0, mid = 0, end = count - 1;
    if (end >= 0 && code_line > entries[end].code_line) {
        return count;
    }
    while (start < end) {
        mid = (start + end) / 2;
        if (code_line < entries[mid].code_line) {
            end = mid;
        } else if (code_line > entries[mid].code_line) {
             start = mid + 1;
        } else {
            return mid;
        }
    }
    if (code_line <= entries[mid].code_line) {
        return mid;
    } else {
        return mid + 1;
    }
}
static PyCodeObject *__pyx_find_code_object(int code_line) {
    PyCodeObject* code_object;
    int pos;
    if (unlikely(!code_line) || unlikely(!__pyx_code_cache.entries)) {
        return NULL;
    }
    pos = __pyx_bisect_code_objects(__pyx_code_cache.entries, __pyx_code_cache.count, code_line);
    if (unlikely(pos >= __pyx_code_cache.count) || unlikely(__pyx_code_cache.entries[pos].code_line != code_line)) {
        return NULL;
    }
    code_object = __pyx_code_cache.entries[pos].code_object;
    Py_INCREF(code_object);
    return code_object;
}
static void __pyx_insert_code_object(int code_line, PyCodeObject* code_object) {
    int pos, i;
    __Pyx_CodeObjectCacheEntry* entries = __pyx_code_cache.entries;
    if (unlikely(!code_line)) {
        return;
    }
    if (unlikely(!entries)) {
        entries = (__Pyx_CodeObjectCacheEntry*)PyMem_Malloc(64*sizeof(__Pyx_CodeObjectCacheEntry));
        if (likely(entries)) {
            __pyx_code_cache.entries = entries;
            __pyx_code_cache.max_count = 64;
            __pyx_code_cache.count = 1;
            entries[0].code_line = code_line;
            entries[0].code_object = code_object;
            Py_INCREF(code_object);
        }
        return;
    }
    pos = __pyx_bisect_code_objects(__pyx_code_cache.entries, __pyx_code_cache.count, code_line);
    if ((pos < __pyx_code_cache.count) && unlikely(__pyx_code_cache.entries[pos].code_line == code_line)) {
        PyCodeObject* tmp = entries[pos].code_object;
        entries[pos].code_object = code_object;
        Py_DECREF(tmp);
        return;
    }
    if (__pyx_code_cache.count == __pyx_code_cache.max_count) {
        int new_max = __pyx_code_cache.max_count + 64;
        entries = (__Pyx_CodeObjectCacheEntry*)PyMem_Realloc(
            __pyx_code_cache.entries, new_max*sizeof(__Pyx_CodeObjectCacheEntry));
        if (unlikely(!entries)) {
            return;
        }
        __pyx_code_cache.entries = entries;
        __pyx_code_cache.max_count = new_max;
    }
    for (i=__pyx_code_cache.count; i>pos; i--) {
        entries[i] = entries[i-1];
    }
    entries[pos].code_line = code_line;
    entries[pos].code_object = code_object;
    __pyx_code_cache.count++;
    Py_INCREF(code_object);
}

#include "compile.h"
#include "frameobject.h"
#include "traceback.h"
static PyCodeObject* __Pyx_CreateCodeObjectForTraceback(
            const char *funcname, int c_line,
            int py_line, const char *filename) {
    PyCodeObject *py_code = 0;
    PyObject *py_srcfile = 0;
    PyObject *py_funcname = 0;
    #if PY_MAJOR_VERSION < 3
    py_srcfile = PyString_FromString(filename);
    #else
    py_srcfile = PyUnicode_FromString(filename);
    #endif
    if (!py_srcfile) goto bad;
    if (c_line) {
        #if PY_MAJOR_VERSION < 3
        py_funcname = PyString_FromFormat( "%s (%s:%d)", funcname, __pyx_cfilenm, c_line);
        #else
        py_funcname = PyUnicode_FromFormat( "%s (%s:%d)", funcname, __pyx_cfilenm, c_line);
        #endif
    }
    else {
        #if PY_MAJOR_VERSION < 3
        py_funcname = PyString_FromString(funcname);
        #else
        py_funcname = PyUnicode_FromString(funcname);
        #endif
    }
    if (!py_funcname) goto bad;
    py_code = __Pyx_PyCode_New(
        0,            /*int argcount,*/
        0,            /*int kwonlyargcount,*/
        0,            /*int nlocals,*/
        0,            /*int stacksize,*/
        0,            /*int flags,*/
        __pyx_empty_bytes, /*PyObject *code,*/
        __pyx_empty_tuple, /*PyObject *consts,*/
        __pyx_empty_tuple, /*PyObject *names,*/
        __pyx_empty_tuple, /*PyObject *varnames,*/
        __pyx_empty_tuple, /*PyObject *freevars,*/
        __pyx_empty_tuple, /*PyObject *cellvars,*/
        py_srcfile,   /*PyObject *filename,*/
        py_funcname,  /*PyObject *name,*/
        py_line,      /*int firstlineno,*/
        __pyx_empty_bytes  /*PyObject *lnotab*/
    );
    Py_DECREF(py_srcfile);
    Py_DECREF(py_funcname);
    return py_code;
bad:
    Py_XDECREF(py_srcfile);
    Py_XDECREF(py_funcname);
    return NULL;
}
static void __Pyx_AddTraceback(const char *funcname, int c_line,
                               int py_line, const char *filename) {
    PyCodeObject *py_code = 0;
    PyObject *py_globals = 0;
    PyFrameObject *py_frame = 0;
    py_code = __pyx_find_code_object(c_line ? c_line : py_line);
    if (!py_code) {
        py_code = __Pyx_CreateCodeObjectForTraceback(
            funcname, c_line, py_line, filename);
        if (!py_code) goto bad;
        __pyx_insert_code_object(c_line ? c_line : py_line, py_code);
    }
    py_globals = PyModule_GetDict(__pyx_m);
    if (!py_globals) goto bad;
    py_frame = PyFrame_New(
        PyThreadState_GET(), /*PyThreadState *tstate,*/
        py_code,             /*PyCodeObject *code,*/
        py_globals,          /*PyObject *globals,*/
        0                    /*PyObject *locals*/
    );
    if (!py_frame) goto bad;
    py_frame->f_lineno = py_line;
    PyTraceBack_Here(py_frame);
bad:
    Py_XDECREF(py_code);
    Py_XDECREF(py_frame);
}

static int __Pyx_InitStrings(__Pyx_StringTabEntry *t) {
    while (t->p) {
        #if PY_MAJOR_VERSION < 3
        if (t->is_unicode) {
            *t->p = PyUnicode_DecodeUTF8(t->s, t->n - 1, NULL);
        } else if (t->intern) {
            *t->p = PyString_InternFromString(t->s);
        } else {
            *t->p = PyString_FromStringAndSize(t->s, t->n - 1);
        }
        #else  /* Python 3+ has unicode identifiers */
        if (t->is_unicode | t->is_str) {
            if (t->intern) {
                *t->p = PyUnicode_InternFromString(t->s);
            } else if (t->encoding) {
                *t->p = PyUnicode_Decode(t->s, t->n - 1, t->encoding, NULL);
            } else {
                *t->p = PyUnicode_FromStringAndSize(t->s, t->n - 1);
            }
        } else {
            *t->p = PyBytes_FromStringAndSize(t->s, t->n - 1);
        }
        #endif
        if (!*t->p)
            return -1;
        ++t;
    }
    return 0;
}

static CYTHON_INLINE PyObject* __Pyx_PyUnicode_FromString(char* c_str) {
    return __Pyx_PyUnicode_FromStringAndSize(c_str, strlen(c_str));
}
static CYTHON_INLINE char* __Pyx_PyObject_AsString(PyObject* o) {
    Py_ssize_t ignore;
    return __Pyx_PyObject_AsStringAndSize(o, &ignore);
}
static CYTHON_INLINE char* __Pyx_PyObject_AsStringAndSize(PyObject* o, Py_ssize_t *length) {
#if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII || __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT
    if (
#if PY_MAJOR_VERSION < 3 && __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
            __Pyx_sys_getdefaultencoding_not_ascii &&
#endif
            PyUnicode_Check(o)) {
#if PY_VERSION_HEX < 0x03030000
        char* defenc_c;
        PyObject* defenc = _PyUnicode_AsDefaultEncodedString(o, NULL);
        if (!defenc) return NULL;
        defenc_c = PyBytes_AS_STRING(defenc);
#if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
        {
            char* end = defenc_c + PyBytes_GET_SIZE(defenc);
            char* c;
            for (c = defenc_c; c < end; c++) {
                if ((unsigned char) (*c) >= 128) {
                    PyUnicode_AsASCIIString(o);
                    return NULL;
                }
            }
        }
#endif /*__PYX_DEFAULT_STRING_ENCODING_IS_ASCII*/
        *length = PyBytes_GET_SIZE(defenc);
        return defenc_c;
#else /* PY_VERSION_HEX < 0x03030000 */
        if (PyUnicode_READY(o) == -1) return NULL;
#if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
        if (PyUnicode_IS_ASCII(o)) {
            *length = PyUnicode_GET_DATA_SIZE(o);
            return PyUnicode_AsUTF8(o);
        } else {
            PyUnicode_AsASCIIString(o);
            return NULL;
        }
#else /* __PYX_DEFAULT_STRING_ENCODING_IS_ASCII */
        return PyUnicode_AsUTF8AndSize(o, length);
#endif /* __PYX_DEFAULT_STRING_ENCODING_IS_ASCII */
#endif /* PY_VERSION_HEX < 0x03030000 */
    } else
#endif /* __PYX_DEFAULT_STRING_ENCODING_IS_ASCII  || __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT */
    {
        char* result;
        int r = PyBytes_AsStringAndSize(o, &result, length);
        if (r < 0) {
            return NULL;
        } else {
            return result;
        }
    }
}
static CYTHON_INLINE int __Pyx_PyObject_IsTrue(PyObject* x) {
   int is_true = x == Py_True;
   if (is_true | (x == Py_False) | (x == Py_None)) return is_true;
   else return PyObject_IsTrue(x);
}
static CYTHON_INLINE PyObject* __Pyx_PyNumber_Int(PyObject* x) {
  PyNumberMethods *m;
  const char *name = NULL;
  PyObject *res = NULL;
#if PY_MAJOR_VERSION < 3
  if (PyInt_Check(x) || PyLong_Check(x))
#else
  if (PyLong_Check(x))
#endif
    return Py_INCREF(x), x;
  m = Py_TYPE(x)->tp_as_number;
#if PY_MAJOR_VERSION < 3
  if (m && m->nb_int) {
    name = "int";
    res = PyNumber_Int(x);
  }
  else if (m && m->nb_long) {
    name = "long";
    res = PyNumber_Long(x);
  }
#else
  if (m && m->nb_int) {
    name = "int";
    res = PyNumber_Long(x);
  }
#endif
  if (res) {
#if PY_MAJOR_VERSION < 3
    if (!PyInt_Check(res) && !PyLong_Check(res)) {
#else
    if (!PyLong_Check(res)) {
#endif
      PyErr_Format(PyExc_TypeError,
                   "__%s__ returned non-%s (type %.200s)",
                   name, name, Py_TYPE(res)->tp_name);
      Py_DECREF(res);
      return NULL;
    }
  }
  else if (!PyErr_Occurred()) {
    PyErr_SetString(PyExc_TypeError,
                    "an integer is required");
  }
  return res;
}
static CYTHON_INLINE Py_ssize_t __Pyx_PyIndex_AsSsize_t(PyObject* b) {
  Py_ssize_t ival;
  PyObject* x = PyNumber_Index(b);
  if (!x) return -1;
  ival = PyInt_AsSsize_t(x);
  Py_DECREF(x);
  return ival;
}
static CYTHON_INLINE PyObject * __Pyx_PyInt_FromSize_t(size_t ival) {
#if PY_VERSION_HEX < 0x02050000
   if (ival <= LONG_MAX)
       return PyInt_FromLong((long)ival);
   else {
       unsigned char *bytes = (unsigned char *) &ival;
       int one = 1; int little = (int)*(unsigned char*)&one;
       return _PyLong_FromByteArray(bytes, sizeof(size_t), little, 0);
   }
#else
   return PyInt_FromSize_t(ival);
#endif
}
static CYTHON_INLINE size_t __Pyx_PyInt_AsSize_t(PyObject* x) {
   unsigned PY_LONG_LONG val = __Pyx_PyInt_AsUnsignedLongLong(x);
   if (unlikely(val != (unsigned PY_LONG_LONG)(size_t)val)) {
       if ((val != (unsigned PY_LONG_LONG)-1) || !PyErr_Occurred())
           PyErr_SetString(PyExc_OverflowError,
                           "value too large to convert to size_t");
       return (size_t)-1;
   }
   return (size_t)val;
}


#endif /* Py_PYTHON_H */
