/* Generated by Cython 0.19.1 on Sun Jun 23 18:13:14 2013 */

#define PY_SSIZE_T_CLEAN
#ifndef CYTHON_USE_PYLONG_INTERNALS
#ifdef PYLONG_BITS_IN_DIGIT
#define CYTHON_USE_PYLONG_INTERNALS 0
#else
#include "pyconfig.h"
#ifdef PYLONG_BITS_IN_DIGIT
#define CYTHON_USE_PYLONG_INTERNALS 1
#else
#define CYTHON_USE_PYLONG_INTERNALS 0
#endif
#endif
#endif
#include "Python.h"
#ifndef Py_PYTHON_H
    #error Python headers needed to compile C extensions, please install development version of Python.
#elif PY_VERSION_HEX < 0x02040000
    #error Cython requires Python 2.4+.
#else
#include <stddef.h> /* For offsetof */
#ifndef offsetof
#define offsetof(type, member) ( (size_t) & ((type*)0) -> member )
#endif
#if !defined(WIN32) && !defined(MS_WINDOWS)
  #ifndef __stdcall
    #define __stdcall
  #endif
  #ifndef __cdecl
    #define __cdecl
  #endif
  #ifndef __fastcall
    #define __fastcall
  #endif
#endif
#ifndef DL_IMPORT
  #define DL_IMPORT(t) t
#endif
#ifndef DL_EXPORT
  #define DL_EXPORT(t) t
#endif
#ifndef PY_LONG_LONG
  #define PY_LONG_LONG LONG_LONG
#endif
#ifndef Py_HUGE_VAL
  #define Py_HUGE_VAL HUGE_VAL
#endif
#ifdef PYPY_VERSION
#define CYTHON_COMPILING_IN_PYPY 1
#define CYTHON_COMPILING_IN_CPYTHON 0
#else
#define CYTHON_COMPILING_IN_PYPY 0
#define CYTHON_COMPILING_IN_CPYTHON 1
#endif
#if PY_VERSION_HEX < 0x02050000
  typedef int Py_ssize_t;
  #define PY_SSIZE_T_MAX INT_MAX
  #define PY_SSIZE_T_MIN INT_MIN
  #define PY_FORMAT_SIZE_T ""
  #define CYTHON_FORMAT_SSIZE_T ""
  #define PyInt_FromSsize_t(z) PyInt_FromLong(z)
  #define PyInt_AsSsize_t(o)   __Pyx_PyInt_AsInt(o)
  #define PyNumber_Index(o)    ((PyNumber_Check(o) && !PyFloat_Check(o)) ? PyNumber_Int(o) : \
                                (PyErr_Format(PyExc_TypeError, \
                                              "expected index value, got %.200s", Py_TYPE(o)->tp_name), \
                                 (PyObject*)0))
  #define __Pyx_PyIndex_Check(o) (PyNumber_Check(o) && !PyFloat_Check(o) && \
                                  !PyComplex_Check(o))
  #define PyIndex_Check __Pyx_PyIndex_Check
  #define PyErr_WarnEx(category, message, stacklevel) PyErr_Warn(category, message)
  #define __PYX_BUILD_PY_SSIZE_T "i"
#else
  #define __PYX_BUILD_PY_SSIZE_T "n"
  #define CYTHON_FORMAT_SSIZE_T "z"
  #define __Pyx_PyIndex_Check PyIndex_Check
#endif
#if PY_VERSION_HEX < 0x02060000
  #define Py_REFCNT(ob) (((PyObject*)(ob))->ob_refcnt)
  #define Py_TYPE(ob)   (((PyObject*)(ob))->ob_type)
  #define Py_SIZE(ob)   (((PyVarObject*)(ob))->ob_size)
  #define PyVarObject_HEAD_INIT(type, size) \
          PyObject_HEAD_INIT(type) size,
  #define PyType_Modified(t)
  typedef struct {
     void *buf;
     PyObject *obj;
     Py_ssize_t len;
     Py_ssize_t itemsize;
     int readonly;
     int ndim;
     char *format;
     Py_ssize_t *shape;
     Py_ssize_t *strides;
     Py_ssize_t *suboffsets;
     void *internal;
  } Py_buffer;
  #define PyBUF_SIMPLE 0
  #define PyBUF_WRITABLE 0x0001
  #define PyBUF_FORMAT 0x0004
  #define PyBUF_ND 0x0008
  #define PyBUF_STRIDES (0x0010 | PyBUF_ND)
  #define PyBUF_C_CONTIGUOUS (0x0020 | PyBUF_STRIDES)
  #define PyBUF_F_CONTIGUOUS (0x0040 | PyBUF_STRIDES)
  #define PyBUF_ANY_CONTIGUOUS (0x0080 | PyBUF_STRIDES)
  #define PyBUF_INDIRECT (0x0100 | PyBUF_STRIDES)
  #define PyBUF_RECORDS (PyBUF_STRIDES | PyBUF_FORMAT | PyBUF_WRITABLE)
  #define PyBUF_FULL (PyBUF_INDIRECT | PyBUF_FORMAT | PyBUF_WRITABLE)
  typedef int (*getbufferproc)(PyObject *, Py_buffer *, int);
  typedef void (*releasebufferproc)(PyObject *, Py_buffer *);
#endif
#if PY_MAJOR_VERSION < 3
  #define __Pyx_BUILTIN_MODULE_NAME "__builtin__"
  #define __Pyx_PyCode_New(a, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos) \
          PyCode_New(a, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)
#else
  #define __Pyx_BUILTIN_MODULE_NAME "builtins"
  #define __Pyx_PyCode_New(a, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos) \
          PyCode_New(a, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)
#endif
#if PY_MAJOR_VERSION < 3 && PY_MINOR_VERSION < 6
  #define PyUnicode_FromString(s) PyUnicode_Decode(s, strlen(s), "UTF-8", "strict")
#endif
#if PY_MAJOR_VERSION >= 3
  #define Py_TPFLAGS_CHECKTYPES 0
  #define Py_TPFLAGS_HAVE_INDEX 0
#endif
#if (PY_VERSION_HEX < 0x02060000) || (PY_MAJOR_VERSION >= 3)
  #define Py_TPFLAGS_HAVE_NEWBUFFER 0
#endif
#if PY_VERSION_HEX < 0x02060000
  #define Py_TPFLAGS_HAVE_VERSION_TAG 0
#endif
#if PY_VERSION_HEX > 0x03030000 && defined(PyUnicode_KIND)
  #define CYTHON_PEP393_ENABLED 1
  #define __Pyx_PyUnicode_READY(op)       (likely(PyUnicode_IS_READY(op)) ? \
                                              0 : _PyUnicode_Ready((PyObject *)(op)))
  #define __Pyx_PyUnicode_GET_LENGTH(u)   PyUnicode_GET_LENGTH(u)
  #define __Pyx_PyUnicode_READ_CHAR(u, i) PyUnicode_READ_CHAR(u, i)
  #define __Pyx_PyUnicode_READ(k, d, i)   PyUnicode_READ(k, d, i)
#else
  #define CYTHON_PEP393_ENABLED 0
  #define __Pyx_PyUnicode_READY(op)       (0)
  #define __Pyx_PyUnicode_GET_LENGTH(u)   PyUnicode_GET_SIZE(u)
  #define __Pyx_PyUnicode_READ_CHAR(u, i) ((Py_UCS4)(PyUnicode_AS_UNICODE(u)[i]))
  #define __Pyx_PyUnicode_READ(k, d, i)   ((k=k), (Py_UCS4)(((Py_UNICODE*)d)[i]))
#endif
#if PY_MAJOR_VERSION >= 3
  #define PyBaseString_Type            PyUnicode_Type
  #define PyStringObject               PyUnicodeObject
  #define PyString_Type                PyUnicode_Type
  #define PyString_Check               PyUnicode_Check
  #define PyString_CheckExact          PyUnicode_CheckExact
#endif
#if PY_VERSION_HEX < 0x02060000
  #define PyBytesObject                PyStringObject
  #define PyBytes_Type                 PyString_Type
  #define PyBytes_Check                PyString_Check
  #define PyBytes_CheckExact           PyString_CheckExact
  #define PyBytes_FromString           PyString_FromString
  #define PyBytes_FromStringAndSize    PyString_FromStringAndSize
  #define PyBytes_FromFormat           PyString_FromFormat
  #define PyBytes_DecodeEscape         PyString_DecodeEscape
  #define PyBytes_AsString             PyString_AsString
  #define PyBytes_AsStringAndSize      PyString_AsStringAndSize
  #define PyBytes_Size                 PyString_Size
  #define PyBytes_AS_STRING            PyString_AS_STRING
  #define PyBytes_GET_SIZE             PyString_GET_SIZE
  #define PyBytes_Repr                 PyString_Repr
  #define PyBytes_Concat               PyString_Concat
  #define PyBytes_ConcatAndDel         PyString_ConcatAndDel
#endif
#if PY_MAJOR_VERSION >= 3
  #define __Pyx_PyBaseString_Check(obj) PyUnicode_Check(obj)
  #define __Pyx_PyBaseString_CheckExact(obj) PyUnicode_CheckExact(obj)
#else
  #define __Pyx_PyBaseString_Check(obj) (PyString_CheckExact(obj) || PyUnicode_CheckExact(obj) || \
                                         PyString_Check(obj) || PyUnicode_Check(obj))
  #define __Pyx_PyBaseString_CheckExact(obj) (Py_TYPE(obj) == &PyBaseString_Type)
#endif
#if PY_VERSION_HEX < 0x02060000
  #define PySet_Check(obj)             PyObject_TypeCheck(obj, &PySet_Type)
  #define PyFrozenSet_Check(obj)       PyObject_TypeCheck(obj, &PyFrozenSet_Type)
#endif
#ifndef PySet_CheckExact
  #define PySet_CheckExact(obj)        (Py_TYPE(obj) == &PySet_Type)
#endif
#define __Pyx_TypeCheck(obj, type) PyObject_TypeCheck(obj, (PyTypeObject *)type)
#if PY_MAJOR_VERSION >= 3
  #define PyIntObject                  PyLongObject
  #define PyInt_Type                   PyLong_Type
  #define PyInt_Check(op)              PyLong_Check(op)
  #define PyInt_CheckExact(op)         PyLong_CheckExact(op)
  #define PyInt_FromString             PyLong_FromString
  #define PyInt_FromUnicode            PyLong_FromUnicode
  #define PyInt_FromLong               PyLong_FromLong
  #define PyInt_FromSize_t             PyLong_FromSize_t
  #define PyInt_FromSsize_t            PyLong_FromSsize_t
  #define PyInt_AsLong                 PyLong_AsLong
  #define PyInt_AS_LONG                PyLong_AS_LONG
  #define PyInt_AsSsize_t              PyLong_AsSsize_t
  #define PyInt_AsUnsignedLongMask     PyLong_AsUnsignedLongMask
  #define PyInt_AsUnsignedLongLongMask PyLong_AsUnsignedLongLongMask
#endif
#if PY_MAJOR_VERSION >= 3
  #define PyBoolObject                 PyLongObject
#endif
#if PY_VERSION_HEX < 0x03020000
  typedef long Py_hash_t;
  #define __Pyx_PyInt_FromHash_t PyInt_FromLong
  #define __Pyx_PyInt_AsHash_t   PyInt_AsLong
#else
  #define __Pyx_PyInt_FromHash_t PyInt_FromSsize_t
  #define __Pyx_PyInt_AsHash_t   PyInt_AsSsize_t
#endif
#if (PY_MAJOR_VERSION < 3) || (PY_VERSION_HEX >= 0x03010300)
  #define __Pyx_PySequence_GetSlice(obj, a, b) PySequence_GetSlice(obj, a, b)
  #define __Pyx_PySequence_SetSlice(obj, a, b, value) PySequence_SetSlice(obj, a, b, value)
  #define __Pyx_PySequence_DelSlice(obj, a, b) PySequence_DelSlice(obj, a, b)
#else
  #define __Pyx_PySequence_GetSlice(obj, a, b) (unlikely(!(obj)) ? \
        (PyErr_SetString(PyExc_SystemError, "null argument to internal routine"), (PyObject*)0) : \
        (likely((obj)->ob_type->tp_as_mapping) ? (PySequence_GetSlice(obj, a, b)) : \
            (PyErr_Format(PyExc_TypeError, "'%.200s' object is unsliceable", (obj)->ob_type->tp_name), (PyObject*)0)))
  #define __Pyx_PySequence_SetSlice(obj, a, b, value) (unlikely(!(obj)) ? \
        (PyErr_SetString(PyExc_SystemError, "null argument to internal routine"), -1) : \
        (likely((obj)->ob_type->tp_as_mapping) ? (PySequence_SetSlice(obj, a, b, value)) : \
            (PyErr_Format(PyExc_TypeError, "'%.200s' object doesn't support slice assignment", (obj)->ob_type->tp_name), -1)))
  #define __Pyx_PySequence_DelSlice(obj, a, b) (unlikely(!(obj)) ? \
        (PyErr_SetString(PyExc_SystemError, "null argument to internal routine"), -1) : \
        (likely((obj)->ob_type->tp_as_mapping) ? (PySequence_DelSlice(obj, a, b)) : \
            (PyErr_Format(PyExc_TypeError, "'%.200s' object doesn't support slice deletion", (obj)->ob_type->tp_name), -1)))
#endif
#if PY_MAJOR_VERSION >= 3
  #define PyMethod_New(func, self, klass) ((self) ? PyMethod_New(func, self) : PyInstanceMethod_New(func))
#endif
#if PY_VERSION_HEX < 0x02050000
  #define __Pyx_GetAttrString(o,n)   PyObject_GetAttrString((o),((char *)(n)))
  #define __Pyx_SetAttrString(o,n,a) PyObject_SetAttrString((o),((char *)(n)),(a))
  #define __Pyx_DelAttrString(o,n)   PyObject_DelAttrString((o),((char *)(n)))
#else
  #define __Pyx_GetAttrString(o,n)   PyObject_GetAttrString((o),(n))
  #define __Pyx_SetAttrString(o,n,a) PyObject_SetAttrString((o),(n),(a))
  #define __Pyx_DelAttrString(o,n)   PyObject_DelAttrString((o),(n))
#endif
#if PY_VERSION_HEX < 0x02050000
  #define __Pyx_NAMESTR(n) ((char *)(n))
  #define __Pyx_DOCSTR(n)  ((char *)(n))
#else
  #define __Pyx_NAMESTR(n) (n)
  #define __Pyx_DOCSTR(n)  (n)
#endif
#ifndef CYTHON_INLINE
  #if defined(__GNUC__)
    #define CYTHON_INLINE __inline__
  #elif defined(_MSC_VER)
    #define CYTHON_INLINE __inline
  #elif defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L
    #define CYTHON_INLINE inline
  #else
    #define CYTHON_INLINE
  #endif
#endif
#ifndef CYTHON_RESTRICT
  #if defined(__GNUC__)
    #define CYTHON_RESTRICT __restrict__
  #elif defined(_MSC_VER)
    #define CYTHON_RESTRICT __restrict
  #elif defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L
    #define CYTHON_RESTRICT restrict
  #else
    #define CYTHON_RESTRICT
  #endif
#endif
#ifdef NAN
#define __PYX_NAN() ((float) NAN)
#else
static CYTHON_INLINE float __PYX_NAN() {
  /* Initialize NaN. The sign is irrelevant, an exponent with all bits 1 and
   a nonzero mantissa means NaN. If the first bit in the mantissa is 1, it is
   a quiet NaN. */
  float value;
  memset(&value, 0xFF, sizeof(value));
  return value;
}
#endif


#if PY_MAJOR_VERSION >= 3
  #define __Pyx_PyNumber_Divide(x,y)         PyNumber_TrueDivide(x,y)
  #define __Pyx_PyNumber_InPlaceDivide(x,y)  PyNumber_InPlaceTrueDivide(x,y)
#else
  #define __Pyx_PyNumber_Divide(x,y)         PyNumber_Divide(x,y)
  #define __Pyx_PyNumber_InPlaceDivide(x,y)  PyNumber_InPlaceDivide(x,y)
#endif

#ifndef __PYX_EXTERN_C
  #ifdef __cplusplus
    #define __PYX_EXTERN_C extern "C"
  #else
    #define __PYX_EXTERN_C extern
  #endif
#endif

#if defined(WIN32) || defined(MS_WINDOWS)
#define _USE_MATH_DEFINES
#endif
#include <math.h>
#define __PYX_HAVE__axon___dumper
#define __PYX_HAVE_API__axon___dumper
#include "math.h"
#include "floatobject.h"
#include "utils.h"
#include "string.h"
#include "stdio.h"
#ifdef _OPENMP
#include <omp.h>
#endif /* _OPENMP */

#ifdef PYREX_WITHOUT_ASSERTIONS
#define CYTHON_WITHOUT_ASSERTIONS
#endif

#ifndef CYTHON_UNUSED
# if defined(__GNUC__)
#   if !(defined(__cplusplus)) || (__GNUC__ > 3 || (__GNUC__ == 3 && __GNUC_MINOR__ >= 4))
#     define CYTHON_UNUSED __attribute__ ((__unused__))
#   else
#     define CYTHON_UNUSED
#   endif
# elif defined(__ICC) || (defined(__INTEL_COMPILER) && !defined(_MSC_VER))
#   define CYTHON_UNUSED __attribute__ ((__unused__))
# else
#   define CYTHON_UNUSED
# endif
#endif
typedef struct {PyObject **p; char *s; const Py_ssize_t n; const char* encoding;
                const char is_unicode; const char is_str; const char intern; } __Pyx_StringTabEntry; /*proto*/

#define __PYX_DEFAULT_STRING_ENCODING_IS_ASCII 0
#define __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT 0
#define __PYX_DEFAULT_STRING_ENCODING ""
#define __Pyx_PyObject_FromString __Pyx_PyBytes_FromString
#define __Pyx_PyObject_FromStringAndSize __Pyx_PyBytes_FromStringAndSize
static CYTHON_INLINE char* __Pyx_PyObject_AsString(PyObject*);
static CYTHON_INLINE char* __Pyx_PyObject_AsStringAndSize(PyObject*, Py_ssize_t* length);
#define __Pyx_PyBytes_FromString        PyBytes_FromString
#define __Pyx_PyBytes_FromStringAndSize PyBytes_FromStringAndSize
static CYTHON_INLINE PyObject* __Pyx_PyUnicode_FromString(char*);
#if PY_MAJOR_VERSION < 3
    #define __Pyx_PyStr_FromString        __Pyx_PyBytes_FromString
    #define __Pyx_PyStr_FromStringAndSize __Pyx_PyBytes_FromStringAndSize
#else
    #define __Pyx_PyStr_FromString        __Pyx_PyUnicode_FromString
    #define __Pyx_PyStr_FromStringAndSize __Pyx_PyUnicode_FromStringAndSize
#endif
#define __Pyx_PyObject_AsUString(s)    ((unsigned char*) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_FromUString(s)  __Pyx_PyObject_FromString((char*)s)
#define __Pyx_PyBytes_FromUString(s)   __Pyx_PyBytes_FromString((char*)s)
#define __Pyx_PyStr_FromUString(s)     __Pyx_PyStr_FromString((char*)s)
#define __Pyx_PyUnicode_FromUString(s) __Pyx_PyUnicode_FromString((char*)s)
#if PY_MAJOR_VERSION < 3
static CYTHON_INLINE size_t __Pyx_Py_UNICODE_strlen(const Py_UNICODE *u)
{
    const Py_UNICODE *u_end = u;
    while (*u_end++) ;
    return u_end - u - 1;
}
#else
#define __Pyx_Py_UNICODE_strlen Py_UNICODE_strlen
#endif
#define __Pyx_PyUnicode_FromUnicode(u)       PyUnicode_FromUnicode(u, __Pyx_Py_UNICODE_strlen(u))
#define __Pyx_PyUnicode_FromUnicodeAndLength PyUnicode_FromUnicode
#define __Pyx_PyUnicode_AsUnicode            PyUnicode_AsUnicode
#define __Pyx_Owned_Py_None(b) (Py_INCREF(Py_None), Py_None)
#define __Pyx_PyBool_FromLong(b) ((b) ? (Py_INCREF(Py_True), Py_True) : (Py_INCREF(Py_False), Py_False))
static CYTHON_INLINE int __Pyx_PyObject_IsTrue(PyObject*);
static CYTHON_INLINE PyObject* __Pyx_PyNumber_Int(PyObject* x);
static CYTHON_INLINE Py_ssize_t __Pyx_PyIndex_AsSsize_t(PyObject*);
static CYTHON_INLINE PyObject * __Pyx_PyInt_FromSize_t(size_t);
static CYTHON_INLINE size_t __Pyx_PyInt_AsSize_t(PyObject*);
#if CYTHON_COMPILING_IN_CPYTHON
#define __pyx_PyFloat_AsDouble(x) (PyFloat_CheckExact(x) ? PyFloat_AS_DOUBLE(x) : PyFloat_AsDouble(x))
#else
#define __pyx_PyFloat_AsDouble(x) PyFloat_AsDouble(x)
#endif
#define __pyx_PyFloat_AsFloat(x) ((float) __pyx_PyFloat_AsDouble(x))
#if PY_MAJOR_VERSION < 3 && __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
static int __Pyx_sys_getdefaultencoding_not_ascii;
static int __Pyx_init_sys_getdefaultencoding_params() {
    PyObject* sys = NULL;
    PyObject* default_encoding = NULL;
    PyObject* ascii_chars_u = NULL;
    PyObject* ascii_chars_b = NULL;
    sys = PyImport_ImportModule("sys");
    if (sys == NULL) goto bad;
    default_encoding = PyObject_CallMethod(sys, (char*) (const char*) "getdefaultencoding", NULL);
    if (default_encoding == NULL) goto bad;
    if (strcmp(PyBytes_AsString(default_encoding), "ascii") == 0) {
        __Pyx_sys_getdefaultencoding_not_ascii = 0;
    } else {
        const char* default_encoding_c = PyBytes_AS_STRING(default_encoding);
        char ascii_chars[128];
        int c;
        for (c = 0; c < 128; c++) {
            ascii_chars[c] = c;
        }
        __Pyx_sys_getdefaultencoding_not_ascii = 1;
        ascii_chars_u = PyUnicode_DecodeASCII(ascii_chars, 128, NULL);
        if (ascii_chars_u == NULL) goto bad;
        ascii_chars_b = PyUnicode_AsEncodedString(ascii_chars_u, default_encoding_c, NULL);
        if (ascii_chars_b == NULL || strncmp(ascii_chars, PyBytes_AS_STRING(ascii_chars_b), 128) != 0) {
            PyErr_Format(
                PyExc_ValueError,
                "This module compiled with c_string_encoding=ascii, but default encoding '%s' is not a superset of ascii.",
                default_encoding_c);
            goto bad;
        }
    }
    Py_XDECREF(sys);
    Py_XDECREF(default_encoding);
    Py_XDECREF(ascii_chars_u);
    Py_XDECREF(ascii_chars_b);
    return 0;
bad:
    Py_XDECREF(sys);
    Py_XDECREF(default_encoding);
    Py_XDECREF(ascii_chars_u);
    Py_XDECREF(ascii_chars_b);
    return -1;
}
#endif
#if __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT && PY_MAJOR_VERSION >= 3
#define __Pyx_PyUnicode_FromStringAndSize(c_str, size) PyUnicode_DecodeUTF8(c_str, size, NULL)
#else
#define __Pyx_PyUnicode_FromStringAndSize(c_str, size) PyUnicode_Decode(c_str, size, __PYX_DEFAULT_STRING_ENCODING, NULL)
#if __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT
static char* __PYX_DEFAULT_STRING_ENCODING;
static int __Pyx_init_sys_getdefaultencoding_params() {
    PyObject* sys = NULL;
    PyObject* default_encoding = NULL;
    char* default_encoding_c;
    sys = PyImport_ImportModule("sys");
    if (sys == NULL) goto bad;
    default_encoding = PyObject_CallMethod(sys, (char*) (const char*) "getdefaultencoding", NULL);
    if (default_encoding == NULL) goto bad;
    default_encoding_c = PyBytes_AS_STRING(default_encoding);
    __PYX_DEFAULT_STRING_ENCODING = (char*) malloc(strlen(default_encoding_c));
    strcpy(__PYX_DEFAULT_STRING_ENCODING, default_encoding_c);
    Py_DECREF(sys);
    Py_DECREF(default_encoding);
    return 0;
bad:
    Py_XDECREF(sys);
    Py_XDECREF(default_encoding);
    return -1;
}
#endif
#endif


#ifdef __GNUC__
  /* Test for GCC > 2.95 */
  #if __GNUC__ > 2 || (__GNUC__ == 2 && (__GNUC_MINOR__ > 95))
    #define likely(x)   __builtin_expect(!!(x), 1)
    #define unlikely(x) __builtin_expect(!!(x), 0)
  #else /* __GNUC__ > 2 ... */
    #define likely(x)   (x)
    #define unlikely(x) (x)
  #endif /* __GNUC__ > 2 ... */
#else /* __GNUC__ */
  #define likely(x)   (x)
  #define unlikely(x) (x)
#endif /* __GNUC__ */

static PyObject *__pyx_m;
static PyObject *__pyx_d;
static PyObject *__pyx_b;
static PyObject *__pyx_empty_tuple;
static PyObject *__pyx_empty_bytes;
static int __pyx_lineno;
static int __pyx_clineno = 0;
static const char * __pyx_cfilenm= __FILE__;
static const char *__pyx_filename;


static const char *__pyx_f[] = {
  "_dumper.py",
  "_dumper.pxd",
  "_objects.pxd",
};

/*--- Type declarations ---*/
struct ReadonlyList;
struct __pyx_obj_4axon_7_dumper___pyx_scope_struct_2_pretty_dump_content;
struct __pyx_obj_4axon_8_objects_Attrs;
struct ElementObject;
struct __pyx_obj_4axon_7_dumper_PyPointer;
struct SequenceObject;
struct CollectionObject;
struct ReadonlyDict;
struct __pyx_obj_4axon_8_objects_StringReader;
struct __pyx_obj_4axon_7_dumper___pyx_scope_struct_1_dump_as_str;
struct __pyx_obj_4axon_7_dumper___pyx_scope_struct_4_genexpr;
struct InstanceObject;
struct SimpleDumpers;
struct __pyx_obj_4axon_7_dumper___pyx_scope_struct_3_genexpr;
struct UndefinedObject;
struct __pyx_obj_4axon_7_dumper_PyInt;
struct EmptyObject;
struct MappingObject;
struct __pyx_obj_4axon_7_dumper___pyx_scope_struct_5_genexpr;
struct Attribute;
struct __pyx_obj_4axon_8_objects_NamedValue;
struct __pyx_obj_4axon_7_dumper___pyx_scope_struct__reduce;
struct Dumper;

/* "axon/_objects.pxd":96
 * 
 * 
 * ctypedef PyObject* PyObjectPtr             # <<<<<<<<<<<<<<
 * 
 * cdef public unicode empty_name
 */
typedef PyObject *__pyx_t_4axon_8_objects_PyObjectPtr;

/* "axon/_objects.pxd":121
 * #
 * @cython.final
 * cdef public class rlist(list)[object ReadonlyList, type ReadonlyListType]:             # <<<<<<<<<<<<<<
 *     pass
 * 
 */
struct ReadonlyList {
  PyListObject __pyx_base;
};

__PYX_EXTERN_C DL_EXPORT(PyTypeObject) ReadonlyListType;

/* "axon/_dumper.py":780
 *         self.write('}')
 *     #
 *     def pretty_dump_content(self, items, offset):             # <<<<<<<<<<<<<<
 *         offset1 = offset + '  '
 *         use_offset = 1
 */
struct __pyx_obj_4axon_7_dumper___pyx_scope_struct_2_pretty_dump_content {
  PyObject_HEAD
  PyObject *__pyx_v_item;
  struct Dumper *__pyx_v_self;
};


/* "axon/_objects.pxd":146
 * cdef public Attribute c_new_attribute(unicode name, object value)
 * 
 * cdef class Attrs(object):             # <<<<<<<<<<<<<<
 *     #
 *     cdef public dict mapping
 */
struct __pyx_obj_4axon_8_objects_Attrs {
  PyObject_HEAD
  PyObject *mapping;
};


/* "axon/_objects.pxd":190
 * #
 * @cython.final
 * cdef public class Element[object ElementObject, type ElementType]:             # <<<<<<<<<<<<<<
 *     cdef public object name
 *     cdef public dict mapping
 */
struct ElementObject {
  PyObject_HEAD
  PyObject *name;
  PyObject *mapping;
  PyObject *sequence;
};

__PYX_EXTERN_C DL_EXPORT(PyTypeObject) ElementType;

/* "axon/_dumper.pxd":96
 * cdef set simple_types
 * 
 * cdef class PyPointer:             # <<<<<<<<<<<<<<
 *     cdef unicode (*ptr)(object)
 * 
 */
struct __pyx_obj_4axon_7_dumper_PyPointer {
  PyObject_HEAD
  PyObject *(*ptr)(PyObject *);
};


/* "axon/_objects.pxd":163
 * #
 * @cython.final
 * cdef public class Sequence[object SequenceObject, type SequenceType]:             # <<<<<<<<<<<<<<
 *     cdef public object name
 *     cdef public list sequence
 */
struct SequenceObject {
  PyObject_HEAD
  PyObject *name;
  PyObject *sequence;
};

__PYX_EXTERN_C DL_EXPORT(PyTypeObject) SequenceType;

/* "axon/_objects.pxd":172
 * #
 * @cython.final
 * cdef public class Collection[object CollectionObject, type CollectionType]:             # <<<<<<<<<<<<<<
 *     cdef public object name
 *     cdef public list sequence
 */
struct CollectionObject {
  PyObject_HEAD
  PyObject *name;
  PyObject *sequence;
};

__PYX_EXTERN_C DL_EXPORT(PyTypeObject) CollectionType;

/* "axon/_objects.pxd":114
 * #
 * @cython.final
 * cdef public class rdict(dict)[object ReadonlyDict, type ReadonlyDictType]:             # <<<<<<<<<<<<<<
 *     pass
 * 
 */
struct ReadonlyDict {
  PyDictObject __pyx_base;
};

__PYX_EXTERN_C DL_EXPORT(PyTypeObject) ReadonlyDictType;

/* "axon/_objects.pxd":227
 * cdef unicode NAME_IS_EMPTY
 * 
 * cdef class StringReader:             # <<<<<<<<<<<<<<
 *     cdef unicode buffer
 *     cdef int pos
 */
struct __pyx_obj_4axon_8_objects_StringReader {
  PyObject_HEAD
  struct __pyx_vtabstruct_4axon_8_objects_StringReader *__pyx_vtab;
  PyObject *buffer;
  int pos;
  int n;
};


/* "axon/_dumper.py":310
 *             self.mapping.update(sd.mapping)
 * 
 * def dump_as_str(tp=None):             # <<<<<<<<<<<<<<
 *     if tp is None:
 *         def _dump_as_str(func):
 */
struct __pyx_obj_4axon_7_dumper___pyx_scope_struct_1_dump_as_str {
  PyObject_HEAD
  PyObject *__pyx_v_tp;
};


/* "axon/_dumper.py":799
 *                     self._pretty_dump_attr_sequence(item, offset1, use_offset)
 *             elif tp is tuple:
 *                 if len(item) <= self.nsize and all(is_simple_type(self, x) for x in item):             # <<<<<<<<<<<<<<
 *                     self.write("\n")
 *                     self.write(offset1)
 */
struct __pyx_obj_4axon_7_dumper___pyx_scope_struct_4_genexpr {
  PyObject_HEAD
  struct __pyx_obj_4axon_7_dumper___pyx_scope_struct_2_pretty_dump_content *__pyx_outer_scope;
  PyObject *__pyx_v_x;
  PyObject *__pyx_t_0;
  Py_ssize_t __pyx_t_1;
  PyObject *(*__pyx_t_2)(PyObject *);
};


/* "axon/_objects.pxd":199
 * #
 * @cython.final
 * cdef public class Instance[object InstanceObject, type InstanceType]:             # <<<<<<<<<<<<<<
 *     cdef public object name
 *     cdef public tuple sequence
 */
struct InstanceObject {
  PyObject_HEAD
  PyObject *name;
  PyObject *sequence;
  PyObject *mapping;
};

__PYX_EXTERN_C DL_EXPORT(PyTypeObject) InstanceType;

/* "axon/_dumper.pxd":102
 * cdef PyPointer c_new_pyptr(unicode (*p)(object))
 * 
 * cdef public class SimpleDumpers[type SimpleDumpersType, object SimpleDumpers]:             # <<<<<<<<<<<<<<
 *     cdef public dict mapping
 * 
 */
struct SimpleDumpers {
  PyObject_HEAD
  struct __pyx_vtabstruct_4axon_7_dumper_SimpleDumpers *__pyx_vtab;
  PyObject *mapping;
};

__PYX_EXTERN_C DL_EXPORT(PyTypeObject) SimpleDumpersType;

/* "axon/_dumper.py":792
 *             tp = type(item)
 *             if tp is dict:
 *                 if len(item) <= self.nsize and all(is_simple_type(self, x) for x in item.values()):             # <<<<<<<<<<<<<<
 *                     self.write("\n")
 *                     self.write(offset1)
 */
struct __pyx_obj_4axon_7_dumper___pyx_scope_struct_3_genexpr {
  PyObject_HEAD
  struct __pyx_obj_4axon_7_dumper___pyx_scope_struct_2_pretty_dump_content *__pyx_outer_scope;
  PyObject *__pyx_v_x;
  PyObject *__pyx_t_0;
  Py_ssize_t __pyx_t_1;
  Py_ssize_t __pyx_t_2;
  int __pyx_t_3;
};


/* "axon/_objects.pxd":107
 * 
 * @cython.final
 * cdef public class Undefined[object UndefinedObject, type UndefinedType]:             # <<<<<<<<<<<<<<
 *     pass
 * 
 */
struct UndefinedObject {
  PyObject_HEAD
};

__PYX_EXTERN_C DL_EXPORT(PyTypeObject) UndefinedType;

/* "axon/_dumper.pxd":54
 * 
 * 
 * cdef class PyInt:             # <<<<<<<<<<<<<<
 *     cdef long val
 * 
 */
struct __pyx_obj_4axon_7_dumper_PyInt {
  PyObject_HEAD
  long val;
};


/* "axon/_objects.pxd":156
 * #
 * @cython.final
 * cdef public class Empty[type EmptyType, object EmptyObject]:             # <<<<<<<<<<<<<<
 *     cdef public object name
 * 
 */
struct EmptyObject {
  PyObject_HEAD
  PyObject *name;
};

__PYX_EXTERN_C DL_EXPORT(PyTypeObject) EmptyType;

/* "axon/_objects.pxd":181
 * #
 * @cython.final
 * cdef public class Mapping[object MappingObject, type MappingType]:             # <<<<<<<<<<<<<<
 *     cdef public object name
 *     cdef public dict mapping
 */
struct MappingObject {
  PyObject_HEAD
  PyObject *name;
  PyObject *mapping;
};

__PYX_EXTERN_C DL_EXPORT(PyTypeObject) MappingType;

/* "axon/_dumper.py":806
 *                     self._pretty_dump_tuple_sequence(item, offset1, use_offset)
 *             elif tp is list:
 *                 if len(item) <= self.nsize and all(is_simple_type(self, x) for x in item):             # <<<<<<<<<<<<<<
 *                     self.write("\n")
 *                     self.write(offset1)
 */
struct __pyx_obj_4axon_7_dumper___pyx_scope_struct_5_genexpr {
  PyObject_HEAD
  struct __pyx_obj_4axon_7_dumper___pyx_scope_struct_2_pretty_dump_content *__pyx_outer_scope;
  PyObject *__pyx_v_x;
  PyObject *__pyx_t_0;
  Py_ssize_t __pyx_t_1;
  PyObject *(*__pyx_t_2)(PyObject *);
};


/* "axon/_objects.pxd":137
 * #
 * @cython.final
 * cdef public class Attribute[type AttributeType, object Attribute]:             # <<<<<<<<<<<<<<
 *     cdef public unicode name
 *     cdef public object value
 */
struct Attribute {
  PyObject_HEAD
  PyObject *name;
  PyObject *value;
};

__PYX_EXTERN_C DL_EXPORT(PyTypeObject) AttributeType;

/* "axon/_objects.pxd":127
 * cdef public rlist c_empty_list
 * 
 * cdef class NamedValue:             # <<<<<<<<<<<<<<
 *     cdef public object __name__
 *     cdef public object __value__
 */
struct __pyx_obj_4axon_8_objects_NamedValue {
  PyObject_HEAD
  PyObject *__name__;
  PyObject *__value__;
};


/* "axon/_dumper.py":103
 * #        self.__dict__.update(kw)
 * 
 * def reduce(type_, reduce_func = None):             # <<<<<<<<<<<<<<
 *     if reduce_func is None:
 *         def _factory(factory_func):
 */
struct __pyx_obj_4axon_7_dumper___pyx_scope_struct__reduce {
  PyObject_HEAD
  PyObject *__pyx_v_type_;
};


/* "axon/_dumper.pxd":161
 * 
 * @cython.final
 * cdef public class Dumper[object Dumper, type DumperType]:             # <<<<<<<<<<<<<<
 *     '''
 *     Dumper class
 */
struct Dumper {
  PyObject_HEAD
  struct __pyx_vtabstruct_4axon_7_dumper_Dumper *__pyx_vtab;
  PyObject *c_simple_dumpers;
  PyObject *c_type_reducers;
  PyObject *write;
  long size;
  long max_size;
  int nsize;
  int pretty;
  int sorted;
  int crossref;
  PyObject *crossref_dict;
  PyObject *crossref_set;
  PyObject *crossref_set2;
  int quote;
};

__PYX_EXTERN_C DL_EXPORT(PyTypeObject) DumperType;

__PYX_EXTERN_C DL_EXPORT(PyTypeObject) SimpleDumpersType;

/* "axon/_dumper.py":292
 * simple_types = set(c_simple_dumpers.keys())
 * 
 * class SimpleDumpers:             # <<<<<<<<<<<<<<
 *     #cdef dict c_mapping
 * 
 */

struct __pyx_vtabstruct_4axon_7_dumper_SimpleDumpers {
  void (*add)(struct SimpleDumpers *, PyObject *, PyObject *(*)(PyObject *));
  void (*update)(struct SimpleDumpers *, PyObject *);
};
static struct __pyx_vtabstruct_4axon_7_dumper_SimpleDumpers *__pyx_vtabptr_4axon_7_dumper_SimpleDumpers;


/* "axon/_objects.pxd":227
 * cdef unicode NAME_IS_EMPTY
 * 
 * cdef class StringReader:             # <<<<<<<<<<<<<<
 *     cdef unicode buffer
 *     cdef int pos
 */

struct __pyx_vtabstruct_4axon_8_objects_StringReader {
  PyObject *(*readline)(struct __pyx_obj_4axon_8_objects_StringReader *, int __pyx_skip_dispatch);
  PyObject *(*close)(struct __pyx_obj_4axon_8_objects_StringReader *, int __pyx_skip_dispatch);
};
static struct __pyx_vtabstruct_4axon_8_objects_StringReader *__pyx_vtabptr_4axon_8_objects_StringReader;

__PYX_EXTERN_C DL_EXPORT(PyTypeObject) DumperType;

/* "axon/_dumper.py":370
 * 
 * 
 * class Dumper:             # <<<<<<<<<<<<<<
 *     '''
 *     Dumper class
 */

struct __pyx_vtabstruct_4axon_7_dumper_Dumper {
  void (*_pretty_dump_crossref)(struct Dumper *, PyObject *);
  void (*_dump_crossref)(struct Dumper *, PyObject *);
  int (*_dump_label)(struct Dumper *, PyObject *);
  int (*_dump)(struct Dumper *, PyObject *);
  void (*_dump_value)(struct Dumper *, PyObject *, PyObject *);
  int (*_dump_dict_sequence)(struct Dumper *, PyObject *);
  int (*_dump_attr_sequence)(struct Dumper *, PyObject *);
  int (*_dump_list_sequence)(struct Dumper *, PyObject *);
  int (*_dump_set_sequence)(struct Dumper *, PyObject *);
  int (*_dump_tuple_sequence)(struct Dumper *, PyObject *);
  int (*dump_list)(struct Dumper *, PyObject *);
  int (*dump_dict)(struct Dumper *, PyObject *);
  int (*_pretty_dump_dict_sequence)(struct Dumper *, PyObject *, PyObject *, int);
  int (*_pretty_dump_attr_sequence)(struct Dumper *, PyObject *, PyObject *, int);
  int (*_pretty_dump_list_sequence)(struct Dumper *, PyObject *, PyObject *, int);
  int (*_pretty_dump_tuple_sequence)(struct Dumper *, PyObject *, PyObject *, int);
  int (*pretty_dump_list)(struct Dumper *, PyObject *, PyObject *, int);
  int (*pretty_dump_dict)(struct Dumper *, PyObject *, PyObject *, int);
  int (*dump_collection)(struct Dumper *, PyObject *, PyObject *);
  int (*dump_content)(struct Dumper *, PyObject *);
  int (*_dump_with_reducer)(struct Dumper *, PyObject *, PyObject *);
  int (*_pretty_dump)(struct Dumper *, PyObject *, PyObject *, int);
  int (*_pretty_dump_with_reducer)(struct Dumper *, PyObject *, PyObject *, PyObject *);
  void (*apply_crossref)(struct Dumper *);
  int (*_collect)(struct Dumper *, PyObject *);
  int (*_collect_list)(struct Dumper *, PyObject *);
  int (*_collect_tuple)(struct Dumper *, PyObject *);
  int (*_collect_set)(struct Dumper *, PyObject *);
  int (*_collect_dict)(struct Dumper *, PyObject *);
  int (*_collect_with_reducer)(struct Dumper *, PyObject *, PyObject *);
  int (*collect)(struct Dumper *, PyObject *);
};
static struct __pyx_vtabstruct_4axon_7_dumper_Dumper *__pyx_vtabptr_4axon_7_dumper_Dumper;
static void __pyx_f_4axon_7_dumper_6Dumper__pretty_dump_crossref(struct Dumper *, PyObject *);
static void __pyx_f_4axon_7_dumper_6Dumper__dump_crossref(struct Dumper *, PyObject *);
static int __pyx_f_4axon_7_dumper_6Dumper__dump_label(struct Dumper *, PyObject *);
static int __pyx_f_4axon_7_dumper_6Dumper__dump(struct Dumper *, PyObject *);
static void __pyx_f_4axon_7_dumper_6Dumper__dump_value(struct Dumper *, PyObject *, PyObject *);
static int __pyx_f_4axon_7_dumper_6Dumper__dump_dict_sequence(struct Dumper *, PyObject *);
static int __pyx_f_4axon_7_dumper_6Dumper__dump_attr_sequence(struct Dumper *, PyObject *);
static int __pyx_f_4axon_7_dumper_6Dumper__dump_list_sequence(struct Dumper *, PyObject *);
static int __pyx_f_4axon_7_dumper_6Dumper__dump_set_sequence(struct Dumper *, PyObject *);
static int __pyx_f_4axon_7_dumper_6Dumper__dump_tuple_sequence(struct Dumper *, PyObject *);
static int __pyx_f_4axon_7_dumper_6Dumper_dump_list(struct Dumper *, PyObject *);
static int __pyx_f_4axon_7_dumper_6Dumper_dump_dict(struct Dumper *, PyObject *);
static int __pyx_f_4axon_7_dumper_6Dumper__pretty_dump_dict_sequence(struct Dumper *, PyObject *, PyObject *, int);
static int __pyx_f_4axon_7_dumper_6Dumper__pretty_dump_attr_sequence(struct Dumper *, PyObject *, PyObject *, int);
static int __pyx_f_4axon_7_dumper_6Dumper__pretty_dump_list_sequence(struct Dumper *, PyObject *, PyObject *, int);
static int __pyx_f_4axon_7_dumper_6Dumper__pretty_dump_tuple_sequence(struct Dumper *, PyObject *, PyObject *, int);
static int __pyx_f_4axon_7_dumper_6Dumper_pretty_dump_list(struct Dumper *, PyObject *, PyObject *, int);
static int __pyx_f_4axon_7_dumper_6Dumper_pretty_dump_dict(struct Dumper *, PyObject *, PyObject *, int);
static int __pyx_f_4axon_7_dumper_6Dumper_dump_collection(struct Dumper *, PyObject *, PyObject *);
static int __pyx_f_4axon_7_dumper_6Dumper_dump_content(struct Dumper *, PyObject *);
static int __pyx_f_4axon_7_dumper_6Dumper__dump_with_reducer(struct Dumper *, PyObject *, PyObject *);
static int __pyx_f_4axon_7_dumper_6Dumper__pretty_dump(struct Dumper *, PyObject *, PyObject *, int);
static int __pyx_f_4axon_7_dumper_6Dumper__pretty_dump_with_reducer(struct Dumper *, PyObject *, PyObject *, PyObject *);
static void __pyx_f_4axon_7_dumper_6Dumper_apply_crossref(struct Dumper *);
static int __pyx_f_4axon_7_dumper_6Dumper__collect(struct Dumper *, PyObject *);
static int __pyx_f_4axon_7_dumper_6Dumper__collect_list(struct Dumper *, PyObject *);
static int __pyx_f_4axon_7_dumper_6Dumper__collect_tuple(struct Dumper *, PyObject *);
static int __pyx_f_4axon_7_dumper_6Dumper__collect_set(struct Dumper *, PyObject *);
static int __pyx_f_4axon_7_dumper_6Dumper__collect_dict(struct Dumper *, PyObject *);
static int __pyx_f_4axon_7_dumper_6Dumper__collect_with_reducer(struct Dumper *, PyObject *, PyObject *);
static int __pyx_f_4axon_7_dumper_6Dumper_collect(struct Dumper *, PyObject *);
#ifndef CYTHON_REFNANNY
  #define CYTHON_REFNANNY 0
#endif
#if CYTHON_REFNANNY
  typedef struct {
    void (*INCREF)(void*, PyObject*, int);
    void (*DECREF)(void*, PyObject*, int);
    void (*GOTREF)(void*, PyObject*, int);
    void (*GIVEREF)(void*, PyObject*, int);
    void* (*SetupContext)(const char*, int, const char*);
    void (*FinishContext)(void**);
  } __Pyx_RefNannyAPIStruct;
  static __Pyx_RefNannyAPIStruct *__Pyx_RefNanny = NULL;
  static __Pyx_RefNannyAPIStruct *__Pyx_RefNannyImportAPI(const char *modname); /*proto*/
  #define __Pyx_RefNannyDeclarations void *__pyx_refnanny = NULL;
#ifdef WITH_THREAD
  #define __Pyx_RefNannySetupContext(name, acquire_gil) \
          if (acquire_gil) { \
              PyGILState_STATE __pyx_gilstate_save = PyGILState_Ensure(); \
              __pyx_refnanny = __Pyx_RefNanny->SetupContext((name), __LINE__, __FILE__); \
              PyGILState_Release(__pyx_gilstate_save); \
          } else { \
              __pyx_refnanny = __Pyx_RefNanny->SetupContext((name), __LINE__, __FILE__); \
          }
#else
  #define __Pyx_RefNannySetupContext(name, acquire_gil) \
          __pyx_refnanny = __Pyx_RefNanny->SetupContext((name), __LINE__, __FILE__)
#endif
  #define __Pyx_RefNannyFinishContext() \
          __Pyx_RefNanny->FinishContext(&__pyx_refnanny)
  #define __Pyx_INCREF(r)  __Pyx_RefNanny->INCREF(__pyx_refnanny, (PyObject *)(r), __LINE__)
  #define __Pyx_DECREF(r)  __Pyx_RefNanny->DECREF(__pyx_refnanny, (PyObject *)(r), __LINE__)
  #define __Pyx_GOTREF(r)  __Pyx_RefNanny->GOTREF(__pyx_refnanny, (PyObject *)(r), __LINE__)
  #define __Pyx_GIVEREF(r) __Pyx_RefNanny->GIVEREF(__pyx_refnanny, (PyObject *)(r), __LINE__)
  #define __Pyx_XINCREF(r)  do { if((r) != NULL) {__Pyx_INCREF(r); }} while(0)
  #define __Pyx_XDECREF(r)  do { if((r) != NULL) {__Pyx_DECREF(r); }} while(0)
  #define __Pyx_XGOTREF(r)  do { if((r) != NULL) {__Pyx_GOTREF(r); }} while(0)
  #define __Pyx_XGIVEREF(r) do { if((r) != NULL) {__Pyx_GIVEREF(r);}} while(0)
#else
  #define __Pyx_RefNannyDeclarations
  #define __Pyx_RefNannySetupContext(name, acquire_gil)
  #define __Pyx_RefNannyFinishContext()
  #define __Pyx_INCREF(r) Py_INCREF(r)
  #define __Pyx_DECREF(r) Py_DECREF(r)
  #define __Pyx_GOTREF(r)
  #define __Pyx_GIVEREF(r)
  #define __Pyx_XINCREF(r) Py_XINCREF(r)
  #define __Pyx_XDECREF(r) Py_XDECREF(r)
  #define __Pyx_XGOTREF(r)
  #define __Pyx_XGIVEREF(r)
#endif /* CYTHON_REFNANNY */
#define __Pyx_CLEAR(r)    do { PyObject* tmp = ((PyObject*)(r)); r = NULL; __Pyx_DECREF(tmp);} while(0)
#define __Pyx_XCLEAR(r)   do { if((r) != NULL) {PyObject* tmp = ((PyObject*)(r)); r = NULL; __Pyx_DECREF(tmp);}} while(0)

#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetAttrStr(PyObject* obj, PyObject* attr_name) {
    PyTypeObject* tp = Py_TYPE(obj);
    if (likely(tp->tp_getattro))
        return tp->tp_getattro(obj, attr_name);
#if PY_MAJOR_VERSION < 3
    if (likely(tp->tp_getattr))
        return tp->tp_getattr(obj, PyString_AS_STRING(attr_name));
#endif
    return PyObject_GetAttr(obj, attr_name);
}
#else
#define __Pyx_PyObject_GetAttrStr(o,n) PyObject_GetAttr(o,n)
#endif

static PyObject *__Pyx_GetBuiltinName(PyObject *name); /*proto*/

static void __Pyx_RaiseDoubleKeywordsError(const char* func_name, PyObject* kw_name); /*proto*/

static int __Pyx_ParseOptionalKeywords(PyObject *kwds, PyObject **argnames[], \
    PyObject *kwds2, PyObject *values[], Py_ssize_t num_pos_args, \
    const char* function_name); /*proto*/

static void __Pyx_RaiseArgtupleInvalid(const char* func_name, int exact,
    Py_ssize_t num_min, Py_ssize_t num_max, Py_ssize_t num_found); /*proto*/

static int __Pyx_ArgTypeTest(PyObject *obj, PyTypeObject *type, int none_allowed,
    const char *name, int exact); /*proto*/

static CYTHON_INLINE void __Pyx_RaiseClosureNameError(const char *varname);

#define __Pyx_CyFunction_USED 1
#include <structmember.h>
#define __Pyx_CYFUNCTION_STATICMETHOD  0x01
#define __Pyx_CYFUNCTION_CLASSMETHOD   0x02
#define __Pyx_CYFUNCTION_CCLASS        0x04
#define __Pyx_CyFunction_GetClosure(f) \
    (((__pyx_CyFunctionObject *) (f))->func_closure)
#define __Pyx_CyFunction_GetClassObj(f) \
    (((__pyx_CyFunctionObject *) (f))->func_classobj)
#define __Pyx_CyFunction_Defaults(type, f) \
    ((type *)(((__pyx_CyFunctionObject *) (f))->defaults))
#define __Pyx_CyFunction_SetDefaultsGetter(f, g) \
    ((__pyx_CyFunctionObject *) (f))->defaults_getter = (g)
typedef struct {
    PyCFunctionObject func;
    int flags;
    PyObject *func_dict;
    PyObject *func_weakreflist;
    PyObject *func_name;
    PyObject *func_qualname;
    PyObject *func_doc;
    PyObject *func_code;
    PyObject *func_closure;
    PyObject *func_classobj; /* No-args super() class cell */
    void *defaults;
    int defaults_pyobjects;
    PyObject *defaults_tuple;   /* Const defaults tuple */
    PyObject *defaults_kwdict;  /* Const kwonly defaults dict */
    PyObject *(*defaults_getter)(PyObject *);
    PyObject *func_annotations; /* function annotations dict */
} __pyx_CyFunctionObject;
static PyTypeObject *__pyx_CyFunctionType = 0;
#define __Pyx_CyFunction_NewEx(ml, flags, qualname, self, module, code) \
    __Pyx_CyFunction_New(__pyx_CyFunctionType, ml, flags, qualname, self, module, code)
static PyObject *__Pyx_CyFunction_New(PyTypeObject *, PyMethodDef *ml,
                                      int flags, PyObject* qualname,
                                      PyObject *self, PyObject *module,
                                      PyObject* code);
static CYTHON_INLINE void *__Pyx_CyFunction_InitDefaults(PyObject *m,
                                                         size_t size,
                                                         int pyobjects);
static CYTHON_INLINE void __Pyx_CyFunction_SetDefaultsTuple(PyObject *m,
                                                            PyObject *tuple);
static CYTHON_INLINE void __Pyx_CyFunction_SetDefaultsKwDict(PyObject *m,
                                                             PyObject *dict);
static CYTHON_INLINE void __Pyx_CyFunction_SetAnnotationsDict(PyObject *m,
                                                              PyObject *dict);
static int __Pyx_CyFunction_init(void);

static CYTHON_INLINE int __Pyx_TypeTest(PyObject *obj, PyTypeObject *type); /*proto*/

#define __Pyx_GetItemInt_Unicode(o, i, size, to_py_func, is_list, wraparound, boundscheck) \
    (((size) <= sizeof(Py_ssize_t)) ? \
    __Pyx_GetItemInt_Unicode_Fast(o, i, wraparound, boundscheck) : \
    __Pyx_GetItemInt_Unicode_Generic(o, to_py_func(i)))
static CYTHON_INLINE Py_UCS4 __Pyx_GetItemInt_Unicode_Fast(PyObject* ustring, Py_ssize_t i,
                                                           int wraparound, int boundscheck);
static CYTHON_INLINE Py_UCS4 __Pyx_GetItemInt_Unicode_Generic(PyObject* ustring, PyObject* j);

static CYTHON_INLINE PyObject* __Pyx_PyUnicode_Substring(
            PyObject* text, Py_ssize_t start, Py_ssize_t stop);

static CYTHON_INLINE PyObject *__Pyx_GetModuleGlobalName(PyObject *name); /*proto*/

static CYTHON_INLINE int __Pyx_CheckKeywordStrings(PyObject *kwdict, const char* function_name, int kw_allowed); /*proto*/

static CYTHON_INLINE void __Pyx_ErrRestore(PyObject *type, PyObject *value, PyObject *tb); /*proto*/
static CYTHON_INLINE void __Pyx_ErrFetch(PyObject **type, PyObject **value, PyObject **tb); /*proto*/

static void __Pyx_WriteUnraisable(const char *name, int clineno,
                                  int lineno, const char *filename); /*proto*/

static CYTHON_INLINE int __Pyx_PySequence_Contains(PyObject* item, PyObject* seq, int eq) {
    int result = PySequence_Contains(seq, item);
    return unlikely(result < 0) ? result : (result == (eq == Py_EQ));
}

#if PY_MAJOR_VERSION >= 3
static PyObject *__Pyx_PyDict_GetItem(PyObject *d, PyObject* key) {
    PyObject *value;
    value = PyDict_GetItemWithError(d, key);
    if (unlikely(!value)) {
        if (!PyErr_Occurred()) {
            PyObject* args = PyTuple_Pack(1, key);
            if (likely(args))
                PyErr_SetObject(PyExc_KeyError, args);
            Py_XDECREF(args);
        }
        return NULL;
    }
    Py_INCREF(value);
    return value;
}
#else
    #define __Pyx_PyDict_GetItem(d, key) PyObject_GetItem(d, key)
#endif

#if PY_VERSION_HEX < 0x02050000
#ifndef PyAnySet_CheckExact
#define PyAnySet_CheckExact(ob) \
    ((ob)->ob_type == &PySet_Type || \
     (ob)->ob_type == &PyFrozenSet_Type)
#define PySet_New(iterable) \
    PyObject_CallFunctionObjArgs((PyObject *)&PySet_Type, (iterable), NULL)
#define Pyx_PyFrozenSet_New(iterable) \
    PyObject_CallFunctionObjArgs((PyObject *)&PyFrozenSet_Type, (iterable), NULL)
#define PySet_Size(anyset) \
    PyObject_Size((anyset))
#define PySet_Contains(anyset, key) \
    PySequence_Contains((anyset), (key))
#define PySet_Pop(set) \
    PyObject_CallMethod(set, (char *)"pop", NULL)
static CYTHON_INLINE int PySet_Clear(PyObject *set) {
    PyObject *ret = PyObject_CallMethod(set, (char *)"clear", NULL);
    if (!ret) return -1;
    Py_DECREF(ret); return 0;
}
static CYTHON_INLINE int PySet_Discard(PyObject *set, PyObject *key) {
    PyObject *ret = PyObject_CallMethod(set, (char *)"discard", (char *)"O", key);
    if (!ret) return -1;
    Py_DECREF(ret); return 0;
}
static CYTHON_INLINE int PySet_Add(PyObject *set, PyObject *key) {
    PyObject *ret = PyObject_CallMethod(set, (char *)"add", (char *)"O", key);
    if (!ret) return -1;
    Py_DECREF(ret); return 0;
}
#endif /* PyAnySet_CheckExact (<= Py2.4) */
#endif /* < Py2.5  */

static PyObject* __Pyx_PyDict_GetItemDefault(PyObject* d, PyObject* key, PyObject* default_value); /*proto*/

static void __Pyx_Raise(PyObject *type, PyObject *value, PyObject *tb, PyObject *cause); /*proto*/

#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE int __Pyx_ListComp_Append(PyObject* list, PyObject* x) {
    PyListObject* L = (PyListObject*) list;
    Py_ssize_t len = Py_SIZE(list);
    if (likely(L->allocated > len)) {
        Py_INCREF(x);
        PyList_SET_ITEM(list, len, x);
        Py_SIZE(list) = len+1;
        return 0;
    }
    return PyList_Append(list, x);
}
#else
#define __Pyx_ListComp_Append(L,x) PyList_Append(L,x)
#endif

#if PY_MAJOR_VERSION >= 3
static CYTHON_INLINE PyObject* __Pyx_PyDict_Items(PyObject* d); /*proto*/
#else
#define __Pyx_PyDict_Items(d) PyDict_Items(d)
#endif

static CYTHON_INLINE void __Pyx_RaiseTooManyValuesError(Py_ssize_t expected);

static CYTHON_INLINE void __Pyx_RaiseNeedMoreValuesError(Py_ssize_t index);

static CYTHON_INLINE int __Pyx_IterFinish(void); /*proto*/

static int __Pyx_IternextUnpackEndCheck(PyObject *retval, Py_ssize_t expected); /*proto*/

#define __Pyx_GetItemInt(o, i, size, to_py_func, is_list, wraparound, boundscheck) \
    (((size) <= sizeof(Py_ssize_t)) ? \
    __Pyx_GetItemInt_Fast(o, i, is_list, wraparound, boundscheck) : \
    __Pyx_GetItemInt_Generic(o, to_py_func(i)))
#define __Pyx_GetItemInt_List(o, i, size, to_py_func, is_list, wraparound, boundscheck) \
    (((size) <= sizeof(Py_ssize_t)) ? \
    __Pyx_GetItemInt_List_Fast(o, i, wraparound, boundscheck) : \
    __Pyx_GetItemInt_Generic(o, to_py_func(i)))
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_List_Fast(PyObject *o, Py_ssize_t i,
                                                              int wraparound, int boundscheck);
#define __Pyx_GetItemInt_Tuple(o, i, size, to_py_func, is_list, wraparound, boundscheck) \
    (((size) <= sizeof(Py_ssize_t)) ? \
    __Pyx_GetItemInt_Tuple_Fast(o, i, wraparound, boundscheck) : \
    __Pyx_GetItemInt_Generic(o, to_py_func(i)))
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_Tuple_Fast(PyObject *o, Py_ssize_t i,
                                                              int wraparound, int boundscheck);
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_Generic(PyObject *o, PyObject* j);
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_Fast(PyObject *o, Py_ssize_t i,
                                                     int is_list, int wraparound, int boundscheck);

static CYTHON_INLINE PyObject* __Pyx_PyObject_GetSlice(
        PyObject* obj, Py_ssize_t cstart, Py_ssize_t cstop,
        PyObject** py_start, PyObject** py_stop, PyObject** py_slice,
        int has_cstart, int has_cstop, int wraparound);

static int __Pyx_PyUnicode_Tailmatch(PyObject* s, PyObject* substr,
                                     Py_ssize_t start, Py_ssize_t end, int direction) {
    if (unlikely(PyTuple_Check(substr))) {
        Py_ssize_t i, count = PyTuple_GET_SIZE(substr);
        for (i = 0; i < count; i++) {
            int result;
#if CYTHON_COMPILING_IN_CPYTHON
            result = PyUnicode_Tailmatch(s, PyTuple_GET_ITEM(substr, i),
                                         start, end, direction);
#else
            PyObject* sub = PySequence_GetItem(substr, i);
            if (unlikely(!sub)) return -1;
            result = PyUnicode_Tailmatch(s, sub, start, end, direction);
            Py_DECREF(sub);
#endif
            if (result) {
                return result;
            }
        }
        return 0;
    }
    return PyUnicode_Tailmatch(s, substr, start, end, direction);
}

static PyObject* __Pyx_PyObject_CallMethodTuple(PyObject* obj, PyObject* method_name, PyObject* args) {
    PyObject *method, *result = NULL;
    if (unlikely(!args)) return NULL;
    method = __Pyx_PyObject_GetAttrStr(obj, method_name);
    if (unlikely(!method)) goto bad;
    result = PyObject_Call(method, args, NULL);
    Py_DECREF(method);
bad:
    Py_DECREF(args);
    return result;
}
#define __Pyx_PyObject_CallMethod3(obj, name, arg1, arg2, arg3) \
    __Pyx_PyObject_CallMethodTuple(obj, name, PyTuple_Pack(3, arg1, arg2, arg3))
#define __Pyx_PyObject_CallMethod2(obj, name, arg1, arg2) \
    __Pyx_PyObject_CallMethodTuple(obj, name, PyTuple_Pack(2, arg1, arg2))
#define __Pyx_PyObject_CallMethod1(obj, name, arg1) \
    __Pyx_PyObject_CallMethodTuple(obj, name, PyTuple_Pack(1, arg1))
#define __Pyx_PyObject_CallMethod0(obj, name) \
    __Pyx_PyObject_CallMethodTuple(obj, name, (Py_INCREF(__pyx_empty_tuple), __pyx_empty_tuple))

static CYTHON_INLINE void __Pyx_RaiseNoneNotIterableError(void);

static void __Pyx_UnpackTupleError(PyObject *, Py_ssize_t index); /*proto*/

static CYTHON_INLINE int __Pyx_unpack_tuple2(PyObject* tuple, PyObject** value1, PyObject** value2,
                                             int is_tuple, int has_known_size, int decref_tuple);

static CYTHON_INLINE PyObject* __Pyx_dict_iterator(PyObject* dict, int is_dict, PyObject* method_name,
                                                   Py_ssize_t* p_orig_length, int* p_is_dict);
static CYTHON_INLINE int __Pyx_dict_iter_next(PyObject* dict_or_iter, Py_ssize_t orig_length, Py_ssize_t* ppos,
                                              PyObject** pkey, PyObject** pvalue, PyObject** pitem, int is_dict);

#define __Pyx_PyIter_Next(obj) __Pyx_PyIter_Next2(obj, NULL)
static CYTHON_INLINE PyObject *__Pyx_PyIter_Next2(PyObject *, PyObject *); /*proto*/

#include <string.h>

static int __Pyx_SetVtable(PyObject *dict, void *vtable); /*proto*/

static void* __Pyx_GetVtable(PyObject *dict); /*proto*/

static int __Pyx_GetException(PyObject **type, PyObject **value, PyObject **tb); /*proto*/

static PyObject* __Pyx_ImportFrom(PyObject* module, PyObject* name); /*proto*/

#if PY_MAJOR_VERSION >= 3
static CYTHON_INLINE PyObject* __Pyx_PyDict_Keys(PyObject* d); /*proto*/
#else
#define __Pyx_PyDict_Keys(d) PyDict_Keys(d)
#endif

static PyObject *__Pyx_Import(PyObject *name, PyObject *from_list, int level); /*proto*/

static CYTHON_INLINE void __Pyx_ExceptionSave(PyObject **type, PyObject **value, PyObject **tb); /*proto*/
static void __Pyx_ExceptionReset(PyObject *type, PyObject *value, PyObject *tb); /*proto*/

static CYTHON_INLINE unsigned char __Pyx_PyInt_AsUnsignedChar(PyObject *);

static CYTHON_INLINE unsigned short __Pyx_PyInt_AsUnsignedShort(PyObject *);

static CYTHON_INLINE unsigned int __Pyx_PyInt_AsUnsignedInt(PyObject *);

static CYTHON_INLINE char __Pyx_PyInt_AsChar(PyObject *);

static CYTHON_INLINE short __Pyx_PyInt_AsShort(PyObject *);

static CYTHON_INLINE int __Pyx_PyInt_AsInt(PyObject *);

static CYTHON_INLINE signed char __Pyx_PyInt_AsSignedChar(PyObject *);

static CYTHON_INLINE signed short __Pyx_PyInt_AsSignedShort(PyObject *);

static CYTHON_INLINE signed int __Pyx_PyInt_AsSignedInt(PyObject *);

static CYTHON_INLINE int __Pyx_PyInt_AsLongDouble(PyObject *);

static CYTHON_INLINE unsigned long __Pyx_PyInt_AsUnsignedLong(PyObject *);

static CYTHON_INLINE unsigned PY_LONG_LONG __Pyx_PyInt_AsUnsignedLongLong(PyObject *);

static CYTHON_INLINE long __Pyx_PyInt_AsLong(PyObject *);

static CYTHON_INLINE PY_LONG_LONG __Pyx_PyInt_AsLongLong(PyObject *);

static CYTHON_INLINE signed long __Pyx_PyInt_AsSignedLong(PyObject *);

static CYTHON_INLINE signed PY_LONG_LONG __Pyx_PyInt_AsSignedLongLong(PyObject *);

static CYTHON_INLINE void __Pyx_ExceptionSwap(PyObject **type, PyObject **value, PyObject **tb); /*proto*/

#define __Pyx_Generator_USED
#include <structmember.h>
#include <frameobject.h>
typedef PyObject *(*__pyx_generator_body_t)(PyObject *, PyObject *);
typedef struct {
    PyObject_HEAD
    __pyx_generator_body_t body;
    PyObject *closure;
    PyObject *exc_type;
    PyObject *exc_value;
    PyObject *exc_traceback;
    PyObject *gi_weakreflist;
    PyObject *classobj;
    PyObject *yieldfrom;
    int resume_label;
    char is_running;  // using T_BOOL for property below requires char value
} __pyx_GeneratorObject;
static __pyx_GeneratorObject *__Pyx_Generator_New(__pyx_generator_body_t body,
                                                  PyObject *closure);
static int __pyx_Generator_init(void);
static int __Pyx_Generator_clear(PyObject* self);
#if 1 || PY_VERSION_HEX < 0x030300B0
static int __Pyx_PyGen_FetchStopIterationValue(PyObject **pvalue);
#else
#define __Pyx_PyGen_FetchStopIterationValue(pvalue) PyGen_FetchStopIterationValue(pvalue)
#endif

static int __Pyx_check_binary_version(void);

#if CYTHON_COMPILING_IN_CPYTHON
#define __Pyx_PyObject_DelAttrStr(o,n) __Pyx_PyObject_SetAttrStr(o,n,NULL)
static CYTHON_INLINE int __Pyx_PyObject_SetAttrStr(PyObject* obj, PyObject* attr_name, PyObject* value) {
    PyTypeObject* tp = Py_TYPE(obj);
    if (likely(tp->tp_setattro))
        return tp->tp_setattro(obj, attr_name, value);
#if PY_MAJOR_VERSION < 3
    if (likely(tp->tp_setattr))
        return tp->tp_setattr(obj, PyString_AS_STRING(attr_name), value);
#endif
    return PyObject_SetAttr(obj, attr_name, value);
}
#else
#define __Pyx_PyObject_DelAttrStr(o,n)   PyObject_DelAttr(o,n)
#define __Pyx_PyObject_SetAttrStr(o,n,v) PyObject_SetAttr(o,n,v)
#endif

static int __Pyx_ExportVoidPtr(PyObject *name, void *p, const char *sig); /*proto*/

static int __Pyx_ExportFunction(const char *name, void (*f)(void), const char *sig); /*proto*/

#if !defined(__Pyx_PyIdentifier_FromString)
#if PY_MAJOR_VERSION < 3
  #define __Pyx_PyIdentifier_FromString(s) PyString_FromString(s)
#else
  #define __Pyx_PyIdentifier_FromString(s) PyUnicode_FromString(s)
#endif
#endif

static PyObject *__Pyx_ImportModule(const char *name); /*proto*/

static PyTypeObject *__Pyx_ImportType(const char *module_name, const char *class_name, size_t size, int strict);  /*proto*/

static int __Pyx_ImportVoidPtr(PyObject *module, const char *name, void **p, const char *sig); /*proto*/

typedef struct {
    int code_line;
    PyCodeObject* code_object;
} __Pyx_CodeObjectCacheEntry;
struct __Pyx_CodeObjectCache {
    int count;
    int max_count;
    __Pyx_CodeObjectCacheEntry* entries;
};
static struct __Pyx_CodeObjectCache __pyx_code_cache = {0,0,NULL};
static int __pyx_bisect_code_objects(__Pyx_CodeObjectCacheEntry* entries, int count, int code_line);
static PyCodeObject *__pyx_find_code_object(int code_line);
static void __pyx_insert_code_object(int code_line, PyCodeObject* code_object);

static void __Pyx_AddTraceback(const char *funcname, int c_line,
                               int py_line, const char *filename); /*proto*/

static int __Pyx_InitStrings(__Pyx_StringTabEntry *t); /*proto*/


/* Module declarations from 'cython' */

/* Module declarations from 'cpython.ref' */

/* Module declarations from 'libc.string' */

/* Module declarations from 'libc.stdio' */

/* Module declarations from 'cpython.object' */

/* Module declarations from 'cpython.unicode' */

/* Module declarations from 'cpython.bytes' */

/* Module declarations from 'cpython.long' */

/* Module declarations from 'axon._objects' */
static PyTypeObject *__pyx_ptype_4axon_8_objects_Undefined = 0;
static PyTypeObject *__pyx_ptype_4axon_8_objects_rdict = 0;
static PyTypeObject *__pyx_ptype_4axon_8_objects_rlist = 0;
static PyTypeObject *__pyx_ptype_4axon_8_objects_NamedValue = 0;
static PyTypeObject *__pyx_ptype_4axon_8_objects_Attribute = 0;
static PyTypeObject *__pyx_ptype_4axon_8_objects_Attrs = 0;
static PyTypeObject *__pyx_ptype_4axon_8_objects_Empty = 0;
static PyTypeObject *__pyx_ptype_4axon_8_objects_Sequence = 0;
static PyTypeObject *__pyx_ptype_4axon_8_objects_Collection = 0;
static PyTypeObject *__pyx_ptype_4axon_8_objects_Mapping = 0;
static PyTypeObject *__pyx_ptype_4axon_8_objects_Element = 0;
static PyTypeObject *__pyx_ptype_4axon_8_objects_Instance = 0;
static PyTypeObject *__pyx_ptype_4axon_8_objects_StringReader = 0;
static PyObject **__pyx_vp_4axon_8_objects__decimal2str = 0;
#define __pyx_v_4axon_8_objects__decimal2str (*__pyx_vp_4axon_8_objects__decimal2str)
static PyObject **__pyx_vp_4axon_8_objects_empty_name = 0;
#define __pyx_v_4axon_8_objects_empty_name (*__pyx_vp_4axon_8_objects_empty_name)
static PyObject **__pyx_vp_4axon_8_objects_c_undescore = 0;
#define __pyx_v_4axon_8_objects_c_undescore (*__pyx_vp_4axon_8_objects_c_undescore)
static PyObject **__pyx_vp_4axon_8_objects_c_undefined = 0;
#define __pyx_v_4axon_8_objects_c_undefined (*__pyx_vp_4axon_8_objects_c_undefined)
static PyObject **__pyx_vp_4axon_8_objects_name_cache = 0;
#define __pyx_v_4axon_8_objects_name_cache (*__pyx_vp_4axon_8_objects_name_cache)
static PyObject **__pyx_vp_4axon_8_objects_c_str_type = 0;
#define __pyx_v_4axon_8_objects_c_str_type (*__pyx_vp_4axon_8_objects_c_str_type)
static struct ReadonlyDict **__pyx_vp_4axon_8_objects_c_empty_dict = 0;
#define __pyx_v_4axon_8_objects_c_empty_dict (*__pyx_vp_4axon_8_objects_c_empty_dict)
static struct ReadonlyList **__pyx_vp_4axon_8_objects_c_empty_list = 0;
#define __pyx_v_4axon_8_objects_c_empty_list (*__pyx_vp_4axon_8_objects_c_empty_list)
static PyObject **__pyx_vp_4axon_8_objects_NAME_IS_EMPTY = 0;
#define __pyx_v_4axon_8_objects_NAME_IS_EMPTY (*__pyx_vp_4axon_8_objects_NAME_IS_EMPTY)
static CYTHON_INLINE PyObject *__pyx_f_4axon_8_objects_c_as_unicode(PyObject *); /*proto*/
static CYTHON_INLINE PyObject *__pyx_f_4axon_8_objects_c_as_name(PyObject *); /*proto*/
static struct Attribute *(*__pyx_f_4axon_8_objects_c_new_attribute)(PyObject *, PyObject *); /*proto*/
static PyObject *(*__pyx_f_4axon_8_objects_c_new_sequence)(PyObject *, PyObject *); /*proto*/
static PyObject *(*__pyx_f_4axon_8_objects_c_new_collection)(PyObject *, PyObject *); /*proto*/
static PyObject *(*__pyx_f_4axon_8_objects_c_new_mapping)(PyObject *, PyObject *); /*proto*/
static PyObject *(*__pyx_f_4axon_8_objects_c_new_element)(PyObject *, PyObject *, PyObject *); /*proto*/
static PyObject *(*__pyx_f_4axon_8_objects_c_new_instance)(PyObject *, PyObject *, PyObject *); /*proto*/
static PyObject *(*__pyx_f_4axon_8_objects_c_new_empty)(PyObject *); /*proto*/

/* Module declarations from 'axon._dumper' */
static PyTypeObject *__pyx_ptype_4axon_7_dumper_PyPointer = 0;
static PyTypeObject *__pyx_ptype_4axon_7_dumper___pyx_scope_struct_2_pretty_dump_content = 0;
static PyTypeObject *__pyx_ptype_4axon_7_dumper___pyx_scope_struct_5_genexpr = 0;
static PyTypeObject *__pyx_ptype_4axon_7_dumper_SimpleDumpers = 0;
static PyTypeObject *__pyx_ptype_4axon_7_dumper___pyx_scope_struct_3_genexpr = 0;
static PyTypeObject *__pyx_ptype_4axon_7_dumper___pyx_scope_struct_1_dump_as_str = 0;
static PyTypeObject *__pyx_ptype_4axon_7_dumper_PyInt = 0;
static PyTypeObject *__pyx_ptype_4axon_7_dumper___pyx_scope_struct_4_genexpr = 0;
static PyTypeObject *__pyx_ptype_4axon_7_dumper___pyx_scope_struct__reduce = 0;
static PyTypeObject *__pyx_ptype_4axon_7_dumper_Dumper = 0;
__PYX_EXTERN_C DL_EXPORT(PyObject) *c_reduce_dict;
__PYX_EXTERN_C DL_EXPORT(PyObject) *__pyx_v_4axon_7_dumper_c_all_names;
static PyObject *__pyx_v_4axon_7_dumper__set_name = 0;
static PyObject *__pyx_v_4axon_7_dumper__tuple_name = 0;
static PyObject *__pyx_v_4axon_7_dumper__list_name = 0;
static PyObject *__pyx_v_4axon_7_dumper__dict_name = 0;
static PyObject *__pyx_v_4axon_7_dumper__c_type_reducers = 0;
__PYX_EXTERN_C DL_EXPORT(PyObject) *__pyx_v_4axon_7_dumper_c_factory_dict;
static PyObject *__pyx_v_4axon_7_dumper_c_simple_dumpers = 0;
static PyObject *__pyx_v_4axon_7_dumper_simple_types = 0;
static PyObject *__pyx_v_4axon_7_dumper__simple_types = 0;
static PyObject *__pyx_f_4axon_7_dumper_mapping_reduce(struct MappingObject *, int __pyx_skip_dispatch); /*proto*/
static PyObject *__pyx_f_4axon_7_dumper_element_reduce(struct ElementObject *, int __pyx_skip_dispatch); /*proto*/
static PyObject *__pyx_f_4axon_7_dumper_sequence_reduce(struct SequenceObject *, int __pyx_skip_dispatch); /*proto*/
static PyObject *__pyx_f_4axon_7_dumper_collection_reduce(struct CollectionObject *, int __pyx_skip_dispatch); /*proto*/
static PyObject *__pyx_f_4axon_7_dumper_instance_reduce(struct InstanceObject *, int __pyx_skip_dispatch); /*proto*/
static PyObject *__pyx_f_4axon_7_dumper_empty_reduce(struct EmptyObject *, int __pyx_skip_dispatch); /*proto*/
static PyObject *__pyx_f_4axon_7_dumper_set_reduce(PyObject *, int __pyx_skip_dispatch); /*proto*/
static PyObject *__pyx_f_4axon_7_dumper_tuple_reduce(PyObject *, int __pyx_skip_dispatch); /*proto*/
static PyObject *__pyx_f_4axon_7_dumper_dict_reduce(PyObject *, int __pyx_skip_dispatch); /*proto*/
static PyObject *__pyx_f_4axon_7_dumper_list_reduce(PyObject *, int __pyx_skip_dispatch); /*proto*/
static struct __pyx_obj_4axon_7_dumper_PyPointer *__pyx_f_4axon_7_dumper_c_new_pyptr(PyObject *(*)(PyObject *)); /*proto*/
static PyObject *__pyx_f_4axon_7_dumper__dump_unicode(PyObject *); /*proto*/
static PyObject *__pyx_f_4axon_7_dumper__dump_str(PyObject *); /*proto*/
static PyObject *__pyx_f_4axon_7_dumper__dump_bool(PyObject *); /*proto*/
static PyObject *__pyx_f_4axon_7_dumper__dump_date(PyObject *); /*proto*/
static PyObject *__pyx_f_4axon_7_dumper__dump_tzinfo(PyObject *); /*proto*/
static PyObject *__pyx_f_4axon_7_dumper__dump_time(PyObject *); /*proto*/
static PyObject *__pyx_f_4axon_7_dumper__dump_datetime(PyObject *); /*proto*/
static PyObject *__pyx_f_4axon_7_dumper__dump_none(PyObject *); /*proto*/
static PyObject *__pyx_f_4axon_7_dumper__dump_int(PyObject *); /*proto*/
static PyObject *__pyx_f_4axon_7_dumper__dump_bytes(PyObject *); /*proto*/
static PyObject *__pyx_f_4axon_7_dumper__dump_long(PyObject *); /*proto*/
static PyObject *__pyx_f_4axon_7_dumper__dump_float(PyObject *); /*proto*/
static PyObject *__pyx_f_4axon_7_dumper__dump_decimal(PyObject *); /*proto*/
static PyObject *__pyx_f_4axon_7_dumper__dump_undef(PyObject *); /*proto*/
static PyObject *__pyx_f_4axon_7_dumper_dump_default(PyObject *); /*proto*/
static PyObject *__pyx_f_4axon_7_dumper__dump_name(PyObject *, int); /*proto*/
static int __pyx_f_4axon_7_dumper_is_simple_type(struct Dumper *, PyObject *); /*proto*/
#define __Pyx_MODULE_NAME "axon._dumper"
int __pyx_module_is_main_axon___dumper = 0;

/* Implementation of 'axon._dumper' */
static PyObject *__pyx_builtin_id;
static PyObject *__pyx_builtin_TypeError;
static PyObject *__pyx_builtin_all;
static PyObject *__pyx_builtin_sorted;
static PyObject *__pyx_builtin_enumerate;
static PyObject *__pyx_builtin_ValueError;
static PyObject *__pyx_builtin_range;
static int __pyx_pf_4axon_7_dumper_5PyInt___init__(struct __pyx_obj_4axon_7_dumper_PyInt *__pyx_v_self, PyObject *__pyx_v_val); /* proto */
static PyObject *__pyx_pf_4axon_7_dumper_5PyInt_2__repr__(struct __pyx_obj_4axon_7_dumper_PyInt *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_4axon_7_dumper_mapping_reduce(CYTHON_UNUSED PyObject *__pyx_self, struct MappingObject *__pyx_v_o); /* proto */
static PyObject *__pyx_pf_4axon_7_dumper_2element_reduce(CYTHON_UNUSED PyObject *__pyx_self, struct ElementObject *__pyx_v_o); /* proto */
static PyObject *__pyx_pf_4axon_7_dumper_4sequence_reduce(CYTHON_UNUSED PyObject *__pyx_self, struct SequenceObject *__pyx_v_o); /* proto */
static PyObject *__pyx_pf_4axon_7_dumper_6collection_reduce(CYTHON_UNUSED PyObject *__pyx_self, struct CollectionObject *__pyx_v_o); /* proto */
static PyObject *__pyx_pf_4axon_7_dumper_8instance_reduce(CYTHON_UNUSED PyObject *__pyx_self, struct InstanceObject *__pyx_v_o); /* proto */
static PyObject *__pyx_pf_4axon_7_dumper_10empty_reduce(CYTHON_UNUSED PyObject *__pyx_self, struct EmptyObject *__pyx_v_o); /* proto */
static PyObject *__pyx_pf_4axon_7_dumper_12set_reduce(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_o); /* proto */
static PyObject *__pyx_pf_4axon_7_dumper_14tuple_reduce(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_o); /* proto */
static PyObject *__pyx_pf_4axon_7_dumper_16dict_reduce(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_o); /* proto */
static PyObject *__pyx_pf_4axon_7_dumper_18list_reduce(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_o); /* proto */
static PyObject *__pyx_pf_4axon_7_dumper_20reset_reduce(CYTHON_UNUSED PyObject *__pyx_self); /* proto */
static PyObject *__pyx_pf_4axon_7_dumper_6reduce__factory(PyObject *__pyx_self, PyObject *__pyx_v_factory_func); /* proto */
static PyObject *__pyx_pf_4axon_7_dumper_22reduce(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_type_, PyObject *__pyx_v_reduce_func); /* proto */
static int __pyx_pf_4axon_7_dumper_13SimpleDumpers___init__(struct SimpleDumpers *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_4axon_7_dumper_13SimpleDumpers_7mapping___get__(struct SimpleDumpers *__pyx_v_self); /* proto */
static int __pyx_pf_4axon_7_dumper_13SimpleDumpers_7mapping_2__set__(struct SimpleDumpers *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static int __pyx_pf_4axon_7_dumper_13SimpleDumpers_7mapping_4__del__(struct SimpleDumpers *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_4axon_7_dumper_11dump_as_str__dump_as_str(PyObject *__pyx_self, PyObject *__pyx_v_func); /* proto */
static PyObject *__pyx_pf_4axon_7_dumper_24dump_as_str(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_tp); /* proto */
static int __pyx_pf_4axon_7_dumper_6Dumper___init__(struct Dumper *__pyx_v_self, PyObject *__pyx_v_fd, PyObject *__pyx_v_crossref, PyObject *__pyx_v_quote, PyObject *__pyx_v_pretty, PyObject *__pyx_v_nsize, PyObject *__pyx_v_sorted); /* proto */
static PyObject *__pyx_pf_4axon_7_dumper_6Dumper_2dump_tuple(struct Dumper *__pyx_v_self, PyObject *__pyx_v_d); /* proto */
static PyObject *__pyx_pf_4axon_7_dumper_6Dumper_4pretty_dump_tuple(struct Dumper *__pyx_v_self, PyObject *__pyx_v_l, PyObject *__pyx_v_w, CYTHON_UNUSED PyObject *__pyx_v_use_offset); /* proto */
static PyObject *__pyx_pf_4axon_7_dumper_6Dumper_19pretty_dump_content_genexpr(PyObject *__pyx_self); /* proto */
static PyObject *__pyx_pf_4axon_7_dumper_6Dumper_19pretty_dump_content_3genexpr(PyObject *__pyx_self); /* proto */
static PyObject *__pyx_pf_4axon_7_dumper_6Dumper_19pretty_dump_content_6genexpr(PyObject *__pyx_self); /* proto */
static PyObject *__pyx_pf_4axon_7_dumper_6Dumper_6pretty_dump_content(struct Dumper *__pyx_v_self, PyObject *__pyx_v_items, PyObject *__pyx_v_offset); /* proto */
static PyObject *__pyx_pf_4axon_7_dumper_6Dumper_8pretty_dump_collection(struct Dumper *__pyx_v_self, PyObject *__pyx_v_name, PyObject *__pyx_v_collection, PyObject *__pyx_v_offset); /* proto */
static PyObject *__pyx_pf_4axon_7_dumper_6Dumper_10dump(struct Dumper *__pyx_v_self, PyObject *__pyx_v_seq); /* proto */
static PyObject *__pyx_tp_new_4axon_7_dumper_PyPointer(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_4axon_7_dumper___pyx_scope_struct_2_pretty_dump_content(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_4axon_7_dumper___pyx_scope_struct_5_genexpr(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_4axon_7_dumper_SimpleDumpers(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_4axon_7_dumper___pyx_scope_struct_3_genexpr(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_4axon_7_dumper___pyx_scope_struct_1_dump_as_str(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_4axon_7_dumper_PyInt(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_4axon_7_dumper___pyx_scope_struct_4_genexpr(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_4axon_7_dumper___pyx_scope_struct__reduce(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_4axon_7_dumper_Dumper(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static char __pyx_k_1[] = "*";
static char __pyx_k_4[] = "/Users/sz/Repos/axon/python/lib/axon/_dumper.py";
static char __pyx_k_5[] = "reduce.<locals>._factory";
static char __pyx_k_6[] = "axon._dumper";
static char __pyx_k_7[] = "\"";
static char __pyx_k_8[] = "\\\"";
static char __pyx_k_9[] = "%d-%02d-%02d";
static char __pyx_k_10[] = "%02d:%02d:%02d.%06d";
static char __pyx_k_11[] = "%02d:%02d:%02d";
static char __pyx_k_12[] = "%02d:%02d";
static char __pyx_k_13[] = "%d-%02d-%02dT%02d:%02d:%02d.%06d";
static char __pyx_k_14[] = "%d-%02d-%02dT%02d:%02d:%02d";
static char __pyx_k_15[] = "%d-%02d-%02dT%02d:%02d";
static char __pyx_k_16[] = "|";
static char __pyx_k_17[] = "?";
static char __pyx_k_18[] = "-\342\210\236";
static char __pyx_k_19[] = "\342\210\236";
static char __pyx_k_20[] = "-0";
static char __pyx_k_21[] = "$";
static char __pyx_k_22[] = "\077\077";
static char __pyx_k_25[] = "dump_as_str.<locals>._dump_as_str";
static char __pyx_k_26[] = "\\'";
static char __pyx_k_27[] = "'";
static char __pyx_k_30[] = " &";
static char __pyx_k_32[] = " ";
static char __pyx_k_34[] = "&";
static char __pyx_k_40[] = "\n";
static char __pyx_k_42[] = "There is no reducer for this type: ";
static char __pyx_k_43[] = "  ";
static char __pyx_k_44[] = "";
static char __pyx_k_46[] = ":";
static char __pyx_k_53[] = "[";
static char __pyx_k_55[] = "]";
static char __pyx_k_57[] = "{";
static char __pyx_k_59[] = "}";
static char __pyx_k_61[] = "(";
static char __pyx_k_63[] = ")";
static char __pyx_k_67[] = ": ";
static char __pyx_k_86[] = "Invalid name for collection %s-th item";
static char __pyx_k_87[] = "Reducer returns invalid number of items: %s";
static char __pyx_k_91[] = "{}";
static char __pyx_k__0[] = "0";
static char __pyx_k__l[] = "l";
static char __pyx_k__w[] = "w";
static char __pyx_k_106[] = ":\n";
static char __pyx_k_108[] = "  ...";
static char __pyx_k_111[] = " {";
  static char __pyx_k_114[] = "pretty_dump_collection";
  static char __pyx_k_121[] = "This object %r is not unicode compatible";
  static char __pyx_k_122[] = "axon.types";
  static char __pyx_k_123[] = "default_decimal_context";
  static char __pyx_k__fd[] = "fd";
  static char __pyx_k__id[] = "id";
  static char __pyx_k__tp[] = "tp";
  static char __pyx_k__all[] = "all";
  static char __pyx_k__day[] = "day";
  static char __pyx_k__get[] = "get";
  static char __pyx_k__set[] = "set";
  static char __pyx_k__val[] = "val";
  static char __pyx_k__args[] = "args";
  static char __pyx_k__date[] = "date";
  static char __pyx_k__dict[] = "dict";
  static char __pyx_k__func[] = "func";
  static char __pyx_k__hour[] = "hour";
  static char __pyx_k__keys[] = "keys";
  static char __pyx_k__list[] = "list";
  static char __pyx_k__name[] = "name";
  static char __pyx_k__null[] = "null";
  static char __pyx_k__send[] = "send";
  static char __pyx_k__time[] = "time";
  static char __pyx_k__true[] = "true";
  static char __pyx_k__year[] = "year";
  static char __pyx_k__ascii[] = "ascii";
  static char __pyx_k__close[] = "close";
  static char __pyx_k__false[] = "false";
  static char __pyx_k__items[] = "items";
  static char __pyx_k__month[] = "month";
  static char __pyx_k__nsize[] = "nsize";
  static char __pyx_k__quote[] = "quote";
  static char __pyx_k__range[] = "range";
  static char __pyx_k__throw[] = "throw";
  static char __pyx_k__tuple[] = "tuple";
  static char __pyx_k__type_[] = "type_";
  static char __pyx_k__types[] = "types";
  static char __pyx_k__write[] = "write";
  static char __pyx_k__base64[] = "base64";
  static char __pyx_k__is_nan[] = "is_nan";
  static char __pyx_k__minute[] = "minute";
  static char __pyx_k__offset[] = "offset";
  static char __pyx_k__pretty[] = "pretty";
  static char __pyx_k__reduce[] = "reduce";
  static char __pyx_k__remove[] = "remove";
  static char __pyx_k__second[] = "second";
  static char __pyx_k__sorted[] = "sorted";
  static char __pyx_k__tzinfo[] = "tzinfo";
  static char __pyx_k__update[] = "update";
  static char __pyx_k__values[] = "values";
  static char __pyx_k__Decimal[] = "Decimal";
  static char __pyx_k__decimal[] = "decimal";
  static char __pyx_k____main__[] = "__main__";
  static char __pyx_k____test__[] = "__test__";
  static char __pyx_k___decimal[] = "_decimal";
  static char __pyx_k___factory[] = "_factory";
  static char __pyx_k__cdecimal[] = "cdecimal";
  static char __pyx_k__crossref[] = "crossref";
  static char __pyx_k__datetime[] = "datetime";
  static char __pyx_k__int_type[] = "int_type";
  static char __pyx_k__str_type[] = "str_type";
  static char __pyx_k__TypeError[] = "TypeError";
  static char __pyx_k___set_name[] = "_set_name";
  static char __pyx_k__bool_type[] = "bool_type";
  static char __pyx_k__date_type[] = "date_type";
  static char __pyx_k__enumerate[] = "enumerate";
  static char __pyx_k__is_finite[] = "is_finite";
  static char __pyx_k__is_signed[] = "is_signed";
  static char __pyx_k__long_type[] = "long_type";
  static char __pyx_k__time_type[] = "time_type";
  static char __pyx_k__ValueError[] = "ValueError";
  static char __pyx_k____import__[] = "__import__";
  static char __pyx_k___dict_name[] = "_dict_name";
  static char __pyx_k___list_name[] = "_list_name";
  static char __pyx_k__bytes_type[] = "bytes_type";
  static char __pyx_k__collection[] = "collection";
  static char __pyx_k__dump_tuple[] = "dump_tuple";
  static char __pyx_k__float_type[] = "float_type";
  static char __pyx_k__getcontext[] = "getcontext";
  static char __pyx_k__set_reduce[] = "set_reduce";
  static char __pyx_k__use_offset[] = "use_offset";
  static char __pyx_k___tuple_name[] = "_tuple_name";
  static char __pyx_k__c_all_names[] = "c_all_names";
  static char __pyx_k__decodebytes[] = "decodebytes";
  static char __pyx_k__dict_reduce[] = "dict_reduce";
  static char __pyx_k__dump_as_str[] = "dump_as_str";
  static char __pyx_k__encodebytes[] = "encodebytes";
  static char __pyx_k__is_infinite[] = "is_infinite";
  static char __pyx_k__list_reduce[] = "list_reduce";
  static char __pyx_k__microsecond[] = "microsecond";
  static char __pyx_k__reduce_func[] = "reduce_func";
  static char __pyx_k____pyx_capi__[] = "__pyx_capi__";
  static char __pyx_k___decimal2str[] = "_decimal2str";
  static char __pyx_k___dump_as_str[] = "_dump_as_str";
  static char __pyx_k__decimal_type[] = "decimal_type";
  static char __pyx_k__decodestring[] = "decodestring";
  static char __pyx_k__empty_reduce[] = "empty_reduce";
  static char __pyx_k__encodestring[] = "encodestring";
  static char __pyx_k__factory_func[] = "factory_func";
  static char __pyx_k__reset_reduce[] = "reset_reduce";
  static char __pyx_k__simple_types[] = "simple_types";
  static char __pyx_k__tuple_reduce[] = "tuple_reduce";
  static char __pyx_k__unicode_type[] = "unicode_type";
  static char __pyx_k___simple_types[] = "_simple_types";
  static char __pyx_k__c_reduce_dict[] = "c_reduce_dict";
  static char __pyx_k__datetime_type[] = "datetime_type";
  static char __pyx_k__to_eng_string[] = "to_eng_string";
  static char __pyx_k____pyx_vtable__[] = "__pyx_vtable__";
  static char __pyx_k__c_factory_dict[] = "c_factory_dict";
  static char __pyx_k__element_reduce[] = "element_reduce";
  static char __pyx_k__mapping_reduce[] = "mapping_reduce";
  static char __pyx_k__instance_reduce[] = "instance_reduce";
  static char __pyx_k__sequence_reduce[] = "sequence_reduce";
  static char __pyx_k___c_type_reducers[] = "_c_type_reducers";
  static char __pyx_k__c_simple_dumpers[] = "c_simple_dumpers";
  static char __pyx_k__collection_reduce[] = "collection_reduce";
  static char __pyx_k__pretty_dump_tuple[] = "pretty_dump_tuple";
  static char __pyx_k__pretty_dump_content[] = "pretty_dump_content";
  static PyObject *__pyx_n_s_1;
  static PyObject *__pyx_kp_u_1;
  static PyObject *__pyx_kp_u_10;
  static PyObject *__pyx_kp_u_106;
  static PyObject *__pyx_kp_u_108;
  static PyObject *__pyx_kp_u_11;
  static PyObject *__pyx_kp_u_111;
  static PyObject *__pyx_n_s_114;
  static PyObject *__pyx_kp_u_12;
  static PyObject *__pyx_kp_u_121;
  static PyObject *__pyx_n_s_122;
  static PyObject *__pyx_n_s_123;
  static PyObject *__pyx_kp_u_13;
  static PyObject *__pyx_kp_u_14;
  static PyObject *__pyx_kp_u_15;
  static PyObject *__pyx_kp_u_16;
  static PyObject *__pyx_kp_u_17;
  static PyObject *__pyx_kp_u_18;
  static PyObject *__pyx_kp_u_19;
  static PyObject *__pyx_kp_u_20;
  static PyObject *__pyx_kp_u_21;
  static PyObject *__pyx_kp_u_22;
  static PyObject *__pyx_n_s_25;
  static PyObject *__pyx_kp_u_26;
  static PyObject *__pyx_kp_u_27;
  static PyObject *__pyx_kp_u_30;
  static PyObject *__pyx_kp_u_32;
  static PyObject *__pyx_kp_u_34;
  static PyObject *__pyx_kp_s_4;
  static PyObject *__pyx_kp_u_40;
  static PyObject *__pyx_kp_u_42;
  static PyObject *__pyx_kp_u_43;
  static PyObject *__pyx_kp_u_44;
  static PyObject *__pyx_kp_u_46;
  static PyObject *__pyx_n_s_5;
  static PyObject *__pyx_kp_u_53;
  static PyObject *__pyx_kp_u_55;
  static PyObject *__pyx_kp_u_57;
  static PyObject *__pyx_kp_u_59;
  static PyObject *__pyx_n_s_6;
  static PyObject *__pyx_kp_u_61;
  static PyObject *__pyx_kp_u_63;
  static PyObject *__pyx_kp_u_67;
  static PyObject *__pyx_kp_u_7;
  static PyObject *__pyx_kp_u_8;
  static PyObject *__pyx_kp_u_86;
  static PyObject *__pyx_kp_u_87;
  static PyObject *__pyx_kp_u_9;
  static PyObject *__pyx_kp_u_91;
  static PyObject *__pyx_kp_u__0;
  static PyObject *__pyx_n_s__Decimal;
  static PyObject *__pyx_n_s__TypeError;
  static PyObject *__pyx_n_s__ValueError;
  static PyObject *__pyx_n_s____import__;
  static PyObject *__pyx_n_s____main__;
  static PyObject *__pyx_n_s____pyx_capi__;
  static PyObject *__pyx_n_s____pyx_vtable__;
  static PyObject *__pyx_n_s____test__;
  static PyObject *__pyx_n_s___c_type_reducers;
  static PyObject *__pyx_n_s___decimal;
  static PyObject *__pyx_n_s___decimal2str;
  static PyObject *__pyx_n_s___dict_name;
  static PyObject *__pyx_n_s___dump_as_str;
  static PyObject *__pyx_n_s___factory;
  static PyObject *__pyx_n_s___list_name;
  static PyObject *__pyx_n_s___set_name;
  static PyObject *__pyx_n_s___simple_types;
  static PyObject *__pyx_n_s___tuple_name;
  static PyObject *__pyx_n_s__all;
  static PyObject *__pyx_n_s__args;
  static PyObject *__pyx_n_u__ascii;
  static PyObject *__pyx_n_s__base64;
  static PyObject *__pyx_n_s__bool_type;
  static PyObject *__pyx_n_s__bytes_type;
  static PyObject *__pyx_n_s__c_all_names;
  static PyObject *__pyx_n_s__c_factory_dict;
  static PyObject *__pyx_n_s__c_reduce_dict;
  static PyObject *__pyx_n_s__c_simple_dumpers;
  static PyObject *__pyx_n_s__cdecimal;
  static PyObject *__pyx_n_s__close;
  static PyObject *__pyx_n_s__collection;
  static PyObject *__pyx_n_s__collection_reduce;
  static PyObject *__pyx_n_s__crossref;
  static PyObject *__pyx_n_s__date;
  static PyObject *__pyx_n_s__date_type;
  static PyObject *__pyx_n_s__datetime;
  static PyObject *__pyx_n_s__datetime_type;
  static PyObject *__pyx_n_s__day;
  static PyObject *__pyx_n_s__decimal;
  static PyObject *__pyx_n_s__decimal_type;
  static PyObject *__pyx_n_s__decodebytes;
  static PyObject *__pyx_n_s__decodestring;
  static PyObject *__pyx_n_u__dict;
  static PyObject *__pyx_n_s__dict_reduce;
  static PyObject *__pyx_n_s__dump_as_str;
  static PyObject *__pyx_n_s__dump_tuple;
  static PyObject *__pyx_n_s__element_reduce;
  static PyObject *__pyx_n_s__empty_reduce;
  static PyObject *__pyx_n_s__encodebytes;
  static PyObject *__pyx_n_s__encodestring;
  static PyObject *__pyx_n_s__enumerate;
  static PyObject *__pyx_n_s__factory_func;
  static PyObject *__pyx_n_u__false;
  static PyObject *__pyx_n_s__fd;
  static PyObject *__pyx_n_s__float_type;
  static PyObject *__pyx_n_s__func;
  static PyObject *__pyx_n_s__get;
  static PyObject *__pyx_n_s__getcontext;
  static PyObject *__pyx_n_s__hour;
  static PyObject *__pyx_n_s__id;
  static PyObject *__pyx_n_s__instance_reduce;
  static PyObject *__pyx_n_s__int_type;
  static PyObject *__pyx_n_s__is_finite;
  static PyObject *__pyx_n_s__is_infinite;
  static PyObject *__pyx_n_s__is_nan;
  static PyObject *__pyx_n_s__is_signed;
  static PyObject *__pyx_n_s__items;
  static PyObject *__pyx_n_s__keys;
  static PyObject *__pyx_n_s__l;
  static PyObject *__pyx_n_u__list;
  static PyObject *__pyx_n_s__list_reduce;
  static PyObject *__pyx_n_s__long_type;
  static PyObject *__pyx_n_s__mapping_reduce;
  static PyObject *__pyx_n_s__microsecond;
  static PyObject *__pyx_n_s__minute;
  static PyObject *__pyx_n_s__month;
  static PyObject *__pyx_n_s__name;
  static PyObject *__pyx_n_s__nsize;
  static PyObject *__pyx_n_u__null;
  static PyObject *__pyx_n_s__offset;
  static PyObject *__pyx_n_s__pretty;
  static PyObject *__pyx_n_s__pretty_dump_content;
  static PyObject *__pyx_n_s__pretty_dump_tuple;
  static PyObject *__pyx_n_s__quote;
  static PyObject *__pyx_n_s__range;
  static PyObject *__pyx_n_s__reduce;
  static PyObject *__pyx_n_s__reduce_func;
  static PyObject *__pyx_n_s__remove;
  static PyObject *__pyx_n_s__reset_reduce;
  static PyObject *__pyx_n_s__second;
  static PyObject *__pyx_n_s__send;
  static PyObject *__pyx_n_s__sequence_reduce;
  static PyObject *__pyx_n_u__set;
  static PyObject *__pyx_n_s__set_reduce;
  static PyObject *__pyx_n_s__simple_types;
  static PyObject *__pyx_n_s__sorted;
  static PyObject *__pyx_n_s__str_type;
  static PyObject *__pyx_n_s__throw;
  static PyObject *__pyx_n_s__time;
  static PyObject *__pyx_n_s__time_type;
  static PyObject *__pyx_n_s__to_eng_string;
  static PyObject *__pyx_n_s__tp;
  static PyObject *__pyx_n_u__true;
  static PyObject *__pyx_n_u__tuple;
  static PyObject *__pyx_n_s__tuple_reduce;
  static PyObject *__pyx_n_s__type_;
  static PyObject *__pyx_n_s__types;
  static PyObject *__pyx_n_s__tzinfo;
  static PyObject *__pyx_n_s__unicode_type;
  static PyObject *__pyx_n_s__update;
  static PyObject *__pyx_n_s__use_offset;
  static PyObject *__pyx_n_s__val;
  static PyObject *__pyx_n_s__values;
  static PyObject *__pyx_n_s__w;
  static PyObject *__pyx_n_s__write;
  static PyObject *__pyx_n_s__year;
  static PyObject *__pyx_int_0;
  static PyObject *__pyx_int_1;
  static PyObject *__pyx_int_3;
  static PyObject *__pyx_k_28;
  static PyObject *__pyx_k_29;
  static PyObject *__pyx_k_tuple_2;
  static PyObject *__pyx_k_slice_88;
  static PyObject *__pyx_k_slice_94;
  static PyObject *__pyx_k_tuple_23;
  static PyObject *__pyx_k_tuple_31;
  static PyObject *__pyx_k_tuple_33;
  static PyObject *__pyx_k_tuple_35;
  static PyObject *__pyx_k_tuple_36;
  static PyObject *__pyx_k_tuple_37;
  static PyObject *__pyx_k_tuple_38;
  static PyObject *__pyx_k_tuple_39;
  static PyObject *__pyx_k_tuple_41;
  static PyObject *__pyx_k_tuple_45;
  static PyObject *__pyx_k_tuple_47;
  static PyObject *__pyx_k_tuple_48;
  static PyObject *__pyx_k_tuple_49;
  static PyObject *__pyx_k_tuple_50;
  static PyObject *__pyx_k_tuple_51;
  static PyObject *__pyx_k_tuple_52;
  static PyObject *__pyx_k_tuple_54;
  static PyObject *__pyx_k_tuple_56;
  static PyObject *__pyx_k_tuple_58;
  static PyObject *__pyx_k_tuple_60;
  static PyObject *__pyx_k_tuple_62;
  static PyObject *__pyx_k_tuple_64;
  static PyObject *__pyx_k_tuple_65;
  static PyObject *__pyx_k_tuple_66;
  static PyObject *__pyx_k_tuple_68;
  static PyObject *__pyx_k_tuple_69;
  static PyObject *__pyx_k_tuple_70;
  static PyObject *__pyx_k_tuple_71;
  static PyObject *__pyx_k_tuple_72;
  static PyObject *__pyx_k_tuple_73;
  static PyObject *__pyx_k_tuple_74;
  static PyObject *__pyx_k_tuple_75;
  static PyObject *__pyx_k_tuple_76;
  static PyObject *__pyx_k_tuple_77;
  static PyObject *__pyx_k_tuple_78;
  static PyObject *__pyx_k_tuple_79;
  static PyObject *__pyx_k_tuple_80;
  static PyObject *__pyx_k_tuple_81;
  static PyObject *__pyx_k_tuple_82;
  static PyObject *__pyx_k_tuple_83;
  static PyObject *__pyx_k_tuple_84;
  static PyObject *__pyx_k_tuple_85;
  static PyObject *__pyx_k_tuple_89;
  static PyObject *__pyx_k_tuple_90;
  static PyObject *__pyx_k_tuple_92;
  static PyObject *__pyx_k_tuple_93;
  static PyObject *__pyx_k_tuple_95;
  static PyObject *__pyx_k_tuple_96;
  static PyObject *__pyx_k_tuple_97;
  static PyObject *__pyx_k_tuple_98;
  static PyObject *__pyx_k_tuple_99;
  static PyObject *__pyx_k_codeobj_3;
  static PyObject *__pyx_k_slice_103;
  static PyObject *__pyx_k_slice_115;
  static PyObject *__pyx_k_tuple_100;
  static PyObject *__pyx_k_tuple_101;
  static PyObject *__pyx_k_tuple_102;
  static PyObject *__pyx_k_tuple_104;
  static PyObject *__pyx_k_tuple_105;
  static PyObject *__pyx_k_tuple_107;
  static PyObject *__pyx_k_tuple_109;
  static PyObject *__pyx_k_tuple_110;
  static PyObject *__pyx_k_tuple_112;
  static PyObject *__pyx_k_tuple_113;
  static PyObject *__pyx_k_tuple_116;
  static PyObject *__pyx_k_tuple_117;
  static PyObject *__pyx_k_tuple_118;
  static PyObject *__pyx_k_tuple_119;
  static PyObject *__pyx_k_tuple_120;
  static PyObject *__pyx_k_tuple_124;
  static PyObject *__pyx_k_tuple_126;
  static PyObject *__pyx_k_tuple_128;
  static PyObject *__pyx_k_tuple_129;
  static PyObject *__pyx_k_tuple_131;
  static PyObject *__pyx_k_codeobj_24;
  static PyObject *__pyx_k_codeobj_125;
  static PyObject *__pyx_k_codeobj_127;
  static PyObject *__pyx_k_codeobj_130;
PyObject *c_reduce_dict = 0;
PyObject *__pyx_v_4axon_7_dumper_c_all_names = 0;
PyObject *__pyx_v_4axon_7_dumper_c_factory_dict = 0;

/* Python wrapper */
static int __pyx_pw_4axon_7_dumper_5PyInt_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_4axon_7_dumper_5PyInt_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_val = 0;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s__val,0};
    PyObject* values[1] = {0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s__val)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "__init__") < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 32; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 1) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
    }
    __pyx_v_val = values[0];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__init__", 1, 1, 1, PyTuple_GET_SIZE(__pyx_args)); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 32; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  __pyx_L3_error:;
  __Pyx_AddTraceback("axon._dumper.PyInt.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_4axon_7_dumper_5PyInt___init__(((struct __pyx_obj_4axon_7_dumper_PyInt *)__pyx_v_self), __pyx_v_val);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_dumper.py":32
 * class PyInt:
 * 
 *     def __init__(self, val):             # <<<<<<<<<<<<<<
 *         self.val = val
 * 
 */

static int __pyx_pf_4axon_7_dumper_5PyInt___init__(struct __pyx_obj_4axon_7_dumper_PyInt *__pyx_v_self, PyObject *__pyx_v_val) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  long __pyx_t_1;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__init__", 0);

  /* "axon/_dumper.py":33
 * 
 *     def __init__(self, val):
 *         self.val = val             # <<<<<<<<<<<<<<
 * 
 *     def __repr__(self):
 */
  __pyx_t_1 = __Pyx_PyInt_AsLong(__pyx_v_val); if (unlikely((__pyx_t_1 == (long)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 33; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_v_self->val = __pyx_t_1;

  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("axon._dumper.PyInt.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_4axon_7_dumper_5PyInt_3__repr__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_4axon_7_dumper_5PyInt_3__repr__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__repr__ (wrapper)", 0);
  __pyx_r = __pyx_pf_4axon_7_dumper_5PyInt_2__repr__(((struct __pyx_obj_4axon_7_dumper_PyInt *)__pyx_v_self));
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_dumper.py":35
 *         self.val = val
 * 
 *     def __repr__(self):             # <<<<<<<<<<<<<<
 *         return str(self.val)
 * 
 */

static PyObject *__pyx_pf_4axon_7_dumper_5PyInt_2__repr__(struct __pyx_obj_4axon_7_dumper_PyInt *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__repr__", 0);

  /* "axon/_dumper.py":36
 * 
 *     def __repr__(self):
 *         return str(self.val)             # <<<<<<<<<<<<<<
 * 
 * #
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyInt_FromLong(__pyx_v_self->val); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 36; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 36; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __pyx_t_1 = 0;
  __pyx_t_1 = PyObject_Call(((PyObject *)((PyObject*)(&PyUnicode_Type))), ((PyObject *)__pyx_t_2), NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 36; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(((PyObject *)__pyx_t_2)); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("axon._dumper.PyInt.__repr__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_dumper.py":42
 * #
 * 
 * def mapping_reduce(o):             # <<<<<<<<<<<<<<
 *     return o.name, o.mapping
 * #
 */

static PyObject *__pyx_pw_4axon_7_dumper_1mapping_reduce(PyObject *__pyx_self, PyObject *__pyx_v_o); /*proto*/
static PyObject *__pyx_f_4axon_7_dumper_mapping_reduce(struct MappingObject *__pyx_v_o, CYTHON_UNUSED int __pyx_skip_dispatch) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("mapping_reduce", 0);

  /* "axon/_dumper.py":43
 * 
 * def mapping_reduce(o):
 *     return o.name, o.mapping             # <<<<<<<<<<<<<<
 * #
 * def element_reduce(o):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyTuple_New(2); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 43; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_v_o->name);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_o->name);
  __Pyx_GIVEREF(__pyx_v_o->name);
  __Pyx_INCREF(((PyObject *)__pyx_v_o->mapping));
  PyTuple_SET_ITEM(__pyx_t_1, 1, ((PyObject *)__pyx_v_o->mapping));
  __Pyx_GIVEREF(((PyObject *)__pyx_v_o->mapping));
  __pyx_r = ((PyObject *)__pyx_t_1);
  __pyx_t_1 = 0;
  goto __pyx_L0;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("axon._dumper.mapping_reduce", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_4axon_7_dumper_1mapping_reduce(PyObject *__pyx_self, PyObject *__pyx_v_o); /*proto*/
static PyObject *__pyx_pw_4axon_7_dumper_1mapping_reduce(PyObject *__pyx_self, PyObject *__pyx_v_o) {
  CYTHON_UNUSED int __pyx_lineno = 0;
  CYTHON_UNUSED const char *__pyx_filename = NULL;
  CYTHON_UNUSED int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("mapping_reduce (wrapper)", 0);
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_o), __pyx_ptype_4axon_8_objects_Mapping, 1, "o", 0))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 42; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_r = __pyx_pf_4axon_7_dumper_mapping_reduce(__pyx_self, ((struct MappingObject *)__pyx_v_o));
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_dumper.py":42
 * #
 * 
 * def mapping_reduce(o):             # <<<<<<<<<<<<<<
 *     return o.name, o.mapping
 * #
 */

static PyObject *__pyx_pf_4axon_7_dumper_mapping_reduce(CYTHON_UNUSED PyObject *__pyx_self, struct MappingObject *__pyx_v_o) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("mapping_reduce", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_4axon_7_dumper_mapping_reduce(__pyx_v_o, 0); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 42; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("axon._dumper.mapping_reduce", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_dumper.py":45
 *     return o.name, o.mapping
 * #
 * def element_reduce(o):             # <<<<<<<<<<<<<<
 *     return o.name, o.mapping, o.sequence
 * #
 */

static PyObject *__pyx_pw_4axon_7_dumper_3element_reduce(PyObject *__pyx_self, PyObject *__pyx_v_o); /*proto*/
static PyObject *__pyx_f_4axon_7_dumper_element_reduce(struct ElementObject *__pyx_v_o, CYTHON_UNUSED int __pyx_skip_dispatch) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("element_reduce", 0);

  /* "axon/_dumper.py":46
 * #
 * def element_reduce(o):
 *     return o.name, o.mapping, o.sequence             # <<<<<<<<<<<<<<
 * #
 * def sequence_reduce(o):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyTuple_New(3); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 46; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_v_o->name);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_o->name);
  __Pyx_GIVEREF(__pyx_v_o->name);
  __Pyx_INCREF(((PyObject *)__pyx_v_o->mapping));
  PyTuple_SET_ITEM(__pyx_t_1, 1, ((PyObject *)__pyx_v_o->mapping));
  __Pyx_GIVEREF(((PyObject *)__pyx_v_o->mapping));
  __Pyx_INCREF(((PyObject *)__pyx_v_o->sequence));
  PyTuple_SET_ITEM(__pyx_t_1, 2, ((PyObject *)__pyx_v_o->sequence));
  __Pyx_GIVEREF(((PyObject *)__pyx_v_o->sequence));
  __pyx_r = ((PyObject *)__pyx_t_1);
  __pyx_t_1 = 0;
  goto __pyx_L0;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("axon._dumper.element_reduce", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_4axon_7_dumper_3element_reduce(PyObject *__pyx_self, PyObject *__pyx_v_o); /*proto*/
static PyObject *__pyx_pw_4axon_7_dumper_3element_reduce(PyObject *__pyx_self, PyObject *__pyx_v_o) {
  CYTHON_UNUSED int __pyx_lineno = 0;
  CYTHON_UNUSED const char *__pyx_filename = NULL;
  CYTHON_UNUSED int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("element_reduce (wrapper)", 0);
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_o), __pyx_ptype_4axon_8_objects_Element, 1, "o", 0))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 45; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_r = __pyx_pf_4axon_7_dumper_2element_reduce(__pyx_self, ((struct ElementObject *)__pyx_v_o));
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_dumper.py":45
 *     return o.name, o.mapping
 * #
 * def element_reduce(o):             # <<<<<<<<<<<<<<
 *     return o.name, o.mapping, o.sequence
 * #
 */

static PyObject *__pyx_pf_4axon_7_dumper_2element_reduce(CYTHON_UNUSED PyObject *__pyx_self, struct ElementObject *__pyx_v_o) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("element_reduce", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_4axon_7_dumper_element_reduce(__pyx_v_o, 0); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 45; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("axon._dumper.element_reduce", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_dumper.py":48
 *     return o.name, o.mapping, o.sequence
 * #
 * def sequence_reduce(o):             # <<<<<<<<<<<<<<
 *     return o.name, o.sequence
 * #
 */

static PyObject *__pyx_pw_4axon_7_dumper_5sequence_reduce(PyObject *__pyx_self, PyObject *__pyx_v_o); /*proto*/
static PyObject *__pyx_f_4axon_7_dumper_sequence_reduce(struct SequenceObject *__pyx_v_o, CYTHON_UNUSED int __pyx_skip_dispatch) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("sequence_reduce", 0);

  /* "axon/_dumper.py":49
 * #
 * def sequence_reduce(o):
 *     return o.name, o.sequence             # <<<<<<<<<<<<<<
 * #
 * def collection_reduce(o):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyTuple_New(2); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 49; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_v_o->name);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_o->name);
  __Pyx_GIVEREF(__pyx_v_o->name);
  __Pyx_INCREF(((PyObject *)__pyx_v_o->sequence));
  PyTuple_SET_ITEM(__pyx_t_1, 1, ((PyObject *)__pyx_v_o->sequence));
  __Pyx_GIVEREF(((PyObject *)__pyx_v_o->sequence));
  __pyx_r = ((PyObject *)__pyx_t_1);
  __pyx_t_1 = 0;
  goto __pyx_L0;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("axon._dumper.sequence_reduce", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_4axon_7_dumper_5sequence_reduce(PyObject *__pyx_self, PyObject *__pyx_v_o); /*proto*/
static PyObject *__pyx_pw_4axon_7_dumper_5sequence_reduce(PyObject *__pyx_self, PyObject *__pyx_v_o) {
  CYTHON_UNUSED int __pyx_lineno = 0;
  CYTHON_UNUSED const char *__pyx_filename = NULL;
  CYTHON_UNUSED int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("sequence_reduce (wrapper)", 0);
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_o), __pyx_ptype_4axon_8_objects_Sequence, 1, "o", 0))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 48; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_r = __pyx_pf_4axon_7_dumper_4sequence_reduce(__pyx_self, ((struct SequenceObject *)__pyx_v_o));
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_dumper.py":48
 *     return o.name, o.mapping, o.sequence
 * #
 * def sequence_reduce(o):             # <<<<<<<<<<<<<<
 *     return o.name, o.sequence
 * #
 */

static PyObject *__pyx_pf_4axon_7_dumper_4sequence_reduce(CYTHON_UNUSED PyObject *__pyx_self, struct SequenceObject *__pyx_v_o) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("sequence_reduce", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_4axon_7_dumper_sequence_reduce(__pyx_v_o, 0); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 48; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("axon._dumper.sequence_reduce", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_dumper.py":51
 *     return o.name, o.sequence
 * #
 * def collection_reduce(o):             # <<<<<<<<<<<<<<
 *     return o.name + '*', o.sequence
 * #
 */

static PyObject *__pyx_pw_4axon_7_dumper_7collection_reduce(PyObject *__pyx_self, PyObject *__pyx_v_o); /*proto*/
static PyObject *__pyx_f_4axon_7_dumper_collection_reduce(struct CollectionObject *__pyx_v_o, CYTHON_UNUSED int __pyx_skip_dispatch) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("collection_reduce", 0);

  /* "axon/_dumper.py":52
 * #
 * def collection_reduce(o):
 *     return o.name + '*', o.sequence             # <<<<<<<<<<<<<<
 * #
 * def instance_reduce(o):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyNumber_Add(__pyx_v_o->name, ((PyObject *)__pyx_kp_u_1)); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 52; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyTuple_New(2); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 52; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_INCREF(((PyObject *)__pyx_v_o->sequence));
  PyTuple_SET_ITEM(__pyx_t_2, 1, ((PyObject *)__pyx_v_o->sequence));
  __Pyx_GIVEREF(((PyObject *)__pyx_v_o->sequence));
  __pyx_t_1 = 0;
  __pyx_r = ((PyObject *)__pyx_t_2);
  __pyx_t_2 = 0;
  goto __pyx_L0;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("axon._dumper.collection_reduce", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_4axon_7_dumper_7collection_reduce(PyObject *__pyx_self, PyObject *__pyx_v_o); /*proto*/
static PyObject *__pyx_pw_4axon_7_dumper_7collection_reduce(PyObject *__pyx_self, PyObject *__pyx_v_o) {
  CYTHON_UNUSED int __pyx_lineno = 0;
  CYTHON_UNUSED const char *__pyx_filename = NULL;
  CYTHON_UNUSED int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("collection_reduce (wrapper)", 0);
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_o), __pyx_ptype_4axon_8_objects_Collection, 1, "o", 0))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 51; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_r = __pyx_pf_4axon_7_dumper_6collection_reduce(__pyx_self, ((struct CollectionObject *)__pyx_v_o));
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_dumper.py":51
 *     return o.name, o.sequence
 * #
 * def collection_reduce(o):             # <<<<<<<<<<<<<<
 *     return o.name + '*', o.sequence
 * #
 */

static PyObject *__pyx_pf_4axon_7_dumper_6collection_reduce(CYTHON_UNUSED PyObject *__pyx_self, struct CollectionObject *__pyx_v_o) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("collection_reduce", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_4axon_7_dumper_collection_reduce(__pyx_v_o, 0); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 51; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("axon._dumper.collection_reduce", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_dumper.py":54
 *     return o.name + '*', o.sequence
 * #
 * def instance_reduce(o):             # <<<<<<<<<<<<<<
 *     return o.name, o.sequence, o.mapping
 * #
 */

static PyObject *__pyx_pw_4axon_7_dumper_9instance_reduce(PyObject *__pyx_self, PyObject *__pyx_v_o); /*proto*/
static PyObject *__pyx_f_4axon_7_dumper_instance_reduce(struct InstanceObject *__pyx_v_o, CYTHON_UNUSED int __pyx_skip_dispatch) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("instance_reduce", 0);

  /* "axon/_dumper.py":55
 * #
 * def instance_reduce(o):
 *     return o.name, o.sequence, o.mapping             # <<<<<<<<<<<<<<
 * #
 * def empty_reduce(o):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyTuple_New(3); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 55; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_v_o->name);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_o->name);
  __Pyx_GIVEREF(__pyx_v_o->name);
  __Pyx_INCREF(((PyObject *)__pyx_v_o->sequence));
  PyTuple_SET_ITEM(__pyx_t_1, 1, ((PyObject *)__pyx_v_o->sequence));
  __Pyx_GIVEREF(((PyObject *)__pyx_v_o->sequence));
  __Pyx_INCREF(((PyObject *)__pyx_v_o->mapping));
  PyTuple_SET_ITEM(__pyx_t_1, 2, ((PyObject *)__pyx_v_o->mapping));
  __Pyx_GIVEREF(((PyObject *)__pyx_v_o->mapping));
  __pyx_r = ((PyObject *)__pyx_t_1);
  __pyx_t_1 = 0;
  goto __pyx_L0;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("axon._dumper.instance_reduce", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_4axon_7_dumper_9instance_reduce(PyObject *__pyx_self, PyObject *__pyx_v_o); /*proto*/
static PyObject *__pyx_pw_4axon_7_dumper_9instance_reduce(PyObject *__pyx_self, PyObject *__pyx_v_o) {
  CYTHON_UNUSED int __pyx_lineno = 0;
  CYTHON_UNUSED const char *__pyx_filename = NULL;
  CYTHON_UNUSED int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("instance_reduce (wrapper)", 0);
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_o), __pyx_ptype_4axon_8_objects_Instance, 1, "o", 0))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 54; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_r = __pyx_pf_4axon_7_dumper_8instance_reduce(__pyx_self, ((struct InstanceObject *)__pyx_v_o));
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_dumper.py":54
 *     return o.name + '*', o.sequence
 * #
 * def instance_reduce(o):             # <<<<<<<<<<<<<<
 *     return o.name, o.sequence, o.mapping
 * #
 */

static PyObject *__pyx_pf_4axon_7_dumper_8instance_reduce(CYTHON_UNUSED PyObject *__pyx_self, struct InstanceObject *__pyx_v_o) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("instance_reduce", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_4axon_7_dumper_instance_reduce(__pyx_v_o, 0); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 54; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("axon._dumper.instance_reduce", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_dumper.py":57
 *     return o.name, o.sequence, o.mapping
 * #
 * def empty_reduce(o):             # <<<<<<<<<<<<<<
 *     return o.name,
 * #
 */

static PyObject *__pyx_pw_4axon_7_dumper_11empty_reduce(PyObject *__pyx_self, PyObject *__pyx_v_o); /*proto*/
static PyObject *__pyx_f_4axon_7_dumper_empty_reduce(struct EmptyObject *__pyx_v_o, CYTHON_UNUSED int __pyx_skip_dispatch) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("empty_reduce", 0);

  /* "axon/_dumper.py":58
 * #
 * def empty_reduce(o):
 *     return o.name,             # <<<<<<<<<<<<<<
 * #
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 58; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_v_o->name);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_o->name);
  __Pyx_GIVEREF(__pyx_v_o->name);
  __pyx_r = ((PyObject *)__pyx_t_1);
  __pyx_t_1 = 0;
  goto __pyx_L0;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("axon._dumper.empty_reduce", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_4axon_7_dumper_11empty_reduce(PyObject *__pyx_self, PyObject *__pyx_v_o); /*proto*/
static PyObject *__pyx_pw_4axon_7_dumper_11empty_reduce(PyObject *__pyx_self, PyObject *__pyx_v_o) {
  CYTHON_UNUSED int __pyx_lineno = 0;
  CYTHON_UNUSED const char *__pyx_filename = NULL;
  CYTHON_UNUSED int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("empty_reduce (wrapper)", 0);
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_o), __pyx_ptype_4axon_8_objects_Empty, 1, "o", 0))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 57; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_r = __pyx_pf_4axon_7_dumper_10empty_reduce(__pyx_self, ((struct EmptyObject *)__pyx_v_o));
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_dumper.py":57
 *     return o.name, o.sequence, o.mapping
 * #
 * def empty_reduce(o):             # <<<<<<<<<<<<<<
 *     return o.name,
 * #
 */

static PyObject *__pyx_pf_4axon_7_dumper_10empty_reduce(CYTHON_UNUSED PyObject *__pyx_self, struct EmptyObject *__pyx_v_o) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("empty_reduce", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_4axon_7_dumper_empty_reduce(__pyx_v_o, 0); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 57; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("axon._dumper.empty_reduce", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_dumper.py":66
 * _dict_name = 'dict'
 * 
 * def set_reduce(o):             # <<<<<<<<<<<<<<
 *     return _set_name, tuple(o)
 * #
 */

static PyObject *__pyx_pw_4axon_7_dumper_13set_reduce(PyObject *__pyx_self, PyObject *__pyx_v_o); /*proto*/
static PyObject *__pyx_f_4axon_7_dumper_set_reduce(PyObject *__pyx_v_o, CYTHON_UNUSED int __pyx_skip_dispatch) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("set_reduce", 0);

  /* "axon/_dumper.py":67
 * 
 * def set_reduce(o):
 *     return _set_name, tuple(o)             # <<<<<<<<<<<<<<
 * #
 * def tuple_reduce(o):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 67; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_v_o);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_o);
  __Pyx_GIVEREF(__pyx_v_o);
  __pyx_t_2 = PyObject_Call(((PyObject *)((PyObject*)(&PyTuple_Type))), ((PyObject *)__pyx_t_1), NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 67; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(((PyObject *)__pyx_t_1)); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(2); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 67; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(((PyObject *)__pyx_v_4axon_7_dumper__set_name));
  PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_4axon_7_dumper__set_name));
  __Pyx_GIVEREF(((PyObject *)__pyx_v_4axon_7_dumper__set_name));
  PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_2);
  __pyx_t_2 = 0;
  __pyx_r = ((PyObject *)__pyx_t_1);
  __pyx_t_1 = 0;
  goto __pyx_L0;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("axon._dumper.set_reduce", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_4axon_7_dumper_13set_reduce(PyObject *__pyx_self, PyObject *__pyx_v_o); /*proto*/
static PyObject *__pyx_pw_4axon_7_dumper_13set_reduce(PyObject *__pyx_self, PyObject *__pyx_v_o) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("set_reduce (wrapper)", 0);
  __pyx_r = __pyx_pf_4axon_7_dumper_12set_reduce(__pyx_self, ((PyObject *)__pyx_v_o));
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_dumper.py":66
 * _dict_name = 'dict'
 * 
 * def set_reduce(o):             # <<<<<<<<<<<<<<
 *     return _set_name, tuple(o)
 * #
 */

static PyObject *__pyx_pf_4axon_7_dumper_12set_reduce(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_o) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("set_reduce", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_4axon_7_dumper_set_reduce(__pyx_v_o, 0); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 66; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("axon._dumper.set_reduce", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_dumper.py":69
 *     return _set_name, tuple(o)
 * #
 * def tuple_reduce(o):             # <<<<<<<<<<<<<<
 *     return _tuple_name, tuple(o)
 * #
 */

static PyObject *__pyx_pw_4axon_7_dumper_15tuple_reduce(PyObject *__pyx_self, PyObject *__pyx_v_o); /*proto*/
static PyObject *__pyx_f_4axon_7_dumper_tuple_reduce(PyObject *__pyx_v_o, CYTHON_UNUSED int __pyx_skip_dispatch) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("tuple_reduce", 0);

  /* "axon/_dumper.py":70
 * #
 * def tuple_reduce(o):
 *     return _tuple_name, tuple(o)             # <<<<<<<<<<<<<<
 * #
 * def dict_reduce(o):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 70; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_v_o);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_o);
  __Pyx_GIVEREF(__pyx_v_o);
  __pyx_t_2 = PyObject_Call(((PyObject *)((PyObject*)(&PyTuple_Type))), ((PyObject *)__pyx_t_1), NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 70; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(((PyObject *)__pyx_t_1)); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(2); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 70; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(((PyObject *)__pyx_v_4axon_7_dumper__tuple_name));
  PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_4axon_7_dumper__tuple_name));
  __Pyx_GIVEREF(((PyObject *)__pyx_v_4axon_7_dumper__tuple_name));
  PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_2);
  __pyx_t_2 = 0;
  __pyx_r = ((PyObject *)__pyx_t_1);
  __pyx_t_1 = 0;
  goto __pyx_L0;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("axon._dumper.tuple_reduce", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_4axon_7_dumper_15tuple_reduce(PyObject *__pyx_self, PyObject *__pyx_v_o); /*proto*/
static PyObject *__pyx_pw_4axon_7_dumper_15tuple_reduce(PyObject *__pyx_self, PyObject *__pyx_v_o) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("tuple_reduce (wrapper)", 0);
  __pyx_r = __pyx_pf_4axon_7_dumper_14tuple_reduce(__pyx_self, ((PyObject *)__pyx_v_o));
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_dumper.py":69
 *     return _set_name, tuple(o)
 * #
 * def tuple_reduce(o):             # <<<<<<<<<<<<<<
 *     return _tuple_name, tuple(o)
 * #
 */

static PyObject *__pyx_pf_4axon_7_dumper_14tuple_reduce(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_o) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("tuple_reduce", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_4axon_7_dumper_tuple_reduce(__pyx_v_o, 0); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 69; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("axon._dumper.tuple_reduce", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_dumper.py":72
 *     return _tuple_name, tuple(o)
 * #
 * def dict_reduce(o):             # <<<<<<<<<<<<<<
 *     return _dict_name, o
 * #
 */

static PyObject *__pyx_pw_4axon_7_dumper_17dict_reduce(PyObject *__pyx_self, PyObject *__pyx_v_o); /*proto*/
static PyObject *__pyx_f_4axon_7_dumper_dict_reduce(PyObject *__pyx_v_o, CYTHON_UNUSED int __pyx_skip_dispatch) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("dict_reduce", 0);

  /* "axon/_dumper.py":73
 * #
 * def dict_reduce(o):
 *     return _dict_name, o             # <<<<<<<<<<<<<<
 * #
 * def list_reduce(o):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyTuple_New(2); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 73; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(((PyObject *)__pyx_v_4axon_7_dumper__dict_name));
  PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_4axon_7_dumper__dict_name));
  __Pyx_GIVEREF(((PyObject *)__pyx_v_4axon_7_dumper__dict_name));
  __Pyx_INCREF(__pyx_v_o);
  PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_v_o);
  __Pyx_GIVEREF(__pyx_v_o);
  __pyx_r = ((PyObject *)__pyx_t_1);
  __pyx_t_1 = 0;
  goto __pyx_L0;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("axon._dumper.dict_reduce", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_4axon_7_dumper_17dict_reduce(PyObject *__pyx_self, PyObject *__pyx_v_o); /*proto*/
static PyObject *__pyx_pw_4axon_7_dumper_17dict_reduce(PyObject *__pyx_self, PyObject *__pyx_v_o) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("dict_reduce (wrapper)", 0);
  __pyx_r = __pyx_pf_4axon_7_dumper_16dict_reduce(__pyx_self, ((PyObject *)__pyx_v_o));
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_dumper.py":72
 *     return _tuple_name, tuple(o)
 * #
 * def dict_reduce(o):             # <<<<<<<<<<<<<<
 *     return _dict_name, o
 * #
 */

static PyObject *__pyx_pf_4axon_7_dumper_16dict_reduce(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_o) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("dict_reduce", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_4axon_7_dumper_dict_reduce(__pyx_v_o, 0); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 72; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("axon._dumper.dict_reduce", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_dumper.py":75
 *     return _dict_name, o
 * #
 * def list_reduce(o):             # <<<<<<<<<<<<<<
 *     return _list_name, o
 * 
 */

static PyObject *__pyx_pw_4axon_7_dumper_19list_reduce(PyObject *__pyx_self, PyObject *__pyx_v_o); /*proto*/
static PyObject *__pyx_f_4axon_7_dumper_list_reduce(PyObject *__pyx_v_o, CYTHON_UNUSED int __pyx_skip_dispatch) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("list_reduce", 0);

  /* "axon/_dumper.py":76
 * #
 * def list_reduce(o):
 *     return _list_name, o             # <<<<<<<<<<<<<<
 * 
 * _c_type_reducers = {
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyTuple_New(2); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 76; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(((PyObject *)__pyx_v_4axon_7_dumper__list_name));
  PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_4axon_7_dumper__list_name));
  __Pyx_GIVEREF(((PyObject *)__pyx_v_4axon_7_dumper__list_name));
  __Pyx_INCREF(__pyx_v_o);
  PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_v_o);
  __Pyx_GIVEREF(__pyx_v_o);
  __pyx_r = ((PyObject *)__pyx_t_1);
  __pyx_t_1 = 0;
  goto __pyx_L0;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("axon._dumper.list_reduce", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_4axon_7_dumper_19list_reduce(PyObject *__pyx_self, PyObject *__pyx_v_o); /*proto*/
static PyObject *__pyx_pw_4axon_7_dumper_19list_reduce(PyObject *__pyx_self, PyObject *__pyx_v_o) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("list_reduce (wrapper)", 0);
  __pyx_r = __pyx_pf_4axon_7_dumper_18list_reduce(__pyx_self, ((PyObject *)__pyx_v_o));
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_dumper.py":75
 *     return _dict_name, o
 * #
 * def list_reduce(o):             # <<<<<<<<<<<<<<
 *     return _list_name, o
 * 
 */

static PyObject *__pyx_pf_4axon_7_dumper_18list_reduce(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_o) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("list_reduce", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_4axon_7_dumper_list_reduce(__pyx_v_o, 0); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 75; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("axon._dumper.list_reduce", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_4axon_7_dumper_21reset_reduce(PyObject *__pyx_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyMethodDef __pyx_mdef_4axon_7_dumper_21reset_reduce = {__Pyx_NAMESTR("reset_reduce"), (PyCFunction)__pyx_pw_4axon_7_dumper_21reset_reduce, METH_NOARGS, __Pyx_DOCSTR(0)};
static PyObject *__pyx_pw_4axon_7_dumper_21reset_reduce(PyObject *__pyx_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("reset_reduce (wrapper)", 0);
  __pyx_r = __pyx_pf_4axon_7_dumper_20reset_reduce(__pyx_self);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_dumper.py":96
 * #
 * 
 * def reset_reduce():             # <<<<<<<<<<<<<<
 *     c_reduce_dict = _c_type_reducers.copy()
 * 
 */

static PyObject *__pyx_pf_4axon_7_dumper_20reset_reduce(CYTHON_UNUSED PyObject *__pyx_self) {
  CYTHON_UNUSED PyObject *__pyx_v_c_reduce_dict = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("reset_reduce", 0);

  /* "axon/_dumper.py":97
 * 
 * def reset_reduce():
 *     c_reduce_dict = _c_type_reducers.copy()             # <<<<<<<<<<<<<<
 * 
 * #class Namespace(dict):
 */
  if (unlikely(((PyObject *)__pyx_v_4axon_7_dumper__c_type_reducers) == Py_None)) {
    PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%s'", "copy");
    {__pyx_filename = __pyx_f[0]; __pyx_lineno = 97; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }
  __pyx_t_1 = ((PyObject *)PyDict_Copy(__pyx_v_4axon_7_dumper__c_type_reducers)); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 97; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_c_reduce_dict = __pyx_t_1;
  __pyx_t_1 = 0;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("axon._dumper.reset_reduce", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_c_reduce_dict);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_4axon_7_dumper_23reduce(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_4axon_7_dumper_23reduce = {__Pyx_NAMESTR("reduce"), (PyCFunction)__pyx_pw_4axon_7_dumper_23reduce, METH_VARARGS|METH_KEYWORDS, __Pyx_DOCSTR(0)};
static PyObject *__pyx_pw_4axon_7_dumper_23reduce(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_type_ = 0;
  PyObject *__pyx_v_reduce_func = 0;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("reduce (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s__type_,&__pyx_n_s__reduce_func,0};
    PyObject* values[2] = {0,0};

    /* "axon/_dumper.py":103
 * #        self.__dict__.update(kw)
 * 
 * def reduce(type_, reduce_func = None):             # <<<<<<<<<<<<<<
 *     if reduce_func is None:
 *         def _factory(factory_func):
 */
    values[1] = ((PyObject *)((PyObject *)Py_None));
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s__type_)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s__reduce_func);
          if (value) { values[1] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "reduce") < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 103; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_type_ = values[0];
    __pyx_v_reduce_func = values[1];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("reduce", 0, 1, 2, PyTuple_GET_SIZE(__pyx_args)); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 103; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  __pyx_L3_error:;
  __Pyx_AddTraceback("axon._dumper.reduce", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_4axon_7_dumper_22reduce(__pyx_self, __pyx_v_type_, __pyx_v_reduce_func);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_4axon_7_dumper_6reduce_1_factory(PyObject *__pyx_self, PyObject *__pyx_v_factory_func); /*proto*/
static PyMethodDef __pyx_mdef_4axon_7_dumper_6reduce_1_factory = {__Pyx_NAMESTR("_factory"), (PyCFunction)__pyx_pw_4axon_7_dumper_6reduce_1_factory, METH_O, __Pyx_DOCSTR(0)};
static PyObject *__pyx_pw_4axon_7_dumper_6reduce_1_factory(PyObject *__pyx_self, PyObject *__pyx_v_factory_func) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_factory (wrapper)", 0);
  __pyx_r = __pyx_pf_4axon_7_dumper_6reduce__factory(__pyx_self, ((PyObject *)__pyx_v_factory_func));
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_dumper.py":105
 * def reduce(type_, reduce_func = None):
 *     if reduce_func is None:
 *         def _factory(factory_func):             # <<<<<<<<<<<<<<
 *             c_reduce_dict[type_] = factory_func
 *             return factory_func
 */

static PyObject *__pyx_pf_4axon_7_dumper_6reduce__factory(PyObject *__pyx_self, PyObject *__pyx_v_factory_func) {
  struct __pyx_obj_4axon_7_dumper___pyx_scope_struct__reduce *__pyx_cur_scope;
  struct __pyx_obj_4axon_7_dumper___pyx_scope_struct__reduce *__pyx_outer_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_factory", 0);
  __pyx_outer_scope = (struct __pyx_obj_4axon_7_dumper___pyx_scope_struct__reduce *) __Pyx_CyFunction_GetClosure(__pyx_self);
  __pyx_cur_scope = __pyx_outer_scope;

  /* "axon/_dumper.py":106
 *     if reduce_func is None:
 *         def _factory(factory_func):
 *             c_reduce_dict[type_] = factory_func             # <<<<<<<<<<<<<<
 *             return factory_func
 *         return _factory
 */
  if (unlikely(((PyObject *)c_reduce_dict) == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    {__pyx_filename = __pyx_f[0]; __pyx_lineno = 106; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }
  if (unlikely(!__pyx_cur_scope->__pyx_v_type_)) { __Pyx_RaiseClosureNameError("type_"); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 106; __pyx_clineno = __LINE__; goto __pyx_L1_error;} }
  if (PyDict_SetItem(((PyObject *)c_reduce_dict), __pyx_cur_scope->__pyx_v_type_, __pyx_v_factory_func) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 106; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

  /* "axon/_dumper.py":107
 *         def _factory(factory_func):
 *             c_reduce_dict[type_] = factory_func
 *             return factory_func             # <<<<<<<<<<<<<<
 *         return _factory
 *     else:
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_factory_func);
  __pyx_r = __pyx_v_factory_func;
  goto __pyx_L0;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("axon._dumper.reduce._factory", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_dumper.py":103
 * #        self.__dict__.update(kw)
 * 
 * def reduce(type_, reduce_func = None):             # <<<<<<<<<<<<<<
 *     if reduce_func is None:
 *         def _factory(factory_func):
 */

static PyObject *__pyx_pf_4axon_7_dumper_22reduce(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_type_, PyObject *__pyx_v_reduce_func) {
  struct __pyx_obj_4axon_7_dumper___pyx_scope_struct__reduce *__pyx_cur_scope;
  PyObject *__pyx_v__factory = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("reduce", 0);
  __pyx_cur_scope = (struct __pyx_obj_4axon_7_dumper___pyx_scope_struct__reduce *)__pyx_tp_new_4axon_7_dumper___pyx_scope_struct__reduce(__pyx_ptype_4axon_7_dumper___pyx_scope_struct__reduce, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __Pyx_RefNannyFinishContext();
    return NULL;
  }
  __Pyx_GOTREF(__pyx_cur_scope);
  __pyx_cur_scope->__pyx_v_type_ = __pyx_v_type_;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_type_);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_type_);

  /* "axon/_dumper.py":104
 * 
 * def reduce(type_, reduce_func = None):
 *     if reduce_func is None:             # <<<<<<<<<<<<<<
 *         def _factory(factory_func):
 *             c_reduce_dict[type_] = factory_func
 */
  __pyx_t_1 = (__pyx_v_reduce_func == Py_None);
  __pyx_t_2 = (__pyx_t_1 != 0);
  if (__pyx_t_2) {

    /* "axon/_dumper.py":105
 * def reduce(type_, reduce_func = None):
 *     if reduce_func is None:
 *         def _factory(factory_func):             # <<<<<<<<<<<<<<
 *             c_reduce_dict[type_] = factory_func
 *             return factory_func
 */
    __pyx_t_3 = __Pyx_CyFunction_NewEx(&__pyx_mdef_4axon_7_dumper_6reduce_1_factory, 0, __pyx_n_s_5, ((PyObject*)__pyx_cur_scope), __pyx_n_s_6, ((PyObject *)__pyx_k_codeobj_3)); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 105; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_v__factory = __pyx_t_3;
    __pyx_t_3 = 0;

    /* "axon/_dumper.py":108
 *             c_reduce_dict[type_] = factory_func
 *             return factory_func
 *         return _factory             # <<<<<<<<<<<<<<
 *     else:
 *         c_reduce_dict[type_] = reduce_func
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_v__factory);
    __pyx_r = __pyx_v__factory;
    goto __pyx_L0;
    goto __pyx_L3;
  }
  /*else*/ {

    /* "axon/_dumper.py":110
 *         return _factory
 *     else:
 *         c_reduce_dict[type_] = reduce_func             # <<<<<<<<<<<<<<
 * 
 * #
 */
    if (unlikely(((PyObject *)c_reduce_dict) == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      {__pyx_filename = __pyx_f[0]; __pyx_lineno = 110; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    }
    if (PyDict_SetItem(((PyObject *)c_reduce_dict), __pyx_cur_scope->__pyx_v_type_, __pyx_v_reduce_func) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 110; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }
  __pyx_L3:;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("axon._dumper.reduce", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v__factory);
  __Pyx_DECREF(((PyObject *)__pyx_cur_scope));
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_dumper.py":123
 *     pass
 * 
 * def c_new_pyptr(p):             # <<<<<<<<<<<<<<
 *     pyptr = PyPointer.__new__(PyPointer)
 *     pyptr.ptr = p
 */

static struct __pyx_obj_4axon_7_dumper_PyPointer *__pyx_f_4axon_7_dumper_c_new_pyptr(PyObject *(*__pyx_v_p)(PyObject *)) {
  struct __pyx_obj_4axon_7_dumper_PyPointer *__pyx_v_pyptr = 0;
  struct __pyx_obj_4axon_7_dumper_PyPointer *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("c_new_pyptr", 0);

  /* "axon/_dumper.py":124
 * 
 * def c_new_pyptr(p):
 *     pyptr = PyPointer.__new__(PyPointer)             # <<<<<<<<<<<<<<
 *     pyptr.ptr = p
 *     return pyptr
 */
  __pyx_t_1 = __pyx_tp_new_4axon_7_dumper_PyPointer(((PyTypeObject *)((PyObject*)__pyx_ptype_4axon_7_dumper_PyPointer)), ((PyObject *)__pyx_empty_tuple), NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 124; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (!(likely(__Pyx_TypeTest(__pyx_t_1, __pyx_ptype_4axon_7_dumper_PyPointer)))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 124; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_v_pyptr = ((struct __pyx_obj_4axon_7_dumper_PyPointer *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "axon/_dumper.py":125
 * def c_new_pyptr(p):
 *     pyptr = PyPointer.__new__(PyPointer)
 *     pyptr.ptr = p             # <<<<<<<<<<<<<<
 *     return pyptr
 * 
 */
  __pyx_v_pyptr->ptr = __pyx_v_p;

  /* "axon/_dumper.py":126
 *     pyptr = PyPointer.__new__(PyPointer)
 *     pyptr.ptr = p
 *     return pyptr             # <<<<<<<<<<<<<<
 * 
 * def _dump_unicode(ob):
 */
  __Pyx_XDECREF(((PyObject *)__pyx_r));
  __Pyx_INCREF(((PyObject *)__pyx_v_pyptr));
  __pyx_r = __pyx_v_pyptr;
  goto __pyx_L0;

  __pyx_r = ((struct __pyx_obj_4axon_7_dumper_PyPointer *)Py_None); __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("axon._dumper.c_new_pyptr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_pyptr);
  __Pyx_XGIVEREF((PyObject *)__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_dumper.py":128
 *     return pyptr
 * 
 * def _dump_unicode(ob):             # <<<<<<<<<<<<<<
 *     line = c_as_unicode(ob)
 *     pos0 = 0
 */

static PyObject *__pyx_f_4axon_7_dumper__dump_unicode(PyObject *__pyx_v_ob) {
  PyObject *__pyx_v_text = 0;
  PyObject *__pyx_v_line = 0;
  unsigned int __pyx_v_pos;
  int __pyx_v_pos0;
  PyObject *__pyx_v_n = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  Py_ssize_t __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  Py_UCS4 __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_dump_unicode", 0);

  /* "axon/_dumper.py":129
 * 
 * def _dump_unicode(ob):
 *     line = c_as_unicode(ob)             # <<<<<<<<<<<<<<
 *     pos0 = 0
 *     pos = 0
 */
  __pyx_t_1 = ((PyObject *)__pyx_f_4axon_8_objects_c_as_unicode(__pyx_v_ob)); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 129; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_line = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "axon/_dumper.py":130
 * def _dump_unicode(ob):
 *     line = c_as_unicode(ob)
 *     pos0 = 0             # <<<<<<<<<<<<<<
 *     pos = 0
 *     text = '"'
 */
  __pyx_v_pos0 = 0;

  /* "axon/_dumper.py":131
 *     line = c_as_unicode(ob)
 *     pos0 = 0
 *     pos = 0             # <<<<<<<<<<<<<<
 *     text = '"'
 * 
 */
  __pyx_v_pos = 0;

  /* "axon/_dumper.py":132
 *     pos0 = 0
 *     pos = 0
 *     text = '"'             # <<<<<<<<<<<<<<
 * 
 *     n = len(line)
 */
  __Pyx_INCREF(((PyObject *)__pyx_kp_u_7));
  __pyx_v_text = __pyx_kp_u_7;

  /* "axon/_dumper.py":134
 *     text = '"'
 * 
 *     n = len(line)             # <<<<<<<<<<<<<<
 *     while pos < n:
 *         if line[pos] == '"':
 */
  if (unlikely(((PyObject *)__pyx_v_line) == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "object of type 'NoneType' has no len()");
    {__pyx_filename = __pyx_f[0]; __pyx_lineno = 134; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }
  __pyx_t_2 = __Pyx_PyUnicode_GET_LENGTH(((PyObject *)__pyx_v_line)); if (unlikely(__pyx_t_2 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 134; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_t_1 = PyInt_FromSsize_t(__pyx_t_2); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 134; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_n = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "axon/_dumper.py":135
 * 
 *     n = len(line)
 *     while pos < n:             # <<<<<<<<<<<<<<
 *         if line[pos] == '"':
 *             if pos != pos0:
 */
  while (1) {
    __pyx_t_1 = PyLong_FromUnsignedLong(__pyx_v_pos); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 135; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = PyObject_RichCompare(__pyx_t_1, __pyx_v_n, Py_LT); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 135; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely(__pyx_t_4 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 135; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (!__pyx_t_4) break;

    /* "axon/_dumper.py":136
 *     n = len(line)
 *     while pos < n:
 *         if line[pos] == '"':             # <<<<<<<<<<<<<<
 *             if pos != pos0:
 *                 text += line[pos0: pos]
 */
    __pyx_t_5 = __Pyx_GetItemInt_Unicode(((PyObject *)__pyx_v_line), __pyx_v_pos, sizeof(unsigned int)+1, PyLong_FromUnsignedLong, 0, 0, 0); if (unlikely(__pyx_t_5 == (Py_UCS4)-1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 136; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
    __pyx_t_4 = ((__pyx_t_5 == 34) != 0);
    if (__pyx_t_4) {

      /* "axon/_dumper.py":137
 *     while pos < n:
 *         if line[pos] == '"':
 *             if pos != pos0:             # <<<<<<<<<<<<<<
 *                 text += line[pos0: pos]
 *             text += '\\"'
 */
      __pyx_t_4 = ((__pyx_v_pos != __pyx_v_pos0) != 0);
      if (__pyx_t_4) {

        /* "axon/_dumper.py":138
 *         if line[pos] == '"':
 *             if pos != pos0:
 *                 text += line[pos0: pos]             # <<<<<<<<<<<<<<
 *             text += '\\"'
 *             pos += 1
 */
        if (unlikely(((PyObject *)__pyx_v_line) == Py_None)) {
          PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
          {__pyx_filename = __pyx_f[0]; __pyx_lineno = 138; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        }
        __pyx_t_3 = __Pyx_PyUnicode_Substring(__pyx_v_line, __pyx_v_pos0, __pyx_v_pos); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 138; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(((PyObject *)__pyx_t_3));
        __pyx_t_1 = PyNumber_InPlaceAdd(((PyObject *)__pyx_v_text), ((PyObject *)__pyx_t_3)); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 138; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(((PyObject *)__pyx_t_1));
        __Pyx_DECREF(((PyObject *)__pyx_t_3)); __pyx_t_3 = 0;
        __Pyx_DECREF(((PyObject *)__pyx_v_text));
        __pyx_v_text = ((PyObject*)__pyx_t_1);
        __pyx_t_1 = 0;
        goto __pyx_L6;
      }
      __pyx_L6:;

      /* "axon/_dumper.py":139
 *             if pos != pos0:
 *                 text += line[pos0: pos]
 *             text += '\\"'             # <<<<<<<<<<<<<<
 *             pos += 1
 *             pos0 = pos
 */
      __pyx_t_1 = PyNumber_InPlaceAdd(((PyObject *)__pyx_v_text), ((PyObject *)__pyx_kp_u_8)); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 139; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(((PyObject *)__pyx_t_1));
      __Pyx_DECREF(((PyObject *)__pyx_v_text));
      __pyx_v_text = ((PyObject*)__pyx_t_1);
      __pyx_t_1 = 0;

      /* "axon/_dumper.py":140
 *                 text += line[pos0: pos]
 *             text += '\\"'
 *             pos += 1             # <<<<<<<<<<<<<<
 *             pos0 = pos
 *         else:
 */
      __pyx_v_pos = (__pyx_v_pos + 1);

      /* "axon/_dumper.py":141
 *             text += '\\"'
 *             pos += 1
 *             pos0 = pos             # <<<<<<<<<<<<<<
 *         else:
 *             pos += 1
 */
      __pyx_v_pos0 = __pyx_v_pos;
      goto __pyx_L5;
    }
    /*else*/ {

      /* "axon/_dumper.py":143
 *             pos0 = pos
 *         else:
 *             pos += 1             # <<<<<<<<<<<<<<
 * 
 *     if pos != pos0:
 */
      __pyx_v_pos = (__pyx_v_pos + 1);
    }
    __pyx_L5:;
  }

  /* "axon/_dumper.py":145
 *             pos += 1
 * 
 *     if pos != pos0:             # <<<<<<<<<<<<<<
 *         text += line[pos0: pos]
 *     return text + '"'
 */
  __pyx_t_4 = ((__pyx_v_pos != __pyx_v_pos0) != 0);
  if (__pyx_t_4) {

    /* "axon/_dumper.py":146
 * 
 *     if pos != pos0:
 *         text += line[pos0: pos]             # <<<<<<<<<<<<<<
 *     return text + '"'
 * 
 */
    if (unlikely(((PyObject *)__pyx_v_line) == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      {__pyx_filename = __pyx_f[0]; __pyx_lineno = 146; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    }
    __pyx_t_1 = __Pyx_PyUnicode_Substring(__pyx_v_line, __pyx_v_pos0, __pyx_v_pos); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 146; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(((PyObject *)__pyx_t_1));
    __pyx_t_3 = PyNumber_InPlaceAdd(((PyObject *)__pyx_v_text), ((PyObject *)__pyx_t_1)); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 146; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(((PyObject *)__pyx_t_3));
    __Pyx_DECREF(((PyObject *)__pyx_t_1)); __pyx_t_1 = 0;
    __Pyx_DECREF(((PyObject *)__pyx_v_text));
    __pyx_v_text = ((PyObject*)__pyx_t_3);
    __pyx_t_3 = 0;
    goto __pyx_L7;
  }
  __pyx_L7:;

  /* "axon/_dumper.py":147
 *     if pos != pos0:
 *         text += line[pos0: pos]
 *     return text + '"'             # <<<<<<<<<<<<<<
 * 
 * def _dump_str(line):
 */
  __Pyx_XDECREF(((PyObject *)__pyx_r));
  __pyx_t_3 = PyNumber_Add(((PyObject *)__pyx_v_text), ((PyObject *)__pyx_kp_u_7)); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 147; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(((PyObject *)__pyx_t_3));
  __pyx_r = ((PyObject*)__pyx_t_3);
  __pyx_t_3 = 0;
  goto __pyx_L0;

  __pyx_r = ((PyObject*)Py_None); __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("axon._dumper._dump_unicode", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_text);
  __Pyx_XDECREF(__pyx_v_line);
  __Pyx_XDECREF(__pyx_v_n);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_dumper.py":149
 *     return text + '"'
 * 
 * def _dump_str(line):             # <<<<<<<<<<<<<<
 *     return _dump_unicode(c_as_unicode(line))
 * 
 */

static PyObject *__pyx_f_4axon_7_dumper__dump_str(PyObject *__pyx_v_line) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_dump_str", 0);

  /* "axon/_dumper.py":150
 * 
 * def _dump_str(line):
 *     return _dump_unicode(c_as_unicode(line))             # <<<<<<<<<<<<<<
 * 
 * def _dump_bool(o):
 */
  __Pyx_XDECREF(((PyObject *)__pyx_r));
  __pyx_t_1 = ((PyObject *)__pyx_f_4axon_8_objects_c_as_unicode(__pyx_v_line)); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 150; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = ((PyObject *)__pyx_f_4axon_7_dumper__dump_unicode(__pyx_t_1)); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 150; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_r = ((PyObject*)__pyx_t_2);
  __pyx_t_2 = 0;
  goto __pyx_L0;

  __pyx_r = ((PyObject*)Py_None); __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("axon._dumper._dump_str", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_dumper.py":152
 *     return _dump_unicode(c_as_unicode(line))
 * 
 * def _dump_bool(o):             # <<<<<<<<<<<<<<
 *     #return '' if o else ''
 *     return 'true' if o else 'false'
 */

static PyObject *__pyx_f_4axon_7_dumper__dump_bool(PyObject *__pyx_v_o) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_dump_bool", 0);

  /* "axon/_dumper.py":154
 * def _dump_bool(o):
 *     #return '' if o else ''
 *     return 'true' if o else 'false'             # <<<<<<<<<<<<<<
 * 
 * def _dump_date(o):
 */
  __Pyx_XDECREF(((PyObject *)__pyx_r));
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_v_o); if (unlikely(__pyx_t_2 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 154; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__pyx_t_2) {
    __Pyx_INCREF(((PyObject *)__pyx_n_u__true));
    __pyx_t_1 = ((PyObject *)__pyx_n_u__true);
  } else {
    __Pyx_INCREF(((PyObject *)__pyx_n_u__false));
    __pyx_t_1 = ((PyObject *)__pyx_n_u__false);
  }
  __pyx_r = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;
  goto __pyx_L0;

  __pyx_r = ((PyObject*)Py_None); __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("axon._dumper._dump_bool", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_dumper.py":156
 *     return 'true' if o else 'false'
 * 
 * def _dump_date(o):             # <<<<<<<<<<<<<<
 *     d = "%d-%02d-%02d" % (o.year, o.month, o.day)
 *     return d
 */

static PyObject *__pyx_f_4axon_7_dumper__dump_date(PyObject *__pyx_v_o) {
  PyObject *__pyx_v_d = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_dump_date", 0);

  /* "axon/_dumper.py":157
 * 
 * def _dump_date(o):
 *     d = "%d-%02d-%02d" % (o.year, o.month, o.day)             # <<<<<<<<<<<<<<
 *     return d
 * 
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_o, __pyx_n_s__year); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 157; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_o, __pyx_n_s__month); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 157; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_o, __pyx_n_s__day); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 157; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = PyTuple_New(3); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 157; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_4);
  PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_4, 2, __pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_3);
  __pyx_t_1 = 0;
  __pyx_t_2 = 0;
  __pyx_t_3 = 0;
  __pyx_t_3 = PyNumber_Remainder(((PyObject *)__pyx_kp_u_9), ((PyObject *)__pyx_t_4)); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 157; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(((PyObject *)__pyx_t_3));
  __Pyx_DECREF(((PyObject *)__pyx_t_4)); __pyx_t_4 = 0;
  __pyx_v_d = ((PyObject*)__pyx_t_3);
  __pyx_t_3 = 0;

  /* "axon/_dumper.py":158
 * def _dump_date(o):
 *     d = "%d-%02d-%02d" % (o.year, o.month, o.day)
 *     return d             # <<<<<<<<<<<<<<
 * 
 * def _dump_tzinfo(o):
 */
  __Pyx_XDECREF(((PyObject *)__pyx_r));
  __Pyx_INCREF(((PyObject *)__pyx_v_d));
  __pyx_r = __pyx_v_d;
  goto __pyx_L0;

  __pyx_r = ((PyObject*)Py_None); __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("axon._dumper._dump_date", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_d);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_dumper.py":160
 *     return d
 * 
 * def _dump_tzinfo(o):             # <<<<<<<<<<<<<<
 *     return str(o)
 * 
 */

static PyObject *__pyx_f_4axon_7_dumper__dump_tzinfo(PyObject *__pyx_v_o) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_dump_tzinfo", 0);

  /* "axon/_dumper.py":161
 * 
 * def _dump_tzinfo(o):
 *     return str(o)             # <<<<<<<<<<<<<<
 * 
 * def _dump_time(o):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 161; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_v_o);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_o);
  __Pyx_GIVEREF(__pyx_v_o);
  __pyx_t_2 = PyObject_Call(((PyObject *)((PyObject*)(&PyUnicode_Type))), ((PyObject *)__pyx_t_1), NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 161; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(((PyObject *)__pyx_t_1)); __pyx_t_1 = 0;
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("axon._dumper._dump_tzinfo", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_dumper.py":163
 *     return str(o)
 * 
 * def _dump_time(o):             # <<<<<<<<<<<<<<
 *     #cdef object t
 * 
 */

static PyObject *__pyx_f_4axon_7_dumper__dump_time(PyObject *__pyx_v_o) {
  PyObject *__pyx_v_t = 0;
  PyObject *__pyx_v_tzinfo = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_dump_time", 0);

  /* "axon/_dumper.py":166
 *     #cdef object t
 * 
 *     if o.second:             # <<<<<<<<<<<<<<
 *         if o.microsecond:
 *             t = "%02d:%02d:%02d.%06d" % (o.hour, o.minute, o.second, o.microsecond)
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_o, __pyx_n_s__second); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 166; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_2 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 166; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_2) {

    /* "axon/_dumper.py":167
 * 
 *     if o.second:
 *         if o.microsecond:             # <<<<<<<<<<<<<<
 *             t = "%02d:%02d:%02d.%06d" % (o.hour, o.minute, o.second, o.microsecond)
 *         else:
 */
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_o, __pyx_n_s__microsecond); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 167; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_2 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 167; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (__pyx_t_2) {

      /* "axon/_dumper.py":168
 *     if o.second:
 *         if o.microsecond:
 *             t = "%02d:%02d:%02d.%06d" % (o.hour, o.minute, o.second, o.microsecond)             # <<<<<<<<<<<<<<
 *         else:
 *             t = "%02d:%02d:%02d" % (o.hour, o.minute, o.second)
 */
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_o, __pyx_n_s__hour); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 168; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_o, __pyx_n_s__minute); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 168; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_o, __pyx_n_s__second); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 168; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_o, __pyx_n_s__microsecond); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 168; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_6 = PyTuple_New(4); if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 168; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_6);
      PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_1);
      __Pyx_GIVEREF(__pyx_t_1);
      PyTuple_SET_ITEM(__pyx_t_6, 1, __pyx_t_3);
      __Pyx_GIVEREF(__pyx_t_3);
      PyTuple_SET_ITEM(__pyx_t_6, 2, __pyx_t_4);
      __Pyx_GIVEREF(__pyx_t_4);
      PyTuple_SET_ITEM(__pyx_t_6, 3, __pyx_t_5);
      __Pyx_GIVEREF(__pyx_t_5);
      __pyx_t_1 = 0;
      __pyx_t_3 = 0;
      __pyx_t_4 = 0;
      __pyx_t_5 = 0;
      __pyx_t_5 = PyNumber_Remainder(((PyObject *)__pyx_kp_u_10), ((PyObject *)__pyx_t_6)); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 168; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(((PyObject *)__pyx_t_5));
      __Pyx_DECREF(((PyObject *)__pyx_t_6)); __pyx_t_6 = 0;
      __pyx_v_t = ((PyObject *)__pyx_t_5);
      __pyx_t_5 = 0;
      goto __pyx_L4;
    }
    /*else*/ {

      /* "axon/_dumper.py":170
 *             t = "%02d:%02d:%02d.%06d" % (o.hour, o.minute, o.second, o.microsecond)
 *         else:
 *             t = "%02d:%02d:%02d" % (o.hour, o.minute, o.second)             # <<<<<<<<<<<<<<
 *     else:
 *             t = "%02d:%02d" % (o.hour, o.minute)
 */
      __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_o, __pyx_n_s__hour); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 170; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_o, __pyx_n_s__minute); if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 170; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_o, __pyx_n_s__second); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 170; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_3 = PyTuple_New(3); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 170; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_3);
      PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_5);
      __Pyx_GIVEREF(__pyx_t_5);
      PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_t_6);
      __Pyx_GIVEREF(__pyx_t_6);
      PyTuple_SET_ITEM(__pyx_t_3, 2, __pyx_t_4);
      __Pyx_GIVEREF(__pyx_t_4);
      __pyx_t_5 = 0;
      __pyx_t_6 = 0;
      __pyx_t_4 = 0;
      __pyx_t_4 = PyNumber_Remainder(((PyObject *)__pyx_kp_u_11), ((PyObject *)__pyx_t_3)); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 170; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(((PyObject *)__pyx_t_4));
      __Pyx_DECREF(((PyObject *)__pyx_t_3)); __pyx_t_3 = 0;
      __pyx_v_t = ((PyObject *)__pyx_t_4);
      __pyx_t_4 = 0;
    }
    __pyx_L4:;
    goto __pyx_L3;
  }
  /*else*/ {

    /* "axon/_dumper.py":172
 *             t = "%02d:%02d:%02d" % (o.hour, o.minute, o.second)
 *     else:
 *             t = "%02d:%02d" % (o.hour, o.minute)             # <<<<<<<<<<<<<<
 * 
 *     tzinfo = o.tzinfo
 */
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_o, __pyx_n_s__hour); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 172; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_o, __pyx_n_s__minute); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 172; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_6 = PyTuple_New(2); if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 172; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_6);
    PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_4);
    __Pyx_GIVEREF(__pyx_t_4);
    PyTuple_SET_ITEM(__pyx_t_6, 1, __pyx_t_3);
    __Pyx_GIVEREF(__pyx_t_3);
    __pyx_t_4 = 0;
    __pyx_t_3 = 0;
    __pyx_t_3 = PyNumber_Remainder(((PyObject *)__pyx_kp_u_12), ((PyObject *)__pyx_t_6)); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 172; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(((PyObject *)__pyx_t_3));
    __Pyx_DECREF(((PyObject *)__pyx_t_6)); __pyx_t_6 = 0;
    __pyx_v_t = ((PyObject *)__pyx_t_3);
    __pyx_t_3 = 0;
  }
  __pyx_L3:;

  /* "axon/_dumper.py":174
 *             t = "%02d:%02d" % (o.hour, o.minute)
 * 
 *     tzinfo = o.tzinfo             # <<<<<<<<<<<<<<
 *     if tzinfo is not None:
 *         t += _dump_tzinfo(tzinfo)
 */
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_o, __pyx_n_s__tzinfo); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 174; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_v_tzinfo = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "axon/_dumper.py":175
 * 
 *     tzinfo = o.tzinfo
 *     if tzinfo is not None:             # <<<<<<<<<<<<<<
 *         t += _dump_tzinfo(tzinfo)
 * 
 */
  __pyx_t_2 = (__pyx_v_tzinfo != Py_None);
  __pyx_t_7 = (__pyx_t_2 != 0);
  if (__pyx_t_7) {

    /* "axon/_dumper.py":176
 *     tzinfo = o.tzinfo
 *     if tzinfo is not None:
 *         t += _dump_tzinfo(tzinfo)             # <<<<<<<<<<<<<<
 * 
 *     return t
 */
    __pyx_t_3 = __pyx_f_4axon_7_dumper__dump_tzinfo(__pyx_v_tzinfo); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 176; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_6 = PyNumber_InPlaceAdd(__pyx_v_t, __pyx_t_3); if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 176; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_v_t);
    __pyx_v_t = __pyx_t_6;
    __pyx_t_6 = 0;
    goto __pyx_L5;
  }
  __pyx_L5:;

  /* "axon/_dumper.py":178
 *         t += _dump_tzinfo(tzinfo)
 * 
 *     return t             # <<<<<<<<<<<<<<
 * 
 * def _dump_datetime(o):
 */
  __Pyx_XDECREF(((PyObject *)__pyx_r));
  if (!(likely(PyUnicode_CheckExact(__pyx_v_t))||((__pyx_v_t) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected unicode, got %.200s", Py_TYPE(__pyx_v_t)->tp_name), 0))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 178; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_INCREF(__pyx_v_t);
  __pyx_r = ((PyObject*)__pyx_v_t);
  goto __pyx_L0;

  __pyx_r = ((PyObject*)Py_None); __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("axon._dumper._dump_time", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_t);
  __Pyx_XDECREF(__pyx_v_tzinfo);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_dumper.py":180
 *     return t
 * 
 * def _dump_datetime(o):             # <<<<<<<<<<<<<<
 *     sign = 0
 * 
 */

static PyObject *__pyx_f_4axon_7_dumper__dump_datetime(PyObject *__pyx_v_o) {
  CYTHON_UNUSED int __pyx_v_sign;
  PyObject *__pyx_v_t = NULL;
  PyObject *__pyx_v_tzinfo = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  int __pyx_t_10;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_dump_datetime", 0);

  /* "axon/_dumper.py":181
 * 
 * def _dump_datetime(o):
 *     sign = 0             # <<<<<<<<<<<<<<
 * 
 *     if o.second:
 */
  __pyx_v_sign = 0;

  /* "axon/_dumper.py":183
 *     sign = 0
 * 
 *     if o.second:             # <<<<<<<<<<<<<<
 *         if o.microsecond:
 *             t = "%d-%02d-%02dT%02d:%02d:%02d.%06d" % (o.year, o.month, o.day, o.hour, o.minute, o.second, o.microsecond)
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_o, __pyx_n_s__second); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 183; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_2 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 183; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_2) {

    /* "axon/_dumper.py":184
 * 
 *     if o.second:
 *         if o.microsecond:             # <<<<<<<<<<<<<<
 *             t = "%d-%02d-%02dT%02d:%02d:%02d.%06d" % (o.year, o.month, o.day, o.hour, o.minute, o.second, o.microsecond)
 *         else:
 */
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_o, __pyx_n_s__microsecond); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 184; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_2 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 184; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (__pyx_t_2) {

      /* "axon/_dumper.py":185
 *     if o.second:
 *         if o.microsecond:
 *             t = "%d-%02d-%02dT%02d:%02d:%02d.%06d" % (o.year, o.month, o.day, o.hour, o.minute, o.second, o.microsecond)             # <<<<<<<<<<<<<<
 *         else:
 *             t = "%d-%02d-%02dT%02d:%02d:%02d" % (o.year, o.month, o.day, o.hour, o.minute, o.second)
 */
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_o, __pyx_n_s__year); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 185; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_o, __pyx_n_s__month); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 185; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_o, __pyx_n_s__day); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 185; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_o, __pyx_n_s__hour); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 185; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_o, __pyx_n_s__minute); if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 185; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_v_o, __pyx_n_s__second); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 185; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_v_o, __pyx_n_s__microsecond); if (unlikely(!__pyx_t_8)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 185; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_8);
      __pyx_t_9 = PyTuple_New(7); if (unlikely(!__pyx_t_9)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 185; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_9);
      PyTuple_SET_ITEM(__pyx_t_9, 0, __pyx_t_1);
      __Pyx_GIVEREF(__pyx_t_1);
      PyTuple_SET_ITEM(__pyx_t_9, 1, __pyx_t_3);
      __Pyx_GIVEREF(__pyx_t_3);
      PyTuple_SET_ITEM(__pyx_t_9, 2, __pyx_t_4);
      __Pyx_GIVEREF(__pyx_t_4);
      PyTuple_SET_ITEM(__pyx_t_9, 3, __pyx_t_5);
      __Pyx_GIVEREF(__pyx_t_5);
      PyTuple_SET_ITEM(__pyx_t_9, 4, __pyx_t_6);
      __Pyx_GIVEREF(__pyx_t_6);
      PyTuple_SET_ITEM(__pyx_t_9, 5, __pyx_t_7);
      __Pyx_GIVEREF(__pyx_t_7);
      PyTuple_SET_ITEM(__pyx_t_9, 6, __pyx_t_8);
      __Pyx_GIVEREF(__pyx_t_8);
      __pyx_t_1 = 0;
      __pyx_t_3 = 0;
      __pyx_t_4 = 0;
      __pyx_t_5 = 0;
      __pyx_t_6 = 0;
      __pyx_t_7 = 0;
      __pyx_t_8 = 0;
      __pyx_t_8 = PyNumber_Remainder(((PyObject *)__pyx_kp_u_13), ((PyObject *)__pyx_t_9)); if (unlikely(!__pyx_t_8)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 185; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(((PyObject *)__pyx_t_8));
      __Pyx_DECREF(((PyObject *)__pyx_t_9)); __pyx_t_9 = 0;
      __pyx_v_t = ((PyObject *)__pyx_t_8);
      __pyx_t_8 = 0;
      goto __pyx_L4;
    }
    /*else*/ {

      /* "axon/_dumper.py":187
 *             t = "%d-%02d-%02dT%02d:%02d:%02d.%06d" % (o.year, o.month, o.day, o.hour, o.minute, o.second, o.microsecond)
 *         else:
 *             t = "%d-%02d-%02dT%02d:%02d:%02d" % (o.year, o.month, o.day, o.hour, o.minute, o.second)             # <<<<<<<<<<<<<<
 *     else:
 *             t = "%d-%02d-%02dT%02d:%02d" % (o.year, o.month, o.day, o.hour, o.minute)
 */
      __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_v_o, __pyx_n_s__year); if (unlikely(!__pyx_t_8)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 187; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_8);
      __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_v_o, __pyx_n_s__month); if (unlikely(!__pyx_t_9)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 187; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_9);
      __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_v_o, __pyx_n_s__day); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 187; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_o, __pyx_n_s__hour); if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 187; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_o, __pyx_n_s__minute); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 187; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_o, __pyx_n_s__second); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 187; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_3 = PyTuple_New(6); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 187; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_3);
      PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_8);
      __Pyx_GIVEREF(__pyx_t_8);
      PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_t_9);
      __Pyx_GIVEREF(__pyx_t_9);
      PyTuple_SET_ITEM(__pyx_t_3, 2, __pyx_t_7);
      __Pyx_GIVEREF(__pyx_t_7);
      PyTuple_SET_ITEM(__pyx_t_3, 3, __pyx_t_6);
      __Pyx_GIVEREF(__pyx_t_6);
      PyTuple_SET_ITEM(__pyx_t_3, 4, __pyx_t_5);
      __Pyx_GIVEREF(__pyx_t_5);
      PyTuple_SET_ITEM(__pyx_t_3, 5, __pyx_t_4);
      __Pyx_GIVEREF(__pyx_t_4);
      __pyx_t_8 = 0;
      __pyx_t_9 = 0;
      __pyx_t_7 = 0;
      __pyx_t_6 = 0;
      __pyx_t_5 = 0;
      __pyx_t_4 = 0;
      __pyx_t_4 = PyNumber_Remainder(((PyObject *)__pyx_kp_u_14), ((PyObject *)__pyx_t_3)); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 187; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(((PyObject *)__pyx_t_4));
      __Pyx_DECREF(((PyObject *)__pyx_t_3)); __pyx_t_3 = 0;
      __pyx_v_t = ((PyObject *)__pyx_t_4);
      __pyx_t_4 = 0;
    }
    __pyx_L4:;
    goto __pyx_L3;
  }
  /*else*/ {

    /* "axon/_dumper.py":189
 *             t = "%d-%02d-%02dT%02d:%02d:%02d" % (o.year, o.month, o.day, o.hour, o.minute, o.second)
 *     else:
 *             t = "%d-%02d-%02dT%02d:%02d" % (o.year, o.month, o.day, o.hour, o.minute)             # <<<<<<<<<<<<<<
 * 
 *     tzinfo = o.tzinfo
 */
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_o, __pyx_n_s__year); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 189; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_o, __pyx_n_s__month); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 189; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_o, __pyx_n_s__day); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 189; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_o, __pyx_n_s__hour); if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 189; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_v_o, __pyx_n_s__minute); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 189; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_9 = PyTuple_New(5); if (unlikely(!__pyx_t_9)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 189; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_9);
    PyTuple_SET_ITEM(__pyx_t_9, 0, __pyx_t_4);
    __Pyx_GIVEREF(__pyx_t_4);
    PyTuple_SET_ITEM(__pyx_t_9, 1, __pyx_t_3);
    __Pyx_GIVEREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_9, 2, __pyx_t_5);
    __Pyx_GIVEREF(__pyx_t_5);
    PyTuple_SET_ITEM(__pyx_t_9, 3, __pyx_t_6);
    __Pyx_GIVEREF(__pyx_t_6);
    PyTuple_SET_ITEM(__pyx_t_9, 4, __pyx_t_7);
    __Pyx_GIVEREF(__pyx_t_7);
    __pyx_t_4 = 0;
    __pyx_t_3 = 0;
    __pyx_t_5 = 0;
    __pyx_t_6 = 0;
    __pyx_t_7 = 0;
    __pyx_t_7 = PyNumber_Remainder(((PyObject *)__pyx_kp_u_15), ((PyObject *)__pyx_t_9)); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 189; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(((PyObject *)__pyx_t_7));
    __Pyx_DECREF(((PyObject *)__pyx_t_9)); __pyx_t_9 = 0;
    __pyx_v_t = ((PyObject *)__pyx_t_7);
    __pyx_t_7 = 0;
  }
  __pyx_L3:;

  /* "axon/_dumper.py":191
 *             t = "%d-%02d-%02dT%02d:%02d" % (o.year, o.month, o.day, o.hour, o.minute)
 * 
 *     tzinfo = o.tzinfo             # <<<<<<<<<<<<<<
 *     if tzinfo is not None:
 *         t += _dump_tzinfo(tzinfo)
 */
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_v_o, __pyx_n_s__tzinfo); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 191; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_v_tzinfo = __pyx_t_7;
  __pyx_t_7 = 0;

  /* "axon/_dumper.py":192
 * 
 *     tzinfo = o.tzinfo
 *     if tzinfo is not None:             # <<<<<<<<<<<<<<
 *         t += _dump_tzinfo(tzinfo)
 * 
 */
  __pyx_t_2 = (__pyx_v_tzinfo != Py_None);
  __pyx_t_10 = (__pyx_t_2 != 0);
  if (__pyx_t_10) {

    /* "axon/_dumper.py":193
 *     tzinfo = o.tzinfo
 *     if tzinfo is not None:
 *         t += _dump_tzinfo(tzinfo)             # <<<<<<<<<<<<<<
 * 
 *     return c_as_unicode(t)
 */
    __pyx_t_7 = __pyx_f_4axon_7_dumper__dump_tzinfo(__pyx_v_tzinfo); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 193; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_9 = PyNumber_InPlaceAdd(__pyx_v_t, __pyx_t_7); if (unlikely(!__pyx_t_9)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 193; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_9);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_v_t);
    __pyx_v_t = __pyx_t_9;
    __pyx_t_9 = 0;
    goto __pyx_L5;
  }
  __pyx_L5:;

  /* "axon/_dumper.py":195
 *         t += _dump_tzinfo(tzinfo)
 * 
 *     return c_as_unicode(t)             # <<<<<<<<<<<<<<
 * 
 * def _dump_none(o):
 */
  __Pyx_XDECREF(((PyObject *)__pyx_r));
  __pyx_t_9 = ((PyObject *)__pyx_f_4axon_8_objects_c_as_unicode(__pyx_v_t)); if (unlikely(!__pyx_t_9)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 195; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_9);
  __pyx_r = ((PyObject*)__pyx_t_9);
  __pyx_t_9 = 0;
  goto __pyx_L0;

  __pyx_r = ((PyObject*)Py_None); __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_AddTraceback("axon._dumper._dump_datetime", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_t);
  __Pyx_XDECREF(__pyx_v_tzinfo);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_dumper.py":197
 *     return c_as_unicode(t)
 * 
 * def _dump_none(o):             # <<<<<<<<<<<<<<
 *     return 'null'
 * 
 */

static PyObject *__pyx_f_4axon_7_dumper__dump_none(CYTHON_UNUSED PyObject *__pyx_v_o) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_dump_none", 0);

  /* "axon/_dumper.py":198
 * 
 * def _dump_none(o):
 *     return 'null'             # <<<<<<<<<<<<<<
 * 
 * def _dump_int(o):
 */
  __Pyx_XDECREF(((PyObject *)__pyx_r));
  __Pyx_INCREF(((PyObject *)__pyx_n_u__null));
  __pyx_r = __pyx_n_u__null;
  goto __pyx_L0;

  __pyx_r = ((PyObject*)Py_None); __Pyx_INCREF(Py_None);
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_dumper.py":200
 *     return 'null'
 * 
 * def _dump_int(o):             # <<<<<<<<<<<<<<
 *     return unicode(o)
 * 
 */

static PyObject *__pyx_f_4axon_7_dumper__dump_int(PyObject *__pyx_v_o) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_dump_int", 0);

  /* "axon/_dumper.py":201
 * 
 * def _dump_int(o):
 *     return unicode(o)             # <<<<<<<<<<<<<<
 * 
 * def _dump_bytes(o):
 */
  __Pyx_XDECREF(((PyObject *)__pyx_r));
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 201; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_v_o);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_o);
  __Pyx_GIVEREF(__pyx_v_o);
  __pyx_t_2 = PyObject_Call(((PyObject *)((PyObject*)(&PyUnicode_Type))), ((PyObject *)__pyx_t_1), NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 201; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(((PyObject *)__pyx_t_1)); __pyx_t_1 = 0;
  __pyx_r = ((PyObject*)__pyx_t_2);
  __pyx_t_2 = 0;
  goto __pyx_L0;

  __pyx_r = ((PyObject*)Py_None); __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("axon._dumper._dump_int", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_dumper.py":203
 *     return unicode(o)
 * 
 * def _dump_bytes(o):             # <<<<<<<<<<<<<<
 *     #print('###', encodebytes(o), '###')
 *     text = unicode(encodebytes(o), 'ascii')
 */

static PyObject *__pyx_f_4axon_7_dumper__dump_bytes(PyObject *__pyx_v_o) {
  PyObject *__pyx_v_text = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_dump_bytes", 0);

  /* "axon/_dumper.py":205
 * def _dump_bytes(o):
 *     #print('###', encodebytes(o), '###')
 *     text = unicode(encodebytes(o), 'ascii')             # <<<<<<<<<<<<<<
 *     return '|' + text
 * 
 */
  __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s__encodebytes); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 205; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 205; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(__pyx_v_o);
  PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_v_o);
  __Pyx_GIVEREF(__pyx_v_o);
  __pyx_t_3 = PyObject_Call(__pyx_t_1, ((PyObject *)__pyx_t_2), NULL); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 205; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_2)); __pyx_t_2 = 0;
  __pyx_t_2 = PyTuple_New(2); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 205; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_3);
  __Pyx_INCREF(((PyObject *)__pyx_n_u__ascii));
  PyTuple_SET_ITEM(__pyx_t_2, 1, ((PyObject *)__pyx_n_u__ascii));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_u__ascii));
  __pyx_t_3 = 0;
  __pyx_t_3 = PyObject_Call(((PyObject *)((PyObject*)(&PyUnicode_Type))), ((PyObject *)__pyx_t_2), NULL); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 205; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(((PyObject *)__pyx_t_2)); __pyx_t_2 = 0;
  __pyx_v_text = ((PyObject*)__pyx_t_3);
  __pyx_t_3 = 0;

  /* "axon/_dumper.py":206
 *     #print('###', encodebytes(o), '###')
 *     text = unicode(encodebytes(o), 'ascii')
 *     return '|' + text             # <<<<<<<<<<<<<<
 * 
 * def _dump_long(o):
 */
  __Pyx_XDECREF(((PyObject *)__pyx_r));
  __pyx_t_3 = PyNumber_Add(((PyObject *)__pyx_kp_u_16), ((PyObject *)__pyx_v_text)); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 206; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(((PyObject *)__pyx_t_3));
  __pyx_r = ((PyObject*)__pyx_t_3);
  __pyx_t_3 = 0;
  goto __pyx_L0;

  __pyx_r = ((PyObject*)Py_None); __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("axon._dumper._dump_bytes", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_text);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_dumper.py":208
 *     return '|' + text
 * 
 * def _dump_long(o):             # <<<<<<<<<<<<<<
 *     return unicode(o)
 * 
 */

static PyObject *__pyx_f_4axon_7_dumper__dump_long(PyObject *__pyx_v_o) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_dump_long", 0);

  /* "axon/_dumper.py":209
 * 
 * def _dump_long(o):
 *     return unicode(o)             # <<<<<<<<<<<<<<
 * 
 * def _dump_float(o):
 */
  __Pyx_XDECREF(((PyObject *)__pyx_r));
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 209; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_v_o);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_o);
  __Pyx_GIVEREF(__pyx_v_o);
  __pyx_t_2 = PyObject_Call(((PyObject *)((PyObject*)(&PyUnicode_Type))), ((PyObject *)__pyx_t_1), NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 209; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(((PyObject *)__pyx_t_1)); __pyx_t_1 = 0;
  __pyx_r = ((PyObject*)__pyx_t_2);
  __pyx_t_2 = 0;
  goto __pyx_L0;

  __pyx_r = ((PyObject*)Py_None); __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("axon._dumper._dump_long", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_dumper.py":211
 *     return unicode(o)
 * 
 * def _dump_float(o):             # <<<<<<<<<<<<<<
 *     d = PyFloat_AS_DOUBLE(o)
 *     if isfinite(d):
 */

static PyObject *__pyx_f_4axon_7_dumper__dump_float(PyObject *__pyx_v_o) {
  double __pyx_v_d;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_dump_float", 0);

  /* "axon/_dumper.py":212
 * 
 * def _dump_float(o):
 *     d = PyFloat_AS_DOUBLE(o)             # <<<<<<<<<<<<<<
 *     if isfinite(d):
 *         return unicode(o)
 */
  __pyx_v_d = PyFloat_AS_DOUBLE(__pyx_v_o);

  /* "axon/_dumper.py":213
 * def _dump_float(o):
 *     d = PyFloat_AS_DOUBLE(o)
 *     if isfinite(d):             # <<<<<<<<<<<<<<
 *         return unicode(o)
 * 
 */
  __pyx_t_1 = (isfinite(__pyx_v_d) != 0);
  if (__pyx_t_1) {

    /* "axon/_dumper.py":214
 *     d = PyFloat_AS_DOUBLE(o)
 *     if isfinite(d):
 *         return unicode(o)             # <<<<<<<<<<<<<<
 * 
 *     if isnan(d):
 */
    __Pyx_XDECREF(((PyObject *)__pyx_r));
    __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 214; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_INCREF(__pyx_v_o);
    PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_v_o);
    __Pyx_GIVEREF(__pyx_v_o);
    __pyx_t_3 = PyObject_Call(((PyObject *)((PyObject*)(&PyUnicode_Type))), ((PyObject *)__pyx_t_2), NULL); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 214; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(((PyObject *)__pyx_t_2)); __pyx_t_2 = 0;
    __pyx_r = ((PyObject*)__pyx_t_3);
    __pyx_t_3 = 0;
    goto __pyx_L0;
    goto __pyx_L3;
  }
  __pyx_L3:;

  /* "axon/_dumper.py":216
 *         return unicode(o)
 * 
 *     if isnan(d):             # <<<<<<<<<<<<<<
 *         return '?'
 * 
 */
  __pyx_t_1 = (isnan(__pyx_v_d) != 0);
  if (__pyx_t_1) {

    /* "axon/_dumper.py":217
 * 
 *     if isnan(d):
 *         return '?'             # <<<<<<<<<<<<<<
 * 
 *     if isinf(d):
 */
    __Pyx_XDECREF(((PyObject *)__pyx_r));
    __Pyx_INCREF(((PyObject *)__pyx_kp_u_17));
    __pyx_r = __pyx_kp_u_17;
    goto __pyx_L0;
    goto __pyx_L4;
  }
  __pyx_L4:;

  /* "axon/_dumper.py":219
 *         return '?'
 * 
 *     if isinf(d):             # <<<<<<<<<<<<<<
 *         if signbit(d):
 *             return '-'
 */
  __pyx_t_1 = (isinf(__pyx_v_d) != 0);
  if (__pyx_t_1) {

    /* "axon/_dumper.py":220
 * 
 *     if isinf(d):
 *         if signbit(d):             # <<<<<<<<<<<<<<
 *             return '-'
 *         else:
 */
    __pyx_t_1 = (signbit(__pyx_v_d) != 0);
    if (__pyx_t_1) {

      /* "axon/_dumper.py":221
 *     if isinf(d):
 *         if signbit(d):
 *             return '-'             # <<<<<<<<<<<<<<
 *         else:
 *             return ''
 */
      __Pyx_XDECREF(((PyObject *)__pyx_r));
      __Pyx_INCREF(((PyObject *)__pyx_kp_u_18));
      __pyx_r = __pyx_kp_u_18;
      goto __pyx_L0;
      goto __pyx_L6;
    }
    /*else*/ {

      /* "axon/_dumper.py":223
 *             return '-'
 *         else:
 *             return ''             # <<<<<<<<<<<<<<
 * 
 *     if signbit(d):
 */
      __Pyx_XDECREF(((PyObject *)__pyx_r));
      __Pyx_INCREF(((PyObject *)__pyx_kp_u_19));
      __pyx_r = __pyx_kp_u_19;
      goto __pyx_L0;
    }
    __pyx_L6:;
    goto __pyx_L5;
  }
  __pyx_L5:;

  /* "axon/_dumper.py":225
 *             return ''
 * 
 *     if signbit(d):             # <<<<<<<<<<<<<<
 *         return '-0'
 * 
 */
  __pyx_t_1 = (signbit(__pyx_v_d) != 0);
  if (__pyx_t_1) {

    /* "axon/_dumper.py":226
 * 
 *     if signbit(d):
 *         return '-0'             # <<<<<<<<<<<<<<
 * 
 *     return '0'
 */
    __Pyx_XDECREF(((PyObject *)__pyx_r));
    __Pyx_INCREF(((PyObject *)__pyx_kp_u_20));
    __pyx_r = __pyx_kp_u_20;
    goto __pyx_L0;
    goto __pyx_L7;
  }
  __pyx_L7:;

  /* "axon/_dumper.py":228
 *         return '-0'
 * 
 *     return '0'             # <<<<<<<<<<<<<<
 * 
 * def _dump_decimal(d):
 */
  __Pyx_XDECREF(((PyObject *)__pyx_r));
  __Pyx_INCREF(((PyObject *)__pyx_kp_u__0));
  __pyx_r = __pyx_kp_u__0;
  goto __pyx_L0;

  __pyx_r = ((PyObject*)Py_None); __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("axon._dumper._dump_float", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_dumper.py":230
 *     return '0'
 * 
 * def _dump_decimal(d):             # <<<<<<<<<<<<<<
 *     #cdef unicode val
 *     if d.is_finite():
 */

static PyObject *__pyx_f_4axon_7_dumper__dump_decimal(PyObject *__pyx_v_d) {
  PyObject *__pyx_v_val = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_dump_decimal", 0);

  /* "axon/_dumper.py":232
 * def _dump_decimal(d):
 *     #cdef unicode val
 *     if d.is_finite():             # <<<<<<<<<<<<<<
 *         val  = c_as_unicode(_decimal2str(d))
 * 
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_d, __pyx_n_s__is_finite); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 232; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyObject_Call(__pyx_t_1, ((PyObject *)__pyx_empty_tuple), NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 232; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely(__pyx_t_3 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 232; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__pyx_t_3) {

    /* "axon/_dumper.py":233
 *     #cdef unicode val
 *     if d.is_finite():
 *         val  = c_as_unicode(_decimal2str(d))             # <<<<<<<<<<<<<<
 * 
 *     elif d.is_nan():
 */
    __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s___decimal2str); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 233; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 233; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(__pyx_v_d);
    PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_d);
    __Pyx_GIVEREF(__pyx_v_d);
    __pyx_t_4 = PyObject_Call(__pyx_t_2, ((PyObject *)__pyx_t_1), NULL); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 233; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(((PyObject *)__pyx_t_1)); __pyx_t_1 = 0;
    __pyx_t_1 = ((PyObject *)__pyx_f_4axon_8_objects_c_as_unicode(__pyx_t_4)); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 233; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_v_val = ((PyObject*)__pyx_t_1);
    __pyx_t_1 = 0;
    goto __pyx_L3;
  }

  /* "axon/_dumper.py":235
 *         val  = c_as_unicode(_decimal2str(d))
 * 
 *     elif d.is_nan():             # <<<<<<<<<<<<<<
 *         val = '?'
 * 
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_d, __pyx_n_s__is_nan); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 235; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_4 = PyObject_Call(__pyx_t_1, ((PyObject *)__pyx_empty_tuple), NULL); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 235; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely(__pyx_t_3 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 235; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (__pyx_t_3) {

    /* "axon/_dumper.py":236
 * 
 *     elif d.is_nan():
 *         val = '?'             # <<<<<<<<<<<<<<
 * 
 *     elif d.is_infinite():
 */
    __Pyx_INCREF(((PyObject *)__pyx_kp_u_17));
    __pyx_v_val = __pyx_kp_u_17;
    goto __pyx_L3;
  }

  /* "axon/_dumper.py":238
 *         val = '?'
 * 
 *     elif d.is_infinite():             # <<<<<<<<<<<<<<
 *         if d.is_signed():
 *             val = '-'
 */
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_d, __pyx_n_s__is_infinite); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 238; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_1 = PyObject_Call(__pyx_t_4, ((PyObject *)__pyx_empty_tuple), NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 238; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_3 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 238; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_3) {

    /* "axon/_dumper.py":239
 * 
 *     elif d.is_infinite():
 *         if d.is_signed():             # <<<<<<<<<<<<<<
 *             val = '-'
 *         else:
 */
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_d, __pyx_n_s__is_signed); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 239; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_4 = PyObject_Call(__pyx_t_1, ((PyObject *)__pyx_empty_tuple), NULL); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 239; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely(__pyx_t_3 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 239; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (__pyx_t_3) {

      /* "axon/_dumper.py":240
 *     elif d.is_infinite():
 *         if d.is_signed():
 *             val = '-'             # <<<<<<<<<<<<<<
 *         else:
 *             val = ''
 */
      __Pyx_INCREF(((PyObject *)__pyx_kp_u_18));
      __pyx_v_val = __pyx_kp_u_18;
      goto __pyx_L4;
    }
    /*else*/ {

      /* "axon/_dumper.py":242
 *             val = '-'
 *         else:
 *             val = ''             # <<<<<<<<<<<<<<
 * 
 *     elif d.is_signed():
 */
      __Pyx_INCREF(((PyObject *)__pyx_kp_u_19));
      __pyx_v_val = __pyx_kp_u_19;
    }
    __pyx_L4:;
    goto __pyx_L3;
  }

  /* "axon/_dumper.py":244
 *             val = ''
 * 
 *     elif d.is_signed():             # <<<<<<<<<<<<<<
 *         val = '-0'
 *     else:
 */
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_d, __pyx_n_s__is_signed); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 244; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_1 = PyObject_Call(__pyx_t_4, ((PyObject *)__pyx_empty_tuple), NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 244; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_3 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 244; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_3) {

    /* "axon/_dumper.py":245
 * 
 *     elif d.is_signed():
 *         val = '-0'             # <<<<<<<<<<<<<<
 *     else:
 *         val = '0'
 */
    __Pyx_INCREF(((PyObject *)__pyx_kp_u_20));
    __pyx_v_val = __pyx_kp_u_20;
    goto __pyx_L3;
  }
  /*else*/ {

    /* "axon/_dumper.py":247
 *         val = '-0'
 *     else:
 *         val = '0'             # <<<<<<<<<<<<<<
 * 
 *     return val + '$'
 */
    __Pyx_INCREF(((PyObject *)__pyx_kp_u__0));
    __pyx_v_val = __pyx_kp_u__0;
  }
  __pyx_L3:;

  /* "axon/_dumper.py":249
 *         val = '0'
 * 
 *     return val + '$'             # <<<<<<<<<<<<<<
 * 
 * def _dump_undef(o):
 */
  __Pyx_XDECREF(((PyObject *)__pyx_r));
  __pyx_t_1 = PyNumber_Add(((PyObject *)__pyx_v_val), ((PyObject *)__pyx_kp_u_21)); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 249; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(((PyObject *)__pyx_t_1));
  __pyx_r = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;
  goto __pyx_L0;

  __pyx_r = ((PyObject*)Py_None); __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("axon._dumper._dump_decimal", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_val);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_dumper.py":251
 *     return val + '$'
 * 
 * def _dump_undef(o):             # <<<<<<<<<<<<<<
 *     return '??'
 * 
 */

static PyObject *__pyx_f_4axon_7_dumper__dump_undef(CYTHON_UNUSED PyObject *__pyx_v_o) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_dump_undef", 0);

  /* "axon/_dumper.py":252
 * 
 * def _dump_undef(o):
 *     return '??'             # <<<<<<<<<<<<<<
 * 
 * # cdef unicode _dump_Name(object o):
 */
  __Pyx_XDECREF(((PyObject *)__pyx_r));
  __Pyx_INCREF(((PyObject *)__pyx_kp_u_22));
  __pyx_r = __pyx_kp_u_22;
  goto __pyx_L0;

  __pyx_r = ((PyObject*)Py_None); __Pyx_INCREF(Py_None);
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_dumper.py":267
 * #     dumper._pertty_dump(attr.c_value, offset, 0)
 * 
 * def dump_default(v):             # <<<<<<<<<<<<<<
 *     return unicode(v)
 * 
 */

static PyObject *__pyx_f_4axon_7_dumper_dump_default(PyObject *__pyx_v_v) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("dump_default", 0);

  /* "axon/_dumper.py":268
 * 
 * def dump_default(v):
 *     return unicode(v)             # <<<<<<<<<<<<<<
 * 
 * c_simple_dumpers = {
 */
  __Pyx_XDECREF(((PyObject *)__pyx_r));
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 268; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_v_v);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_v);
  __Pyx_GIVEREF(__pyx_v_v);
  __pyx_t_2 = PyObject_Call(((PyObject *)((PyObject*)(&PyUnicode_Type))), ((PyObject *)__pyx_t_1), NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 268; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(((PyObject *)__pyx_t_1)); __pyx_t_1 = 0;
  __pyx_r = ((PyObject*)__pyx_t_2);
  __pyx_t_2 = 0;
  goto __pyx_L0;

  __pyx_r = ((PyObject*)Py_None); __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("axon._dumper.dump_default", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_4axon_7_dumper_13SimpleDumpers_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_4axon_7_dumper_13SimpleDumpers_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  if (unlikely(PyTuple_GET_SIZE(__pyx_args) > 0)) {
    __Pyx_RaiseArgtupleInvalid("__init__", 1, 0, 0, PyTuple_GET_SIZE(__pyx_args)); return -1;}
  if (unlikely(__pyx_kwds) && unlikely(PyDict_Size(__pyx_kwds) > 0) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "__init__", 0))) return -1;
  __pyx_r = __pyx_pf_4axon_7_dumper_13SimpleDumpers___init__(((struct SimpleDumpers *)__pyx_v_self));
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_dumper.py":295
 *     #cdef dict c_mapping
 * 
 *     def __init__(self):             # <<<<<<<<<<<<<<
 *         self.mapping = c_simple_dumpers.copy()
 * 
 */

static int __pyx_pf_4axon_7_dumper_13SimpleDumpers___init__(struct SimpleDumpers *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__init__", 0);

  /* "axon/_dumper.py":296
 * 
 *     def __init__(self):
 *         self.mapping = c_simple_dumpers.copy()             # <<<<<<<<<<<<<<
 * 
 *     def add(self, tp, ptr):
 */
  if (unlikely(((PyObject *)__pyx_v_4axon_7_dumper_c_simple_dumpers) == Py_None)) {
    PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%s'", "copy");
    {__pyx_filename = __pyx_f[0]; __pyx_lineno = 296; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }
  __pyx_t_1 = ((PyObject *)PyDict_Copy(__pyx_v_4axon_7_dumper_c_simple_dumpers)); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 296; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->mapping);
  __Pyx_DECREF(((PyObject *)__pyx_v_self->mapping));
  __pyx_v_self->mapping = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("axon._dumper.SimpleDumpers.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_dumper.py":298
 *         self.mapping = c_simple_dumpers.copy()
 * 
 *     def add(self, tp, ptr):             # <<<<<<<<<<<<<<
 *         self.mapping[tp] = c_new_pyptr(ptr)
 * 
 */

static void __pyx_f_4axon_7_dumper_13SimpleDumpers_add(struct SimpleDumpers *__pyx_v_self, PyObject *__pyx_v_tp, PyObject *(*__pyx_v_ptr)(PyObject *)) {
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("add", 0);

  /* "axon/_dumper.py":299
 * 
 *     def add(self, tp, ptr):
 *         self.mapping[tp] = c_new_pyptr(ptr)             # <<<<<<<<<<<<<<
 * 
 *     def update(self, o):
 */
  __pyx_t_1 = ((PyObject *)__pyx_f_4axon_7_dumper_c_new_pyptr(__pyx_v_ptr)); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 299; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (unlikely(((PyObject *)__pyx_v_self->mapping) == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    {__pyx_filename = __pyx_f[0]; __pyx_lineno = 299; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }
  if (PyDict_SetItem(((PyObject *)__pyx_v_self->mapping), ((PyObject *)__pyx_v_tp), __pyx_t_1) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 299; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_WriteUnraisable("axon._dumper.SimpleDumpers.add", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
}

/* "axon/_dumper.py":301
 *         self.mapping[tp] = c_new_pyptr(ptr)
 * 
 *     def update(self, o):             # <<<<<<<<<<<<<<
 *         #cdef SimpleDumpers sd
 * 
 */

static void __pyx_f_4axon_7_dumper_13SimpleDumpers_update(struct SimpleDumpers *__pyx_v_self, PyObject *__pyx_v_o) {
  struct SimpleDumpers *__pyx_v_sd = 0;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("update", 0);

  /* "axon/_dumper.py":304
 *         #cdef SimpleDumpers sd
 * 
 *         if type(o) is dict:             # <<<<<<<<<<<<<<
 *             self.mapping.update(o)
 *         elif type(o) is SimpleDumpers:
 */
  __pyx_t_1 = (((PyObject *)Py_TYPE(__pyx_v_o)) == ((PyObject *)((PyObject*)(&PyDict_Type))));
  __pyx_t_2 = (__pyx_t_1 != 0);
  if (__pyx_t_2) {

    /* "axon/_dumper.py":305
 * 
 *         if type(o) is dict:
 *             self.mapping.update(o)             # <<<<<<<<<<<<<<
 *         elif type(o) is SimpleDumpers:
 *             sd = o
 */
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self->mapping), __pyx_n_s__update); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 305; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = PyTuple_New(1); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 305; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_INCREF(__pyx_v_o);
    PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_v_o);
    __Pyx_GIVEREF(__pyx_v_o);
    __pyx_t_5 = PyObject_Call(__pyx_t_3, ((PyObject *)__pyx_t_4), NULL); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 305; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(((PyObject *)__pyx_t_4)); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    goto __pyx_L3;
  }

  /* "axon/_dumper.py":306
 *         if type(o) is dict:
 *             self.mapping.update(o)
 *         elif type(o) is SimpleDumpers:             # <<<<<<<<<<<<<<
 *             sd = o
 *             self.mapping.update(sd.mapping)
 */
  __pyx_t_2 = (((PyObject *)Py_TYPE(__pyx_v_o)) == ((PyObject *)((PyObject*)__pyx_ptype_4axon_7_dumper_SimpleDumpers)));
  __pyx_t_1 = (__pyx_t_2 != 0);
  if (__pyx_t_1) {

    /* "axon/_dumper.py":307
 *             self.mapping.update(o)
 *         elif type(o) is SimpleDumpers:
 *             sd = o             # <<<<<<<<<<<<<<
 *             self.mapping.update(sd.mapping)
 * 
 */
    if (!(likely(((__pyx_v_o) == Py_None) || likely(__Pyx_TypeTest(__pyx_v_o, __pyx_ptype_4axon_7_dumper_SimpleDumpers))))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 307; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_INCREF(__pyx_v_o);
    __pyx_v_sd = ((struct SimpleDumpers *)__pyx_v_o);

    /* "axon/_dumper.py":308
 *         elif type(o) is SimpleDumpers:
 *             sd = o
 *             self.mapping.update(sd.mapping)             # <<<<<<<<<<<<<<
 * 
 * def dump_as_str(tp=None):
 */
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self->mapping), __pyx_n_s__update); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 308; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_4 = PyTuple_New(1); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 308; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_INCREF(((PyObject *)__pyx_v_sd->mapping));
    PyTuple_SET_ITEM(__pyx_t_4, 0, ((PyObject *)__pyx_v_sd->mapping));
    __Pyx_GIVEREF(((PyObject *)__pyx_v_sd->mapping));
    __pyx_t_3 = PyObject_Call(__pyx_t_5, ((PyObject *)__pyx_t_4), NULL); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 308; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(((PyObject *)__pyx_t_4)); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    goto __pyx_L3;
  }
  __pyx_L3:;

  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_WriteUnraisable("axon._dumper.SimpleDumpers.update", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_sd);
  __Pyx_RefNannyFinishContext();
}

/* Python wrapper */
static PyObject *__pyx_pw_4axon_7_dumper_13SimpleDumpers_7mapping_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_4axon_7_dumper_13SimpleDumpers_7mapping_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_4axon_7_dumper_13SimpleDumpers_7mapping___get__(((struct SimpleDumpers *)__pyx_v_self));
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_dumper.pxd":103
 * 
 * cdef public class SimpleDumpers[type SimpleDumpersType, object SimpleDumpers]:
 *     cdef public dict mapping             # <<<<<<<<<<<<<<
 * 
 *     cdef void add(self, type tp, unicode (*ptr)(object))
 */

static PyObject *__pyx_pf_4axon_7_dumper_13SimpleDumpers_7mapping___get__(struct SimpleDumpers *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(((PyObject *)__pyx_v_self->mapping));
  __pyx_r = ((PyObject *)__pyx_v_self->mapping);
  goto __pyx_L0;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_4axon_7_dumper_13SimpleDumpers_7mapping_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_4axon_7_dumper_13SimpleDumpers_7mapping_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_r = __pyx_pf_4axon_7_dumper_13SimpleDumpers_7mapping_2__set__(((struct SimpleDumpers *)__pyx_v_self), ((PyObject *)__pyx_v_value));
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_4axon_7_dumper_13SimpleDumpers_7mapping_2__set__(struct SimpleDumpers *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__set__", 0);
  if (!(likely(PyDict_CheckExact(__pyx_v_value))||((__pyx_v_value) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected dict, got %.200s", Py_TYPE(__pyx_v_value)->tp_name), 0))) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 103; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_INCREF(__pyx_v_value);
  __Pyx_GIVEREF(__pyx_v_value);
  __Pyx_GOTREF(__pyx_v_self->mapping);
  __Pyx_DECREF(((PyObject *)__pyx_v_self->mapping));
  __pyx_v_self->mapping = ((PyObject*)__pyx_v_value);

  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("axon._dumper.SimpleDumpers.mapping.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_4axon_7_dumper_13SimpleDumpers_7mapping_5__del__(PyObject *__pyx_v_self); /*proto*/
static int __pyx_pw_4axon_7_dumper_13SimpleDumpers_7mapping_5__del__(PyObject *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__ (wrapper)", 0);
  __pyx_r = __pyx_pf_4axon_7_dumper_13SimpleDumpers_7mapping_4__del__(((struct SimpleDumpers *)__pyx_v_self));
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_4axon_7_dumper_13SimpleDumpers_7mapping_4__del__(struct SimpleDumpers *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__", 0);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->mapping);
  __Pyx_DECREF(((PyObject *)__pyx_v_self->mapping));
  __pyx_v_self->mapping = ((PyObject*)Py_None);

  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_4axon_7_dumper_25dump_as_str(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_4axon_7_dumper_25dump_as_str = {__Pyx_NAMESTR("dump_as_str"), (PyCFunction)__pyx_pw_4axon_7_dumper_25dump_as_str, METH_VARARGS|METH_KEYWORDS, __Pyx_DOCSTR(0)};
static PyObject *__pyx_pw_4axon_7_dumper_25dump_as_str(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_tp = 0;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("dump_as_str (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s__tp,0};
    PyObject* values[1] = {0};

    /* "axon/_dumper.py":310
 *             self.mapping.update(sd.mapping)
 * 
 * def dump_as_str(tp=None):             # <<<<<<<<<<<<<<
 *     if tp is None:
 *         def _dump_as_str(func):
 */
    values[0] = ((PyObject *)((PyObject *)Py_None));
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s__tp);
          if (value) { values[0] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "dump_as_str") < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 310; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_tp = values[0];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("dump_as_str", 0, 0, 1, PyTuple_GET_SIZE(__pyx_args)); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 310; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  __pyx_L3_error:;
  __Pyx_AddTraceback("axon._dumper.dump_as_str", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_4axon_7_dumper_24dump_as_str(__pyx_self, __pyx_v_tp);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_4axon_7_dumper_11dump_as_str_1_dump_as_str(PyObject *__pyx_self, PyObject *__pyx_v_func); /*proto*/
static PyMethodDef __pyx_mdef_4axon_7_dumper_11dump_as_str_1_dump_as_str = {__Pyx_NAMESTR("_dump_as_str"), (PyCFunction)__pyx_pw_4axon_7_dumper_11dump_as_str_1_dump_as_str, METH_O, __Pyx_DOCSTR(0)};
static PyObject *__pyx_pw_4axon_7_dumper_11dump_as_str_1_dump_as_str(PyObject *__pyx_self, PyObject *__pyx_v_func) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_dump_as_str (wrapper)", 0);
  __pyx_r = __pyx_pf_4axon_7_dumper_11dump_as_str__dump_as_str(__pyx_self, ((PyObject *)__pyx_v_func));
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_dumper.py":312
 * def dump_as_str(tp=None):
 *     if tp is None:
 *         def _dump_as_str(func):             # <<<<<<<<<<<<<<
 *             c_simple_dumpers[tp] = func
 *             return func
 */

static PyObject *__pyx_pf_4axon_7_dumper_11dump_as_str__dump_as_str(PyObject *__pyx_self, PyObject *__pyx_v_func) {
  struct __pyx_obj_4axon_7_dumper___pyx_scope_struct_1_dump_as_str *__pyx_cur_scope;
  struct __pyx_obj_4axon_7_dumper___pyx_scope_struct_1_dump_as_str *__pyx_outer_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_dump_as_str", 0);
  __pyx_outer_scope = (struct __pyx_obj_4axon_7_dumper___pyx_scope_struct_1_dump_as_str *) __Pyx_CyFunction_GetClosure(__pyx_self);
  __pyx_cur_scope = __pyx_outer_scope;

  /* "axon/_dumper.py":313
 *     if tp is None:
 *         def _dump_as_str(func):
 *             c_simple_dumpers[tp] = func             # <<<<<<<<<<<<<<
 *             return func
 *         return _dump_as_str
 */
  if (unlikely(((PyObject *)__pyx_v_4axon_7_dumper_c_simple_dumpers) == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    {__pyx_filename = __pyx_f[0]; __pyx_lineno = 313; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }
  if (unlikely(!__pyx_cur_scope->__pyx_v_tp)) { __Pyx_RaiseClosureNameError("tp"); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 313; __pyx_clineno = __LINE__; goto __pyx_L1_error;} }
  if (PyDict_SetItem(((PyObject *)__pyx_v_4axon_7_dumper_c_simple_dumpers), __pyx_cur_scope->__pyx_v_tp, __pyx_v_func) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 313; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

  /* "axon/_dumper.py":314
 *         def _dump_as_str(func):
 *             c_simple_dumpers[tp] = func
 *             return func             # <<<<<<<<<<<<<<
 *         return _dump_as_str
 *     else:
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_func);
  __pyx_r = __pyx_v_func;
  goto __pyx_L0;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("axon._dumper.dump_as_str._dump_as_str", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_dumper.py":310
 *             self.mapping.update(sd.mapping)
 * 
 * def dump_as_str(tp=None):             # <<<<<<<<<<<<<<
 *     if tp is None:
 *         def _dump_as_str(func):
 */

static PyObject *__pyx_pf_4axon_7_dumper_24dump_as_str(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_tp) {
  struct __pyx_obj_4axon_7_dumper___pyx_scope_struct_1_dump_as_str *__pyx_cur_scope;
  PyObject *__pyx_v__dump_as_str = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("dump_as_str", 0);
  __pyx_cur_scope = (struct __pyx_obj_4axon_7_dumper___pyx_scope_struct_1_dump_as_str *)__pyx_tp_new_4axon_7_dumper___pyx_scope_struct_1_dump_as_str(__pyx_ptype_4axon_7_dumper___pyx_scope_struct_1_dump_as_str, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __Pyx_RefNannyFinishContext();
    return NULL;
  }
  __Pyx_GOTREF(__pyx_cur_scope);
  __pyx_cur_scope->__pyx_v_tp = __pyx_v_tp;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_tp);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_tp);

  /* "axon/_dumper.py":311
 * 
 * def dump_as_str(tp=None):
 *     if tp is None:             # <<<<<<<<<<<<<<
 *         def _dump_as_str(func):
 *             c_simple_dumpers[tp] = func
 */
  __pyx_t_1 = (__pyx_cur_scope->__pyx_v_tp == Py_None);
  __pyx_t_2 = (__pyx_t_1 != 0);
  if (__pyx_t_2) {

    /* "axon/_dumper.py":312
 * def dump_as_str(tp=None):
 *     if tp is None:
 *         def _dump_as_str(func):             # <<<<<<<<<<<<<<
 *             c_simple_dumpers[tp] = func
 *             return func
 */
    __pyx_t_3 = __Pyx_CyFunction_NewEx(&__pyx_mdef_4axon_7_dumper_11dump_as_str_1_dump_as_str, 0, __pyx_n_s_25, ((PyObject*)__pyx_cur_scope), __pyx_n_s_6, ((PyObject *)__pyx_k_codeobj_24)); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 312; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_v__dump_as_str = __pyx_t_3;
    __pyx_t_3 = 0;

    /* "axon/_dumper.py":315
 *             c_simple_dumpers[tp] = func
 *             return func
 *         return _dump_as_str             # <<<<<<<<<<<<<<
 *     else:
 *         c_simple_dumpers[tp] = c_new_pyptr(dump_default)
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_v__dump_as_str);
    __pyx_r = __pyx_v__dump_as_str;
    goto __pyx_L0;
    goto __pyx_L3;
  }
  /*else*/ {

    /* "axon/_dumper.py":317
 *         return _dump_as_str
 *     else:
 *         c_simple_dumpers[tp] = c_new_pyptr(dump_default)             # <<<<<<<<<<<<<<
 * 
 * 
 */
    __pyx_t_3 = ((PyObject *)__pyx_f_4axon_7_dumper_c_new_pyptr(__pyx_f_4axon_7_dumper_dump_default)); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 317; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    if (unlikely(((PyObject *)__pyx_v_4axon_7_dumper_c_simple_dumpers) == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      {__pyx_filename = __pyx_f[0]; __pyx_lineno = 317; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    }
    if (PyDict_SetItem(((PyObject *)__pyx_v_4axon_7_dumper_c_simple_dumpers), __pyx_cur_scope->__pyx_v_tp, __pyx_t_3) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 317; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_L3:;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("axon._dumper.dump_as_str", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v__dump_as_str);
  __Pyx_DECREF(((PyObject *)__pyx_cur_scope));
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_dumper.py":324
 * #
 * 
 * def _dump_name(ob, quote):             # <<<<<<<<<<<<<<
 *     name = ob
 *     pos0 = 0
 */

static PyObject *__pyx_f_4axon_7_dumper__dump_name(PyObject *__pyx_v_ob, int __pyx_v_quote) {
  Py_UCS4 __pyx_v_ch;
  int __pyx_v_is_qname;
  PyObject *__pyx_v_text = 0;
  int __pyx_v_pos;
  int __pyx_v_pos0;
  PyObject *__pyx_v_name = 0;
  PyObject *__pyx_v_n = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  Py_ssize_t __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  Py_UCS4 __pyx_t_5;
  int __pyx_t_6;
  int __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_dump_name", 0);

  /* "axon/_dumper.py":325
 * 
 * def _dump_name(ob, quote):
 *     name = ob             # <<<<<<<<<<<<<<
 *     pos0 = 0
 *     pos = 0
 */
  if (!(likely(PyUnicode_CheckExact(__pyx_v_ob))||((__pyx_v_ob) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected unicode, got %.200s", Py_TYPE(__pyx_v_ob)->tp_name), 0))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 325; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_INCREF(__pyx_v_ob);
  __pyx_v_name = ((PyObject*)__pyx_v_ob);

  /* "axon/_dumper.py":326
 * def _dump_name(ob, quote):
 *     name = ob
 *     pos0 = 0             # <<<<<<<<<<<<<<
 *     pos = 0
 *     text = None
 */
  __pyx_v_pos0 = 0;

  /* "axon/_dumper.py":327
 *     name = ob
 *     pos0 = 0
 *     pos = 0             # <<<<<<<<<<<<<<
 *     text = None
 *     is_qname = quote
 */
  __pyx_v_pos = 0;

  /* "axon/_dumper.py":328
 *     pos0 = 0
 *     pos = 0
 *     text = None             # <<<<<<<<<<<<<<
 *     is_qname = quote
 * 
 */
  __Pyx_INCREF(Py_None);
  __pyx_v_text = ((PyObject*)Py_None);

  /* "axon/_dumper.py":329
 *     pos = 0
 *     text = None
 *     is_qname = quote             # <<<<<<<<<<<<<<
 * 
 *     n = len(name)
 */
  __pyx_v_is_qname = __pyx_v_quote;

  /* "axon/_dumper.py":331
 *     is_qname = quote
 * 
 *     n = len(name)             # <<<<<<<<<<<<<<
 *     while pos < n:
 *         ch = name[pos]
 */
  if (unlikely(((PyObject *)__pyx_v_name) == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "object of type 'NoneType' has no len()");
    {__pyx_filename = __pyx_f[0]; __pyx_lineno = 331; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }
  __pyx_t_1 = __Pyx_PyUnicode_GET_LENGTH(((PyObject *)__pyx_v_name)); if (unlikely(__pyx_t_1 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 331; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_t_2 = PyInt_FromSsize_t(__pyx_t_1); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 331; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_v_n = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "axon/_dumper.py":332
 * 
 *     n = len(name)
 *     while pos < n:             # <<<<<<<<<<<<<<
 *         ch = name[pos]
 *         if ch.isalnum() or ch == '_' or ch == '-':
 */
  while (1) {
    __pyx_t_2 = PyInt_FromLong(__pyx_v_pos); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 332; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = PyObject_RichCompare(__pyx_t_2, __pyx_v_n, Py_LT); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 332; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely(__pyx_t_4 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 332; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (!__pyx_t_4) break;

    /* "axon/_dumper.py":333
 *     n = len(name)
 *     while pos < n:
 *         ch = name[pos]             # <<<<<<<<<<<<<<
 *         if ch.isalnum() or ch == '_' or ch == '-':
 *             pos += 1
 */
    __pyx_t_5 = __Pyx_GetItemInt_Unicode(((PyObject *)__pyx_v_name), __pyx_v_pos, sizeof(int), PyInt_FromLong, 0, 0, 0); if (unlikely(__pyx_t_5 == (Py_UCS4)-1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 333; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
    __pyx_v_ch = __pyx_t_5;

    /* "axon/_dumper.py":334
 *     while pos < n:
 *         ch = name[pos]
 *         if ch.isalnum() or ch == '_' or ch == '-':             # <<<<<<<<<<<<<<
 *             pos += 1
 *         elif ch == "'":
 */
    __pyx_t_4 = Py_UNICODE_ISALNUM(__pyx_v_ch); 
    if (!(__pyx_t_4 != 0)) {
      switch (__pyx_v_ch) {
        case 95:
        case 45:
        __pyx_t_6 = 1;
        break;
        default:
        __pyx_t_6 = 0;
        break;
      }
      __pyx_t_7 = __pyx_t_6;
    } else {
      __pyx_t_7 = (__pyx_t_4 != 0);
    }
    if (__pyx_t_7) {

      /* "axon/_dumper.py":335
 *         ch = name[pos]
 *         if ch.isalnum() or ch == '_' or ch == '-':
 *             pos += 1             # <<<<<<<<<<<<<<
 *         elif ch == "'":
 *             if pos != pos0:
 */
      __pyx_v_pos = (__pyx_v_pos + 1);
      goto __pyx_L5;
    }

    /* "axon/_dumper.py":336
 *         if ch.isalnum() or ch == '_' or ch == '-':
 *             pos += 1
 *         elif ch == "'":             # <<<<<<<<<<<<<<
 *             if pos != pos0:
 *                 if text is None:
 */
    __pyx_t_7 = ((__pyx_v_ch == 39) != 0);
    if (__pyx_t_7) {

      /* "axon/_dumper.py":337
 *             pos += 1
 *         elif ch == "'":
 *             if pos != pos0:             # <<<<<<<<<<<<<<
 *                 if text is None:
 *                     text = name[pos0, pos]
 */
      __pyx_t_7 = ((__pyx_v_pos != __pyx_v_pos0) != 0);
      if (__pyx_t_7) {

        /* "axon/_dumper.py":338
 *         elif ch == "'":
 *             if pos != pos0:
 *                 if text is None:             # <<<<<<<<<<<<<<
 *                     text = name[pos0, pos]
 *                 else:
 */
        __pyx_t_7 = (__pyx_v_text == ((PyObject*)Py_None));
        __pyx_t_4 = (__pyx_t_7 != 0);
        if (__pyx_t_4) {

          /* "axon/_dumper.py":339
 *             if pos != pos0:
 *                 if text is None:
 *                     text = name[pos0, pos]             # <<<<<<<<<<<<<<
 *                 else:
 *                     text += name[pos0: pos]
 */
          __pyx_t_3 = PyInt_FromLong(__pyx_v_pos0); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 339; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
          __Pyx_GOTREF(__pyx_t_3);
          __pyx_t_2 = PyInt_FromLong(__pyx_v_pos); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 339; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
          __Pyx_GOTREF(__pyx_t_2);
          __pyx_t_8 = PyTuple_New(2); if (unlikely(!__pyx_t_8)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 339; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
          __Pyx_GOTREF(__pyx_t_8);
          PyTuple_SET_ITEM(__pyx_t_8, 0, __pyx_t_3);
          __Pyx_GIVEREF(__pyx_t_3);
          PyTuple_SET_ITEM(__pyx_t_8, 1, __pyx_t_2);
          __Pyx_GIVEREF(__pyx_t_2);
          __pyx_t_3 = 0;
          __pyx_t_2 = 0;
          __pyx_t_2 = PyObject_GetItem(((PyObject *)__pyx_v_name), ((PyObject *)__pyx_t_8)); if (!__pyx_t_2) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 339; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(((PyObject *)__pyx_t_8)); __pyx_t_8 = 0;
          if (!(likely(PyUnicode_CheckExact(__pyx_t_2))||((__pyx_t_2) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected unicode, got %.200s", Py_TYPE(__pyx_t_2)->tp_name), 0))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 339; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
          __Pyx_DECREF(((PyObject *)__pyx_v_text));
          __pyx_v_text = ((PyObject*)__pyx_t_2);
          __pyx_t_2 = 0;
          goto __pyx_L7;
        }
        /*else*/ {

          /* "axon/_dumper.py":341
 *                     text = name[pos0, pos]
 *                 else:
 *                     text += name[pos0: pos]             # <<<<<<<<<<<<<<
 *             text += "\\'"
 *             pos += 1
 */
          if (unlikely(((PyObject *)__pyx_v_name) == Py_None)) {
            PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
            {__pyx_filename = __pyx_f[0]; __pyx_lineno = 341; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
          }
          __pyx_t_2 = __Pyx_PyUnicode_Substring(__pyx_v_name, __pyx_v_pos0, __pyx_v_pos); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 341; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
          __Pyx_GOTREF(((PyObject *)__pyx_t_2));
          __pyx_t_8 = PyNumber_InPlaceAdd(((PyObject *)__pyx_v_text), ((PyObject *)__pyx_t_2)); if (unlikely(!__pyx_t_8)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 341; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
          __Pyx_GOTREF(((PyObject *)__pyx_t_8));
          __Pyx_DECREF(((PyObject *)__pyx_t_2)); __pyx_t_2 = 0;
          __Pyx_DECREF(((PyObject *)__pyx_v_text));
          __pyx_v_text = ((PyObject*)__pyx_t_8);
          __pyx_t_8 = 0;
        }
        __pyx_L7:;
        goto __pyx_L6;
      }
      __pyx_L6:;

      /* "axon/_dumper.py":342
 *                 else:
 *                     text += name[pos0: pos]
 *             text += "\\'"             # <<<<<<<<<<<<<<
 *             pos += 1
 *             pos0 = pos
 */
      __pyx_t_8 = PyNumber_InPlaceAdd(((PyObject *)__pyx_v_text), ((PyObject *)__pyx_kp_u_26)); if (unlikely(!__pyx_t_8)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 342; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(((PyObject *)__pyx_t_8));
      __Pyx_DECREF(((PyObject *)__pyx_v_text));
      __pyx_v_text = ((PyObject*)__pyx_t_8);
      __pyx_t_8 = 0;

      /* "axon/_dumper.py":343
 *                     text += name[pos0: pos]
 *             text += "\\'"
 *             pos += 1             # <<<<<<<<<<<<<<
 *             pos0 = pos
 *             is_qname = 1
 */
      __pyx_v_pos = (__pyx_v_pos + 1);

      /* "axon/_dumper.py":344
 *             text += "\\'"
 *             pos += 1
 *             pos0 = pos             # <<<<<<<<<<<<<<
 *             is_qname = 1
 *         else:
 */
      __pyx_v_pos0 = __pyx_v_pos;

      /* "axon/_dumper.py":345
 *             pos += 1
 *             pos0 = pos
 *             is_qname = 1             # <<<<<<<<<<<<<<
 *         else:
 *             pos += 1
 */
      __pyx_v_is_qname = 1;
      goto __pyx_L5;
    }
    /*else*/ {

      /* "axon/_dumper.py":347
 *             is_qname = 1
 *         else:
 *             pos += 1             # <<<<<<<<<<<<<<
 *             is_qname = 1
 * 
 */
      __pyx_v_pos = (__pyx_v_pos + 1);

      /* "axon/_dumper.py":348
 *         else:
 *             pos += 1
 *             is_qname = 1             # <<<<<<<<<<<<<<
 * 
 *     if pos != pos0:
 */
      __pyx_v_is_qname = 1;
    }
    __pyx_L5:;
  }

  /* "axon/_dumper.py":350
 *             is_qname = 1
 * 
 *     if pos != pos0:             # <<<<<<<<<<<<<<
 *         if text is None:
 *             text = name[pos0: pos]
 */
  __pyx_t_4 = ((__pyx_v_pos != __pyx_v_pos0) != 0);
  if (__pyx_t_4) {

    /* "axon/_dumper.py":351
 * 
 *     if pos != pos0:
 *         if text is None:             # <<<<<<<<<<<<<<
 *             text = name[pos0: pos]
 *         else:
 */
    __pyx_t_4 = (__pyx_v_text == ((PyObject*)Py_None));
    __pyx_t_7 = (__pyx_t_4 != 0);
    if (__pyx_t_7) {

      /* "axon/_dumper.py":352
 *     if pos != pos0:
 *         if text is None:
 *             text = name[pos0: pos]             # <<<<<<<<<<<<<<
 *         else:
 *             text += name[pos0: pos]
 */
      if (unlikely(((PyObject *)__pyx_v_name) == Py_None)) {
        PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
        {__pyx_filename = __pyx_f[0]; __pyx_lineno = 352; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      }
      __pyx_t_8 = __Pyx_PyUnicode_Substring(__pyx_v_name, __pyx_v_pos0, __pyx_v_pos); if (unlikely(!__pyx_t_8)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 352; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(((PyObject *)__pyx_t_8));
      __Pyx_DECREF(((PyObject *)__pyx_v_text));
      __pyx_v_text = ((PyObject*)__pyx_t_8);
      __pyx_t_8 = 0;
      goto __pyx_L9;
    }
    /*else*/ {

      /* "axon/_dumper.py":354
 *             text = name[pos0: pos]
 *         else:
 *             text += name[pos0: pos]             # <<<<<<<<<<<<<<
 * 
 *     if is_qname:
 */
      if (unlikely(((PyObject *)__pyx_v_name) == Py_None)) {
        PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
        {__pyx_filename = __pyx_f[0]; __pyx_lineno = 354; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      }
      __pyx_t_8 = __Pyx_PyUnicode_Substring(__pyx_v_name, __pyx_v_pos0, __pyx_v_pos); if (unlikely(!__pyx_t_8)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 354; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(((PyObject *)__pyx_t_8));
      __pyx_t_2 = PyNumber_InPlaceAdd(((PyObject *)__pyx_v_text), ((PyObject *)__pyx_t_8)); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 354; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(((PyObject *)__pyx_t_2));
      __Pyx_DECREF(((PyObject *)__pyx_t_8)); __pyx_t_8 = 0;
      __Pyx_DECREF(((PyObject *)__pyx_v_text));
      __pyx_v_text = ((PyObject*)__pyx_t_2);
      __pyx_t_2 = 0;
    }
    __pyx_L9:;
    goto __pyx_L8;
  }
  __pyx_L8:;

  /* "axon/_dumper.py":356
 *             text += name[pos0: pos]
 * 
 *     if is_qname:             # <<<<<<<<<<<<<<
 *         return "'" + text + "'"
 *     else:
 */
  __pyx_t_7 = (__pyx_v_is_qname != 0);
  if (__pyx_t_7) {

    /* "axon/_dumper.py":357
 * 
 *     if is_qname:
 *         return "'" + text + "'"             # <<<<<<<<<<<<<<
 *     else:
 *         return text
 */
    __Pyx_XDECREF(((PyObject *)__pyx_r));
    __pyx_t_2 = PyNumber_Add(((PyObject *)__pyx_kp_u_27), ((PyObject *)__pyx_v_text)); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 357; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(((PyObject *)__pyx_t_2));
    __pyx_t_8 = PyNumber_Add(((PyObject *)__pyx_t_2), ((PyObject *)__pyx_kp_u_27)); if (unlikely(!__pyx_t_8)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 357; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(((PyObject *)__pyx_t_8));
    __Pyx_DECREF(((PyObject *)__pyx_t_2)); __pyx_t_2 = 0;
    __pyx_r = ((PyObject*)__pyx_t_8);
    __pyx_t_8 = 0;
    goto __pyx_L0;
    goto __pyx_L10;
  }
  /*else*/ {

    /* "axon/_dumper.py":359
 *         return "'" + text + "'"
 *     else:
 *         return text             # <<<<<<<<<<<<<<
 * 
 * _simple_types = {
 */
    __Pyx_XDECREF(((PyObject *)__pyx_r));
    __Pyx_INCREF(((PyObject *)__pyx_v_text));
    __pyx_r = __pyx_v_text;
    goto __pyx_L0;
  }
  __pyx_L10:;

  __pyx_r = ((PyObject*)Py_None); __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("axon._dumper._dump_name", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_text);
  __Pyx_XDECREF(__pyx_v_name);
  __Pyx_XDECREF(__pyx_v_n);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_dumper.py":366
 *     types.date_type, types.time_type, types.datetime_type}
 * 
 * def is_simple_type(self, o):             # <<<<<<<<<<<<<<
 *     return type(o) in _simple_types or (self.crossref and id(o) in self.crossref_set2)
 * 
 */

static int __pyx_f_4axon_7_dumper_is_simple_type(struct Dumper *__pyx_v_self, PyObject *__pyx_v_o) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("is_simple_type", 0);

  /* "axon/_dumper.py":367
 * 
 * def is_simple_type(self, o):
 *     return type(o) in _simple_types or (self.crossref and id(o) in self.crossref_set2)             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_t_1 = (__Pyx_PySequence_Contains(((PyObject *)Py_TYPE(__pyx_v_o)), ((PyObject *)__pyx_v_4axon_7_dumper__simple_types), Py_EQ)); if (unlikely(__pyx_t_1 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 367; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (!__pyx_t_1) {
    if (__pyx_v_self->crossref) {
      __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 367; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_INCREF(__pyx_v_o);
      PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_v_o);
      __Pyx_GIVEREF(__pyx_v_o);
      __pyx_t_3 = PyObject_Call(__pyx_builtin_id, ((PyObject *)__pyx_t_2), NULL); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 367; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(((PyObject *)__pyx_t_2)); __pyx_t_2 = 0;
      __pyx_t_4 = (__Pyx_PySequence_Contains(__pyx_t_3, ((PyObject *)__pyx_v_self->crossref_set2), Py_EQ)); if (unlikely(__pyx_t_4 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 367; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_5 = __pyx_t_4;
    } else {
      __pyx_t_5 = __pyx_v_self->crossref;
    }
    __pyx_t_4 = __pyx_t_5;
  } else {
    __pyx_t_4 = __pyx_t_1;
  }
  __pyx_r = __pyx_t_4;
  goto __pyx_L0;

  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_WriteUnraisable("axon._dumper.is_simple_type", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_4axon_7_dumper_6Dumper_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_4axon_7_dumper_6Dumper_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_fd = 0;
  PyObject *__pyx_v_crossref = 0;
  PyObject *__pyx_v_quote = 0;
  PyObject *__pyx_v_pretty = 0;
  PyObject *__pyx_v_nsize = 0;
  PyObject *__pyx_v_sorted = 0;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s__fd,&__pyx_n_s__crossref,&__pyx_n_s__quote,&__pyx_n_s__pretty,&__pyx_n_s__nsize,&__pyx_n_s__sorted,0};
    PyObject* values[6] = {0,0,0,0,0,0};
    values[1] = __pyx_k_28;
    values[2] = __pyx_k_29;
    values[3] = ((PyObject *)__pyx_int_0);
    values[4] = ((PyObject *)__pyx_int_1);
    values[5] = ((PyObject *)__pyx_int_1);
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  6: values[5] = PyTuple_GET_ITEM(__pyx_args, 5);
        case  5: values[4] = PyTuple_GET_ITEM(__pyx_args, 4);
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s__fd)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s__crossref);
          if (value) { values[1] = value; kw_args--; }
        }
        case  2:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s__quote);
          if (value) { values[2] = value; kw_args--; }
        }
        case  3:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s__pretty);
          if (value) { values[3] = value; kw_args--; }
        }
        case  4:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s__nsize);
          if (value) { values[4] = value; kw_args--; }
        }
        case  5:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s__sorted);
          if (value) { values[5] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "__init__") < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 375; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  6: values[5] = PyTuple_GET_ITEM(__pyx_args, 5);
        case  5: values[4] = PyTuple_GET_ITEM(__pyx_args, 4);
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_fd = values[0];
    __pyx_v_crossref = values[1];
    __pyx_v_quote = values[2];
    __pyx_v_pretty = values[3];
    __pyx_v_nsize = values[4];
    __pyx_v_sorted = values[5];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__init__", 0, 1, 6, PyTuple_GET_SIZE(__pyx_args)); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 375; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  __pyx_L3_error:;
  __Pyx_AddTraceback("axon._dumper.Dumper.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_4axon_7_dumper_6Dumper___init__(((struct Dumper *)__pyx_v_self), __pyx_v_fd, __pyx_v_crossref, __pyx_v_quote, __pyx_v_pretty, __pyx_v_nsize, __pyx_v_sorted);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_dumper.py":375
 *     '''
 *     #
 *     def __init__(self, fd, crossref=False, quote=False, pretty=0, nsize=1, sorted=1):             # <<<<<<<<<<<<<<
 * 
 *         self.max_size = 65000
 */

static int __pyx_pf_4axon_7_dumper_6Dumper___init__(struct Dumper *__pyx_v_self, PyObject *__pyx_v_fd, PyObject *__pyx_v_crossref, PyObject *__pyx_v_quote, PyObject *__pyx_v_pretty, PyObject *__pyx_v_nsize, PyObject *__pyx_v_sorted) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  long __pyx_t_1;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__init__", 0);

  /* "axon/_dumper.py":377
 *     def __init__(self, fd, crossref=False, quote=False, pretty=0, nsize=1, sorted=1):
 * 
 *         self.max_size = 65000             # <<<<<<<<<<<<<<
 *         self.size = 0
 * 
 */
  __pyx_v_self->max_size = 65000;

  /* "axon/_dumper.py":378
 * 
 *         self.max_size = 65000
 *         self.size = 0             # <<<<<<<<<<<<<<
 * 
 *         self.crossref = 1 if crossref else 0
 */
  __pyx_v_self->size = 0;

  /* "axon/_dumper.py":380
 *         self.size = 0
 * 
 *         self.crossref = 1 if crossref else 0             # <<<<<<<<<<<<<<
 *         self.crossref_set = None
 *         self.crossref_set2 = None
 */
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_v_crossref); if (unlikely(__pyx_t_2 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 380; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__pyx_t_2) {
    __pyx_t_1 = 1;
  } else {
    __pyx_t_1 = 0;
  }
  __pyx_v_self->crossref = __pyx_t_1;

  /* "axon/_dumper.py":381
 * 
 *         self.crossref = 1 if crossref else 0
 *         self.crossref_set = None             # <<<<<<<<<<<<<<
 *         self.crossref_set2 = None
 *         self.crossref_dict = None
 */
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->crossref_set);
  __Pyx_DECREF(((PyObject *)__pyx_v_self->crossref_set));
  __pyx_v_self->crossref_set = ((PyObject*)Py_None);

  /* "axon/_dumper.py":382
 *         self.crossref = 1 if crossref else 0
 *         self.crossref_set = None
 *         self.crossref_set2 = None             # <<<<<<<<<<<<<<
 *         self.crossref_dict = None
 * 
 */
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->crossref_set2);
  __Pyx_DECREF(((PyObject *)__pyx_v_self->crossref_set2));
  __pyx_v_self->crossref_set2 = ((PyObject*)Py_None);

  /* "axon/_dumper.py":383
 *         self.crossref_set = None
 *         self.crossref_set2 = None
 *         self.crossref_dict = None             # <<<<<<<<<<<<<<
 * 
 *         self.quote = 1 if quote else 0
 */
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->crossref_dict);
  __Pyx_DECREF(((PyObject *)__pyx_v_self->crossref_dict));
  __pyx_v_self->crossref_dict = ((PyObject*)Py_None);

  /* "axon/_dumper.py":385
 *         self.crossref_dict = None
 * 
 *         self.quote = 1 if quote else 0             # <<<<<<<<<<<<<<
 * 
 *         self.pretty = pretty
 */
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_v_quote); if (unlikely(__pyx_t_2 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 385; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__pyx_t_2) {
    __pyx_t_1 = 1;
  } else {
    __pyx_t_1 = 0;
  }
  __pyx_v_self->quote = __pyx_t_1;

  /* "axon/_dumper.py":387
 *         self.quote = 1 if quote else 0
 * 
 *         self.pretty = pretty             # <<<<<<<<<<<<<<
 *         #self.offset = '  '
 *         self.nsize = nsize
 */
  __pyx_t_3 = __Pyx_PyInt_AsInt(__pyx_v_pretty); if (unlikely((__pyx_t_3 == (int)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 387; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_v_self->pretty = __pyx_t_3;

  /* "axon/_dumper.py":389
 *         self.pretty = pretty
 *         #self.offset = '  '
 *         self.nsize = nsize             # <<<<<<<<<<<<<<
 * 
 *         self.sorted = sorted
 */
  __pyx_t_3 = __Pyx_PyInt_AsInt(__pyx_v_nsize); if (unlikely((__pyx_t_3 == (int)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 389; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_v_self->nsize = __pyx_t_3;

  /* "axon/_dumper.py":391
 *         self.nsize = nsize
 * 
 *         self.sorted = sorted             # <<<<<<<<<<<<<<
 * 
 *         self.c_simple_dumpers = c_simple_dumpers
 */
  __pyx_t_3 = __Pyx_PyInt_AsInt(__pyx_v_sorted); if (unlikely((__pyx_t_3 == (int)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 391; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_v_self->sorted = __pyx_t_3;

  /* "axon/_dumper.py":393
 *         self.sorted = sorted
 * 
 *         self.c_simple_dumpers = c_simple_dumpers             # <<<<<<<<<<<<<<
 *         self.c_type_reducers = c_reduce_dict
 * 
 */
  __Pyx_INCREF(((PyObject *)__pyx_v_4axon_7_dumper_c_simple_dumpers));
  __Pyx_GIVEREF(((PyObject *)__pyx_v_4axon_7_dumper_c_simple_dumpers));
  __Pyx_GOTREF(__pyx_v_self->c_simple_dumpers);
  __Pyx_DECREF(((PyObject *)__pyx_v_self->c_simple_dumpers));
  __pyx_v_self->c_simple_dumpers = __pyx_v_4axon_7_dumper_c_simple_dumpers;

  /* "axon/_dumper.py":394
 * 
 *         self.c_simple_dumpers = c_simple_dumpers
 *         self.c_type_reducers = c_reduce_dict             # <<<<<<<<<<<<<<
 * 
 *         self.write = fd.write
 */
  __Pyx_INCREF(((PyObject *)c_reduce_dict));
  __Pyx_GIVEREF(((PyObject *)c_reduce_dict));
  __Pyx_GOTREF(__pyx_v_self->c_type_reducers);
  __Pyx_DECREF(((PyObject *)__pyx_v_self->c_type_reducers));
  __pyx_v_self->c_type_reducers = c_reduce_dict;

  /* "axon/_dumper.py":396
 *         self.c_type_reducers = c_reduce_dict
 * 
 *         self.write = fd.write             # <<<<<<<<<<<<<<
 *     #
 *     def _pretty_dump_crossref(self, o):
 */
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_fd, __pyx_n_s__write); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 396; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_GIVEREF(__pyx_t_4);
  __Pyx_GOTREF(__pyx_v_self->write);
  __Pyx_DECREF(__pyx_v_self->write);
  __pyx_v_self->write = __pyx_t_4;
  __pyx_t_4 = 0;

  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("axon._dumper.Dumper.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_dumper.py":398
 *         self.write = fd.write
 *     #
 *     def _pretty_dump_crossref(self, o):             # <<<<<<<<<<<<<<
 *         o_id = id(o)
 *         if o_id in self.crossref_set:
 */

static void __pyx_f_4axon_7_dumper_6Dumper__pretty_dump_crossref(struct Dumper *__pyx_v_self, PyObject *__pyx_v_o) {
  PyObject *__pyx_v_o_id = NULL;
  PyObject *__pyx_v_label = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_t_3;
  int __pyx_t_4;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_pretty_dump_crossref", 0);

  /* "axon/_dumper.py":399
 *     #
 *     def _pretty_dump_crossref(self, o):
 *         o_id = id(o)             # <<<<<<<<<<<<<<
 *         if o_id in self.crossref_set:
 *             self.write(' &')
 */
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 399; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_v_o);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_o);
  __Pyx_GIVEREF(__pyx_v_o);
  __pyx_t_2 = PyObject_Call(__pyx_builtin_id, ((PyObject *)__pyx_t_1), NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 399; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(((PyObject *)__pyx_t_1)); __pyx_t_1 = 0;
  __pyx_v_o_id = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "axon/_dumper.py":400
 *     def _pretty_dump_crossref(self, o):
 *         o_id = id(o)
 *         if o_id in self.crossref_set:             # <<<<<<<<<<<<<<
 *             self.write(' &')
 * 
 */
  __pyx_t_3 = (__Pyx_PySequence_Contains(__pyx_v_o_id, ((PyObject *)__pyx_v_self->crossref_set), Py_EQ)); if (unlikely(__pyx_t_3 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 400; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_t_4 = (__pyx_t_3 != 0);
  if (__pyx_t_4) {

    /* "axon/_dumper.py":401
 *         o_id = id(o)
 *         if o_id in self.crossref_set:
 *             self.write(' &')             # <<<<<<<<<<<<<<
 * 
 *             label = self.crossref_dict[o_id]
 */
    __pyx_t_2 = PyObject_Call(__pyx_v_self->write, ((PyObject *)__pyx_k_tuple_31), NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 401; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "axon/_dumper.py":403
 *             self.write(' &')
 * 
 *             label = self.crossref_dict[o_id]             # <<<<<<<<<<<<<<
 *             self.write(label)
 *             self.write(' ')
 */
    if (unlikely(((PyObject *)__pyx_v_self->crossref_dict) == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      {__pyx_filename = __pyx_f[0]; __pyx_lineno = 403; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    }
    __pyx_t_2 = __Pyx_PyDict_GetItem(((PyObject *)__pyx_v_self->crossref_dict), __pyx_v_o_id); if (!__pyx_t_2) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 403; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_v_label = __pyx_t_2;
    __pyx_t_2 = 0;

    /* "axon/_dumper.py":404
 * 
 *             label = self.crossref_dict[o_id]
 *             self.write(label)             # <<<<<<<<<<<<<<
 *             self.write(' ')
 *             self.crossref_set2.add(o_id)
 */
    __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 404; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_INCREF(__pyx_v_label);
    PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_v_label);
    __Pyx_GIVEREF(__pyx_v_label);
    __pyx_t_1 = PyObject_Call(__pyx_v_self->write, ((PyObject *)__pyx_t_2), NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 404; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(((PyObject *)__pyx_t_2)); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "axon/_dumper.py":405
 *             label = self.crossref_dict[o_id]
 *             self.write(label)
 *             self.write(' ')             # <<<<<<<<<<<<<<
 *             self.crossref_set2.add(o_id)
 *     #
 */
    __pyx_t_1 = PyObject_Call(__pyx_v_self->write, ((PyObject *)__pyx_k_tuple_33), NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 405; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "axon/_dumper.py":406
 *             self.write(label)
 *             self.write(' ')
 *             self.crossref_set2.add(o_id)             # <<<<<<<<<<<<<<
 *     #
 *     def _dump_crossref(self, o):
 */
    if (unlikely(((PyObject *)__pyx_v_self->crossref_set2) == Py_None)) {
      PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%s'", "add");
      {__pyx_filename = __pyx_f[0]; __pyx_lineno = 406; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    }
    __pyx_t_5 = PySet_Add(__pyx_v_self->crossref_set2, __pyx_v_o_id); if (unlikely(__pyx_t_5 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 406; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    goto __pyx_L3;
  }
  __pyx_L3:;

  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_WriteUnraisable("axon._dumper.Dumper._pretty_dump_crossref", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_o_id);
  __Pyx_XDECREF(__pyx_v_label);
  __Pyx_RefNannyFinishContext();
}

/* "axon/_dumper.py":408
 *             self.crossref_set2.add(o_id)
 *     #
 *     def _dump_crossref(self, o):             # <<<<<<<<<<<<<<
 *         o_id = id(o)
 *         if o_id in self.crossref_set:
 */

static void __pyx_f_4axon_7_dumper_6Dumper__dump_crossref(struct Dumper *__pyx_v_self, PyObject *__pyx_v_o) {
  PyObject *__pyx_v_o_id = NULL;
  PyObject *__pyx_v_label = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_t_3;
  int __pyx_t_4;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_dump_crossref", 0);

  /* "axon/_dumper.py":409
 *     #
 *     def _dump_crossref(self, o):
 *         o_id = id(o)             # <<<<<<<<<<<<<<
 *         if o_id in self.crossref_set:
 *             self.write('&')
 */
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 409; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_v_o);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_o);
  __Pyx_GIVEREF(__pyx_v_o);
  __pyx_t_2 = PyObject_Call(__pyx_builtin_id, ((PyObject *)__pyx_t_1), NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 409; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(((PyObject *)__pyx_t_1)); __pyx_t_1 = 0;
  __pyx_v_o_id = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "axon/_dumper.py":410
 *     def _dump_crossref(self, o):
 *         o_id = id(o)
 *         if o_id in self.crossref_set:             # <<<<<<<<<<<<<<
 *             self.write('&')
 * 
 */
  __pyx_t_3 = (__Pyx_PySequence_Contains(__pyx_v_o_id, ((PyObject *)__pyx_v_self->crossref_set), Py_EQ)); if (unlikely(__pyx_t_3 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 410; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_t_4 = (__pyx_t_3 != 0);
  if (__pyx_t_4) {

    /* "axon/_dumper.py":411
 *         o_id = id(o)
 *         if o_id in self.crossref_set:
 *             self.write('&')             # <<<<<<<<<<<<<<
 * 
 *             label = self.crossref_dict[o_id]
 */
    __pyx_t_2 = PyObject_Call(__pyx_v_self->write, ((PyObject *)__pyx_k_tuple_35), NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 411; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "axon/_dumper.py":413
 *             self.write('&')
 * 
 *             label = self.crossref_dict[o_id]             # <<<<<<<<<<<<<<
 *             self.write(label)
 *             self.write(' ')
 */
    if (unlikely(((PyObject *)__pyx_v_self->crossref_dict) == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      {__pyx_filename = __pyx_f[0]; __pyx_lineno = 413; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    }
    __pyx_t_2 = __Pyx_PyDict_GetItem(((PyObject *)__pyx_v_self->crossref_dict), __pyx_v_o_id); if (!__pyx_t_2) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 413; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_v_label = __pyx_t_2;
    __pyx_t_2 = 0;

    /* "axon/_dumper.py":414
 * 
 *             label = self.crossref_dict[o_id]
 *             self.write(label)             # <<<<<<<<<<<<<<
 *             self.write(' ')
 *             self.crossref_set2.add(o_id)
 */
    __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 414; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_INCREF(__pyx_v_label);
    PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_v_label);
    __Pyx_GIVEREF(__pyx_v_label);
    __pyx_t_1 = PyObject_Call(__pyx_v_self->write, ((PyObject *)__pyx_t_2), NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 414; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(((PyObject *)__pyx_t_2)); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "axon/_dumper.py":415
 *             label = self.crossref_dict[o_id]
 *             self.write(label)
 *             self.write(' ')             # <<<<<<<<<<<<<<
 *             self.crossref_set2.add(o_id)
 *     #
 */
    __pyx_t_1 = PyObject_Call(__pyx_v_self->write, ((PyObject *)__pyx_k_tuple_36), NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 415; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "axon/_dumper.py":416
 *             self.write(label)
 *             self.write(' ')
 *             self.crossref_set2.add(o_id)             # <<<<<<<<<<<<<<
 *     #
 *     def _dump_label(self, o):
 */
    if (unlikely(((PyObject *)__pyx_v_self->crossref_set2) == Py_None)) {
      PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%s'", "add");
      {__pyx_filename = __pyx_f[0]; __pyx_lineno = 416; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    }
    __pyx_t_5 = PySet_Add(__pyx_v_self->crossref_set2, __pyx_v_o_id); if (unlikely(__pyx_t_5 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 416; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    goto __pyx_L3;
  }
  __pyx_L3:;

  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_WriteUnraisable("axon._dumper.Dumper._dump_crossref", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_o_id);
  __Pyx_XDECREF(__pyx_v_label);
  __Pyx_RefNannyFinishContext();
}

/* "axon/_dumper.py":418
 *             self.crossref_set2.add(o_id)
 *     #
 *     def _dump_label(self, o):             # <<<<<<<<<<<<<<
 *         o_id = id(o)
 *         if  o_id in self.crossref_set2:
 */

static int __pyx_f_4axon_7_dumper_6Dumper__dump_label(struct Dumper *__pyx_v_self, PyObject *__pyx_v_o) {
  PyObject *__pyx_v_o_id = NULL;
  PyObject *__pyx_v_label = NULL;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_t_3;
  int __pyx_t_4;
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_dump_label", 0);

  /* "axon/_dumper.py":419
 *     #
 *     def _dump_label(self, o):
 *         o_id = id(o)             # <<<<<<<<<<<<<<
 *         if  o_id in self.crossref_set2:
 *             self.write('*')
 */
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 419; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_v_o);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_o);
  __Pyx_GIVEREF(__pyx_v_o);
  __pyx_t_2 = PyObject_Call(__pyx_builtin_id, ((PyObject *)__pyx_t_1), NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 419; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(((PyObject *)__pyx_t_1)); __pyx_t_1 = 0;
  __pyx_v_o_id = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "axon/_dumper.py":420
 *     def _dump_label(self, o):
 *         o_id = id(o)
 *         if  o_id in self.crossref_set2:             # <<<<<<<<<<<<<<
 *             self.write('*')
 * #
 */
  __pyx_t_3 = (__Pyx_PySequence_Contains(__pyx_v_o_id, ((PyObject *)__pyx_v_self->crossref_set2), Py_EQ)); if (unlikely(__pyx_t_3 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 420; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_t_4 = (__pyx_t_3 != 0);
  if (__pyx_t_4) {

    /* "axon/_dumper.py":421
 *         o_id = id(o)
 *         if  o_id in self.crossref_set2:
 *             self.write('*')             # <<<<<<<<<<<<<<
 * #
 *             label = self.crossref_dict[o_id]
 */
    __pyx_t_2 = PyObject_Call(__pyx_v_self->write, ((PyObject *)__pyx_k_tuple_37), NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 421; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "axon/_dumper.py":423
 *             self.write('*')
 * #
 *             label = self.crossref_dict[o_id]             # <<<<<<<<<<<<<<
 *             self.write(label)
 *             return 1
 */
    if (unlikely(((PyObject *)__pyx_v_self->crossref_dict) == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      {__pyx_filename = __pyx_f[0]; __pyx_lineno = 423; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    }
    __pyx_t_2 = __Pyx_PyDict_GetItem(((PyObject *)__pyx_v_self->crossref_dict), __pyx_v_o_id); if (!__pyx_t_2) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 423; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_v_label = __pyx_t_2;
    __pyx_t_2 = 0;

    /* "axon/_dumper.py":424
 * #
 *             label = self.crossref_dict[o_id]
 *             self.write(label)             # <<<<<<<<<<<<<<
 *             return 1
 *         elif  o_id in self.crossref_set:
 */
    __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 424; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_INCREF(__pyx_v_label);
    PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_v_label);
    __Pyx_GIVEREF(__pyx_v_label);
    __pyx_t_1 = PyObject_Call(__pyx_v_self->write, ((PyObject *)__pyx_t_2), NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 424; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(((PyObject *)__pyx_t_2)); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "axon/_dumper.py":425
 *             label = self.crossref_dict[o_id]
 *             self.write(label)
 *             return 1             # <<<<<<<<<<<<<<
 *         elif  o_id in self.crossref_set:
 *             self.write('&')
 */
    __pyx_r = 1;
    goto __pyx_L0;
    goto __pyx_L3;
  }

  /* "axon/_dumper.py":426
 *             self.write(label)
 *             return 1
 *         elif  o_id in self.crossref_set:             # <<<<<<<<<<<<<<
 *             self.write('&')
 * #
 */
  __pyx_t_4 = (__Pyx_PySequence_Contains(__pyx_v_o_id, ((PyObject *)__pyx_v_self->crossref_set), Py_EQ)); if (unlikely(__pyx_t_4 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 426; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_t_3 = (__pyx_t_4 != 0);
  if (__pyx_t_3) {

    /* "axon/_dumper.py":427
 *             return 1
 *         elif  o_id in self.crossref_set:
 *             self.write('&')             # <<<<<<<<<<<<<<
 * #
 *             label = self.crossref_dict[o_id]
 */
    __pyx_t_1 = PyObject_Call(__pyx_v_self->write, ((PyObject *)__pyx_k_tuple_38), NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 427; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "axon/_dumper.py":429
 *             self.write('&')
 * #
 *             label = self.crossref_dict[o_id]             # <<<<<<<<<<<<<<
 *             self.write(label)
 *             self.write(' ')
 */
    if (unlikely(((PyObject *)__pyx_v_self->crossref_dict) == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      {__pyx_filename = __pyx_f[0]; __pyx_lineno = 429; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    }
    __pyx_t_1 = __Pyx_PyDict_GetItem(((PyObject *)__pyx_v_self->crossref_dict), __pyx_v_o_id); if (!__pyx_t_1) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 429; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_v_label = __pyx_t_1;
    __pyx_t_1 = 0;

    /* "axon/_dumper.py":430
 * #
 *             label = self.crossref_dict[o_id]
 *             self.write(label)             # <<<<<<<<<<<<<<
 *             self.write(' ')
 *             self.crossref_set2.add(o_id)
 */
    __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 430; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(__pyx_v_label);
    PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_label);
    __Pyx_GIVEREF(__pyx_v_label);
    __pyx_t_2 = PyObject_Call(__pyx_v_self->write, ((PyObject *)__pyx_t_1), NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 430; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(((PyObject *)__pyx_t_1)); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "axon/_dumper.py":431
 *             label = self.crossref_dict[o_id]
 *             self.write(label)
 *             self.write(' ')             # <<<<<<<<<<<<<<
 *             self.crossref_set2.add(o_id)
 *             self.crossref_set.remove(o_id)
 */
    __pyx_t_2 = PyObject_Call(__pyx_v_self->write, ((PyObject *)__pyx_k_tuple_39), NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 431; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "axon/_dumper.py":432
 *             self.write(label)
 *             self.write(' ')
 *             self.crossref_set2.add(o_id)             # <<<<<<<<<<<<<<
 *             self.crossref_set.remove(o_id)
 *             return 2
 */
    if (unlikely(((PyObject *)__pyx_v_self->crossref_set2) == Py_None)) {
      PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%s'", "add");
      {__pyx_filename = __pyx_f[0]; __pyx_lineno = 432; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    }
    __pyx_t_5 = PySet_Add(__pyx_v_self->crossref_set2, __pyx_v_o_id); if (unlikely(__pyx_t_5 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 432; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

    /* "axon/_dumper.py":433
 *             self.write(' ')
 *             self.crossref_set2.add(o_id)
 *             self.crossref_set.remove(o_id)             # <<<<<<<<<<<<<<
 *             return 2
 *         else:
 */
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self->crossref_set), __pyx_n_s__remove); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 433; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 433; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(__pyx_v_o_id);
    PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_o_id);
    __Pyx_GIVEREF(__pyx_v_o_id);
    __pyx_t_6 = PyObject_Call(__pyx_t_2, ((PyObject *)__pyx_t_1), NULL); if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 433; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(((PyObject *)__pyx_t_1)); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

    /* "axon/_dumper.py":434
 *             self.crossref_set2.add(o_id)
 *             self.crossref_set.remove(o_id)
 *             return 2             # <<<<<<<<<<<<<<
 *         else:
 *             return -1
 */
    __pyx_r = 2;
    goto __pyx_L0;
    goto __pyx_L3;
  }
  /*else*/ {

    /* "axon/_dumper.py":436
 *             return 2
 *         else:
 *             return -1             # <<<<<<<<<<<<<<
 *     #
 *     def _dump(self, o):
 */
    __pyx_r = -1;
    goto __pyx_L0;
  }
  __pyx_L3:;

  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_WriteUnraisable("axon._dumper.Dumper._dump_label", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_o_id);
  __Pyx_XDECREF(__pyx_v_label);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_dumper.py":438
 *             return -1
 *     #
 *     def _dump(self, o):             # <<<<<<<<<<<<<<
 * 
 *         if self.size > self.max_size:
 */

static int __pyx_f_4axon_7_dumper_6Dumper__dump(struct Dumper *__pyx_v_self, PyObject *__pyx_v_o) {
  PyObject *__pyx_v_otype = NULL;
  PyObject *__pyx_v_dumper = NULL;
  PyObject *__pyx_v_reducer = NULL;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_t_3;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_dump", 0);

  /* "axon/_dumper.py":440
 *     def _dump(self, o):
 * 
 *         if self.size > self.max_size:             # <<<<<<<<<<<<<<
 *             self.write('\n')
 *             self.size = 0
 */
  __pyx_t_1 = ((__pyx_v_self->size > __pyx_v_self->max_size) != 0);
  if (__pyx_t_1) {

    /* "axon/_dumper.py":441
 * 
 *         if self.size > self.max_size:
 *             self.write('\n')             # <<<<<<<<<<<<<<
 *             self.size = 0
 * 
 */
    __pyx_t_2 = PyObject_Call(__pyx_v_self->write, ((PyObject *)__pyx_k_tuple_41), NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 441; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "axon/_dumper.py":442
 *         if self.size > self.max_size:
 *             self.write('\n')
 *             self.size = 0             # <<<<<<<<<<<<<<
 * 
 *         otype = type(o)
 */
    __pyx_v_self->size = 0;
    goto __pyx_L3;
  }
  __pyx_L3:;

  /* "axon/_dumper.py":444
 *             self.size = 0
 * 
 *         otype = type(o)             # <<<<<<<<<<<<<<
 *         dumper = self.c_simple_dumpers.get(otype, None)
 *         if dumper is None:
 */
  __Pyx_INCREF(((PyObject *)Py_TYPE(__pyx_v_o)));
  __pyx_v_otype = ((PyObject*)((PyObject *)Py_TYPE(__pyx_v_o)));

  /* "axon/_dumper.py":445
 * 
 *         otype = type(o)
 *         dumper = self.c_simple_dumpers.get(otype, None)             # <<<<<<<<<<<<<<
 *         if dumper is None:
 *             if self.crossref:
 */
  if (unlikely(((PyObject *)__pyx_v_self->c_simple_dumpers) == Py_None)) {
    PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%s'", "get");
    {__pyx_filename = __pyx_f[0]; __pyx_lineno = 445; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }
  __pyx_t_2 = __Pyx_PyDict_GetItemDefault(((PyObject *)__pyx_v_self->c_simple_dumpers), ((PyObject *)__pyx_v_otype), Py_None); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 445; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_v_dumper = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "axon/_dumper.py":446
 *         otype = type(o)
 *         dumper = self.c_simple_dumpers.get(otype, None)
 *         if dumper is None:             # <<<<<<<<<<<<<<
 *             if self.crossref:
 *                 if self._dump_label(o) == 1:
 */
  __pyx_t_1 = (__pyx_v_dumper == Py_None);
  __pyx_t_3 = (__pyx_t_1 != 0);
  if (__pyx_t_3) {

    /* "axon/_dumper.py":447
 *         dumper = self.c_simple_dumpers.get(otype, None)
 *         if dumper is None:
 *             if self.crossref:             # <<<<<<<<<<<<<<
 *                 if self._dump_label(o) == 1:
 *                     return 0
 */
    __pyx_t_3 = (__pyx_v_self->crossref != 0);
    if (__pyx_t_3) {

      /* "axon/_dumper.py":448
 *         if dumper is None:
 *             if self.crossref:
 *                 if self._dump_label(o) == 1:             # <<<<<<<<<<<<<<
 *                     return 0
 * 
 */
      __pyx_t_3 = ((__pyx_f_4axon_7_dumper_6Dumper__dump_label(__pyx_v_self, __pyx_v_o) == 1) != 0);
      if (__pyx_t_3) {

        /* "axon/_dumper.py":449
 *             if self.crossref:
 *                 if self._dump_label(o) == 1:
 *                     return 0             # <<<<<<<<<<<<<<
 * 
 *             if otype is list:
 */
        __pyx_r = 0;
        goto __pyx_L0;
        goto __pyx_L6;
      }
      __pyx_L6:;
      goto __pyx_L5;
    }
    __pyx_L5:;

    /* "axon/_dumper.py":451
 *                     return 0
 * 
 *             if otype is list:             # <<<<<<<<<<<<<<
 *                 self.dump_list(o)
 *             elif otype is dict:
 */
    __pyx_t_3 = (__pyx_v_otype == ((PyObject*)(&PyList_Type)));
    __pyx_t_1 = (__pyx_t_3 != 0);
    if (__pyx_t_1) {

      /* "axon/_dumper.py":452
 * 
 *             if otype is list:
 *                 self.dump_list(o)             # <<<<<<<<<<<<<<
 *             elif otype is dict:
 *                 self.dump_dict(o)
 */
      if (!(likely(PyList_CheckExact(__pyx_v_o))||((__pyx_v_o) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected list, got %.200s", Py_TYPE(__pyx_v_o)->tp_name), 0))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 452; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __pyx_t_4 = __pyx_f_4axon_7_dumper_6Dumper_dump_list(__pyx_v_self, ((PyObject*)__pyx_v_o)); if (unlikely(__pyx_t_4 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 452; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      goto __pyx_L7;
    }

    /* "axon/_dumper.py":453
 *             if otype is list:
 *                 self.dump_list(o)
 *             elif otype is dict:             # <<<<<<<<<<<<<<
 *                 self.dump_dict(o)
 *             elif otype is tuple:
 */
    __pyx_t_1 = (__pyx_v_otype == ((PyObject*)(&PyDict_Type)));
    __pyx_t_3 = (__pyx_t_1 != 0);
    if (__pyx_t_3) {

      /* "axon/_dumper.py":454
 *                 self.dump_list(o)
 *             elif otype is dict:
 *                 self.dump_dict(o)             # <<<<<<<<<<<<<<
 *             elif otype is tuple:
 *                 self.dump_tuple(o)
 */
      if (!(likely(PyDict_CheckExact(__pyx_v_o))||((__pyx_v_o) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected dict, got %.200s", Py_TYPE(__pyx_v_o)->tp_name), 0))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 454; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __pyx_t_4 = __pyx_f_4axon_7_dumper_6Dumper_dump_dict(__pyx_v_self, ((PyObject*)__pyx_v_o)); if (unlikely(__pyx_t_4 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 454; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      goto __pyx_L7;
    }

    /* "axon/_dumper.py":455
 *             elif otype is dict:
 *                 self.dump_dict(o)
 *             elif otype is tuple:             # <<<<<<<<<<<<<<
 *                 self.dump_tuple(o)
 *             #elif otype is set:
 */
    __pyx_t_3 = (__pyx_v_otype == ((PyObject*)(&PyTuple_Type)));
    __pyx_t_1 = (__pyx_t_3 != 0);
    if (__pyx_t_1) {

      /* "axon/_dumper.py":456
 *                 self.dump_dict(o)
 *             elif otype is tuple:
 *                 self.dump_tuple(o)             # <<<<<<<<<<<<<<
 *             #elif otype is set:
 *             #    self.dump_set(o)
 */
      __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s__dump_tuple); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 456; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_5 = PyTuple_New(1); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 456; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_INCREF(__pyx_v_o);
      PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_v_o);
      __Pyx_GIVEREF(__pyx_v_o);
      __pyx_t_6 = PyObject_Call(__pyx_t_2, ((PyObject *)__pyx_t_5), NULL); if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 456; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_DECREF(((PyObject *)__pyx_t_5)); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      goto __pyx_L7;
    }
    /*else*/ {

      /* "axon/_dumper.py":460
 *             #    self.dump_set(o)
 *             else:
 *                 reducer = self.c_type_reducers.get(otype, None)             # <<<<<<<<<<<<<<
 *                 if reducer is None:
 *                     raise TypeError('There is no reducer for this type: ' + repr(otype))
 */
      if (unlikely(((PyObject *)__pyx_v_self->c_type_reducers) == Py_None)) {
        PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%s'", "get");
        {__pyx_filename = __pyx_f[0]; __pyx_lineno = 460; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      }
      __pyx_t_6 = __Pyx_PyDict_GetItemDefault(((PyObject *)__pyx_v_self->c_type_reducers), ((PyObject *)__pyx_v_otype), Py_None); if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 460; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_v_reducer = __pyx_t_6;
      __pyx_t_6 = 0;

      /* "axon/_dumper.py":461
 *             else:
 *                 reducer = self.c_type_reducers.get(otype, None)
 *                 if reducer is None:             # <<<<<<<<<<<<<<
 *                     raise TypeError('There is no reducer for this type: ' + repr(otype))
 *                 else:
 */
      __pyx_t_1 = (__pyx_v_reducer == Py_None);
      __pyx_t_3 = (__pyx_t_1 != 0);
      if (__pyx_t_3) {

        /* "axon/_dumper.py":462
 *                 reducer = self.c_type_reducers.get(otype, None)
 *                 if reducer is None:
 *                     raise TypeError('There is no reducer for this type: ' + repr(otype))             # <<<<<<<<<<<<<<
 *                 else:
 *                     self._dump_with_reducer(reducer, o)
 */
        __pyx_t_6 = PyObject_Repr(((PyObject *)__pyx_v_otype)); if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 462; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_6);
        __pyx_t_5 = PyNumber_Add(((PyObject *)__pyx_kp_u_42), __pyx_t_6); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 462; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        __pyx_t_6 = PyTuple_New(1); if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 462; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_6);
        PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_5);
        __Pyx_GIVEREF(__pyx_t_5);
        __pyx_t_5 = 0;
        __pyx_t_5 = PyObject_Call(__pyx_builtin_TypeError, ((PyObject *)__pyx_t_6), NULL); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 462; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(((PyObject *)__pyx_t_6)); __pyx_t_6 = 0;
        __Pyx_Raise(__pyx_t_5, 0, 0, 0);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        {__pyx_filename = __pyx_f[0]; __pyx_lineno = 462; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        goto __pyx_L8;
      }
      /*else*/ {

        /* "axon/_dumper.py":464
 *                     raise TypeError('There is no reducer for this type: ' + repr(otype))
 *                 else:
 *                     self._dump_with_reducer(reducer, o)             # <<<<<<<<<<<<<<
 *         else:
 *             self._dump_value(o, dumper)
 */
        __pyx_t_4 = __pyx_f_4axon_7_dumper_6Dumper__dump_with_reducer(__pyx_v_self, __pyx_v_reducer, __pyx_v_o); if (unlikely(__pyx_t_4 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 464; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      }
      __pyx_L8:;
    }
    __pyx_L7:;
    goto __pyx_L4;
  }
  /*else*/ {

    /* "axon/_dumper.py":466
 *                     self._dump_with_reducer(reducer, o)
 *         else:
 *             self._dump_value(o, dumper)             # <<<<<<<<<<<<<<
 *     #
 *     def _pretty_dump(self, o, offset, use_offset):
 */
    __pyx_f_4axon_7_dumper_6Dumper__dump_value(__pyx_v_self, __pyx_v_o, __pyx_v_dumper);
  }
  __pyx_L4:;

  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("axon._dumper.Dumper._dump", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_otype);
  __Pyx_XDECREF(__pyx_v_dumper);
  __Pyx_XDECREF(__pyx_v_reducer);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_dumper.py":468
 *             self._dump_value(o, dumper)
 *     #
 *     def _pretty_dump(self, o, offset, use_offset):             # <<<<<<<<<<<<<<
 *         this_offset = offset
 *         new_offset = offset + '  '
 */

static int __pyx_f_4axon_7_dumper_6Dumper__pretty_dump(struct Dumper *__pyx_v_self, PyObject *__pyx_v_o, PyObject *__pyx_v_offset, int __pyx_v_use_offset) {
  PyObject *__pyx_v_this_offset = 0;
  PyObject *__pyx_v_new_offset = 0;
  PyObject *__pyx_v_otype = NULL;
  PyObject *__pyx_v_dumper = NULL;
  PyObject *__pyx_v_reducer = NULL;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  Py_ssize_t __pyx_t_5;
  PyObject *(*__pyx_t_6)(PyObject *);
  PyObject *__pyx_t_7 = NULL;
  int __pyx_t_8;
  int __pyx_t_9;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_pretty_dump", 0);

  /* "axon/_dumper.py":469
 *     #
 *     def _pretty_dump(self, o, offset, use_offset):
 *         this_offset = offset             # <<<<<<<<<<<<<<
 *         new_offset = offset + '  '
 * 
 */
  __Pyx_INCREF(((PyObject *)__pyx_v_offset));
  __pyx_v_this_offset = __pyx_v_offset;

  /* "axon/_dumper.py":470
 *     def _pretty_dump(self, o, offset, use_offset):
 *         this_offset = offset
 *         new_offset = offset + '  '             # <<<<<<<<<<<<<<
 * 
 *         if not use_offset:
 */
  __pyx_t_1 = PyNumber_Add(((PyObject *)__pyx_v_offset), ((PyObject *)__pyx_kp_u_43)); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 470; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(((PyObject *)__pyx_t_1));
  __pyx_v_new_offset = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "axon/_dumper.py":472
 *         new_offset = offset + '  '
 * 
 *         if not use_offset:             # <<<<<<<<<<<<<<
 *             this_offset = ''
 * 
 */
  __pyx_t_2 = ((!(__pyx_v_use_offset != 0)) != 0);
  if (__pyx_t_2) {

    /* "axon/_dumper.py":473
 * 
 *         if not use_offset:
 *             this_offset = ''             # <<<<<<<<<<<<<<
 * 
 *         self.write(this_offset)
 */
    __Pyx_INCREF(((PyObject *)__pyx_kp_u_44));
    __Pyx_DECREF(((PyObject *)__pyx_v_this_offset));
    __pyx_v_this_offset = __pyx_kp_u_44;
    goto __pyx_L3;
  }
  __pyx_L3:;

  /* "axon/_dumper.py":475
 *             this_offset = ''
 * 
 *         self.write(this_offset)             # <<<<<<<<<<<<<<
 * 
 *         otype = type(o)
 */
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 475; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(((PyObject *)__pyx_v_this_offset));
  PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_this_offset));
  __Pyx_GIVEREF(((PyObject *)__pyx_v_this_offset));
  __pyx_t_3 = PyObject_Call(__pyx_v_self->write, ((PyObject *)__pyx_t_1), NULL); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 475; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(((PyObject *)__pyx_t_1)); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "axon/_dumper.py":477
 *         self.write(this_offset)
 * 
 *         otype = type(o)             # <<<<<<<<<<<<<<
 *         dumper = self.c_simple_dumpers.get(otype, None)
 *         if dumper is None:
 */
  __Pyx_INCREF(((PyObject *)Py_TYPE(__pyx_v_o)));
  __pyx_v_otype = ((PyObject*)((PyObject *)Py_TYPE(__pyx_v_o)));

  /* "axon/_dumper.py":478
 * 
 *         otype = type(o)
 *         dumper = self.c_simple_dumpers.get(otype, None)             # <<<<<<<<<<<<<<
 *         if dumper is None:
 *             if self.crossref:
 */
  if (unlikely(((PyObject *)__pyx_v_self->c_simple_dumpers) == Py_None)) {
    PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%s'", "get");
    {__pyx_filename = __pyx_f[0]; __pyx_lineno = 478; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }
  __pyx_t_3 = __Pyx_PyDict_GetItemDefault(((PyObject *)__pyx_v_self->c_simple_dumpers), ((PyObject *)__pyx_v_otype), Py_None); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 478; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_v_dumper = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "axon/_dumper.py":479
 *         otype = type(o)
 *         dumper = self.c_simple_dumpers.get(otype, None)
 *         if dumper is None:             # <<<<<<<<<<<<<<
 *             if self.crossref:
 *                 if self._dump_label(o) == 1:
 */
  __pyx_t_2 = (__pyx_v_dumper == Py_None);
  __pyx_t_4 = (__pyx_t_2 != 0);
  if (__pyx_t_4) {

    /* "axon/_dumper.py":480
 *         dumper = self.c_simple_dumpers.get(otype, None)
 *         if dumper is None:
 *             if self.crossref:             # <<<<<<<<<<<<<<
 *                 if self._dump_label(o) == 1:
 *                     return 0
 */
    __pyx_t_4 = (__pyx_v_self->crossref != 0);
    if (__pyx_t_4) {

      /* "axon/_dumper.py":481
 *         if dumper is None:
 *             if self.crossref:
 *                 if self._dump_label(o) == 1:             # <<<<<<<<<<<<<<
 *                     return 0
 * 
 */
      __pyx_t_4 = ((__pyx_f_4axon_7_dumper_6Dumper__dump_label(__pyx_v_self, __pyx_v_o) == 1) != 0);
      if (__pyx_t_4) {

        /* "axon/_dumper.py":482
 *             if self.crossref:
 *                 if self._dump_label(o) == 1:
 *                     return 0             # <<<<<<<<<<<<<<
 * 
 *             if otype is list:
 */
        __pyx_r = 0;
        goto __pyx_L0;
        goto __pyx_L6;
      }
      __pyx_L6:;
      goto __pyx_L5;
    }
    __pyx_L5:;

    /* "axon/_dumper.py":484
 *                     return 0
 * 
 *             if otype is list:             # <<<<<<<<<<<<<<
 *                 if len(o) <= self.nsize and all([is_simple_type(self, v) for v in o]):
 *                     self.dump_list(o)
 */
    __pyx_t_4 = (__pyx_v_otype == ((PyObject*)(&PyList_Type)));
    __pyx_t_2 = (__pyx_t_4 != 0);
    if (__pyx_t_2) {

      /* "axon/_dumper.py":485
 * 
 *             if otype is list:
 *                 if len(o) <= self.nsize and all([is_simple_type(self, v) for v in o]):             # <<<<<<<<<<<<<<
 *                     self.dump_list(o)
 *                 else:
 */
      __pyx_t_5 = PyObject_Length(__pyx_v_o); if (unlikely(__pyx_t_5 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 485; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __pyx_t_2 = (__pyx_t_5 <= __pyx_v_self->nsize);
      if (__pyx_t_2) {
        { /* enter inner scope */
          PyObject *__pyx_7genexpr__pyx_v_v = NULL;
          __pyx_t_3 = PyList_New(0); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 485; __pyx_clineno = __LINE__; goto __pyx_L11_error;}
          __Pyx_GOTREF(__pyx_t_3);
          if (PyList_CheckExact(__pyx_v_o) || PyTuple_CheckExact(__pyx_v_o)) {
            __pyx_t_1 = __pyx_v_o; __Pyx_INCREF(__pyx_t_1); __pyx_t_5 = 0;
            __pyx_t_6 = NULL;
          } else {
            __pyx_t_5 = -1; __pyx_t_1 = PyObject_GetIter(__pyx_v_o); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 485; __pyx_clineno = __LINE__; goto __pyx_L11_error;}
            __Pyx_GOTREF(__pyx_t_1);
            __pyx_t_6 = Py_TYPE(__pyx_t_1)->tp_iternext;
          }
          for (;;) {
            if (!__pyx_t_6 && PyList_CheckExact(__pyx_t_1)) {
              if (__pyx_t_5 >= PyList_GET_SIZE(__pyx_t_1)) break;
              #if CYTHON_COMPILING_IN_CPYTHON
              __pyx_t_7 = PyList_GET_ITEM(__pyx_t_1, __pyx_t_5); __Pyx_INCREF(__pyx_t_7); __pyx_t_5++; if (unlikely(0 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 485; __pyx_clineno = __LINE__; goto __pyx_L11_error;}
              #else
              __pyx_t_7 = PySequence_ITEM(__pyx_t_1, __pyx_t_5); __pyx_t_5++; if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 485; __pyx_clineno = __LINE__; goto __pyx_L11_error;}
              #endif
            } else if (!__pyx_t_6 && PyTuple_CheckExact(__pyx_t_1)) {
              if (__pyx_t_5 >= PyTuple_GET_SIZE(__pyx_t_1)) break;
              #if CYTHON_COMPILING_IN_CPYTHON
              __pyx_t_7 = PyTuple_GET_ITEM(__pyx_t_1, __pyx_t_5); __Pyx_INCREF(__pyx_t_7); __pyx_t_5++; if (unlikely(0 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 485; __pyx_clineno = __LINE__; goto __pyx_L11_error;}
              #else
              __pyx_t_7 = PySequence_ITEM(__pyx_t_1, __pyx_t_5); __pyx_t_5++; if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 485; __pyx_clineno = __LINE__; goto __pyx_L11_error;}
              #endif
            } else {
              __pyx_t_7 = __pyx_t_6(__pyx_t_1);
              if (unlikely(!__pyx_t_7)) {
                if (PyErr_Occurred()) {
                  if (likely(PyErr_ExceptionMatches(PyExc_StopIteration))) PyErr_Clear();
                  else {__pyx_filename = __pyx_f[0]; __pyx_lineno = 485; __pyx_clineno = __LINE__; goto __pyx_L11_error;}
                }
                break;
              }
              __Pyx_GOTREF(__pyx_t_7);
            }
            __Pyx_XDECREF(__pyx_7genexpr__pyx_v_v);
            __pyx_7genexpr__pyx_v_v = __pyx_t_7;
            __pyx_t_7 = 0;
            __pyx_t_7 = __Pyx_PyBool_FromLong(__pyx_f_4axon_7_dumper_is_simple_type(__pyx_v_self, __pyx_7genexpr__pyx_v_v)); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 485; __pyx_clineno = __LINE__; goto __pyx_L11_error;}
            __Pyx_GOTREF(__pyx_t_7);
            if (unlikely(__Pyx_ListComp_Append(__pyx_t_3, (PyObject*)__pyx_t_7))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 485; __pyx_clineno = __LINE__; goto __pyx_L11_error;}
            __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
          }
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
          __Pyx_XDECREF(__pyx_7genexpr__pyx_v_v);
          goto __pyx_L14_exit_scope;
          __pyx_L11_error:;
          __Pyx_XDECREF(__pyx_7genexpr__pyx_v_v);
          goto __pyx_L1_error;
          __pyx_L14_exit_scope:;
        } /* exit inner scope */
        __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 485; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_1);
        PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_t_3));
        __Pyx_GIVEREF(((PyObject *)__pyx_t_3));
        __pyx_t_3 = 0;
        __pyx_t_3 = PyObject_Call(__pyx_builtin_all, ((PyObject *)__pyx_t_1), NULL); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 485; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(((PyObject *)__pyx_t_1)); __pyx_t_1 = 0;
        __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely(__pyx_t_4 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 485; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __pyx_t_8 = __pyx_t_4;
      } else {
        __pyx_t_8 = __pyx_t_2;
      }
      if (__pyx_t_8) {

        /* "axon/_dumper.py":486
 *             if otype is list:
 *                 if len(o) <= self.nsize and all([is_simple_type(self, v) for v in o]):
 *                     self.dump_list(o)             # <<<<<<<<<<<<<<
 *                 else:
 *                     self.pretty_dump_list(o, new_offset, not use_offset)
 */
        if (!(likely(PyList_CheckExact(__pyx_v_o))||((__pyx_v_o) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected list, got %.200s", Py_TYPE(__pyx_v_o)->tp_name), 0))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 486; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __pyx_t_9 = __pyx_f_4axon_7_dumper_6Dumper_dump_list(__pyx_v_self, ((PyObject*)__pyx_v_o)); if (unlikely(__pyx_t_9 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 486; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        goto __pyx_L8;
      }
      /*else*/ {

        /* "axon/_dumper.py":488
 *                     self.dump_list(o)
 *                 else:
 *                     self.pretty_dump_list(o, new_offset, not use_offset)             # <<<<<<<<<<<<<<
 *             elif otype is dict:
 *                 if len(o) <= self.nsize and all([is_simple_type(self, v) for v in o]):
 */
        if (!(likely(PyList_CheckExact(__pyx_v_o))||((__pyx_v_o) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected list, got %.200s", Py_TYPE(__pyx_v_o)->tp_name), 0))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 488; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __pyx_t_9 = __pyx_f_4axon_7_dumper_6Dumper_pretty_dump_list(__pyx_v_self, ((PyObject*)__pyx_v_o), __pyx_v_new_offset, (!(__pyx_v_use_offset != 0))); if (unlikely(__pyx_t_9 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 488; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      }
      __pyx_L8:;
      goto __pyx_L7;
    }

    /* "axon/_dumper.py":489
 *                 else:
 *                     self.pretty_dump_list(o, new_offset, not use_offset)
 *             elif otype is dict:             # <<<<<<<<<<<<<<
 *                 if len(o) <= self.nsize and all([is_simple_type(self, v) for v in o]):
 *                     self.dump_dict(o)
 */
    __pyx_t_8 = (__pyx_v_otype == ((PyObject*)(&PyDict_Type)));
    __pyx_t_2 = (__pyx_t_8 != 0);
    if (__pyx_t_2) {

      /* "axon/_dumper.py":490
 *                     self.pretty_dump_list(o, new_offset, not use_offset)
 *             elif otype is dict:
 *                 if len(o) <= self.nsize and all([is_simple_type(self, v) for v in o]):             # <<<<<<<<<<<<<<
 *                     self.dump_dict(o)
 *                 else:
 */
      __pyx_t_5 = PyObject_Length(__pyx_v_o); if (unlikely(__pyx_t_5 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 490; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __pyx_t_2 = (__pyx_t_5 <= __pyx_v_self->nsize);
      if (__pyx_t_2) {
        { /* enter inner scope */
          PyObject *__pyx_8genexpr1__pyx_v_v = NULL;
          __pyx_t_3 = PyList_New(0); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 490; __pyx_clineno = __LINE__; goto __pyx_L18_error;}
          __Pyx_GOTREF(__pyx_t_3);
          if (PyList_CheckExact(__pyx_v_o) || PyTuple_CheckExact(__pyx_v_o)) {
            __pyx_t_1 = __pyx_v_o; __Pyx_INCREF(__pyx_t_1); __pyx_t_5 = 0;
            __pyx_t_6 = NULL;
          } else {
            __pyx_t_5 = -1; __pyx_t_1 = PyObject_GetIter(__pyx_v_o); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 490; __pyx_clineno = __LINE__; goto __pyx_L18_error;}
            __Pyx_GOTREF(__pyx_t_1);
            __pyx_t_6 = Py_TYPE(__pyx_t_1)->tp_iternext;
          }
          for (;;) {
            if (!__pyx_t_6 && PyList_CheckExact(__pyx_t_1)) {
              if (__pyx_t_5 >= PyList_GET_SIZE(__pyx_t_1)) break;
              #if CYTHON_COMPILING_IN_CPYTHON
              __pyx_t_7 = PyList_GET_ITEM(__pyx_t_1, __pyx_t_5); __Pyx_INCREF(__pyx_t_7); __pyx_t_5++; if (unlikely(0 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 490; __pyx_clineno = __LINE__; goto __pyx_L18_error;}
              #else
              __pyx_t_7 = PySequence_ITEM(__pyx_t_1, __pyx_t_5); __pyx_t_5++; if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 490; __pyx_clineno = __LINE__; goto __pyx_L18_error;}
              #endif
            } else if (!__pyx_t_6 && PyTuple_CheckExact(__pyx_t_1)) {
              if (__pyx_t_5 >= PyTuple_GET_SIZE(__pyx_t_1)) break;
              #if CYTHON_COMPILING_IN_CPYTHON
              __pyx_t_7 = PyTuple_GET_ITEM(__pyx_t_1, __pyx_t_5); __Pyx_INCREF(__pyx_t_7); __pyx_t_5++; if (unlikely(0 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 490; __pyx_clineno = __LINE__; goto __pyx_L18_error;}
              #else
              __pyx_t_7 = PySequence_ITEM(__pyx_t_1, __pyx_t_5); __pyx_t_5++; if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 490; __pyx_clineno = __LINE__; goto __pyx_L18_error;}
              #endif
            } else {
              __pyx_t_7 = __pyx_t_6(__pyx_t_1);
              if (unlikely(!__pyx_t_7)) {
                if (PyErr_Occurred()) {
                  if (likely(PyErr_ExceptionMatches(PyExc_StopIteration))) PyErr_Clear();
                  else {__pyx_filename = __pyx_f[0]; __pyx_lineno = 490; __pyx_clineno = __LINE__; goto __pyx_L18_error;}
                }
                break;
              }
              __Pyx_GOTREF(__pyx_t_7);
            }
            __Pyx_XDECREF(__pyx_8genexpr1__pyx_v_v);
            __pyx_8genexpr1__pyx_v_v = __pyx_t_7;
            __pyx_t_7 = 0;
            __pyx_t_7 = __Pyx_PyBool_FromLong(__pyx_f_4axon_7_dumper_is_simple_type(__pyx_v_self, __pyx_8genexpr1__pyx_v_v)); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 490; __pyx_clineno = __LINE__; goto __pyx_L18_error;}
            __Pyx_GOTREF(__pyx_t_7);
            if (unlikely(__Pyx_ListComp_Append(__pyx_t_3, (PyObject*)__pyx_t_7))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 490; __pyx_clineno = __LINE__; goto __pyx_L18_error;}
            __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
          }
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
          __Pyx_XDECREF(__pyx_8genexpr1__pyx_v_v);
          goto __pyx_L21_exit_scope;
          __pyx_L18_error:;
          __Pyx_XDECREF(__pyx_8genexpr1__pyx_v_v);
          goto __pyx_L1_error;
          __pyx_L21_exit_scope:;
        } /* exit inner scope */
        __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 490; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_1);
        PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_t_3));
        __Pyx_GIVEREF(((PyObject *)__pyx_t_3));
        __pyx_t_3 = 0;
        __pyx_t_3 = PyObject_Call(__pyx_builtin_all, ((PyObject *)__pyx_t_1), NULL); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 490; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(((PyObject *)__pyx_t_1)); __pyx_t_1 = 0;
        __pyx_t_8 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely(__pyx_t_8 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 490; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __pyx_t_4 = __pyx_t_8;
      } else {
        __pyx_t_4 = __pyx_t_2;
      }
      if (__pyx_t_4) {

        /* "axon/_dumper.py":491
 *             elif otype is dict:
 *                 if len(o) <= self.nsize and all([is_simple_type(self, v) for v in o]):
 *                     self.dump_dict(o)             # <<<<<<<<<<<<<<
 *                 else:
 *                     self.pretty_dump_dict(o, new_offset, not use_offset)
 */
        if (!(likely(PyDict_CheckExact(__pyx_v_o))||((__pyx_v_o) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected dict, got %.200s", Py_TYPE(__pyx_v_o)->tp_name), 0))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 491; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __pyx_t_9 = __pyx_f_4axon_7_dumper_6Dumper_dump_dict(__pyx_v_self, ((PyObject*)__pyx_v_o)); if (unlikely(__pyx_t_9 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 491; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        goto __pyx_L15;
      }
      /*else*/ {

        /* "axon/_dumper.py":493
 *                     self.dump_dict(o)
 *                 else:
 *                     self.pretty_dump_dict(o, new_offset, not use_offset)             # <<<<<<<<<<<<<<
 *             elif otype is tuple:
 *                 if len(o) <= self.nsize and all([is_simple_type(self, v) for v in o]):
 */
        if (!(likely(PyDict_CheckExact(__pyx_v_o))||((__pyx_v_o) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected dict, got %.200s", Py_TYPE(__pyx_v_o)->tp_name), 0))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 493; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __pyx_t_9 = __pyx_f_4axon_7_dumper_6Dumper_pretty_dump_dict(__pyx_v_self, ((PyObject*)__pyx_v_o), __pyx_v_new_offset, (!(__pyx_v_use_offset != 0))); if (unlikely(__pyx_t_9 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 493; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      }
      __pyx_L15:;
      goto __pyx_L7;
    }

    /* "axon/_dumper.py":494
 *                 else:
 *                     self.pretty_dump_dict(o, new_offset, not use_offset)
 *             elif otype is tuple:             # <<<<<<<<<<<<<<
 *                 if len(o) <= self.nsize and all([is_simple_type(self, v) for v in o]):
 *                     self.dump_tuple(o)
 */
    __pyx_t_4 = (__pyx_v_otype == ((PyObject*)(&PyTuple_Type)));
    __pyx_t_2 = (__pyx_t_4 != 0);
    if (__pyx_t_2) {

      /* "axon/_dumper.py":495
 *                     self.pretty_dump_dict(o, new_offset, not use_offset)
 *             elif otype is tuple:
 *                 if len(o) <= self.nsize and all([is_simple_type(self, v) for v in o]):             # <<<<<<<<<<<<<<
 *                     self.dump_tuple(o)
 *                 else:
 */
      __pyx_t_5 = PyObject_Length(__pyx_v_o); if (unlikely(__pyx_t_5 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 495; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __pyx_t_2 = (__pyx_t_5 <= __pyx_v_self->nsize);
      if (__pyx_t_2) {
        { /* enter inner scope */
          PyObject *__pyx_8genexpr2__pyx_v_v = NULL;
          __pyx_t_3 = PyList_New(0); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 495; __pyx_clineno = __LINE__; goto __pyx_L25_error;}
          __Pyx_GOTREF(__pyx_t_3);
          if (PyList_CheckExact(__pyx_v_o) || PyTuple_CheckExact(__pyx_v_o)) {
            __pyx_t_1 = __pyx_v_o; __Pyx_INCREF(__pyx_t_1); __pyx_t_5 = 0;
            __pyx_t_6 = NULL;
          } else {
            __pyx_t_5 = -1; __pyx_t_1 = PyObject_GetIter(__pyx_v_o); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 495; __pyx_clineno = __LINE__; goto __pyx_L25_error;}
            __Pyx_GOTREF(__pyx_t_1);
            __pyx_t_6 = Py_TYPE(__pyx_t_1)->tp_iternext;
          }
          for (;;) {
            if (!__pyx_t_6 && PyList_CheckExact(__pyx_t_1)) {
              if (__pyx_t_5 >= PyList_GET_SIZE(__pyx_t_1)) break;
              #if CYTHON_COMPILING_IN_CPYTHON
              __pyx_t_7 = PyList_GET_ITEM(__pyx_t_1, __pyx_t_5); __Pyx_INCREF(__pyx_t_7); __pyx_t_5++; if (unlikely(0 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 495; __pyx_clineno = __LINE__; goto __pyx_L25_error;}
              #else
              __pyx_t_7 = PySequence_ITEM(__pyx_t_1, __pyx_t_5); __pyx_t_5++; if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 495; __pyx_clineno = __LINE__; goto __pyx_L25_error;}
              #endif
            } else if (!__pyx_t_6 && PyTuple_CheckExact(__pyx_t_1)) {
              if (__pyx_t_5 >= PyTuple_GET_SIZE(__pyx_t_1)) break;
              #if CYTHON_COMPILING_IN_CPYTHON
              __pyx_t_7 = PyTuple_GET_ITEM(__pyx_t_1, __pyx_t_5); __Pyx_INCREF(__pyx_t_7); __pyx_t_5++; if (unlikely(0 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 495; __pyx_clineno = __LINE__; goto __pyx_L25_error;}
              #else
              __pyx_t_7 = PySequence_ITEM(__pyx_t_1, __pyx_t_5); __pyx_t_5++; if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 495; __pyx_clineno = __LINE__; goto __pyx_L25_error;}
              #endif
            } else {
              __pyx_t_7 = __pyx_t_6(__pyx_t_1);
              if (unlikely(!__pyx_t_7)) {
                if (PyErr_Occurred()) {
                  if (likely(PyErr_ExceptionMatches(PyExc_StopIteration))) PyErr_Clear();
                  else {__pyx_filename = __pyx_f[0]; __pyx_lineno = 495; __pyx_clineno = __LINE__; goto __pyx_L25_error;}
                }
                break;
              }
              __Pyx_GOTREF(__pyx_t_7);
            }
            __Pyx_XDECREF(__pyx_8genexpr2__pyx_v_v);
            __pyx_8genexpr2__pyx_v_v = __pyx_t_7;
            __pyx_t_7 = 0;
            __pyx_t_7 = __Pyx_PyBool_FromLong(__pyx_f_4axon_7_dumper_is_simple_type(__pyx_v_self, __pyx_8genexpr2__pyx_v_v)); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 495; __pyx_clineno = __LINE__; goto __pyx_L25_error;}
            __Pyx_GOTREF(__pyx_t_7);
            if (unlikely(__Pyx_ListComp_Append(__pyx_t_3, (PyObject*)__pyx_t_7))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 495; __pyx_clineno = __LINE__; goto __pyx_L25_error;}
            __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
          }
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
          __Pyx_XDECREF(__pyx_8genexpr2__pyx_v_v);
          goto __pyx_L28_exit_scope;
          __pyx_L25_error:;
          __Pyx_XDECREF(__pyx_8genexpr2__pyx_v_v);
          goto __pyx_L1_error;
          __pyx_L28_exit_scope:;
        } /* exit inner scope */
        __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 495; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_1);
        PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_t_3));
        __Pyx_GIVEREF(((PyObject *)__pyx_t_3));
        __pyx_t_3 = 0;
        __pyx_t_3 = PyObject_Call(__pyx_builtin_all, ((PyObject *)__pyx_t_1), NULL); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 495; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(((PyObject *)__pyx_t_1)); __pyx_t_1 = 0;
        __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely(__pyx_t_4 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 495; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __pyx_t_8 = __pyx_t_4;
      } else {
        __pyx_t_8 = __pyx_t_2;
      }
      if (__pyx_t_8) {

        /* "axon/_dumper.py":496
 *             elif otype is tuple:
 *                 if len(o) <= self.nsize and all([is_simple_type(self, v) for v in o]):
 *                     self.dump_tuple(o)             # <<<<<<<<<<<<<<
 *                 else:
 *                     self.pretty_dump_tuple(o, new_offset, not use_offset)
 */
        __pyx_t_3 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s__dump_tuple); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 496; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_3);
        __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 496; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_INCREF(__pyx_v_o);
        PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_o);
        __Pyx_GIVEREF(__pyx_v_o);
        __pyx_t_7 = PyObject_Call(__pyx_t_3, ((PyObject *)__pyx_t_1), NULL); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 496; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __Pyx_DECREF(((PyObject *)__pyx_t_1)); __pyx_t_1 = 0;
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        goto __pyx_L22;
      }
      /*else*/ {

        /* "axon/_dumper.py":498
 *                     self.dump_tuple(o)
 *                 else:
 *                     self.pretty_dump_tuple(o, new_offset, not use_offset)             # <<<<<<<<<<<<<<
 *             #elif otype is set:
 *             #    self.pretty_dump_set(o, new_offset, not use_offset)
 */
        __pyx_t_7 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s__pretty_dump_tuple); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 498; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_7);
        __pyx_t_1 = __Pyx_PyBool_FromLong((!(__pyx_v_use_offset != 0))); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 498; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_1);
        __pyx_t_3 = PyTuple_New(3); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 498; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_INCREF(__pyx_v_o);
        PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_v_o);
        __Pyx_GIVEREF(__pyx_v_o);
        __Pyx_INCREF(((PyObject *)__pyx_v_new_offset));
        PyTuple_SET_ITEM(__pyx_t_3, 1, ((PyObject *)__pyx_v_new_offset));
        __Pyx_GIVEREF(((PyObject *)__pyx_v_new_offset));
        PyTuple_SET_ITEM(__pyx_t_3, 2, __pyx_t_1);
        __Pyx_GIVEREF(__pyx_t_1);
        __pyx_t_1 = 0;
        __pyx_t_1 = PyObject_Call(__pyx_t_7, ((PyObject *)__pyx_t_3), NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 498; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        __Pyx_DECREF(((PyObject *)__pyx_t_3)); __pyx_t_3 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      }
      __pyx_L22:;
      goto __pyx_L7;
    }
    /*else*/ {

      /* "axon/_dumper.py":502
 *             #    self.pretty_dump_set(o, new_offset, not use_offset)
 *             else:
 *                 reducer = self.c_type_reducers.get(otype, None)             # <<<<<<<<<<<<<<
 *                 if reducer is None:
 *                     raise TypeError('There is no reducer for this type: ' + repr(otype))
 */
      if (unlikely(((PyObject *)__pyx_v_self->c_type_reducers) == Py_None)) {
        PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%s'", "get");
        {__pyx_filename = __pyx_f[0]; __pyx_lineno = 502; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      }
      __pyx_t_1 = __Pyx_PyDict_GetItemDefault(((PyObject *)__pyx_v_self->c_type_reducers), ((PyObject *)__pyx_v_otype), Py_None); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 502; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_v_reducer = __pyx_t_1;
      __pyx_t_1 = 0;

      /* "axon/_dumper.py":503
 *             else:
 *                 reducer = self.c_type_reducers.get(otype, None)
 *                 if reducer is None:             # <<<<<<<<<<<<<<
 *                     raise TypeError('There is no reducer for this type: ' + repr(otype))
 *                 else:
 */
      __pyx_t_8 = (__pyx_v_reducer == Py_None);
      __pyx_t_2 = (__pyx_t_8 != 0);
      if (__pyx_t_2) {

        /* "axon/_dumper.py":504
 *                 reducer = self.c_type_reducers.get(otype, None)
 *                 if reducer is None:
 *                     raise TypeError('There is no reducer for this type: ' + repr(otype))             # <<<<<<<<<<<<<<
 *                 else:
 *                     self._pretty_dump_with_reducer(reducer, o, offset)
 */
        __pyx_t_1 = PyObject_Repr(((PyObject *)__pyx_v_otype)); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 504; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_1);
        __pyx_t_3 = PyNumber_Add(((PyObject *)__pyx_kp_u_42), __pyx_t_1); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 504; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 504; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_1);
        PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_t_3);
        __Pyx_GIVEREF(__pyx_t_3);
        __pyx_t_3 = 0;
        __pyx_t_3 = PyObject_Call(__pyx_builtin_TypeError, ((PyObject *)__pyx_t_1), NULL); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 504; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(((PyObject *)__pyx_t_1)); __pyx_t_1 = 0;
        __Pyx_Raise(__pyx_t_3, 0, 0, 0);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        {__pyx_filename = __pyx_f[0]; __pyx_lineno = 504; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        goto __pyx_L29;
      }
      /*else*/ {

        /* "axon/_dumper.py":506
 *                     raise TypeError('There is no reducer for this type: ' + repr(otype))
 *                 else:
 *                     self._pretty_dump_with_reducer(reducer, o, offset)             # <<<<<<<<<<<<<<
 *         else:
 *             self._dump_value(o, dumper)
 */
        __pyx_t_9 = __pyx_f_4axon_7_dumper_6Dumper__pretty_dump_with_reducer(__pyx_v_self, __pyx_v_reducer, __pyx_v_o, __pyx_v_offset); if (unlikely(__pyx_t_9 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 506; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      }
      __pyx_L29:;
    }
    __pyx_L7:;
    goto __pyx_L4;
  }
  /*else*/ {

    /* "axon/_dumper.py":508
 *                     self._pretty_dump_with_reducer(reducer, o, offset)
 *         else:
 *             self._dump_value(o, dumper)             # <<<<<<<<<<<<<<
 *     #
 *     def _dump_value(self, o, dumper):
 */
    __pyx_f_4axon_7_dumper_6Dumper__dump_value(__pyx_v_self, __pyx_v_o, __pyx_v_dumper);
  }
  __pyx_L4:;

  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("axon._dumper.Dumper._pretty_dump", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_this_offset);
  __Pyx_XDECREF(__pyx_v_new_offset);
  __Pyx_XDECREF(__pyx_v_otype);
  __Pyx_XDECREF(__pyx_v_dumper);
  __Pyx_XDECREF(__pyx_v_reducer);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_dumper.py":510
 *             self._dump_value(o, dumper)
 *     #
 *     def _dump_value(self, o, dumper):             # <<<<<<<<<<<<<<
 *             if type(dumper) is PyPointer:
 *                 ptr = dumper
 */

static void __pyx_f_4axon_7_dumper_6Dumper__dump_value(struct Dumper *__pyx_v_self, PyObject *__pyx_v_o, PyObject *__pyx_v_dumper) {
  PyObject *__pyx_v_text = 0;
  struct __pyx_obj_4axon_7_dumper_PyPointer *__pyx_v_ptr = 0;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  Py_ssize_t __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_dump_value", 0);

  /* "axon/_dumper.py":511
 *     #
 *     def _dump_value(self, o, dumper):
 *             if type(dumper) is PyPointer:             # <<<<<<<<<<<<<<
 *                 ptr = dumper
 *                 text = ptr.ptr(o)
 */
  __pyx_t_1 = (((PyObject *)Py_TYPE(__pyx_v_dumper)) == ((PyObject *)((PyObject*)__pyx_ptype_4axon_7_dumper_PyPointer)));
  __pyx_t_2 = (__pyx_t_1 != 0);
  if (__pyx_t_2) {

    /* "axon/_dumper.py":512
 *     def _dump_value(self, o, dumper):
 *             if type(dumper) is PyPointer:
 *                 ptr = dumper             # <<<<<<<<<<<<<<
 *                 text = ptr.ptr(o)
 *             else:
 */
    if (!(likely(((__pyx_v_dumper) == Py_None) || likely(__Pyx_TypeTest(__pyx_v_dumper, __pyx_ptype_4axon_7_dumper_PyPointer))))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 512; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_INCREF(__pyx_v_dumper);
    __pyx_v_ptr = ((struct __pyx_obj_4axon_7_dumper_PyPointer *)__pyx_v_dumper);

    /* "axon/_dumper.py":513
 *             if type(dumper) is PyPointer:
 *                 ptr = dumper
 *                 text = ptr.ptr(o)             # <<<<<<<<<<<<<<
 *             else:
 *                 text = dumper(o)
 */
    __pyx_t_3 = ((PyObject *)__pyx_v_ptr->ptr(__pyx_v_o)); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 513; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_v_text = ((PyObject*)__pyx_t_3);
    __pyx_t_3 = 0;
    goto __pyx_L3;
  }
  /*else*/ {

    /* "axon/_dumper.py":515
 *                 text = ptr.ptr(o)
 *             else:
 *                 text = dumper(o)             # <<<<<<<<<<<<<<
 *             self.size += len(text)
 *             self.write(text)
 */
    __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 515; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_INCREF(__pyx_v_o);
    PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_v_o);
    __Pyx_GIVEREF(__pyx_v_o);
    __pyx_t_4 = PyObject_Call(__pyx_v_dumper, ((PyObject *)__pyx_t_3), NULL); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 515; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(((PyObject *)__pyx_t_3)); __pyx_t_3 = 0;
    if (!(likely(PyUnicode_CheckExact(__pyx_t_4))||((__pyx_t_4) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected unicode, got %.200s", Py_TYPE(__pyx_t_4)->tp_name), 0))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 515; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __pyx_v_text = ((PyObject*)__pyx_t_4);
    __pyx_t_4 = 0;
  }
  __pyx_L3:;

  /* "axon/_dumper.py":516
 *             else:
 *                 text = dumper(o)
 *             self.size += len(text)             # <<<<<<<<<<<<<<
 *             self.write(text)
 *     #
 */
  if (unlikely(((PyObject *)__pyx_v_text) == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "object of type 'NoneType' has no len()");
    {__pyx_filename = __pyx_f[0]; __pyx_lineno = 516; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }
  __pyx_t_5 = __Pyx_PyUnicode_GET_LENGTH(((PyObject *)__pyx_v_text)); if (unlikely(__pyx_t_5 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 516; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_v_self->size = (__pyx_v_self->size + __pyx_t_5);

  /* "axon/_dumper.py":517
 *                 text = dumper(o)
 *             self.size += len(text)
 *             self.write(text)             # <<<<<<<<<<<<<<
 *     #
 *     def _dump_dict_sequence(self, d):
 */
  __pyx_t_4 = PyTuple_New(1); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 517; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_INCREF(((PyObject *)__pyx_v_text));
  PyTuple_SET_ITEM(__pyx_t_4, 0, ((PyObject *)__pyx_v_text));
  __Pyx_GIVEREF(((PyObject *)__pyx_v_text));
  __pyx_t_3 = PyObject_Call(__pyx_v_self->write, ((PyObject *)__pyx_t_4), NULL); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 517; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(((PyObject *)__pyx_t_4)); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_WriteUnraisable("axon._dumper.Dumper._dump_value", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_text);
  __Pyx_XDECREF((PyObject *)__pyx_v_ptr);
  __Pyx_RefNannyFinishContext();
}

/* "axon/_dumper.py":519
 *             self.write(text)
 *     #
 *     def _dump_dict_sequence(self, d):             # <<<<<<<<<<<<<<
 *         i = 0
 * 
 */

static int __pyx_f_4axon_7_dumper_6Dumper__dump_dict_sequence(struct Dumper *__pyx_v_self, PyObject *__pyx_v_d) {
  int __pyx_v_i;
  PyObject *__pyx_v_text = 0;
  PyObject *__pyx_v_items = NULL;
  PyObject *__pyx_v_k = NULL;
  PyObject *__pyx_v_v = NULL;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  Py_ssize_t __pyx_t_4;
  PyObject *(*__pyx_t_5)(PyObject *);
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *(*__pyx_t_9)(PyObject *);
  Py_ssize_t __pyx_t_10;
  int __pyx_t_11;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_dump_dict_sequence", 0);

  /* "axon/_dumper.py":520
 *     #
 *     def _dump_dict_sequence(self, d):
 *         i = 0             # <<<<<<<<<<<<<<
 * 
 *         if self.sorted:
 */
  __pyx_v_i = 0;

  /* "axon/_dumper.py":522
 *         i = 0
 * 
 *         if self.sorted:             # <<<<<<<<<<<<<<
 *             items = sorted(d.items())
 *         else:
 */
  __pyx_t_1 = (__pyx_v_self->sorted != 0);
  if (__pyx_t_1) {

    /* "axon/_dumper.py":523
 * 
 *         if self.sorted:
 *             items = sorted(d.items())             # <<<<<<<<<<<<<<
 *         else:
 *             items = d.items()
 */
    if (unlikely(((PyObject *)__pyx_v_d) == Py_None)) {
      PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%s'", "items");
      {__pyx_filename = __pyx_f[0]; __pyx_lineno = 523; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    }
    __pyx_t_2 = __Pyx_PyDict_Items(__pyx_v_d); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 523; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 523; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_2);
    __Pyx_GIVEREF(__pyx_t_2);
    __pyx_t_2 = 0;
    __pyx_t_2 = PyObject_Call(__pyx_builtin_sorted, ((PyObject *)__pyx_t_3), NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 523; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(((PyObject *)__pyx_t_3)); __pyx_t_3 = 0;
    __pyx_v_items = __pyx_t_2;
    __pyx_t_2 = 0;
    goto __pyx_L3;
  }
  /*else*/ {

    /* "axon/_dumper.py":525
 *             items = sorted(d.items())
 *         else:
 *             items = d.items()             # <<<<<<<<<<<<<<
 * 
 *         for k,v in items:
 */
    if (unlikely(((PyObject *)__pyx_v_d) == Py_None)) {
      PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%s'", "items");
      {__pyx_filename = __pyx_f[0]; __pyx_lineno = 525; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    }
    __pyx_t_2 = __Pyx_PyDict_Items(__pyx_v_d); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 525; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_v_items = __pyx_t_2;
    __pyx_t_2 = 0;
  }
  __pyx_L3:;

  /* "axon/_dumper.py":527
 *             items = d.items()
 * 
 *         for k,v in items:             # <<<<<<<<<<<<<<
 *             if i > 0:
 *                 self.write(' ')
 */
  if (PyList_CheckExact(__pyx_v_items) || PyTuple_CheckExact(__pyx_v_items)) {
    __pyx_t_2 = __pyx_v_items; __Pyx_INCREF(__pyx_t_2); __pyx_t_4 = 0;
    __pyx_t_5 = NULL;
  } else {
    __pyx_t_4 = -1; __pyx_t_2 = PyObject_GetIter(__pyx_v_items); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 527; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_5 = Py_TYPE(__pyx_t_2)->tp_iternext;
  }
  for (;;) {
    if (!__pyx_t_5 && PyList_CheckExact(__pyx_t_2)) {
      if (__pyx_t_4 >= PyList_GET_SIZE(__pyx_t_2)) break;
      #if CYTHON_COMPILING_IN_CPYTHON
      __pyx_t_3 = PyList_GET_ITEM(__pyx_t_2, __pyx_t_4); __Pyx_INCREF(__pyx_t_3); __pyx_t_4++; if (unlikely(0 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 527; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      #else
      __pyx_t_3 = PySequence_ITEM(__pyx_t_2, __pyx_t_4); __pyx_t_4++; if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 527; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      #endif
    } else if (!__pyx_t_5 && PyTuple_CheckExact(__pyx_t_2)) {
      if (__pyx_t_4 >= PyTuple_GET_SIZE(__pyx_t_2)) break;
      #if CYTHON_COMPILING_IN_CPYTHON
      __pyx_t_3 = PyTuple_GET_ITEM(__pyx_t_2, __pyx_t_4); __Pyx_INCREF(__pyx_t_3); __pyx_t_4++; if (unlikely(0 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 527; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      #else
      __pyx_t_3 = PySequence_ITEM(__pyx_t_2, __pyx_t_4); __pyx_t_4++; if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 527; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      #endif
    } else {
      __pyx_t_3 = __pyx_t_5(__pyx_t_2);
      if (unlikely(!__pyx_t_3)) {
        if (PyErr_Occurred()) {
          if (likely(PyErr_ExceptionMatches(PyExc_StopIteration))) PyErr_Clear();
          else {__pyx_filename = __pyx_f[0]; __pyx_lineno = 527; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_3);
    }
    if ((likely(PyTuple_CheckExact(__pyx_t_3))) || (PyList_CheckExact(__pyx_t_3))) {
      PyObject* sequence = __pyx_t_3;
      #if CYTHON_COMPILING_IN_CPYTHON
      Py_ssize_t size = Py_SIZE(sequence);
      #else
      Py_ssize_t size = PySequence_Size(sequence);
      #endif
      if (unlikely(size != 2)) {
        if (size > 2) __Pyx_RaiseTooManyValuesError(2);
        else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
        {__pyx_filename = __pyx_f[0]; __pyx_lineno = 527; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      }
      #if CYTHON_COMPILING_IN_CPYTHON
      if (likely(PyTuple_CheckExact(sequence))) {
        __pyx_t_6 = PyTuple_GET_ITEM(sequence, 0); 
        __pyx_t_7 = PyTuple_GET_ITEM(sequence, 1); 
      } else {
        __pyx_t_6 = PyList_GET_ITEM(sequence, 0); 
        __pyx_t_7 = PyList_GET_ITEM(sequence, 1); 
      }
      __Pyx_INCREF(__pyx_t_6);
      __Pyx_INCREF(__pyx_t_7);
      #else
      __pyx_t_6 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 527; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_7 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 527; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_7);
      #endif
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    } else
    {
      Py_ssize_t index = -1;
      __pyx_t_8 = PyObject_GetIter(__pyx_t_3); if (unlikely(!__pyx_t_8)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 527; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_9 = Py_TYPE(__pyx_t_8)->tp_iternext;
      index = 0; __pyx_t_6 = __pyx_t_9(__pyx_t_8); if (unlikely(!__pyx_t_6)) goto __pyx_L6_unpacking_failed;
      __Pyx_GOTREF(__pyx_t_6);
      index = 1; __pyx_t_7 = __pyx_t_9(__pyx_t_8); if (unlikely(!__pyx_t_7)) goto __pyx_L6_unpacking_failed;
      __Pyx_GOTREF(__pyx_t_7);
      if (__Pyx_IternextUnpackEndCheck(__pyx_t_9(__pyx_t_8), 2) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 527; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __pyx_t_9 = NULL;
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      goto __pyx_L7_unpacking_done;
      __pyx_L6_unpacking_failed:;
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_t_9 = NULL;
      if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
      {__pyx_filename = __pyx_f[0]; __pyx_lineno = 527; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __pyx_L7_unpacking_done:;
    }
    __Pyx_XDECREF(__pyx_v_k);
    __pyx_v_k = __pyx_t_6;
    __pyx_t_6 = 0;
    __Pyx_XDECREF(__pyx_v_v);
    __pyx_v_v = __pyx_t_7;
    __pyx_t_7 = 0;

    /* "axon/_dumper.py":528
 * 
 *         for k,v in items:
 *             if i > 0:             # <<<<<<<<<<<<<<
 *                 self.write(' ')
 * 
 */
    __pyx_t_1 = ((__pyx_v_i > 0) != 0);
    if (__pyx_t_1) {

      /* "axon/_dumper.py":529
 *         for k,v in items:
 *             if i > 0:
 *                 self.write(' ')             # <<<<<<<<<<<<<<
 * 
 *             text = c_as_unicode(k)
 */
      __pyx_t_3 = PyObject_Call(__pyx_v_self->write, ((PyObject *)__pyx_k_tuple_45), NULL); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 529; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      goto __pyx_L8;
    }
    __pyx_L8:;

    /* "axon/_dumper.py":531
 *                 self.write(' ')
 * 
 *             text = c_as_unicode(k)             # <<<<<<<<<<<<<<
 *             self.write(_dump_name(text, self.quote))
 *             self.size += len(text)
 */
    __pyx_t_3 = ((PyObject *)__pyx_f_4axon_8_objects_c_as_unicode(__pyx_v_k)); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 531; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_XDECREF(((PyObject *)__pyx_v_text));
    __pyx_v_text = ((PyObject*)__pyx_t_3);
    __pyx_t_3 = 0;

    /* "axon/_dumper.py":532
 * 
 *             text = c_as_unicode(k)
 *             self.write(_dump_name(text, self.quote))             # <<<<<<<<<<<<<<
 *             self.size += len(text)
 * 
 */
    __pyx_t_3 = ((PyObject *)__pyx_f_4axon_7_dumper__dump_name(((PyObject *)__pyx_v_text), __pyx_v_self->quote)); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 532; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_7 = PyTuple_New(1); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 532; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_7);
    PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_3);
    __Pyx_GIVEREF(__pyx_t_3);
    __pyx_t_3 = 0;
    __pyx_t_3 = PyObject_Call(__pyx_v_self->write, ((PyObject *)__pyx_t_7), NULL); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 532; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(((PyObject *)__pyx_t_7)); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "axon/_dumper.py":533
 *             text = c_as_unicode(k)
 *             self.write(_dump_name(text, self.quote))
 *             self.size += len(text)             # <<<<<<<<<<<<<<
 * 
 *             self.write(':')
 */
    if (unlikely(((PyObject *)__pyx_v_text) == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "object of type 'NoneType' has no len()");
      {__pyx_filename = __pyx_f[0]; __pyx_lineno = 533; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    }
    __pyx_t_10 = __Pyx_PyUnicode_GET_LENGTH(((PyObject *)__pyx_v_text)); if (unlikely(__pyx_t_10 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 533; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __pyx_v_self->size = (__pyx_v_self->size + __pyx_t_10);

    /* "axon/_dumper.py":535
 *             self.size += len(text)
 * 
 *             self.write(':')             # <<<<<<<<<<<<<<
 *             self._dump(v)
 *             i += 1
 */
    __pyx_t_3 = PyObject_Call(__pyx_v_self->write, ((PyObject *)__pyx_k_tuple_47), NULL); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 535; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "axon/_dumper.py":536
 * 
 *             self.write(':')
 *             self._dump(v)             # <<<<<<<<<<<<<<
 *             i += 1
 *     #
 */
    __pyx_t_11 = __pyx_f_4axon_7_dumper_6Dumper__dump(__pyx_v_self, __pyx_v_v); if (unlikely(__pyx_t_11 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 536; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

    /* "axon/_dumper.py":537
 *             self.write(':')
 *             self._dump(v)
 *             i += 1             # <<<<<<<<<<<<<<
 *     #
 *     def _dump_attr_sequence(self, d):
 */
    __pyx_v_i = (__pyx_v_i + 1);
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("axon._dumper.Dumper._dump_dict_sequence", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_text);
  __Pyx_XDECREF(__pyx_v_items);
  __Pyx_XDECREF(__pyx_v_k);
  __Pyx_XDECREF(__pyx_v_v);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_dumper.py":539
 *             i += 1
 *     #
 *     def _dump_attr_sequence(self, d):             # <<<<<<<<<<<<<<
 *         i = 0
 * 
 */

static int __pyx_f_4axon_7_dumper_6Dumper__dump_attr_sequence(struct Dumper *__pyx_v_self, PyObject *__pyx_v_d) {
  int __pyx_v_i;
  PyObject *__pyx_v_text = 0;
  PyObject *__pyx_v_items = NULL;
  PyObject *__pyx_v_k = NULL;
  PyObject *__pyx_v_v = NULL;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  Py_ssize_t __pyx_t_4;
  PyObject *(*__pyx_t_5)(PyObject *);
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *(*__pyx_t_9)(PyObject *);
  Py_ssize_t __pyx_t_10;
  int __pyx_t_11;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_dump_attr_sequence", 0);

  /* "axon/_dumper.py":540
 *     #
 *     def _dump_attr_sequence(self, d):
 *         i = 0             # <<<<<<<<<<<<<<
 * 
 *         if self.sorted:
 */
  __pyx_v_i = 0;

  /* "axon/_dumper.py":542
 *         i = 0
 * 
 *         if self.sorted:             # <<<<<<<<<<<<<<
 *             items = sorted(d.items())
 *         else:
 */
  __pyx_t_1 = (__pyx_v_self->sorted != 0);
  if (__pyx_t_1) {

    /* "axon/_dumper.py":543
 * 
 *         if self.sorted:
 *             items = sorted(d.items())             # <<<<<<<<<<<<<<
 *         else:
 *             items = d.items()
 */
    if (unlikely(((PyObject *)__pyx_v_d) == Py_None)) {
      PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%s'", "items");
      {__pyx_filename = __pyx_f[0]; __pyx_lineno = 543; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    }
    __pyx_t_2 = __Pyx_PyDict_Items(__pyx_v_d); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 543; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 543; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_2);
    __Pyx_GIVEREF(__pyx_t_2);
    __pyx_t_2 = 0;
    __pyx_t_2 = PyObject_Call(__pyx_builtin_sorted, ((PyObject *)__pyx_t_3), NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 543; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(((PyObject *)__pyx_t_3)); __pyx_t_3 = 0;
    __pyx_v_items = __pyx_t_2;
    __pyx_t_2 = 0;
    goto __pyx_L3;
  }
  /*else*/ {

    /* "axon/_dumper.py":545
 *             items = sorted(d.items())
 *         else:
 *             items = d.items()             # <<<<<<<<<<<<<<
 * 
 *         for k,v in items:
 */
    if (unlikely(((PyObject *)__pyx_v_d) == Py_None)) {
      PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%s'", "items");
      {__pyx_filename = __pyx_f[0]; __pyx_lineno = 545; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    }
    __pyx_t_2 = __Pyx_PyDict_Items(__pyx_v_d); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 545; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_v_items = __pyx_t_2;
    __pyx_t_2 = 0;
  }
  __pyx_L3:;

  /* "axon/_dumper.py":547
 *             items = d.items()
 * 
 *         for k,v in items:             # <<<<<<<<<<<<<<
 *             if i > 0:
 *                 self.write(' ')
 */
  if (PyList_CheckExact(__pyx_v_items) || PyTuple_CheckExact(__pyx_v_items)) {
    __pyx_t_2 = __pyx_v_items; __Pyx_INCREF(__pyx_t_2); __pyx_t_4 = 0;
    __pyx_t_5 = NULL;
  } else {
    __pyx_t_4 = -1; __pyx_t_2 = PyObject_GetIter(__pyx_v_items); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 547; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_5 = Py_TYPE(__pyx_t_2)->tp_iternext;
  }
  for (;;) {
    if (!__pyx_t_5 && PyList_CheckExact(__pyx_t_2)) {
      if (__pyx_t_4 >= PyList_GET_SIZE(__pyx_t_2)) break;
      #if CYTHON_COMPILING_IN_CPYTHON
      __pyx_t_3 = PyList_GET_ITEM(__pyx_t_2, __pyx_t_4); __Pyx_INCREF(__pyx_t_3); __pyx_t_4++; if (unlikely(0 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 547; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      #else
      __pyx_t_3 = PySequence_ITEM(__pyx_t_2, __pyx_t_4); __pyx_t_4++; if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 547; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      #endif
    } else if (!__pyx_t_5 && PyTuple_CheckExact(__pyx_t_2)) {
      if (__pyx_t_4 >= PyTuple_GET_SIZE(__pyx_t_2)) break;
      #if CYTHON_COMPILING_IN_CPYTHON
      __pyx_t_3 = PyTuple_GET_ITEM(__pyx_t_2, __pyx_t_4); __Pyx_INCREF(__pyx_t_3); __pyx_t_4++; if (unlikely(0 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 547; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      #else
      __pyx_t_3 = PySequence_ITEM(__pyx_t_2, __pyx_t_4); __pyx_t_4++; if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 547; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      #endif
    } else {
      __pyx_t_3 = __pyx_t_5(__pyx_t_2);
      if (unlikely(!__pyx_t_3)) {
        if (PyErr_Occurred()) {
          if (likely(PyErr_ExceptionMatches(PyExc_StopIteration))) PyErr_Clear();
          else {__pyx_filename = __pyx_f[0]; __pyx_lineno = 547; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_3);
    }
    if ((likely(PyTuple_CheckExact(__pyx_t_3))) || (PyList_CheckExact(__pyx_t_3))) {
      PyObject* sequence = __pyx_t_3;
      #if CYTHON_COMPILING_IN_CPYTHON
      Py_ssize_t size = Py_SIZE(sequence);
      #else
      Py_ssize_t size = PySequence_Size(sequence);
      #endif
      if (unlikely(size != 2)) {
        if (size > 2) __Pyx_RaiseTooManyValuesError(2);
        else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
        {__pyx_filename = __pyx_f[0]; __pyx_lineno = 547; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      }
      #if CYTHON_COMPILING_IN_CPYTHON
      if (likely(PyTuple_CheckExact(sequence))) {
        __pyx_t_6 = PyTuple_GET_ITEM(sequence, 0); 
        __pyx_t_7 = PyTuple_GET_ITEM(sequence, 1); 
      } else {
        __pyx_t_6 = PyList_GET_ITEM(sequence, 0); 
        __pyx_t_7 = PyList_GET_ITEM(sequence, 1); 
      }
      __Pyx_INCREF(__pyx_t_6);
      __Pyx_INCREF(__pyx_t_7);
      #else
      __pyx_t_6 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 547; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_7 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 547; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_7);
      #endif
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    } else
    {
      Py_ssize_t index = -1;
      __pyx_t_8 = PyObject_GetIter(__pyx_t_3); if (unlikely(!__pyx_t_8)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 547; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_9 = Py_TYPE(__pyx_t_8)->tp_iternext;
      index = 0; __pyx_t_6 = __pyx_t_9(__pyx_t_8); if (unlikely(!__pyx_t_6)) goto __pyx_L6_unpacking_failed;
      __Pyx_GOTREF(__pyx_t_6);
      index = 1; __pyx_t_7 = __pyx_t_9(__pyx_t_8); if (unlikely(!__pyx_t_7)) goto __pyx_L6_unpacking_failed;
      __Pyx_GOTREF(__pyx_t_7);
      if (__Pyx_IternextUnpackEndCheck(__pyx_t_9(__pyx_t_8), 2) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 547; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __pyx_t_9 = NULL;
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      goto __pyx_L7_unpacking_done;
      __pyx_L6_unpacking_failed:;
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_t_9 = NULL;
      if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
      {__pyx_filename = __pyx_f[0]; __pyx_lineno = 547; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __pyx_L7_unpacking_done:;
    }
    __Pyx_XDECREF(__pyx_v_k);
    __pyx_v_k = __pyx_t_6;
    __pyx_t_6 = 0;
    __Pyx_XDECREF(__pyx_v_v);
    __pyx_v_v = __pyx_t_7;
    __pyx_t_7 = 0;

    /* "axon/_dumper.py":548
 * 
 *         for k,v in items:
 *             if i > 0:             # <<<<<<<<<<<<<<
 *                 self.write(' ')
 * 
 */
    __pyx_t_1 = ((__pyx_v_i > 0) != 0);
    if (__pyx_t_1) {

      /* "axon/_dumper.py":549
 *         for k,v in items:
 *             if i > 0:
 *                 self.write(' ')             # <<<<<<<<<<<<<<
 * 
 *             text = c_as_unicode(k)
 */
      __pyx_t_3 = PyObject_Call(__pyx_v_self->write, ((PyObject *)__pyx_k_tuple_48), NULL); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 549; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      goto __pyx_L8;
    }
    __pyx_L8:;

    /* "axon/_dumper.py":551
 *                 self.write(' ')
 * 
 *             text = c_as_unicode(k)             # <<<<<<<<<<<<<<
 *             self.write(_dump_name(text, self.quote))
 *             self.size += len(text)
 */
    __pyx_t_3 = ((PyObject *)__pyx_f_4axon_8_objects_c_as_unicode(__pyx_v_k)); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 551; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_XDECREF(((PyObject *)__pyx_v_text));
    __pyx_v_text = ((PyObject*)__pyx_t_3);
    __pyx_t_3 = 0;

    /* "axon/_dumper.py":552
 * 
 *             text = c_as_unicode(k)
 *             self.write(_dump_name(text, self.quote))             # <<<<<<<<<<<<<<
 *             self.size += len(text)
 * 
 */
    __pyx_t_3 = ((PyObject *)__pyx_f_4axon_7_dumper__dump_name(((PyObject *)__pyx_v_text), __pyx_v_self->quote)); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 552; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_7 = PyTuple_New(1); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 552; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_7);
    PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_3);
    __Pyx_GIVEREF(__pyx_t_3);
    __pyx_t_3 = 0;
    __pyx_t_3 = PyObject_Call(__pyx_v_self->write, ((PyObject *)__pyx_t_7), NULL); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 552; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(((PyObject *)__pyx_t_7)); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "axon/_dumper.py":553
 *             text = c_as_unicode(k)
 *             self.write(_dump_name(text, self.quote))
 *             self.size += len(text)             # <<<<<<<<<<<<<<
 * 
 *             self.write(':')
 */
    if (unlikely(((PyObject *)__pyx_v_text) == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "object of type 'NoneType' has no len()");
      {__pyx_filename = __pyx_f[0]; __pyx_lineno = 553; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    }
    __pyx_t_10 = __Pyx_PyUnicode_GET_LENGTH(((PyObject *)__pyx_v_text)); if (unlikely(__pyx_t_10 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 553; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __pyx_v_self->size = (__pyx_v_self->size + __pyx_t_10);

    /* "axon/_dumper.py":555
 *             self.size += len(text)
 * 
 *             self.write(':')             # <<<<<<<<<<<<<<
 *             self._dump(v)
 *             i += 1
 */
    __pyx_t_3 = PyObject_Call(__pyx_v_self->write, ((PyObject *)__pyx_k_tuple_49), NULL); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 555; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "axon/_dumper.py":556
 * 
 *             self.write(':')
 *             self._dump(v)             # <<<<<<<<<<<<<<
 *             i += 1
 *     #
 */
    __pyx_t_11 = __pyx_f_4axon_7_dumper_6Dumper__dump(__pyx_v_self, __pyx_v_v); if (unlikely(__pyx_t_11 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 556; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

    /* "axon/_dumper.py":557
 *             self.write(':')
 *             self._dump(v)
 *             i += 1             # <<<<<<<<<<<<<<
 *     #
 *     def _dump_list_sequence(self, l):
 */
    __pyx_v_i = (__pyx_v_i + 1);
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("axon._dumper.Dumper._dump_attr_sequence", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_text);
  __Pyx_XDECREF(__pyx_v_items);
  __Pyx_XDECREF(__pyx_v_k);
  __Pyx_XDECREF(__pyx_v_v);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_dumper.py":559
 *             i += 1
 *     #
 *     def _dump_list_sequence(self, l):             # <<<<<<<<<<<<<<
 *         i = 0
 * 
 */

static int __pyx_f_4axon_7_dumper_6Dumper__dump_list_sequence(struct Dumper *__pyx_v_self, PyObject *__pyx_v_l) {
  int __pyx_v_i;
  PyObject *__pyx_v_v = NULL;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  Py_ssize_t __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_dump_list_sequence", 0);

  /* "axon/_dumper.py":560
 *     #
 *     def _dump_list_sequence(self, l):
 *         i = 0             # <<<<<<<<<<<<<<
 * 
 *         for v in l:
 */
  __pyx_v_i = 0;

  /* "axon/_dumper.py":562
 *         i = 0
 * 
 *         for v in l:             # <<<<<<<<<<<<<<
 *             if i > 0:
 *                 self.write(' ')
 */
  if (unlikely(((PyObject *)__pyx_v_l) == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not iterable");
    {__pyx_filename = __pyx_f[0]; __pyx_lineno = 562; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }
  __pyx_t_1 = ((PyObject *)__pyx_v_l); __Pyx_INCREF(__pyx_t_1); __pyx_t_2 = 0;
  for (;;) {
    if (__pyx_t_2 >= PyList_GET_SIZE(__pyx_t_1)) break;
    #if CYTHON_COMPILING_IN_CPYTHON
    __pyx_t_3 = PyList_GET_ITEM(__pyx_t_1, __pyx_t_2); __Pyx_INCREF(__pyx_t_3); __pyx_t_2++; if (unlikely(0 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 562; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    #else
    __pyx_t_3 = PySequence_ITEM(__pyx_t_1, __pyx_t_2); __pyx_t_2++; if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 562; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    #endif
    __Pyx_XDECREF(__pyx_v_v);
    __pyx_v_v = __pyx_t_3;
    __pyx_t_3 = 0;

    /* "axon/_dumper.py":563
 * 
 *         for v in l:
 *             if i > 0:             # <<<<<<<<<<<<<<
 *                 self.write(' ')
 *             self._dump(v)
 */
    __pyx_t_4 = ((__pyx_v_i > 0) != 0);
    if (__pyx_t_4) {

      /* "axon/_dumper.py":564
 *         for v in l:
 *             if i > 0:
 *                 self.write(' ')             # <<<<<<<<<<<<<<
 *             self._dump(v)
 *             i += 1
 */
      __pyx_t_3 = PyObject_Call(__pyx_v_self->write, ((PyObject *)__pyx_k_tuple_50), NULL); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 564; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      goto __pyx_L5;
    }
    __pyx_L5:;

    /* "axon/_dumper.py":565
 *             if i > 0:
 *                 self.write(' ')
 *             self._dump(v)             # <<<<<<<<<<<<<<
 *             i += 1
 *     #
 */
    __pyx_t_5 = __pyx_f_4axon_7_dumper_6Dumper__dump(__pyx_v_self, __pyx_v_v); if (unlikely(__pyx_t_5 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 565; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

    /* "axon/_dumper.py":566
 *                 self.write(' ')
 *             self._dump(v)
 *             i += 1             # <<<<<<<<<<<<<<
 *     #
 *     def _dump_set_sequence(self, l):
 */
    __pyx_v_i = (__pyx_v_i + 1);
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("axon._dumper.Dumper._dump_list_sequence", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_v);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_dumper.py":568
 *             i += 1
 *     #
 *     def _dump_set_sequence(self, l):             # <<<<<<<<<<<<<<
 *         i = 0
 * 
 */

static int __pyx_f_4axon_7_dumper_6Dumper__dump_set_sequence(struct Dumper *__pyx_v_self, PyObject *__pyx_v_l) {
  int __pyx_v_i;
  PyObject *__pyx_v_v = NULL;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *(*__pyx_t_2)(PyObject *);
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_dump_set_sequence", 0);

  /* "axon/_dumper.py":569
 *     #
 *     def _dump_set_sequence(self, l):
 *         i = 0             # <<<<<<<<<<<<<<
 * 
 *         for v in l:
 */
  __pyx_v_i = 0;

  /* "axon/_dumper.py":571
 *         i = 0
 * 
 *         for v in l:             # <<<<<<<<<<<<<<
 *             if i > 0:
 *                 self.write(' ')
 */
  __pyx_t_1 = PyObject_GetIter(((PyObject *)__pyx_v_l)); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 571; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = Py_TYPE(__pyx_t_1)->tp_iternext;
  for (;;) {
    {
      __pyx_t_3 = __pyx_t_2(__pyx_t_1);
      if (unlikely(!__pyx_t_3)) {
        if (PyErr_Occurred()) {
          if (likely(PyErr_ExceptionMatches(PyExc_StopIteration))) PyErr_Clear();
          else {__pyx_filename = __pyx_f[0]; __pyx_lineno = 571; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_3);
    }
    __Pyx_XDECREF(__pyx_v_v);
    __pyx_v_v = __pyx_t_3;
    __pyx_t_3 = 0;

    /* "axon/_dumper.py":572
 * 
 *         for v in l:
 *             if i > 0:             # <<<<<<<<<<<<<<
 *                 self.write(' ')
 *             self._dump(v)
 */
    __pyx_t_4 = ((__pyx_v_i > 0) != 0);
    if (__pyx_t_4) {

      /* "axon/_dumper.py":573
 *         for v in l:
 *             if i > 0:
 *                 self.write(' ')             # <<<<<<<<<<<<<<
 *             self._dump(v)
 *             i += 1
 */
      __pyx_t_3 = PyObject_Call(__pyx_v_self->write, ((PyObject *)__pyx_k_tuple_51), NULL); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 573; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      goto __pyx_L5;
    }
    __pyx_L5:;

    /* "axon/_dumper.py":574
 *             if i > 0:
 *                 self.write(' ')
 *             self._dump(v)             # <<<<<<<<<<<<<<
 *             i += 1
 *     #
 */
    __pyx_t_5 = __pyx_f_4axon_7_dumper_6Dumper__dump(__pyx_v_self, __pyx_v_v); if (unlikely(__pyx_t_5 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 574; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

    /* "axon/_dumper.py":575
 *                 self.write(' ')
 *             self._dump(v)
 *             i += 1             # <<<<<<<<<<<<<<
 *     #
 *     def _dump_tuple_sequence(self, l):
 */
    __pyx_v_i = (__pyx_v_i + 1);
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("axon._dumper.Dumper._dump_set_sequence", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_v);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_dumper.py":577
 *             i += 1
 *     #
 *     def _dump_tuple_sequence(self, l):             # <<<<<<<<<<<<<<
 *         i = 0
 * 
 */

static int __pyx_f_4axon_7_dumper_6Dumper__dump_tuple_sequence(struct Dumper *__pyx_v_self, PyObject *__pyx_v_l) {
  int __pyx_v_i;
  PyObject *__pyx_v_v = NULL;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  Py_ssize_t __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_dump_tuple_sequence", 0);

  /* "axon/_dumper.py":578
 *     #
 *     def _dump_tuple_sequence(self, l):
 *         i = 0             # <<<<<<<<<<<<<<
 * 
 *         for v in l:
 */
  __pyx_v_i = 0;

  /* "axon/_dumper.py":580
 *         i = 0
 * 
 *         for v in l:             # <<<<<<<<<<<<<<
 *             if i > 0:
 *                 self.write(' ')
 */
  if (unlikely(((PyObject *)__pyx_v_l) == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not iterable");
    {__pyx_filename = __pyx_f[0]; __pyx_lineno = 580; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }
  __pyx_t_1 = ((PyObject *)__pyx_v_l); __Pyx_INCREF(__pyx_t_1); __pyx_t_2 = 0;
  for (;;) {
    if (__pyx_t_2 >= PyTuple_GET_SIZE(__pyx_t_1)) break;
    #if CYTHON_COMPILING_IN_CPYTHON
    __pyx_t_3 = PyTuple_GET_ITEM(__pyx_t_1, __pyx_t_2); __Pyx_INCREF(__pyx_t_3); __pyx_t_2++; if (unlikely(0 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 580; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    #else
    __pyx_t_3 = PySequence_ITEM(__pyx_t_1, __pyx_t_2); __pyx_t_2++; if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 580; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    #endif
    __Pyx_XDECREF(__pyx_v_v);
    __pyx_v_v = __pyx_t_3;
    __pyx_t_3 = 0;

    /* "axon/_dumper.py":581
 * 
 *         for v in l:
 *             if i > 0:             # <<<<<<<<<<<<<<
 *                 self.write(' ')
 *             self._dump(v)
 */
    __pyx_t_4 = ((__pyx_v_i > 0) != 0);
    if (__pyx_t_4) {

      /* "axon/_dumper.py":582
 *         for v in l:
 *             if i > 0:
 *                 self.write(' ')             # <<<<<<<<<<<<<<
 *             self._dump(v)
 *             i += 1
 */
      __pyx_t_3 = PyObject_Call(__pyx_v_self->write, ((PyObject *)__pyx_k_tuple_52), NULL); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 582; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      goto __pyx_L5;
    }
    __pyx_L5:;

    /* "axon/_dumper.py":583
 *             if i > 0:
 *                 self.write(' ')
 *             self._dump(v)             # <<<<<<<<<<<<<<
 *             i += 1
 *     #
 */
    __pyx_t_5 = __pyx_f_4axon_7_dumper_6Dumper__dump(__pyx_v_self, __pyx_v_v); if (unlikely(__pyx_t_5 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 583; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

    /* "axon/_dumper.py":584
 *                 self.write(' ')
 *             self._dump(v)
 *             i += 1             # <<<<<<<<<<<<<<
 *     #
 *     def dump_list(self, l):
 */
    __pyx_v_i = (__pyx_v_i + 1);
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("axon._dumper.Dumper._dump_tuple_sequence", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_v);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_dumper.py":586
 *             i += 1
 *     #
 *     def dump_list(self, l):             # <<<<<<<<<<<<<<
 *         self.write('[')
 *         self._dump_list_sequence(l)
 */

static int __pyx_f_4axon_7_dumper_6Dumper_dump_list(struct Dumper *__pyx_v_self, PyObject *__pyx_v_l) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("dump_list", 0);

  /* "axon/_dumper.py":587
 *     #
 *     def dump_list(self, l):
 *         self.write('[')             # <<<<<<<<<<<<<<
 *         self._dump_list_sequence(l)
 *         self.write(']')
 */
  __pyx_t_1 = PyObject_Call(__pyx_v_self->write, ((PyObject *)__pyx_k_tuple_54), NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 587; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "axon/_dumper.py":588
 *     def dump_list(self, l):
 *         self.write('[')
 *         self._dump_list_sequence(l)             # <<<<<<<<<<<<<<
 *         self.write(']')
 *     #
 */
  __pyx_t_2 = __pyx_f_4axon_7_dumper_6Dumper__dump_list_sequence(__pyx_v_self, __pyx_v_l); if (unlikely(__pyx_t_2 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 588; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

  /* "axon/_dumper.py":589
 *         self.write('[')
 *         self._dump_list_sequence(l)
 *         self.write(']')             # <<<<<<<<<<<<<<
 *     #
 * #    def dump_set(self, l):
 */
  __pyx_t_1 = PyObject_Call(__pyx_v_self->write, ((PyObject *)__pyx_k_tuple_56), NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 589; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("axon._dumper.Dumper.dump_list", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_dumper.py":599
 * #            self.write('}')
 *     #
 *     def dump_dict(self, d):             # <<<<<<<<<<<<<<
 *         self.write('{')
 *         self._dump_dict_sequence(d)
 */

static int __pyx_f_4axon_7_dumper_6Dumper_dump_dict(struct Dumper *__pyx_v_self, PyObject *__pyx_v_d) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("dump_dict", 0);

  /* "axon/_dumper.py":600
 *     #
 *     def dump_dict(self, d):
 *         self.write('{')             # <<<<<<<<<<<<<<
 *         self._dump_dict_sequence(d)
 *         self.write('}')
 */
  __pyx_t_1 = PyObject_Call(__pyx_v_self->write, ((PyObject *)__pyx_k_tuple_58), NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 600; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "axon/_dumper.py":601
 *     def dump_dict(self, d):
 *         self.write('{')
 *         self._dump_dict_sequence(d)             # <<<<<<<<<<<<<<
 *         self.write('}')
 *     #
 */
  __pyx_t_2 = __pyx_f_4axon_7_dumper_6Dumper__dump_dict_sequence(__pyx_v_self, __pyx_v_d); if (unlikely(__pyx_t_2 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 601; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

  /* "axon/_dumper.py":602
 *         self.write('{')
 *         self._dump_dict_sequence(d)
 *         self.write('}')             # <<<<<<<<<<<<<<
 *     #
 *     def dump_tuple(self, d):
 */
  __pyx_t_1 = PyObject_Call(__pyx_v_self->write, ((PyObject *)__pyx_k_tuple_60), NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 602; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("axon._dumper.Dumper.dump_dict", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_4axon_7_dumper_6Dumper_3dump_tuple(PyObject *__pyx_v_self, PyObject *__pyx_v_d); /*proto*/
static PyObject *__pyx_pw_4axon_7_dumper_6Dumper_3dump_tuple(PyObject *__pyx_v_self, PyObject *__pyx_v_d) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("dump_tuple (wrapper)", 0);
  __pyx_r = __pyx_pf_4axon_7_dumper_6Dumper_2dump_tuple(((struct Dumper *)__pyx_v_self), ((PyObject *)__pyx_v_d));
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_dumper.py":604
 *         self.write('}')
 *     #
 *     def dump_tuple(self, d):             # <<<<<<<<<<<<<<
 *         self.write('(')
 *         self._dump_tuple_sequence(d)
 */

static PyObject *__pyx_pf_4axon_7_dumper_6Dumper_2dump_tuple(struct Dumper *__pyx_v_self, PyObject *__pyx_v_d) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("dump_tuple", 0);

  /* "axon/_dumper.py":605
 *     #
 *     def dump_tuple(self, d):
 *         self.write('(')             # <<<<<<<<<<<<<<
 *         self._dump_tuple_sequence(d)
 *         self.write(')')
 */
  __pyx_t_1 = PyObject_Call(__pyx_v_self->write, ((PyObject *)__pyx_k_tuple_62), NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 605; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "axon/_dumper.py":606
 *     def dump_tuple(self, d):
 *         self.write('(')
 *         self._dump_tuple_sequence(d)             # <<<<<<<<<<<<<<
 *         self.write(')')
 *     #
 */
  if (!(likely(PyTuple_CheckExact(__pyx_v_d))||((__pyx_v_d) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected tuple, got %.200s", Py_TYPE(__pyx_v_d)->tp_name), 0))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 606; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_t_2 = __pyx_f_4axon_7_dumper_6Dumper__dump_tuple_sequence(__pyx_v_self, ((PyObject*)__pyx_v_d)); if (unlikely(__pyx_t_2 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 606; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

  /* "axon/_dumper.py":607
 *         self.write('(')
 *         self._dump_tuple_sequence(d)
 *         self.write(')')             # <<<<<<<<<<<<<<
 *     #
 *     def _pretty_dump_dict_sequence(self, d, w, use_offset):
 */
  __pyx_t_1 = PyObject_Call(__pyx_v_self->write, ((PyObject *)__pyx_k_tuple_64), NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 607; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("axon._dumper.Dumper.dump_tuple", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_dumper.py":609
 *         self.write(')')
 *     #
 *     def _pretty_dump_dict_sequence(self, d, w, use_offset):             # <<<<<<<<<<<<<<
 *         if self.sorted:
 *             items = sorted(d.items())
 */

static int __pyx_f_4axon_7_dumper_6Dumper__pretty_dump_dict_sequence(struct Dumper *__pyx_v_self, PyObject *__pyx_v_d, PyObject *__pyx_v_w, int __pyx_v_use_offset) {
  PyObject *__pyx_v_text = 0;
  PyObject *__pyx_v_items = NULL;
  PyObject *__pyx_v_k = NULL;
  PyObject *__pyx_v_v = NULL;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  Py_ssize_t __pyx_t_4;
  PyObject *(*__pyx_t_5)(PyObject *);
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *(*__pyx_t_9)(PyObject *);
  int __pyx_t_10;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_pretty_dump_dict_sequence", 0);

  /* "axon/_dumper.py":610
 *     #
 *     def _pretty_dump_dict_sequence(self, d, w, use_offset):
 *         if self.sorted:             # <<<<<<<<<<<<<<
 *             items = sorted(d.items())
 *         else:
 */
  __pyx_t_1 = (__pyx_v_self->sorted != 0);
  if (__pyx_t_1) {

    /* "axon/_dumper.py":611
 *     def _pretty_dump_dict_sequence(self, d, w, use_offset):
 *         if self.sorted:
 *             items = sorted(d.items())             # <<<<<<<<<<<<<<
 *         else:
 *             items = d.items()
 */
    if (unlikely(((PyObject *)__pyx_v_d) == Py_None)) {
      PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%s'", "items");
      {__pyx_filename = __pyx_f[0]; __pyx_lineno = 611; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    }
    __pyx_t_2 = __Pyx_PyDict_Items(__pyx_v_d); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 611; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 611; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_2);
    __Pyx_GIVEREF(__pyx_t_2);
    __pyx_t_2 = 0;
    __pyx_t_2 = PyObject_Call(__pyx_builtin_sorted, ((PyObject *)__pyx_t_3), NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 611; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(((PyObject *)__pyx_t_3)); __pyx_t_3 = 0;
    __pyx_v_items = __pyx_t_2;
    __pyx_t_2 = 0;
    goto __pyx_L3;
  }
  /*else*/ {

    /* "axon/_dumper.py":613
 *             items = sorted(d.items())
 *         else:
 *             items = d.items()             # <<<<<<<<<<<<<<
 * 
 *         for k,v in items:
 */
    if (unlikely(((PyObject *)__pyx_v_d) == Py_None)) {
      PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%s'", "items");
      {__pyx_filename = __pyx_f[0]; __pyx_lineno = 613; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    }
    __pyx_t_2 = __Pyx_PyDict_Items(__pyx_v_d); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 613; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_v_items = __pyx_t_2;
    __pyx_t_2 = 0;
  }
  __pyx_L3:;

  /* "axon/_dumper.py":615
 *             items = d.items()
 * 
 *         for k,v in items:             # <<<<<<<<<<<<<<
 *             if use_offset:
 *                 self.write('\n')
 */
  if (PyList_CheckExact(__pyx_v_items) || PyTuple_CheckExact(__pyx_v_items)) {
    __pyx_t_2 = __pyx_v_items; __Pyx_INCREF(__pyx_t_2); __pyx_t_4 = 0;
    __pyx_t_5 = NULL;
  } else {
    __pyx_t_4 = -1; __pyx_t_2 = PyObject_GetIter(__pyx_v_items); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 615; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_5 = Py_TYPE(__pyx_t_2)->tp_iternext;
  }
  for (;;) {
    if (!__pyx_t_5 && PyList_CheckExact(__pyx_t_2)) {
      if (__pyx_t_4 >= PyList_GET_SIZE(__pyx_t_2)) break;
      #if CYTHON_COMPILING_IN_CPYTHON
      __pyx_t_3 = PyList_GET_ITEM(__pyx_t_2, __pyx_t_4); __Pyx_INCREF(__pyx_t_3); __pyx_t_4++; if (unlikely(0 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 615; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      #else
      __pyx_t_3 = PySequence_ITEM(__pyx_t_2, __pyx_t_4); __pyx_t_4++; if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 615; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      #endif
    } else if (!__pyx_t_5 && PyTuple_CheckExact(__pyx_t_2)) {
      if (__pyx_t_4 >= PyTuple_GET_SIZE(__pyx_t_2)) break;
      #if CYTHON_COMPILING_IN_CPYTHON
      __pyx_t_3 = PyTuple_GET_ITEM(__pyx_t_2, __pyx_t_4); __Pyx_INCREF(__pyx_t_3); __pyx_t_4++; if (unlikely(0 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 615; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      #else
      __pyx_t_3 = PySequence_ITEM(__pyx_t_2, __pyx_t_4); __pyx_t_4++; if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 615; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      #endif
    } else {
      __pyx_t_3 = __pyx_t_5(__pyx_t_2);
      if (unlikely(!__pyx_t_3)) {
        if (PyErr_Occurred()) {
          if (likely(PyErr_ExceptionMatches(PyExc_StopIteration))) PyErr_Clear();
          else {__pyx_filename = __pyx_f[0]; __pyx_lineno = 615; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_3);
    }
    if ((likely(PyTuple_CheckExact(__pyx_t_3))) || (PyList_CheckExact(__pyx_t_3))) {
      PyObject* sequence = __pyx_t_3;
      #if CYTHON_COMPILING_IN_CPYTHON
      Py_ssize_t size = Py_SIZE(sequence);
      #else
      Py_ssize_t size = PySequence_Size(sequence);
      #endif
      if (unlikely(size != 2)) {
        if (size > 2) __Pyx_RaiseTooManyValuesError(2);
        else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
        {__pyx_filename = __pyx_f[0]; __pyx_lineno = 615; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      }
      #if CYTHON_COMPILING_IN_CPYTHON
      if (likely(PyTuple_CheckExact(sequence))) {
        __pyx_t_6 = PyTuple_GET_ITEM(sequence, 0); 
        __pyx_t_7 = PyTuple_GET_ITEM(sequence, 1); 
      } else {
        __pyx_t_6 = PyList_GET_ITEM(sequence, 0); 
        __pyx_t_7 = PyList_GET_ITEM(sequence, 1); 
      }
      __Pyx_INCREF(__pyx_t_6);
      __Pyx_INCREF(__pyx_t_7);
      #else
      __pyx_t_6 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 615; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_7 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 615; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_7);
      #endif
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    } else
    {
      Py_ssize_t index = -1;
      __pyx_t_8 = PyObject_GetIter(__pyx_t_3); if (unlikely(!__pyx_t_8)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 615; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_9 = Py_TYPE(__pyx_t_8)->tp_iternext;
      index = 0; __pyx_t_6 = __pyx_t_9(__pyx_t_8); if (unlikely(!__pyx_t_6)) goto __pyx_L6_unpacking_failed;
      __Pyx_GOTREF(__pyx_t_6);
      index = 1; __pyx_t_7 = __pyx_t_9(__pyx_t_8); if (unlikely(!__pyx_t_7)) goto __pyx_L6_unpacking_failed;
      __Pyx_GOTREF(__pyx_t_7);
      if (__Pyx_IternextUnpackEndCheck(__pyx_t_9(__pyx_t_8), 2) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 615; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __pyx_t_9 = NULL;
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      goto __pyx_L7_unpacking_done;
      __pyx_L6_unpacking_failed:;
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_t_9 = NULL;
      if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
      {__pyx_filename = __pyx_f[0]; __pyx_lineno = 615; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __pyx_L7_unpacking_done:;
    }
    __Pyx_XDECREF(__pyx_v_k);
    __pyx_v_k = __pyx_t_6;
    __pyx_t_6 = 0;
    __Pyx_XDECREF(__pyx_v_v);
    __pyx_v_v = __pyx_t_7;
    __pyx_t_7 = 0;

    /* "axon/_dumper.py":616
 * 
 *         for k,v in items:
 *             if use_offset:             # <<<<<<<<<<<<<<
 *                 self.write('\n')
 *                 self.write(w)
 */
    __pyx_t_1 = (__pyx_v_use_offset != 0);
    if (__pyx_t_1) {

      /* "axon/_dumper.py":617
 *         for k,v in items:
 *             if use_offset:
 *                 self.write('\n')             # <<<<<<<<<<<<<<
 *                 self.write(w)
 *             else:
 */
      __pyx_t_3 = PyObject_Call(__pyx_v_self->write, ((PyObject *)__pyx_k_tuple_65), NULL); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 617; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

      /* "axon/_dumper.py":618
 *             if use_offset:
 *                 self.write('\n')
 *                 self.write(w)             # <<<<<<<<<<<<<<
 *             else:
 *                 use_offset = 0
 */
      __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 618; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_INCREF(((PyObject *)__pyx_v_w));
      PyTuple_SET_ITEM(__pyx_t_3, 0, ((PyObject *)__pyx_v_w));
      __Pyx_GIVEREF(((PyObject *)__pyx_v_w));
      __pyx_t_7 = PyObject_Call(__pyx_v_self->write, ((PyObject *)__pyx_t_3), NULL); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 618; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(((PyObject *)__pyx_t_3)); __pyx_t_3 = 0;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      goto __pyx_L8;
    }
    /*else*/ {

      /* "axon/_dumper.py":620
 *                 self.write(w)
 *             else:
 *                 use_offset = 0             # <<<<<<<<<<<<<<
 *                 self.write(' ')
 *                 use_offset = 1
 */
      __pyx_v_use_offset = 0;

      /* "axon/_dumper.py":621
 *             else:
 *                 use_offset = 0
 *                 self.write(' ')             # <<<<<<<<<<<<<<
 *                 use_offset = 1
 * 
 */
      __pyx_t_7 = PyObject_Call(__pyx_v_self->write, ((PyObject *)__pyx_k_tuple_66), NULL); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 621; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

      /* "axon/_dumper.py":622
 *                 use_offset = 0
 *                 self.write(' ')
 *                 use_offset = 1             # <<<<<<<<<<<<<<
 * 
 *             text = c_as_unicode(k)
 */
      __pyx_v_use_offset = 1;
    }
    __pyx_L8:;

    /* "axon/_dumper.py":624
 *                 use_offset = 1
 * 
 *             text = c_as_unicode(k)             # <<<<<<<<<<<<<<
 *             self.write(_dump_name(text, self.quote))
 *             self.write(': ')
 */
    __pyx_t_7 = ((PyObject *)__pyx_f_4axon_8_objects_c_as_unicode(__pyx_v_k)); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 624; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_XDECREF(((PyObject *)__pyx_v_text));
    __pyx_v_text = ((PyObject*)__pyx_t_7);
    __pyx_t_7 = 0;

    /* "axon/_dumper.py":625
 * 
 *             text = c_as_unicode(k)
 *             self.write(_dump_name(text, self.quote))             # <<<<<<<<<<<<<<
 *             self.write(': ')
 *             self._pretty_dump(v, w, 0)
 */
    __pyx_t_7 = ((PyObject *)__pyx_f_4axon_7_dumper__dump_name(((PyObject *)__pyx_v_text), __pyx_v_self->quote)); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 625; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 625; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_7);
    __Pyx_GIVEREF(__pyx_t_7);
    __pyx_t_7 = 0;
    __pyx_t_7 = PyObject_Call(__pyx_v_self->write, ((PyObject *)__pyx_t_3), NULL); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 625; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(((PyObject *)__pyx_t_3)); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

    /* "axon/_dumper.py":626
 *             text = c_as_unicode(k)
 *             self.write(_dump_name(text, self.quote))
 *             self.write(': ')             # <<<<<<<<<<<<<<
 *             self._pretty_dump(v, w, 0)
 *     #
 */
    __pyx_t_7 = PyObject_Call(__pyx_v_self->write, ((PyObject *)__pyx_k_tuple_68), NULL); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 626; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

    /* "axon/_dumper.py":627
 *             self.write(_dump_name(text, self.quote))
 *             self.write(': ')
 *             self._pretty_dump(v, w, 0)             # <<<<<<<<<<<<<<
 *     #
 *     def _pretty_dump_attr_sequence(self, d, w, use_offset):
 */
    __pyx_t_10 = __pyx_f_4axon_7_dumper_6Dumper__pretty_dump(__pyx_v_self, __pyx_v_v, __pyx_v_w, 0); if (unlikely(__pyx_t_10 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 627; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("axon._dumper.Dumper._pretty_dump_dict_sequence", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_text);
  __Pyx_XDECREF(__pyx_v_items);
  __Pyx_XDECREF(__pyx_v_k);
  __Pyx_XDECREF(__pyx_v_v);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_dumper.py":629
 *             self._pretty_dump(v, w, 0)
 *     #
 *     def _pretty_dump_attr_sequence(self, d, w, use_offset):             # <<<<<<<<<<<<<<
 *         if self.sorted:
 *             items = sorted(d.items())
 */

static int __pyx_f_4axon_7_dumper_6Dumper__pretty_dump_attr_sequence(struct Dumper *__pyx_v_self, PyObject *__pyx_v_d, PyObject *__pyx_v_w, int __pyx_v_use_offset) {
  PyObject *__pyx_v_text = 0;
  PyObject *__pyx_v_items = NULL;
  PyObject *__pyx_v_k = NULL;
  PyObject *__pyx_v_v = NULL;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  Py_ssize_t __pyx_t_4;
  PyObject *(*__pyx_t_5)(PyObject *);
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *(*__pyx_t_9)(PyObject *);
  int __pyx_t_10;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_pretty_dump_attr_sequence", 0);

  /* "axon/_dumper.py":630
 *     #
 *     def _pretty_dump_attr_sequence(self, d, w, use_offset):
 *         if self.sorted:             # <<<<<<<<<<<<<<
 *             items = sorted(d.items())
 *         else:
 */
  __pyx_t_1 = (__pyx_v_self->sorted != 0);
  if (__pyx_t_1) {

    /* "axon/_dumper.py":631
 *     def _pretty_dump_attr_sequence(self, d, w, use_offset):
 *         if self.sorted:
 *             items = sorted(d.items())             # <<<<<<<<<<<<<<
 *         else:
 *             items = d.items()
 */
    if (unlikely(((PyObject *)__pyx_v_d) == Py_None)) {
      PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%s'", "items");
      {__pyx_filename = __pyx_f[0]; __pyx_lineno = 631; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    }
    __pyx_t_2 = __Pyx_PyDict_Items(__pyx_v_d); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 631; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 631; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_2);
    __Pyx_GIVEREF(__pyx_t_2);
    __pyx_t_2 = 0;
    __pyx_t_2 = PyObject_Call(__pyx_builtin_sorted, ((PyObject *)__pyx_t_3), NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 631; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(((PyObject *)__pyx_t_3)); __pyx_t_3 = 0;
    __pyx_v_items = __pyx_t_2;
    __pyx_t_2 = 0;
    goto __pyx_L3;
  }
  /*else*/ {

    /* "axon/_dumper.py":633
 *             items = sorted(d.items())
 *         else:
 *             items = d.items()             # <<<<<<<<<<<<<<
 * 
 *         for k,v in items:
 */
    if (unlikely(((PyObject *)__pyx_v_d) == Py_None)) {
      PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%s'", "items");
      {__pyx_filename = __pyx_f[0]; __pyx_lineno = 633; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    }
    __pyx_t_2 = __Pyx_PyDict_Items(__pyx_v_d); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 633; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_v_items = __pyx_t_2;
    __pyx_t_2 = 0;
  }
  __pyx_L3:;

  /* "axon/_dumper.py":635
 *             items = d.items()
 * 
 *         for k,v in items:             # <<<<<<<<<<<<<<
 *             if use_offset:
 *                 self.write('\n')
 */
  if (PyList_CheckExact(__pyx_v_items) || PyTuple_CheckExact(__pyx_v_items)) {
    __pyx_t_2 = __pyx_v_items; __Pyx_INCREF(__pyx_t_2); __pyx_t_4 = 0;
    __pyx_t_5 = NULL;
  } else {
    __pyx_t_4 = -1; __pyx_t_2 = PyObject_GetIter(__pyx_v_items); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 635; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_5 = Py_TYPE(__pyx_t_2)->tp_iternext;
  }
  for (;;) {
    if (!__pyx_t_5 && PyList_CheckExact(__pyx_t_2)) {
      if (__pyx_t_4 >= PyList_GET_SIZE(__pyx_t_2)) break;
      #if CYTHON_COMPILING_IN_CPYTHON
      __pyx_t_3 = PyList_GET_ITEM(__pyx_t_2, __pyx_t_4); __Pyx_INCREF(__pyx_t_3); __pyx_t_4++; if (unlikely(0 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 635; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      #else
      __pyx_t_3 = PySequence_ITEM(__pyx_t_2, __pyx_t_4); __pyx_t_4++; if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 635; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      #endif
    } else if (!__pyx_t_5 && PyTuple_CheckExact(__pyx_t_2)) {
      if (__pyx_t_4 >= PyTuple_GET_SIZE(__pyx_t_2)) break;
      #if CYTHON_COMPILING_IN_CPYTHON
      __pyx_t_3 = PyTuple_GET_ITEM(__pyx_t_2, __pyx_t_4); __Pyx_INCREF(__pyx_t_3); __pyx_t_4++; if (unlikely(0 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 635; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      #else
      __pyx_t_3 = PySequence_ITEM(__pyx_t_2, __pyx_t_4); __pyx_t_4++; if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 635; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      #endif
    } else {
      __pyx_t_3 = __pyx_t_5(__pyx_t_2);
      if (unlikely(!__pyx_t_3)) {
        if (PyErr_Occurred()) {
          if (likely(PyErr_ExceptionMatches(PyExc_StopIteration))) PyErr_Clear();
          else {__pyx_filename = __pyx_f[0]; __pyx_lineno = 635; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_3);
    }
    if ((likely(PyTuple_CheckExact(__pyx_t_3))) || (PyList_CheckExact(__pyx_t_3))) {
      PyObject* sequence = __pyx_t_3;
      #if CYTHON_COMPILING_IN_CPYTHON
      Py_ssize_t size = Py_SIZE(sequence);
      #else
      Py_ssize_t size = PySequence_Size(sequence);
      #endif
      if (unlikely(size != 2)) {
        if (size > 2) __Pyx_RaiseTooManyValuesError(2);
        else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
        {__pyx_filename = __pyx_f[0]; __pyx_lineno = 635; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      }
      #if CYTHON_COMPILING_IN_CPYTHON
      if (likely(PyTuple_CheckExact(sequence))) {
        __pyx_t_6 = PyTuple_GET_ITEM(sequence, 0); 
        __pyx_t_7 = PyTuple_GET_ITEM(sequence, 1); 
      } else {
        __pyx_t_6 = PyList_GET_ITEM(sequence, 0); 
        __pyx_t_7 = PyList_GET_ITEM(sequence, 1); 
      }
      __Pyx_INCREF(__pyx_t_6);
      __Pyx_INCREF(__pyx_t_7);
      #else
      __pyx_t_6 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 635; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_7 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 635; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_7);
      #endif
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    } else
    {
      Py_ssize_t index = -1;
      __pyx_t_8 = PyObject_GetIter(__pyx_t_3); if (unlikely(!__pyx_t_8)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 635; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_9 = Py_TYPE(__pyx_t_8)->tp_iternext;
      index = 0; __pyx_t_6 = __pyx_t_9(__pyx_t_8); if (unlikely(!__pyx_t_6)) goto __pyx_L6_unpacking_failed;
      __Pyx_GOTREF(__pyx_t_6);
      index = 1; __pyx_t_7 = __pyx_t_9(__pyx_t_8); if (unlikely(!__pyx_t_7)) goto __pyx_L6_unpacking_failed;
      __Pyx_GOTREF(__pyx_t_7);
      if (__Pyx_IternextUnpackEndCheck(__pyx_t_9(__pyx_t_8), 2) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 635; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __pyx_t_9 = NULL;
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      goto __pyx_L7_unpacking_done;
      __pyx_L6_unpacking_failed:;
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_t_9 = NULL;
      if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
      {__pyx_filename = __pyx_f[0]; __pyx_lineno = 635; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __pyx_L7_unpacking_done:;
    }
    __Pyx_XDECREF(__pyx_v_k);
    __pyx_v_k = __pyx_t_6;
    __pyx_t_6 = 0;
    __Pyx_XDECREF(__pyx_v_v);
    __pyx_v_v = __pyx_t_7;
    __pyx_t_7 = 0;

    /* "axon/_dumper.py":636
 * 
 *         for k,v in items:
 *             if use_offset:             # <<<<<<<<<<<<<<
 *                 self.write('\n')
 *                 self.write(w)
 */
    __pyx_t_1 = (__pyx_v_use_offset != 0);
    if (__pyx_t_1) {

      /* "axon/_dumper.py":637
 *         for k,v in items:
 *             if use_offset:
 *                 self.write('\n')             # <<<<<<<<<<<<<<
 *                 self.write(w)
 *             else:
 */
      __pyx_t_3 = PyObject_Call(__pyx_v_self->write, ((PyObject *)__pyx_k_tuple_69), NULL); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 637; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

      /* "axon/_dumper.py":638
 *             if use_offset:
 *                 self.write('\n')
 *                 self.write(w)             # <<<<<<<<<<<<<<
 *             else:
 *                 use_offset = 0
 */
      __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 638; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_INCREF(((PyObject *)__pyx_v_w));
      PyTuple_SET_ITEM(__pyx_t_3, 0, ((PyObject *)__pyx_v_w));
      __Pyx_GIVEREF(((PyObject *)__pyx_v_w));
      __pyx_t_7 = PyObject_Call(__pyx_v_self->write, ((PyObject *)__pyx_t_3), NULL); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 638; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(((PyObject *)__pyx_t_3)); __pyx_t_3 = 0;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      goto __pyx_L8;
    }
    /*else*/ {

      /* "axon/_dumper.py":640
 *                 self.write(w)
 *             else:
 *                 use_offset = 0             # <<<<<<<<<<<<<<
 *                 self.write(' ')
 *                 use_offset = 1
 */
      __pyx_v_use_offset = 0;

      /* "axon/_dumper.py":641
 *             else:
 *                 use_offset = 0
 *                 self.write(' ')             # <<<<<<<<<<<<<<
 *                 use_offset = 1
 * 
 */
      __pyx_t_7 = PyObject_Call(__pyx_v_self->write, ((PyObject *)__pyx_k_tuple_70), NULL); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 641; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

      /* "axon/_dumper.py":642
 *                 use_offset = 0
 *                 self.write(' ')
 *                 use_offset = 1             # <<<<<<<<<<<<<<
 * 
 *             text = c_as_unicode(k)
 */
      __pyx_v_use_offset = 1;
    }
    __pyx_L8:;

    /* "axon/_dumper.py":644
 *                 use_offset = 1
 * 
 *             text = c_as_unicode(k)             # <<<<<<<<<<<<<<
 *             self.write(_dump_name(text, self.quote))
 *             self.write(': ')
 */
    __pyx_t_7 = ((PyObject *)__pyx_f_4axon_8_objects_c_as_unicode(__pyx_v_k)); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 644; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_XDECREF(((PyObject *)__pyx_v_text));
    __pyx_v_text = ((PyObject*)__pyx_t_7);
    __pyx_t_7 = 0;

    /* "axon/_dumper.py":645
 * 
 *             text = c_as_unicode(k)
 *             self.write(_dump_name(text, self.quote))             # <<<<<<<<<<<<<<
 *             self.write(': ')
 *             self._pretty_dump(v, w, 0)
 */
    __pyx_t_7 = ((PyObject *)__pyx_f_4axon_7_dumper__dump_name(((PyObject *)__pyx_v_text), __pyx_v_self->quote)); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 645; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 645; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_7);
    __Pyx_GIVEREF(__pyx_t_7);
    __pyx_t_7 = 0;
    __pyx_t_7 = PyObject_Call(__pyx_v_self->write, ((PyObject *)__pyx_t_3), NULL); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 645; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(((PyObject *)__pyx_t_3)); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

    /* "axon/_dumper.py":646
 *             text = c_as_unicode(k)
 *             self.write(_dump_name(text, self.quote))
 *             self.write(': ')             # <<<<<<<<<<<<<<
 *             self._pretty_dump(v, w, 0)
 *     #
 */
    __pyx_t_7 = PyObject_Call(__pyx_v_self->write, ((PyObject *)__pyx_k_tuple_71), NULL); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 646; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

    /* "axon/_dumper.py":647
 *             self.write(_dump_name(text, self.quote))
 *             self.write(': ')
 *             self._pretty_dump(v, w, 0)             # <<<<<<<<<<<<<<
 *     #
 *     def _pretty_dump_list_sequence(self, l, w, use_offset):
 */
    __pyx_t_10 = __pyx_f_4axon_7_dumper_6Dumper__pretty_dump(__pyx_v_self, __pyx_v_v, __pyx_v_w, 0); if (unlikely(__pyx_t_10 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 647; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("axon._dumper.Dumper._pretty_dump_attr_sequence", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_text);
  __Pyx_XDECREF(__pyx_v_items);
  __Pyx_XDECREF(__pyx_v_k);
  __Pyx_XDECREF(__pyx_v_v);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_dumper.py":649
 *             self._pretty_dump(v, w, 0)
 *     #
 *     def _pretty_dump_list_sequence(self, l, w, use_offset):             # <<<<<<<<<<<<<<
 *         for v in l:
 *             if use_offset:
 */

static int __pyx_f_4axon_7_dumper_6Dumper__pretty_dump_list_sequence(struct Dumper *__pyx_v_self, PyObject *__pyx_v_l, PyObject *__pyx_v_w, int __pyx_v_use_offset) {
  PyObject *__pyx_v_v = NULL;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  Py_ssize_t __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_pretty_dump_list_sequence", 0);

  /* "axon/_dumper.py":650
 *     #
 *     def _pretty_dump_list_sequence(self, l, w, use_offset):
 *         for v in l:             # <<<<<<<<<<<<<<
 *             if use_offset:
 *                 self.write('\n')
 */
  if (unlikely(((PyObject *)__pyx_v_l) == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not iterable");
    {__pyx_filename = __pyx_f[0]; __pyx_lineno = 650; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }
  __pyx_t_1 = ((PyObject *)__pyx_v_l); __Pyx_INCREF(__pyx_t_1); __pyx_t_2 = 0;
  for (;;) {
    if (__pyx_t_2 >= PyList_GET_SIZE(__pyx_t_1)) break;
    #if CYTHON_COMPILING_IN_CPYTHON
    __pyx_t_3 = PyList_GET_ITEM(__pyx_t_1, __pyx_t_2); __Pyx_INCREF(__pyx_t_3); __pyx_t_2++; if (unlikely(0 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 650; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    #else
    __pyx_t_3 = PySequence_ITEM(__pyx_t_1, __pyx_t_2); __pyx_t_2++; if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 650; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    #endif
    __Pyx_XDECREF(__pyx_v_v);
    __pyx_v_v = __pyx_t_3;
    __pyx_t_3 = 0;

    /* "axon/_dumper.py":651
 *     def _pretty_dump_list_sequence(self, l, w, use_offset):
 *         for v in l:
 *             if use_offset:             # <<<<<<<<<<<<<<
 *                 self.write('\n')
 *                 self._pretty_dump(v, w, 1)
 */
    __pyx_t_4 = (__pyx_v_use_offset != 0);
    if (__pyx_t_4) {

      /* "axon/_dumper.py":652
 *         for v in l:
 *             if use_offset:
 *                 self.write('\n')             # <<<<<<<<<<<<<<
 *                 self._pretty_dump(v, w, 1)
 *             else:
 */
      __pyx_t_3 = PyObject_Call(__pyx_v_self->write, ((PyObject *)__pyx_k_tuple_72), NULL); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 652; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

      /* "axon/_dumper.py":653
 *             if use_offset:
 *                 self.write('\n')
 *                 self._pretty_dump(v, w, 1)             # <<<<<<<<<<<<<<
 *             else:
 *                 self.write(' ')
 */
      __pyx_t_5 = __pyx_f_4axon_7_dumper_6Dumper__pretty_dump(__pyx_v_self, __pyx_v_v, __pyx_v_w, 1); if (unlikely(__pyx_t_5 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 653; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      goto __pyx_L5;
    }
    /*else*/ {

      /* "axon/_dumper.py":655
 *                 self._pretty_dump(v, w, 1)
 *             else:
 *                 self.write(' ')             # <<<<<<<<<<<<<<
 *                 self._pretty_dump(v, w, 0)
 *                 use_offset = 1
 */
      __pyx_t_3 = PyObject_Call(__pyx_v_self->write, ((PyObject *)__pyx_k_tuple_73), NULL); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 655; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

      /* "axon/_dumper.py":656
 *             else:
 *                 self.write(' ')
 *                 self._pretty_dump(v, w, 0)             # <<<<<<<<<<<<<<
 *                 use_offset = 1
 *     #
 */
      __pyx_t_5 = __pyx_f_4axon_7_dumper_6Dumper__pretty_dump(__pyx_v_self, __pyx_v_v, __pyx_v_w, 0); if (unlikely(__pyx_t_5 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 656; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

      /* "axon/_dumper.py":657
 *                 self.write(' ')
 *                 self._pretty_dump(v, w, 0)
 *                 use_offset = 1             # <<<<<<<<<<<<<<
 *     #
 *     def _pretty_dump_tuple_sequence(self, l, w, use_offset):
 */
      __pyx_v_use_offset = 1;
    }
    __pyx_L5:;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("axon._dumper.Dumper._pretty_dump_list_sequence", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_v);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_dumper.py":659
 *                 use_offset = 1
 *     #
 *     def _pretty_dump_tuple_sequence(self, l, w, use_offset):             # <<<<<<<<<<<<<<
 *         for v in l:
 *             if use_offset:
 */

static int __pyx_f_4axon_7_dumper_6Dumper__pretty_dump_tuple_sequence(struct Dumper *__pyx_v_self, PyObject *__pyx_v_l, PyObject *__pyx_v_w, int __pyx_v_use_offset) {
  PyObject *__pyx_v_v = NULL;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  Py_ssize_t __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_pretty_dump_tuple_sequence", 0);

  /* "axon/_dumper.py":660
 *     #
 *     def _pretty_dump_tuple_sequence(self, l, w, use_offset):
 *         for v in l:             # <<<<<<<<<<<<<<
 *             if use_offset:
 *                 self.write('\n')
 */
  if (unlikely(((PyObject *)__pyx_v_l) == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not iterable");
    {__pyx_filename = __pyx_f[0]; __pyx_lineno = 660; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }
  __pyx_t_1 = ((PyObject *)__pyx_v_l); __Pyx_INCREF(__pyx_t_1); __pyx_t_2 = 0;
  for (;;) {
    if (__pyx_t_2 >= PyTuple_GET_SIZE(__pyx_t_1)) break;
    #if CYTHON_COMPILING_IN_CPYTHON
    __pyx_t_3 = PyTuple_GET_ITEM(__pyx_t_1, __pyx_t_2); __Pyx_INCREF(__pyx_t_3); __pyx_t_2++; if (unlikely(0 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 660; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    #else
    __pyx_t_3 = PySequence_ITEM(__pyx_t_1, __pyx_t_2); __pyx_t_2++; if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 660; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    #endif
    __Pyx_XDECREF(__pyx_v_v);
    __pyx_v_v = __pyx_t_3;
    __pyx_t_3 = 0;

    /* "axon/_dumper.py":661
 *     def _pretty_dump_tuple_sequence(self, l, w, use_offset):
 *         for v in l:
 *             if use_offset:             # <<<<<<<<<<<<<<
 *                 self.write('\n')
 *                 self._pretty_dump(v, w, 1)
 */
    __pyx_t_4 = (__pyx_v_use_offset != 0);
    if (__pyx_t_4) {

      /* "axon/_dumper.py":662
 *         for v in l:
 *             if use_offset:
 *                 self.write('\n')             # <<<<<<<<<<<<<<
 *                 self._pretty_dump(v, w, 1)
 *             else:
 */
      __pyx_t_3 = PyObject_Call(__pyx_v_self->write, ((PyObject *)__pyx_k_tuple_74), NULL); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 662; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

      /* "axon/_dumper.py":663
 *             if use_offset:
 *                 self.write('\n')
 *                 self._pretty_dump(v, w, 1)             # <<<<<<<<<<<<<<
 *             else:
 *                 self.write(' ')
 */
      __pyx_t_5 = __pyx_f_4axon_7_dumper_6Dumper__pretty_dump(__pyx_v_self, __pyx_v_v, __pyx_v_w, 1); if (unlikely(__pyx_t_5 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 663; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      goto __pyx_L5;
    }
    /*else*/ {

      /* "axon/_dumper.py":665
 *                 self._pretty_dump(v, w, 1)
 *             else:
 *                 self.write(' ')             # <<<<<<<<<<<<<<
 *                 self._pretty_dump(v, w, 0)
 *                 use_offset = 1
 */
      __pyx_t_3 = PyObject_Call(__pyx_v_self->write, ((PyObject *)__pyx_k_tuple_75), NULL); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 665; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

      /* "axon/_dumper.py":666
 *             else:
 *                 self.write(' ')
 *                 self._pretty_dump(v, w, 0)             # <<<<<<<<<<<<<<
 *                 use_offset = 1
 *     #
 */
      __pyx_t_5 = __pyx_f_4axon_7_dumper_6Dumper__pretty_dump(__pyx_v_self, __pyx_v_v, __pyx_v_w, 0); if (unlikely(__pyx_t_5 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 666; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

      /* "axon/_dumper.py":667
 *                 self.write(' ')
 *                 self._pretty_dump(v, w, 0)
 *                 use_offset = 1             # <<<<<<<<<<<<<<
 *     #
 *     def pretty_dump_list(self, l, w, use_offset):
 */
      __pyx_v_use_offset = 1;
    }
    __pyx_L5:;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("axon._dumper.Dumper._pretty_dump_tuple_sequence", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_v);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_dumper.py":669
 *                 use_offset = 1
 *     #
 *     def pretty_dump_list(self, l, w, use_offset):             # <<<<<<<<<<<<<<
 *         self.write('[')
 *         self._pretty_dump_list_sequence(l, w, use_offset)
 */

static int __pyx_f_4axon_7_dumper_6Dumper_pretty_dump_list(struct Dumper *__pyx_v_self, PyObject *__pyx_v_l, PyObject *__pyx_v_w, int __pyx_v_use_offset) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("pretty_dump_list", 0);

  /* "axon/_dumper.py":670
 *     #
 *     def pretty_dump_list(self, l, w, use_offset):
 *         self.write('[')             # <<<<<<<<<<<<<<
 *         self._pretty_dump_list_sequence(l, w, use_offset)
 *         self.write(']')
 */
  __pyx_t_1 = PyObject_Call(__pyx_v_self->write, ((PyObject *)__pyx_k_tuple_76), NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 670; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "axon/_dumper.py":671
 *     def pretty_dump_list(self, l, w, use_offset):
 *         self.write('[')
 *         self._pretty_dump_list_sequence(l, w, use_offset)             # <<<<<<<<<<<<<<
 *         self.write(']')
 *     #
 */
  __pyx_t_2 = __pyx_f_4axon_7_dumper_6Dumper__pretty_dump_list_sequence(__pyx_v_self, __pyx_v_l, __pyx_v_w, __pyx_v_use_offset); if (unlikely(__pyx_t_2 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 671; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

  /* "axon/_dumper.py":672
 *         self.write('[')
 *         self._pretty_dump_list_sequence(l, w, use_offset)
 *         self.write(']')             # <<<<<<<<<<<<<<
 *     #
 * #    def pretty_dump_set(self, l, w, use_offset):
 */
  __pyx_t_1 = PyObject_Call(__pyx_v_self->write, ((PyObject *)__pyx_k_tuple_77), NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 672; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("axon._dumper.Dumper.pretty_dump_list", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_dumper.py":682
 * #            self.write('}')
 *     #
 *     def pretty_dump_dict(self, d, w, use_offset):             # <<<<<<<<<<<<<<
 *         self.write('{')
 *         self._pretty_dump_dict_sequence(d, w, use_offset)
 */

static int __pyx_f_4axon_7_dumper_6Dumper_pretty_dump_dict(struct Dumper *__pyx_v_self, PyObject *__pyx_v_d, PyObject *__pyx_v_w, int __pyx_v_use_offset) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("pretty_dump_dict", 0);

  /* "axon/_dumper.py":683
 *     #
 *     def pretty_dump_dict(self, d, w, use_offset):
 *         self.write('{')             # <<<<<<<<<<<<<<
 *         self._pretty_dump_dict_sequence(d, w, use_offset)
 *         self.write('}')
 */
  __pyx_t_1 = PyObject_Call(__pyx_v_self->write, ((PyObject *)__pyx_k_tuple_78), NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 683; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "axon/_dumper.py":684
 *     def pretty_dump_dict(self, d, w, use_offset):
 *         self.write('{')
 *         self._pretty_dump_dict_sequence(d, w, use_offset)             # <<<<<<<<<<<<<<
 *         self.write('}')
 *     #
 */
  __pyx_t_2 = __pyx_f_4axon_7_dumper_6Dumper__pretty_dump_dict_sequence(__pyx_v_self, __pyx_v_d, __pyx_v_w, __pyx_v_use_offset); if (unlikely(__pyx_t_2 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 684; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

  /* "axon/_dumper.py":685
 *         self.write('{')
 *         self._pretty_dump_dict_sequence(d, w, use_offset)
 *         self.write('}')             # <<<<<<<<<<<<<<
 *     #
 *     def pretty_dump_tuple(self, l, w, use_offset):
 */
  __pyx_t_1 = PyObject_Call(__pyx_v_self->write, ((PyObject *)__pyx_k_tuple_79), NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 685; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("axon._dumper.Dumper.pretty_dump_dict", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_4axon_7_dumper_6Dumper_5pretty_dump_tuple(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyObject *__pyx_pw_4axon_7_dumper_6Dumper_5pretty_dump_tuple(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_l = 0;
  PyObject *__pyx_v_w = 0;
  CYTHON_UNUSED PyObject *__pyx_v_use_offset = 0;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("pretty_dump_tuple (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s__l,&__pyx_n_s__w,&__pyx_n_s__use_offset,0};
    PyObject* values[3] = {0,0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s__l)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s__w)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("pretty_dump_tuple", 1, 3, 3, 1); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 687; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
        }
        case  2:
        if (likely((values[2] = PyDict_GetItem(__pyx_kwds, __pyx_n_s__use_offset)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("pretty_dump_tuple", 1, 3, 3, 2); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 687; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "pretty_dump_tuple") < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 687; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 3) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
      values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
    }
    __pyx_v_l = values[0];
    __pyx_v_w = values[1];
    __pyx_v_use_offset = values[2];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("pretty_dump_tuple", 1, 3, 3, PyTuple_GET_SIZE(__pyx_args)); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 687; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  __pyx_L3_error:;
  __Pyx_AddTraceback("axon._dumper.Dumper.pretty_dump_tuple", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_4axon_7_dumper_6Dumper_4pretty_dump_tuple(((struct Dumper *)__pyx_v_self), __pyx_v_l, __pyx_v_w, __pyx_v_use_offset);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_dumper.py":687
 *         self.write('}')
 *     #
 *     def pretty_dump_tuple(self, l, w, use_offset):             # <<<<<<<<<<<<<<
 *         self.write('(')
 *         self._pretty_dump_tuple_sequence(l, w, 0)
 */

static PyObject *__pyx_pf_4axon_7_dumper_6Dumper_4pretty_dump_tuple(struct Dumper *__pyx_v_self, PyObject *__pyx_v_l, PyObject *__pyx_v_w, CYTHON_UNUSED PyObject *__pyx_v_use_offset) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("pretty_dump_tuple", 0);

  /* "axon/_dumper.py":688
 *     #
 *     def pretty_dump_tuple(self, l, w, use_offset):
 *         self.write('(')             # <<<<<<<<<<<<<<
 *         self._pretty_dump_tuple_sequence(l, w, 0)
 *         self.write(')')
 */
  __pyx_t_1 = PyObject_Call(__pyx_v_self->write, ((PyObject *)__pyx_k_tuple_80), NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 688; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "axon/_dumper.py":689
 *     def pretty_dump_tuple(self, l, w, use_offset):
 *         self.write('(')
 *         self._pretty_dump_tuple_sequence(l, w, 0)             # <<<<<<<<<<<<<<
 *         self.write(')')
 *     #
 */
  if (!(likely(PyTuple_CheckExact(__pyx_v_l))||((__pyx_v_l) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected tuple, got %.200s", Py_TYPE(__pyx_v_l)->tp_name), 0))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 689; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (!(likely(PyUnicode_CheckExact(__pyx_v_w))||((__pyx_v_w) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected unicode, got %.200s", Py_TYPE(__pyx_v_w)->tp_name), 0))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 689; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_t_2 = __pyx_f_4axon_7_dumper_6Dumper__pretty_dump_tuple_sequence(__pyx_v_self, ((PyObject*)__pyx_v_l), ((PyObject*)__pyx_v_w), 0); if (unlikely(__pyx_t_2 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 689; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

  /* "axon/_dumper.py":690
 *         self.write('(')
 *         self._pretty_dump_tuple_sequence(l, w, 0)
 *         self.write(')')             # <<<<<<<<<<<<<<
 *     #
 *     def dump_content(self, items):
 */
  __pyx_t_1 = PyObject_Call(__pyx_v_self->write, ((PyObject *)__pyx_k_tuple_81), NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 690; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("axon._dumper.Dumper.pretty_dump_tuple", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_dumper.py":692
 *         self.write(')')
 *     #
 *     def dump_content(self, items):             # <<<<<<<<<<<<<<
 *         for i, item in enumerate(items):
 * 
 */

static int __pyx_f_4axon_7_dumper_6Dumper_dump_content(struct Dumper *__pyx_v_self, PyObject *__pyx_v_items) {
  Py_ssize_t __pyx_v_i;
  PyObject *__pyx_v_item = NULL;
  PyObject *__pyx_v_tp = NULL;
  PyObject *__pyx_v_j = NULL;
  PyObject *__pyx_v_v = NULL;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  Py_ssize_t __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  Py_ssize_t __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_t_6;
  int __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  Py_ssize_t __pyx_t_9;
  PyObject *(*__pyx_t_10)(PyObject *);
  PyObject *__pyx_t_11 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("dump_content", 0);

  /* "axon/_dumper.py":693
 *     #
 *     def dump_content(self, items):
 *         for i, item in enumerate(items):             # <<<<<<<<<<<<<<
 * 
 *             if item is None:
 */
  __pyx_t_1 = 0;
  __pyx_t_2 = ((PyObject *)__pyx_v_items); __Pyx_INCREF(__pyx_t_2); __pyx_t_3 = 0;
  for (;;) {
    if (__pyx_t_3 >= PyTuple_GET_SIZE(__pyx_t_2)) break;
    #if CYTHON_COMPILING_IN_CPYTHON
    __pyx_t_4 = PyTuple_GET_ITEM(__pyx_t_2, __pyx_t_3); __Pyx_INCREF(__pyx_t_4); __pyx_t_3++; if (unlikely(0 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 693; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    #else
    __pyx_t_4 = PySequence_ITEM(__pyx_t_2, __pyx_t_3); __pyx_t_3++; if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 693; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    #endif
    __Pyx_XDECREF(__pyx_v_item);
    __pyx_v_item = __pyx_t_4;
    __pyx_t_4 = 0;
    __pyx_v_i = __pyx_t_1;
    __pyx_t_1 = (__pyx_t_1 + 1);

    /* "axon/_dumper.py":695
 *         for i, item in enumerate(items):
 * 
 *             if item is None:             # <<<<<<<<<<<<<<
 *                 continue
 * 
 */
    __pyx_t_5 = (__pyx_v_item == Py_None);
    __pyx_t_6 = (__pyx_t_5 != 0);
    if (__pyx_t_6) {

      /* "axon/_dumper.py":696
 * 
 *             if item is None:
 *                 continue             # <<<<<<<<<<<<<<
 * 
 *             if i == 1:
 */
      goto __pyx_L3_continue;
      goto __pyx_L5;
    }
    __pyx_L5:;

    /* "axon/_dumper.py":698
 *                 continue
 * 
 *             if i == 1:             # <<<<<<<<<<<<<<
 *                 self.write(' ')
 * 
 */
    __pyx_t_6 = ((__pyx_v_i == 1) != 0);
    if (__pyx_t_6) {

      /* "axon/_dumper.py":699
 * 
 *             if i == 1:
 *                 self.write(' ')             # <<<<<<<<<<<<<<
 * 
 *             tp = type(item)
 */
      __pyx_t_4 = PyObject_Call(__pyx_v_self->write, ((PyObject *)__pyx_k_tuple_82), NULL); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 699; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      goto __pyx_L6;
    }
    __pyx_L6:;

    /* "axon/_dumper.py":701
 *                 self.write(' ')
 * 
 *             tp = type(item)             # <<<<<<<<<<<<<<
 *             if tp is dict:
 *                 self._dump_attr_sequence(item)
 */
    __Pyx_INCREF(((PyObject *)Py_TYPE(__pyx_v_item)));
    __Pyx_XDECREF(((PyObject *)__pyx_v_tp));
    __pyx_v_tp = ((PyObject*)((PyObject *)Py_TYPE(__pyx_v_item)));

    /* "axon/_dumper.py":702
 * 
 *             tp = type(item)
 *             if tp is dict:             # <<<<<<<<<<<<<<
 *                 self._dump_attr_sequence(item)
 *             elif tp is tuple:
 */
    __pyx_t_6 = (__pyx_v_tp == ((PyObject*)(&PyDict_Type)));
    __pyx_t_5 = (__pyx_t_6 != 0);
    if (__pyx_t_5) {

      /* "axon/_dumper.py":703
 *             tp = type(item)
 *             if tp is dict:
 *                 self._dump_attr_sequence(item)             # <<<<<<<<<<<<<<
 *             elif tp is tuple:
 *                 self._dump_tuple_sequence(item)
 */
      if (!(likely(PyDict_CheckExact(__pyx_v_item))||((__pyx_v_item) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected dict, got %.200s", Py_TYPE(__pyx_v_item)->tp_name), 0))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 703; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __pyx_t_7 = __pyx_f_4axon_7_dumper_6Dumper__dump_attr_sequence(__pyx_v_self, ((PyObject*)__pyx_v_item)); if (unlikely(__pyx_t_7 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 703; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      goto __pyx_L7;
    }

    /* "axon/_dumper.py":704
 *             if tp is dict:
 *                 self._dump_attr_sequence(item)
 *             elif tp is tuple:             # <<<<<<<<<<<<<<
 *                 self._dump_tuple_sequence(item)
 *             elif tp is list:
 */
    __pyx_t_5 = (__pyx_v_tp == ((PyObject*)(&PyTuple_Type)));
    __pyx_t_6 = (__pyx_t_5 != 0);
    if (__pyx_t_6) {

      /* "axon/_dumper.py":705
 *                 self._dump_attr_sequence(item)
 *             elif tp is tuple:
 *                 self._dump_tuple_sequence(item)             # <<<<<<<<<<<<<<
 *             elif tp is list:
 *                 self._dump_list_sequence(item)
 */
      if (!(likely(PyTuple_CheckExact(__pyx_v_item))||((__pyx_v_item) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected tuple, got %.200s", Py_TYPE(__pyx_v_item)->tp_name), 0))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 705; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __pyx_t_7 = __pyx_f_4axon_7_dumper_6Dumper__dump_tuple_sequence(__pyx_v_self, ((PyObject*)__pyx_v_item)); if (unlikely(__pyx_t_7 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 705; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      goto __pyx_L7;
    }

    /* "axon/_dumper.py":706
 *             elif tp is tuple:
 *                 self._dump_tuple_sequence(item)
 *             elif tp is list:             # <<<<<<<<<<<<<<
 *                 self._dump_list_sequence(item)
 *             elif tp is set:
 */
    __pyx_t_6 = (__pyx_v_tp == ((PyObject*)(&PyList_Type)));
    __pyx_t_5 = (__pyx_t_6 != 0);
    if (__pyx_t_5) {

      /* "axon/_dumper.py":707
 *                 self._dump_tuple_sequence(item)
 *             elif tp is list:
 *                 self._dump_list_sequence(item)             # <<<<<<<<<<<<<<
 *             elif tp is set:
 *                 self._dump_set_sequence(item)
 */
      if (!(likely(PyList_CheckExact(__pyx_v_item))||((__pyx_v_item) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected list, got %.200s", Py_TYPE(__pyx_v_item)->tp_name), 0))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 707; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __pyx_t_7 = __pyx_f_4axon_7_dumper_6Dumper__dump_list_sequence(__pyx_v_self, ((PyObject*)__pyx_v_item)); if (unlikely(__pyx_t_7 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 707; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      goto __pyx_L7;
    }

    /* "axon/_dumper.py":708
 *             elif tp is list:
 *                 self._dump_list_sequence(item)
 *             elif tp is set:             # <<<<<<<<<<<<<<
 *                 self._dump_set_sequence(item)
 *             else:
 */
    __pyx_t_5 = (__pyx_v_tp == ((PyObject*)(&PySet_Type)));
    __pyx_t_6 = (__pyx_t_5 != 0);
    if (__pyx_t_6) {

      /* "axon/_dumper.py":709
 *                 self._dump_list_sequence(item)
 *             elif tp is set:
 *                 self._dump_set_sequence(item)             # <<<<<<<<<<<<<<
 *             else:
 *                 for j, v in enumerate(item):
 */
      if (!(likely(PySet_CheckExact(__pyx_v_item))||((__pyx_v_item) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected set, got %.200s", Py_TYPE(__pyx_v_item)->tp_name), 0))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 709; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __pyx_t_7 = __pyx_f_4axon_7_dumper_6Dumper__dump_set_sequence(__pyx_v_self, ((PyObject*)__pyx_v_item)); if (unlikely(__pyx_t_7 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 709; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      goto __pyx_L7;
    }
    /*else*/ {

      /* "axon/_dumper.py":711
 *                 self._dump_set_sequence(item)
 *             else:
 *                 for j, v in enumerate(item):             # <<<<<<<<<<<<<<
 *                     if j > 0:
 *                         self.write(' ')
 */
      __Pyx_INCREF(__pyx_int_0);
      __pyx_t_4 = __pyx_int_0;
      if (PyList_CheckExact(__pyx_v_item) || PyTuple_CheckExact(__pyx_v_item)) {
        __pyx_t_8 = __pyx_v_item; __Pyx_INCREF(__pyx_t_8); __pyx_t_9 = 0;
        __pyx_t_10 = NULL;
      } else {
        __pyx_t_9 = -1; __pyx_t_8 = PyObject_GetIter(__pyx_v_item); if (unlikely(!__pyx_t_8)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 711; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_8);
        __pyx_t_10 = Py_TYPE(__pyx_t_8)->tp_iternext;
      }
      for (;;) {
        if (!__pyx_t_10 && PyList_CheckExact(__pyx_t_8)) {
          if (__pyx_t_9 >= PyList_GET_SIZE(__pyx_t_8)) break;
          #if CYTHON_COMPILING_IN_CPYTHON
          __pyx_t_11 = PyList_GET_ITEM(__pyx_t_8, __pyx_t_9); __Pyx_INCREF(__pyx_t_11); __pyx_t_9++; if (unlikely(0 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 711; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
          #else
          __pyx_t_11 = PySequence_ITEM(__pyx_t_8, __pyx_t_9); __pyx_t_9++; if (unlikely(!__pyx_t_11)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 711; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
          #endif
        } else if (!__pyx_t_10 && PyTuple_CheckExact(__pyx_t_8)) {
          if (__pyx_t_9 >= PyTuple_GET_SIZE(__pyx_t_8)) break;
          #if CYTHON_COMPILING_IN_CPYTHON
          __pyx_t_11 = PyTuple_GET_ITEM(__pyx_t_8, __pyx_t_9); __Pyx_INCREF(__pyx_t_11); __pyx_t_9++; if (unlikely(0 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 711; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
          #else
          __pyx_t_11 = PySequence_ITEM(__pyx_t_8, __pyx_t_9); __pyx_t_9++; if (unlikely(!__pyx_t_11)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 711; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
          #endif
        } else {
          __pyx_t_11 = __pyx_t_10(__pyx_t_8);
          if (unlikely(!__pyx_t_11)) {
            if (PyErr_Occurred()) {
              if (likely(PyErr_ExceptionMatches(PyExc_StopIteration))) PyErr_Clear();
              else {__pyx_filename = __pyx_f[0]; __pyx_lineno = 711; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
            }
            break;
          }
          __Pyx_GOTREF(__pyx_t_11);
        }
        __Pyx_XDECREF(__pyx_v_v);
        __pyx_v_v = __pyx_t_11;
        __pyx_t_11 = 0;
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_XDECREF(__pyx_v_j);
        __pyx_v_j = __pyx_t_4;
        __pyx_t_11 = PyNumber_Add(__pyx_t_4, __pyx_int_1); if (unlikely(!__pyx_t_11)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 711; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_11);
        __Pyx_DECREF(__pyx_t_4);
        __pyx_t_4 = __pyx_t_11;
        __pyx_t_11 = 0;

        /* "axon/_dumper.py":712
 *             else:
 *                 for j, v in enumerate(item):
 *                     if j > 0:             # <<<<<<<<<<<<<<
 *                         self.write(' ')
 *                     self._dump(v)
 */
        __pyx_t_11 = PyObject_RichCompare(__pyx_v_j, __pyx_int_0, Py_GT); __Pyx_XGOTREF(__pyx_t_11); if (unlikely(!__pyx_t_11)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 712; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_11); if (unlikely(__pyx_t_6 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 712; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
        if (__pyx_t_6) {

          /* "axon/_dumper.py":713
 *                 for j, v in enumerate(item):
 *                     if j > 0:
 *                         self.write(' ')             # <<<<<<<<<<<<<<
 *                     self._dump(v)
 *     #
 */
          __pyx_t_11 = PyObject_Call(__pyx_v_self->write, ((PyObject *)__pyx_k_tuple_83), NULL); if (unlikely(!__pyx_t_11)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 713; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
          __Pyx_GOTREF(__pyx_t_11);
          __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
          goto __pyx_L10;
        }
        __pyx_L10:;

        /* "axon/_dumper.py":714
 *                     if j > 0:
 *                         self.write(' ')
 *                     self._dump(v)             # <<<<<<<<<<<<<<
 *     #
 *     def dump_collection(self, name, collection):
 */
        __pyx_t_7 = __pyx_f_4axon_7_dumper_6Dumper__dump(__pyx_v_self, __pyx_v_v); if (unlikely(__pyx_t_7 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 714; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      }
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
    __pyx_L7:;
    __pyx_L3_continue:;
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_AddTraceback("axon._dumper.Dumper.dump_content", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_item);
  __Pyx_XDECREF(__pyx_v_tp);
  __Pyx_XDECREF(__pyx_v_j);
  __Pyx_XDECREF(__pyx_v_v);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_dumper.py":716
 *                     self._dump(v)
 *     #
 *     def dump_collection(self, name, collection):             # <<<<<<<<<<<<<<
 *         N = len(collection)
 *         for i, o in enumerate(collection):
 */

static int __pyx_f_4axon_7_dumper_6Dumper_dump_collection(struct Dumper *__pyx_v_self, PyObject *__pyx_v_name, PyObject *__pyx_v_collection) {
  CYTHON_UNUSED PyObject *__pyx_v_N = NULL;
  PyObject *__pyx_v_i = NULL;
  PyObject *__pyx_v_o = NULL;
  int __pyx_v_v;
  PyObject *__pyx_v_otype = NULL;
  PyObject *__pyx_v_reducer = NULL;
  PyObject *__pyx_v_items = NULL;
  PyObject *__pyx_v_n = NULL;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  Py_ssize_t __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  Py_ssize_t __pyx_t_8;
  int __pyx_t_9;
  int __pyx_t_10;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("dump_collection", 0);

  /* "axon/_dumper.py":717
 *     #
 *     def dump_collection(self, name, collection):
 *         N = len(collection)             # <<<<<<<<<<<<<<
 *         for i, o in enumerate(collection):
 *             if self.crossref:
 */
  if (unlikely(((PyObject *)__pyx_v_collection) == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "object of type 'NoneType' has no len()");
    {__pyx_filename = __pyx_f[0]; __pyx_lineno = 717; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }
  __pyx_t_1 = PyList_GET_SIZE(((PyObject *)__pyx_v_collection)); if (unlikely(__pyx_t_1 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 717; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_t_2 = PyInt_FromSsize_t(__pyx_t_1); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 717; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_v_N = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "axon/_dumper.py":718
 *     def dump_collection(self, name, collection):
 *         N = len(collection)
 *         for i, o in enumerate(collection):             # <<<<<<<<<<<<<<
 *             if self.crossref:
 *                 self.write(' ')
 */
  __Pyx_INCREF(__pyx_int_0);
  __pyx_t_2 = __pyx_int_0;
  __pyx_t_3 = ((PyObject *)__pyx_v_collection); __Pyx_INCREF(__pyx_t_3); __pyx_t_1 = 0;
  for (;;) {
    if (__pyx_t_1 >= PyList_GET_SIZE(__pyx_t_3)) break;
    #if CYTHON_COMPILING_IN_CPYTHON
    __pyx_t_4 = PyList_GET_ITEM(__pyx_t_3, __pyx_t_1); __Pyx_INCREF(__pyx_t_4); __pyx_t_1++; if (unlikely(0 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 718; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    #else
    __pyx_t_4 = PySequence_ITEM(__pyx_t_3, __pyx_t_1); __pyx_t_1++; if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 718; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    #endif
    __Pyx_XDECREF(__pyx_v_o);
    __pyx_v_o = __pyx_t_4;
    __pyx_t_4 = 0;
    __Pyx_INCREF(__pyx_t_2);
    __Pyx_XDECREF(__pyx_v_i);
    __pyx_v_i = __pyx_t_2;
    __pyx_t_4 = PyNumber_Add(__pyx_t_2, __pyx_int_1); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 718; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_2);
    __pyx_t_2 = __pyx_t_4;
    __pyx_t_4 = 0;

    /* "axon/_dumper.py":719
 *         N = len(collection)
 *         for i, o in enumerate(collection):
 *             if self.crossref:             # <<<<<<<<<<<<<<
 *                 self.write(' ')
 *                 v =  self._dump_label(o)
 */
    __pyx_t_5 = (__pyx_v_self->crossref != 0);
    if (__pyx_t_5) {

      /* "axon/_dumper.py":720
 *         for i, o in enumerate(collection):
 *             if self.crossref:
 *                 self.write(' ')             # <<<<<<<<<<<<<<
 *                 v =  self._dump_label(o)
 *                 if v == 1:
 */
      __pyx_t_4 = PyObject_Call(__pyx_v_self->write, ((PyObject *)__pyx_k_tuple_84), NULL); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 720; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

      /* "axon/_dumper.py":721
 *             if self.crossref:
 *                 self.write(' ')
 *                 v =  self._dump_label(o)             # <<<<<<<<<<<<<<
 *                 if v == 1:
 *                     return 0
 */
      __pyx_v_v = __pyx_f_4axon_7_dumper_6Dumper__dump_label(__pyx_v_self, __pyx_v_o);

      /* "axon/_dumper.py":722
 *                 self.write(' ')
 *                 v =  self._dump_label(o)
 *                 if v == 1:             # <<<<<<<<<<<<<<
 *                     return 0
 * 
 */
      __pyx_t_5 = ((__pyx_v_v == 1) != 0);
      if (__pyx_t_5) {

        /* "axon/_dumper.py":723
 *                 v =  self._dump_label(o)
 *                 if v == 1:
 *                     return 0             # <<<<<<<<<<<<<<
 * 
 *             self.write('{')
 */
        __pyx_r = 0;
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        goto __pyx_L0;
        goto __pyx_L6;
      }
      __pyx_L6:;
      goto __pyx_L5;
    }
    __pyx_L5:;

    /* "axon/_dumper.py":725
 *                     return 0
 * 
 *             self.write('{')             # <<<<<<<<<<<<<<
 * 
 *             otype = type(o)
 */
    __pyx_t_4 = PyObject_Call(__pyx_v_self->write, ((PyObject *)__pyx_k_tuple_85), NULL); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 725; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

    /* "axon/_dumper.py":727
 *             self.write('{')
 * 
 *             otype = type(o)             # <<<<<<<<<<<<<<
 *             reducer = self.c_type_reducers.get(otype, None)
 *             if reducer is None:
 */
    __Pyx_INCREF(((PyObject *)Py_TYPE(__pyx_v_o)));
    __Pyx_XDECREF(((PyObject *)__pyx_v_otype));
    __pyx_v_otype = ((PyObject*)((PyObject *)Py_TYPE(__pyx_v_o)));

    /* "axon/_dumper.py":728
 * 
 *             otype = type(o)
 *             reducer = self.c_type_reducers.get(otype, None)             # <<<<<<<<<<<<<<
 *             if reducer is None:
 *                 raise TypeError('There is no reducer for this type: ' + repr(otype))
 */
    if (unlikely(((PyObject *)__pyx_v_self->c_type_reducers) == Py_None)) {
      PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%s'", "get");
      {__pyx_filename = __pyx_f[0]; __pyx_lineno = 728; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    }
    __pyx_t_4 = __Pyx_PyDict_GetItemDefault(((PyObject *)__pyx_v_self->c_type_reducers), ((PyObject *)__pyx_v_otype), Py_None); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 728; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_XDECREF(__pyx_v_reducer);
    __pyx_v_reducer = __pyx_t_4;
    __pyx_t_4 = 0;

    /* "axon/_dumper.py":729
 *             otype = type(o)
 *             reducer = self.c_type_reducers.get(otype, None)
 *             if reducer is None:             # <<<<<<<<<<<<<<
 *                 raise TypeError('There is no reducer for this type: ' + repr(otype))
 *             else:
 */
    __pyx_t_5 = (__pyx_v_reducer == Py_None);
    __pyx_t_6 = (__pyx_t_5 != 0);
    if (__pyx_t_6) {

      /* "axon/_dumper.py":730
 *             reducer = self.c_type_reducers.get(otype, None)
 *             if reducer is None:
 *                 raise TypeError('There is no reducer for this type: ' + repr(otype))             # <<<<<<<<<<<<<<
 *             else:
 *                 items = reducer(o)
 */
      __pyx_t_4 = PyObject_Repr(((PyObject *)__pyx_v_otype)); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 730; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_7 = PyNumber_Add(((PyObject *)__pyx_kp_u_42), __pyx_t_4); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 730; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_4 = PyTuple_New(1); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 730; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_4);
      PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_7);
      __Pyx_GIVEREF(__pyx_t_7);
      __pyx_t_7 = 0;
      __pyx_t_7 = PyObject_Call(__pyx_builtin_TypeError, ((PyObject *)__pyx_t_4), NULL); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 730; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(((PyObject *)__pyx_t_4)); __pyx_t_4 = 0;
      __Pyx_Raise(__pyx_t_7, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      {__pyx_filename = __pyx_f[0]; __pyx_lineno = 730; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      goto __pyx_L7;
    }
    /*else*/ {

      /* "axon/_dumper.py":732
 *                 raise TypeError('There is no reducer for this type: ' + repr(otype))
 *             else:
 *                 items = reducer(o)             # <<<<<<<<<<<<<<
 *                 n = len(items)
 * 
 */
      __pyx_t_7 = PyTuple_New(1); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 732; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_INCREF(__pyx_v_o);
      PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_v_o);
      __Pyx_GIVEREF(__pyx_v_o);
      __pyx_t_4 = PyObject_Call(__pyx_v_reducer, ((PyObject *)__pyx_t_7), NULL); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 732; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(((PyObject *)__pyx_t_7)); __pyx_t_7 = 0;
      __Pyx_XDECREF(__pyx_v_items);
      __pyx_v_items = __pyx_t_4;
      __pyx_t_4 = 0;

      /* "axon/_dumper.py":733
 *             else:
 *                 items = reducer(o)
 *                 n = len(items)             # <<<<<<<<<<<<<<
 * 
 *                 if name != items[0]:
 */
      __pyx_t_8 = PyObject_Length(__pyx_v_items); if (unlikely(__pyx_t_8 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 733; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __pyx_t_4 = PyInt_FromSsize_t(__pyx_t_8); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 733; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_XDECREF(__pyx_v_n);
      __pyx_v_n = __pyx_t_4;
      __pyx_t_4 = 0;

      /* "axon/_dumper.py":735
 *                 n = len(items)
 * 
 *                 if name != items[0]:             # <<<<<<<<<<<<<<
 *                     raise ValueError("Invalid name for collection %s-th item" % i)
 * 
 */
      __pyx_t_4 = __Pyx_GetItemInt(__pyx_v_items, 0, sizeof(long), PyInt_FromLong, 0, 0, 0); if (!__pyx_t_4) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 735; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_7 = PyObject_RichCompare(((PyObject *)__pyx_v_name), __pyx_t_4, Py_NE); __Pyx_XGOTREF(__pyx_t_7); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 735; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_7); if (unlikely(__pyx_t_6 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 735; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      if (__pyx_t_6) {

        /* "axon/_dumper.py":736
 * 
 *                 if name != items[0]:
 *                     raise ValueError("Invalid name for collection %s-th item" % i)             # <<<<<<<<<<<<<<
 * 
 *                 if n < 1 or n > 3:
 */
        __pyx_t_7 = PyNumber_Remainder(((PyObject *)__pyx_kp_u_86), __pyx_v_i); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 736; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(((PyObject *)__pyx_t_7));
        __pyx_t_4 = PyTuple_New(1); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 736; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_4);
        PyTuple_SET_ITEM(__pyx_t_4, 0, ((PyObject *)__pyx_t_7));
        __Pyx_GIVEREF(((PyObject *)__pyx_t_7));
        __pyx_t_7 = 0;
        __pyx_t_7 = PyObject_Call(__pyx_builtin_ValueError, ((PyObject *)__pyx_t_4), NULL); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 736; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_DECREF(((PyObject *)__pyx_t_4)); __pyx_t_4 = 0;
        __Pyx_Raise(__pyx_t_7, 0, 0, 0);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        {__pyx_filename = __pyx_f[0]; __pyx_lineno = 736; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        goto __pyx_L8;
      }
      __pyx_L8:;

      /* "axon/_dumper.py":738
 *                     raise ValueError("Invalid name for collection %s-th item" % i)
 * 
 *                 if n < 1 or n > 3:             # <<<<<<<<<<<<<<
 *                     raise ValueError('Reducer returns invalid number of items: %s' % n)
 *                 elif n > 1:
 */
      __pyx_t_7 = PyObject_RichCompare(__pyx_v_n, __pyx_int_1, Py_LT); __Pyx_XGOTREF(__pyx_t_7); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 738; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_7); if (unlikely(__pyx_t_6 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 738; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      if (!__pyx_t_6) {
        __pyx_t_7 = PyObject_RichCompare(__pyx_v_n, __pyx_int_3, Py_GT); __Pyx_XGOTREF(__pyx_t_7); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 738; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_7); if (unlikely(__pyx_t_5 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 738; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        __pyx_t_9 = __pyx_t_5;
      } else {
        __pyx_t_9 = __pyx_t_6;
      }
      if (__pyx_t_9) {

        /* "axon/_dumper.py":739
 * 
 *                 if n < 1 or n > 3:
 *                     raise ValueError('Reducer returns invalid number of items: %s' % n)             # <<<<<<<<<<<<<<
 *                 elif n > 1:
 *                     self.dump_content(items[1:])
 */
        __pyx_t_7 = PyNumber_Remainder(((PyObject *)__pyx_kp_u_87), __pyx_v_n); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 739; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(((PyObject *)__pyx_t_7));
        __pyx_t_4 = PyTuple_New(1); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 739; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_4);
        PyTuple_SET_ITEM(__pyx_t_4, 0, ((PyObject *)__pyx_t_7));
        __Pyx_GIVEREF(((PyObject *)__pyx_t_7));
        __pyx_t_7 = 0;
        __pyx_t_7 = PyObject_Call(__pyx_builtin_ValueError, ((PyObject *)__pyx_t_4), NULL); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 739; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_DECREF(((PyObject *)__pyx_t_4)); __pyx_t_4 = 0;
        __Pyx_Raise(__pyx_t_7, 0, 0, 0);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        {__pyx_filename = __pyx_f[0]; __pyx_lineno = 739; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        goto __pyx_L9;
      }

      /* "axon/_dumper.py":740
 *                 if n < 1 or n > 3:
 *                     raise ValueError('Reducer returns invalid number of items: %s' % n)
 *                 elif n > 1:             # <<<<<<<<<<<<<<
 *                     self.dump_content(items[1:])
 * 
 */
      __pyx_t_7 = PyObject_RichCompare(__pyx_v_n, __pyx_int_1, Py_GT); __Pyx_XGOTREF(__pyx_t_7); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 740; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __pyx_t_9 = __Pyx_PyObject_IsTrue(__pyx_t_7); if (unlikely(__pyx_t_9 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 740; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      if (__pyx_t_9) {

        /* "axon/_dumper.py":741
 *                     raise ValueError('Reducer returns invalid number of items: %s' % n)
 *                 elif n > 1:
 *                     self.dump_content(items[1:])             # <<<<<<<<<<<<<<
 * 
 *                 self.write('}')
 */
        __pyx_t_7 = __Pyx_PyObject_GetSlice(__pyx_v_items, 1, 0, NULL, NULL, &__pyx_k_slice_88, 1, 0, 0); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 741; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_7);
        if (!(likely(PyTuple_CheckExact(__pyx_t_7))||((__pyx_t_7) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected tuple, got %.200s", Py_TYPE(__pyx_t_7)->tp_name), 0))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 741; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __pyx_t_10 = __pyx_f_4axon_7_dumper_6Dumper_dump_content(__pyx_v_self, ((PyObject*)__pyx_t_7)); if (unlikely(__pyx_t_10 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 741; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        goto __pyx_L9;
      }
      __pyx_L9:;

      /* "axon/_dumper.py":743
 *                     self.dump_content(items[1:])
 * 
 *                 self.write('}')             # <<<<<<<<<<<<<<
 *     #
 *     def _dump_with_reducer(self, reducer, o):
 */
      __pyx_t_7 = PyObject_Call(__pyx_v_self->write, ((PyObject *)__pyx_k_tuple_89), NULL); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 743; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    }
    __pyx_L7:;
  }
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("axon._dumper.Dumper.dump_collection", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_N);
  __Pyx_XDECREF(__pyx_v_i);
  __Pyx_XDECREF(__pyx_v_o);
  __Pyx_XDECREF(__pyx_v_otype);
  __Pyx_XDECREF(__pyx_v_reducer);
  __Pyx_XDECREF(__pyx_v_items);
  __Pyx_XDECREF(__pyx_v_n);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_dumper.py":745
 *                 self.write('}')
 *     #
 *     def _dump_with_reducer(self, reducer, o):             # <<<<<<<<<<<<<<
 * 
 *         results = reducer(o)
 */

static int __pyx_f_4axon_7_dumper_6Dumper__dump_with_reducer(struct Dumper *__pyx_v_self, PyObject *__pyx_v_reducer, PyObject *__pyx_v_o) {
  PyObject *__pyx_v_name = 0;
  unsigned int __pyx_v_n;
  PyObject *__pyx_v_results = NULL;
  long __pyx_v_is_collection;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  Py_ssize_t __pyx_t_3;
  int __pyx_t_4;
  int __pyx_t_5;
  int __pyx_t_6;
  int __pyx_t_7;
  int __pyx_t_8;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_dump_with_reducer", 0);

  /* "axon/_dumper.py":747
 *     def _dump_with_reducer(self, reducer, o):
 * 
 *         results = reducer(o)             # <<<<<<<<<<<<<<
 *         n = len(results)
 * 
 */
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 747; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_v_o);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_o);
  __Pyx_GIVEREF(__pyx_v_o);
  __pyx_t_2 = PyObject_Call(__pyx_v_reducer, ((PyObject *)__pyx_t_1), NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 747; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(((PyObject *)__pyx_t_1)); __pyx_t_1 = 0;
  __pyx_v_results = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "axon/_dumper.py":748
 * 
 *         results = reducer(o)
 *         n = len(results)             # <<<<<<<<<<<<<<
 * 
 *         name = c_as_unicode(results[0])
 */
  __pyx_t_3 = PyObject_Length(__pyx_v_results); if (unlikely(__pyx_t_3 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 748; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_v_n = __pyx_t_3;

  /* "axon/_dumper.py":750
 *         n = len(results)
 * 
 *         name = c_as_unicode(results[0])             # <<<<<<<<<<<<<<
 * 
 *         if name.endswith('*'):
 */
  __pyx_t_2 = __Pyx_GetItemInt(__pyx_v_results, 0, sizeof(long), PyInt_FromLong, 0, 0, 0); if (!__pyx_t_2) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 750; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = ((PyObject *)__pyx_f_4axon_8_objects_c_as_unicode(__pyx_t_2)); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 750; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_name = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "axon/_dumper.py":752
 *         name = c_as_unicode(results[0])
 * 
 *         if name.endswith('*'):             # <<<<<<<<<<<<<<
 *             is_collection = 1
 *             name = c_unicode_substr(name, 0, c_unicode_length(name)-1)
 */
  if (unlikely(((PyObject *)__pyx_v_name) == Py_None)) {
    PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%s'", "endswith");
    {__pyx_filename = __pyx_f[0]; __pyx_lineno = 752; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }
  __pyx_t_4 = __Pyx_PyUnicode_Tailmatch(((PyObject *)__pyx_v_name), ((PyObject *)__pyx_kp_u_1), 0, PY_SSIZE_T_MAX, 1); if (unlikely(__pyx_t_4 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 752; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if ((__pyx_t_4 != 0)) {

    /* "axon/_dumper.py":753
 * 
 *         if name.endswith('*'):
 *             is_collection = 1             # <<<<<<<<<<<<<<
 *             name = c_unicode_substr(name, 0, c_unicode_length(name)-1)
 *         else:
 */
    __pyx_v_is_collection = 1;

    /* "axon/_dumper.py":754
 *         if name.endswith('*'):
 *             is_collection = 1
 *             name = c_unicode_substr(name, 0, c_unicode_length(name)-1)             # <<<<<<<<<<<<<<
 *         else:
 *             is_collection = 0
 */
    __pyx_t_1 = ((PyObject *)c_unicode_substr(__pyx_v_name, 0, (c_unicode_length(__pyx_v_name) - 1))); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 754; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(((PyObject *)__pyx_v_name));
    __pyx_v_name = ((PyObject*)__pyx_t_1);
    __pyx_t_1 = 0;
    goto __pyx_L3;
  }
  /*else*/ {

    /* "axon/_dumper.py":756
 *             name = c_unicode_substr(name, 0, c_unicode_length(name)-1)
 *         else:
 *             is_collection = 0             # <<<<<<<<<<<<<<
 * 
 *         self.write(_dump_name(name, self.quote))
 */
    __pyx_v_is_collection = 0;
  }
  __pyx_L3:;

  /* "axon/_dumper.py":758
 *             is_collection = 0
 * 
 *         self.write(_dump_name(name, self.quote))             # <<<<<<<<<<<<<<
 *         self.size += len(name)
 * 
 */
  __pyx_t_1 = ((PyObject *)__pyx_f_4axon_7_dumper__dump_name(((PyObject *)__pyx_v_name), __pyx_v_self->quote)); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 758; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 758; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __pyx_t_1 = 0;
  __pyx_t_1 = PyObject_Call(__pyx_v_self->write, ((PyObject *)__pyx_t_2), NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 758; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(((PyObject *)__pyx_t_2)); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "axon/_dumper.py":759
 * 
 *         self.write(_dump_name(name, self.quote))
 *         self.size += len(name)             # <<<<<<<<<<<<<<
 * 
 *         if is_collection:
 */
  if (unlikely(((PyObject *)__pyx_v_name) == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "object of type 'NoneType' has no len()");
    {__pyx_filename = __pyx_f[0]; __pyx_lineno = 759; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }
  __pyx_t_3 = __Pyx_PyUnicode_GET_LENGTH(((PyObject *)__pyx_v_name)); if (unlikely(__pyx_t_3 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 759; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_v_self->size = (__pyx_v_self->size + __pyx_t_3);

  /* "axon/_dumper.py":761
 *         self.size += len(name)
 * 
 *         if is_collection:             # <<<<<<<<<<<<<<
 *             self.write('*')
 * 
 */
  __pyx_t_4 = (__pyx_v_is_collection != 0);
  if (__pyx_t_4) {

    /* "axon/_dumper.py":762
 * 
 *         if is_collection:
 *             self.write('*')             # <<<<<<<<<<<<<<
 * 
 *         if not is_collection and (n < 1 or n > 3):
 */
    __pyx_t_1 = PyObject_Call(__pyx_v_self->write, ((PyObject *)__pyx_k_tuple_90), NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 762; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    goto __pyx_L4;
  }
  __pyx_L4:;

  /* "axon/_dumper.py":764
 *             self.write('*')
 * 
 *         if not is_collection and (n < 1 or n > 3):             # <<<<<<<<<<<<<<
 *             raise ValueError('Reducer returns invalid number of items: %s' % n)
 * 
 */
  __pyx_t_4 = ((!(__pyx_v_is_collection != 0)) != 0);
  if (__pyx_t_4) {
    __pyx_t_5 = ((__pyx_v_n < 1) != 0);
    if (!__pyx_t_5) {
      __pyx_t_6 = ((__pyx_v_n > 3) != 0);
      __pyx_t_7 = __pyx_t_6;
    } else {
      __pyx_t_7 = __pyx_t_5;
    }
    __pyx_t_5 = __pyx_t_7;
  } else {
    __pyx_t_5 = __pyx_t_4;
  }
  if (__pyx_t_5) {

    /* "axon/_dumper.py":765
 * 
 *         if not is_collection and (n < 1 or n > 3):
 *             raise ValueError('Reducer returns invalid number of items: %s' % n)             # <<<<<<<<<<<<<<
 * 
 *         if n == 1:
 */
    __pyx_t_1 = PyLong_FromUnsignedLong(__pyx_v_n); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 765; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = PyNumber_Remainder(((PyObject *)__pyx_kp_u_87), __pyx_t_1); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 765; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(((PyObject *)__pyx_t_2));
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 765; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_t_2));
    __Pyx_GIVEREF(((PyObject *)__pyx_t_2));
    __pyx_t_2 = 0;
    __pyx_t_2 = PyObject_Call(__pyx_builtin_ValueError, ((PyObject *)__pyx_t_1), NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 765; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(((PyObject *)__pyx_t_1)); __pyx_t_1 = 0;
    __Pyx_Raise(__pyx_t_2, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    {__pyx_filename = __pyx_f[0]; __pyx_lineno = 765; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    goto __pyx_L5;
  }
  __pyx_L5:;

  /* "axon/_dumper.py":767
 *             raise ValueError('Reducer returns invalid number of items: %s' % n)
 * 
 *         if n == 1:             # <<<<<<<<<<<<<<
 *             self.write('{}')
 *             return 0
 */
  __pyx_t_5 = ((__pyx_v_n == 1) != 0);
  if (__pyx_t_5) {

    /* "axon/_dumper.py":768
 * 
 *         if n == 1:
 *             self.write('{}')             # <<<<<<<<<<<<<<
 *             return 0
 * 
 */
    __pyx_t_2 = PyObject_Call(__pyx_v_self->write, ((PyObject *)__pyx_k_tuple_92), NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 768; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "axon/_dumper.py":769
 *         if n == 1:
 *             self.write('{}')
 *             return 0             # <<<<<<<<<<<<<<
 * 
 *         self.write('{')
 */
    __pyx_r = 0;
    goto __pyx_L0;
    goto __pyx_L6;
  }
  __pyx_L6:;

  /* "axon/_dumper.py":771
 *             return 0
 * 
 *         self.write('{')             # <<<<<<<<<<<<<<
 * 
 *         if is_collection:
 */
  __pyx_t_2 = PyObject_Call(__pyx_v_self->write, ((PyObject *)__pyx_k_tuple_93), NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 771; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "axon/_dumper.py":773
 *         self.write('{')
 * 
 *         if is_collection:             # <<<<<<<<<<<<<<
 *             self.dump_collection(name, results[1])
 *         else:
 */
  __pyx_t_5 = (__pyx_v_is_collection != 0);
  if (__pyx_t_5) {

    /* "axon/_dumper.py":774
 * 
 *         if is_collection:
 *             self.dump_collection(name, results[1])             # <<<<<<<<<<<<<<
 *         else:
 *             self.dump_content(results[1:])
 */
    __pyx_t_2 = __Pyx_GetItemInt(__pyx_v_results, 1, sizeof(long), PyInt_FromLong, 0, 0, 0); if (!__pyx_t_2) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 774; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    if (!(likely(PyList_CheckExact(__pyx_t_2))||((__pyx_t_2) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected list, got %.200s", Py_TYPE(__pyx_t_2)->tp_name), 0))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 774; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __pyx_t_8 = __pyx_f_4axon_7_dumper_6Dumper_dump_collection(__pyx_v_self, __pyx_v_name, ((PyObject*)__pyx_t_2)); if (unlikely(__pyx_t_8 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 774; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    goto __pyx_L7;
  }
  /*else*/ {

    /* "axon/_dumper.py":776
 *             self.dump_collection(name, results[1])
 *         else:
 *             self.dump_content(results[1:])             # <<<<<<<<<<<<<<
 * 
 *         self.write('}')
 */
    __pyx_t_2 = __Pyx_PyObject_GetSlice(__pyx_v_results, 1, 0, NULL, NULL, &__pyx_k_slice_94, 1, 0, 0); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 776; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    if (!(likely(PyTuple_CheckExact(__pyx_t_2))||((__pyx_t_2) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected tuple, got %.200s", Py_TYPE(__pyx_t_2)->tp_name), 0))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 776; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __pyx_t_8 = __pyx_f_4axon_7_dumper_6Dumper_dump_content(__pyx_v_self, ((PyObject*)__pyx_t_2)); if (unlikely(__pyx_t_8 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 776; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_L7:;

  /* "axon/_dumper.py":778
 *             self.dump_content(results[1:])
 * 
 *         self.write('}')             # <<<<<<<<<<<<<<
 *     #
 *     def pretty_dump_content(self, items, offset):
 */
  __pyx_t_2 = PyObject_Call(__pyx_v_self->write, ((PyObject *)__pyx_k_tuple_95), NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 778; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("axon._dumper.Dumper._dump_with_reducer", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_name);
  __Pyx_XDECREF(__pyx_v_results);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_4axon_7_dumper_6Dumper_7pretty_dump_content(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyObject *__pyx_pw_4axon_7_dumper_6Dumper_7pretty_dump_content(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_items = 0;
  PyObject *__pyx_v_offset = 0;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("pretty_dump_content (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s__items,&__pyx_n_s__offset,0};
    PyObject* values[2] = {0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s__items)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s__offset)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("pretty_dump_content", 1, 2, 2, 1); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 780; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "pretty_dump_content") < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 780; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 2) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
    }
    __pyx_v_items = values[0];
    __pyx_v_offset = values[1];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("pretty_dump_content", 1, 2, 2, PyTuple_GET_SIZE(__pyx_args)); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 780; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  __pyx_L3_error:;
  __Pyx_AddTraceback("axon._dumper.Dumper.pretty_dump_content", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_4axon_7_dumper_6Dumper_6pretty_dump_content(((struct Dumper *)__pyx_v_self), __pyx_v_items, __pyx_v_offset);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}
static PyObject *__pyx_gb_4axon_7_dumper_6Dumper_19pretty_dump_content_2generator(__pyx_GeneratorObject *__pyx_generator, PyObject *__pyx_sent_value); /* proto */

/* "axon/_dumper.py":792
 *             tp = type(item)
 *             if tp is dict:
 *                 if len(item) <= self.nsize and all(is_simple_type(self, x) for x in item.values()):             # <<<<<<<<<<<<<<
 *                     self.write("\n")
 *                     self.write(offset1)
 */

static PyObject *__pyx_pf_4axon_7_dumper_6Dumper_19pretty_dump_content_genexpr(PyObject *__pyx_self) {
  struct __pyx_obj_4axon_7_dumper___pyx_scope_struct_3_genexpr *__pyx_cur_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("genexpr", 0);
  __pyx_cur_scope = (struct __pyx_obj_4axon_7_dumper___pyx_scope_struct_3_genexpr *)__pyx_tp_new_4axon_7_dumper___pyx_scope_struct_3_genexpr(__pyx_ptype_4axon_7_dumper___pyx_scope_struct_3_genexpr, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __Pyx_RefNannyFinishContext();
    return NULL;
  }
  __Pyx_GOTREF(__pyx_cur_scope);
  __pyx_cur_scope->__pyx_outer_scope = (struct __pyx_obj_4axon_7_dumper___pyx_scope_struct_2_pretty_dump_content *) __pyx_self;
  __Pyx_INCREF(((PyObject *)__pyx_cur_scope->__pyx_outer_scope));
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_outer_scope);
  {
    __pyx_GeneratorObject *gen = __Pyx_Generator_New((__pyx_generator_body_t) __pyx_gb_4axon_7_dumper_6Dumper_19pretty_dump_content_2generator, (PyObject *) __pyx_cur_scope); if (unlikely(!gen)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 792; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_DECREF(__pyx_cur_scope);
    __Pyx_RefNannyFinishContext();
    return (PyObject *) gen;
  }

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("axon._dumper.Dumper.pretty_dump_content.genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_DECREF(((PyObject *)__pyx_cur_scope));
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_gb_4axon_7_dumper_6Dumper_19pretty_dump_content_2generator(__pyx_GeneratorObject *__pyx_generator, PyObject *__pyx_sent_value) /* generator body */
{
  struct __pyx_obj_4axon_7_dumper___pyx_scope_struct_3_genexpr *__pyx_cur_scope = ((struct __pyx_obj_4axon_7_dumper___pyx_scope_struct_3_genexpr *)__pyx_generator->closure);
  PyObject *__pyx_r = NULL;
  PyObject *__pyx_t_1 = NULL;
  Py_ssize_t __pyx_t_2;
  Py_ssize_t __pyx_t_3;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("None", 0);
  switch (__pyx_generator->resume_label) {
    case 0: goto __pyx_L3_first_run;
    case 1: goto __pyx_L6_resume_from_yield;
    default: /* CPython raises the right error here */
    __Pyx_RefNannyFinishContext();
    return NULL;
  }
  __pyx_L3_first_run:;
  if (unlikely(!__pyx_sent_value)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 792; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_t_2 = 0;
  if (unlikely(!__pyx_cur_scope->__pyx_outer_scope->__pyx_v_item)) { __Pyx_RaiseClosureNameError("item"); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 792; __pyx_clineno = __LINE__; goto __pyx_L1_error;} }
  if (unlikely(__pyx_cur_scope->__pyx_outer_scope->__pyx_v_item == Py_None)) {
    PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%s'", "values");
    {__pyx_filename = __pyx_f[0]; __pyx_lineno = 792; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }
  __pyx_t_5 = __Pyx_dict_iterator(__pyx_cur_scope->__pyx_outer_scope->__pyx_v_item, 0, ((PyObject *)__pyx_n_s__values), (&__pyx_t_3), (&__pyx_t_4)); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 792; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_1);
  __pyx_t_1 = __pyx_t_5;
  __pyx_t_5 = 0;
  while (1) {
    __pyx_t_6 = __Pyx_dict_iter_next(__pyx_t_1, __pyx_t_3, &__pyx_t_2, NULL, &__pyx_t_5, NULL, __pyx_t_4);
    if (unlikely(__pyx_t_6 == 0)) break;
    if (unlikely(__pyx_t_6 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 792; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_XGOTREF(__pyx_cur_scope->__pyx_v_x);
    __Pyx_XDECREF(__pyx_cur_scope->__pyx_v_x);
    __Pyx_GIVEREF(__pyx_t_5);
    __pyx_cur_scope->__pyx_v_x = __pyx_t_5;
    __pyx_t_5 = 0;
    if (unlikely(!__pyx_cur_scope->__pyx_outer_scope->__pyx_v_self)) { __Pyx_RaiseClosureNameError("self"); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 792; __pyx_clineno = __LINE__; goto __pyx_L1_error;} }
    __pyx_t_5 = ((PyObject *)__pyx_cur_scope->__pyx_outer_scope->__pyx_v_self);
    __Pyx_INCREF(__pyx_t_5);
    __pyx_t_7 = __Pyx_PyBool_FromLong(__pyx_f_4axon_7_dumper_is_simple_type(((struct Dumper *)__pyx_t_5), __pyx_cur_scope->__pyx_v_x)); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 792; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_r = __pyx_t_7;
    __pyx_t_7 = 0;
    __Pyx_XGIVEREF(__pyx_t_1);
    __pyx_cur_scope->__pyx_t_0 = __pyx_t_1;
    __pyx_cur_scope->__pyx_t_1 = __pyx_t_2;
    __pyx_cur_scope->__pyx_t_2 = __pyx_t_3;
    __pyx_cur_scope->__pyx_t_3 = __pyx_t_4;
    __Pyx_XGIVEREF(__pyx_r);
    __Pyx_RefNannyFinishContext();
    /* return from generator, yielding value */
    __pyx_generator->resume_label = 1;
    return __pyx_r;
    __pyx_L6_resume_from_yield:;
    __pyx_t_1 = __pyx_cur_scope->__pyx_t_0;
    __pyx_cur_scope->__pyx_t_0 = 0;
    __Pyx_XGOTREF(__pyx_t_1);
    __pyx_t_2 = __pyx_cur_scope->__pyx_t_1;
    __pyx_t_3 = __pyx_cur_scope->__pyx_t_2;
    __pyx_t_4 = __pyx_cur_scope->__pyx_t_3;
    if (unlikely(!__pyx_sent_value)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 792; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  PyErr_SetNone(PyExc_StopIteration);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_r);
  __pyx_generator->resume_label = -1;
  __Pyx_Generator_clear((PyObject*)__pyx_generator);
  __Pyx_RefNannyFinishContext();
  return NULL;
}
static PyObject *__pyx_gb_4axon_7_dumper_6Dumper_19pretty_dump_content_5generator1(__pyx_GeneratorObject *__pyx_generator, PyObject *__pyx_sent_value); /* proto */

/* "axon/_dumper.py":799
 *                     self._pretty_dump_attr_sequence(item, offset1, use_offset)
 *             elif tp is tuple:
 *                 if len(item) <= self.nsize and all(is_simple_type(self, x) for x in item):             # <<<<<<<<<<<<<<
 *                     self.write("\n")
 *                     self.write(offset1)
 */

static PyObject *__pyx_pf_4axon_7_dumper_6Dumper_19pretty_dump_content_3genexpr(PyObject *__pyx_self) {
  struct __pyx_obj_4axon_7_dumper___pyx_scope_struct_4_genexpr *__pyx_cur_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("genexpr", 0);
  __pyx_cur_scope = (struct __pyx_obj_4axon_7_dumper___pyx_scope_struct_4_genexpr *)__pyx_tp_new_4axon_7_dumper___pyx_scope_struct_4_genexpr(__pyx_ptype_4axon_7_dumper___pyx_scope_struct_4_genexpr, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __Pyx_RefNannyFinishContext();
    return NULL;
  }
  __Pyx_GOTREF(__pyx_cur_scope);
  __pyx_cur_scope->__pyx_outer_scope = (struct __pyx_obj_4axon_7_dumper___pyx_scope_struct_2_pretty_dump_content *) __pyx_self;
  __Pyx_INCREF(((PyObject *)__pyx_cur_scope->__pyx_outer_scope));
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_outer_scope);
  {
    __pyx_GeneratorObject *gen = __Pyx_Generator_New((__pyx_generator_body_t) __pyx_gb_4axon_7_dumper_6Dumper_19pretty_dump_content_5generator1, (PyObject *) __pyx_cur_scope); if (unlikely(!gen)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 799; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_DECREF(__pyx_cur_scope);
    __Pyx_RefNannyFinishContext();
    return (PyObject *) gen;
  }

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("axon._dumper.Dumper.pretty_dump_content.genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_DECREF(((PyObject *)__pyx_cur_scope));
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_gb_4axon_7_dumper_6Dumper_19pretty_dump_content_5generator1(__pyx_GeneratorObject *__pyx_generator, PyObject *__pyx_sent_value) /* generator body */
{
  struct __pyx_obj_4axon_7_dumper___pyx_scope_struct_4_genexpr *__pyx_cur_scope = ((struct __pyx_obj_4axon_7_dumper___pyx_scope_struct_4_genexpr *)__pyx_generator->closure);
  PyObject *__pyx_r = NULL;
  PyObject *__pyx_t_1 = NULL;
  Py_ssize_t __pyx_t_2;
  PyObject *(*__pyx_t_3)(PyObject *);
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("None", 0);
  switch (__pyx_generator->resume_label) {
    case 0: goto __pyx_L3_first_run;
    case 1: goto __pyx_L6_resume_from_yield;
    default: /* CPython raises the right error here */
    __Pyx_RefNannyFinishContext();
    return NULL;
  }
  __pyx_L3_first_run:;
  if (unlikely(!__pyx_sent_value)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 799; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (unlikely(!__pyx_cur_scope->__pyx_outer_scope->__pyx_v_item)) { __Pyx_RaiseClosureNameError("item"); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 799; __pyx_clineno = __LINE__; goto __pyx_L1_error;} }
  if (PyList_CheckExact(__pyx_cur_scope->__pyx_outer_scope->__pyx_v_item) || PyTuple_CheckExact(__pyx_cur_scope->__pyx_outer_scope->__pyx_v_item)) {
    __pyx_t_1 = __pyx_cur_scope->__pyx_outer_scope->__pyx_v_item; __Pyx_INCREF(__pyx_t_1); __pyx_t_2 = 0;
    __pyx_t_3 = NULL;
  } else {
    __pyx_t_2 = -1; __pyx_t_1 = PyObject_GetIter(__pyx_cur_scope->__pyx_outer_scope->__pyx_v_item); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 799; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = Py_TYPE(__pyx_t_1)->tp_iternext;
  }
  for (;;) {
    if (!__pyx_t_3 && PyList_CheckExact(__pyx_t_1)) {
      if (__pyx_t_2 >= PyList_GET_SIZE(__pyx_t_1)) break;
      #if CYTHON_COMPILING_IN_CPYTHON
      __pyx_t_4 = PyList_GET_ITEM(__pyx_t_1, __pyx_t_2); __Pyx_INCREF(__pyx_t_4); __pyx_t_2++; if (unlikely(0 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 799; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      #else
      __pyx_t_4 = PySequence_ITEM(__pyx_t_1, __pyx_t_2); __pyx_t_2++; if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 799; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      #endif
    } else if (!__pyx_t_3 && PyTuple_CheckExact(__pyx_t_1)) {
      if (__pyx_t_2 >= PyTuple_GET_SIZE(__pyx_t_1)) break;
      #if CYTHON_COMPILING_IN_CPYTHON
      __pyx_t_4 = PyTuple_GET_ITEM(__pyx_t_1, __pyx_t_2); __Pyx_INCREF(__pyx_t_4); __pyx_t_2++; if (unlikely(0 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 799; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      #else
      __pyx_t_4 = PySequence_ITEM(__pyx_t_1, __pyx_t_2); __pyx_t_2++; if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 799; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      #endif
    } else {
      __pyx_t_4 = __pyx_t_3(__pyx_t_1);
      if (unlikely(!__pyx_t_4)) {
        if (PyErr_Occurred()) {
          if (likely(PyErr_ExceptionMatches(PyExc_StopIteration))) PyErr_Clear();
          else {__pyx_filename = __pyx_f[0]; __pyx_lineno = 799; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_4);
    }
    __Pyx_XGOTREF(__pyx_cur_scope->__pyx_v_x);
    __Pyx_XDECREF(__pyx_cur_scope->__pyx_v_x);
    __Pyx_GIVEREF(__pyx_t_4);
    __pyx_cur_scope->__pyx_v_x = __pyx_t_4;
    __pyx_t_4 = 0;
    if (unlikely(!__pyx_cur_scope->__pyx_outer_scope->__pyx_v_self)) { __Pyx_RaiseClosureNameError("self"); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 799; __pyx_clineno = __LINE__; goto __pyx_L1_error;} }
    __pyx_t_4 = ((PyObject *)__pyx_cur_scope->__pyx_outer_scope->__pyx_v_self);
    __Pyx_INCREF(__pyx_t_4);
    __pyx_t_5 = __Pyx_PyBool_FromLong(__pyx_f_4axon_7_dumper_is_simple_type(((struct Dumper *)__pyx_t_4), __pyx_cur_scope->__pyx_v_x)); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 799; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_r = __pyx_t_5;
    __pyx_t_5 = 0;
    __Pyx_XGIVEREF(__pyx_t_1);
    __pyx_cur_scope->__pyx_t_0 = __pyx_t_1;
    __pyx_cur_scope->__pyx_t_1 = __pyx_t_2;
    __pyx_cur_scope->__pyx_t_2 = __pyx_t_3;
    __Pyx_XGIVEREF(__pyx_r);
    __Pyx_RefNannyFinishContext();
    /* return from generator, yielding value */
    __pyx_generator->resume_label = 1;
    return __pyx_r;
    __pyx_L6_resume_from_yield:;
    __pyx_t_1 = __pyx_cur_scope->__pyx_t_0;
    __pyx_cur_scope->__pyx_t_0 = 0;
    __Pyx_XGOTREF(__pyx_t_1);
    __pyx_t_2 = __pyx_cur_scope->__pyx_t_1;
    __pyx_t_3 = __pyx_cur_scope->__pyx_t_2;
    if (unlikely(!__pyx_sent_value)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 799; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  PyErr_SetNone(PyExc_StopIteration);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_r);
  __pyx_generator->resume_label = -1;
  __Pyx_Generator_clear((PyObject*)__pyx_generator);
  __Pyx_RefNannyFinishContext();
  return NULL;
}
static PyObject *__pyx_gb_4axon_7_dumper_6Dumper_19pretty_dump_content_8generator2(__pyx_GeneratorObject *__pyx_generator, PyObject *__pyx_sent_value); /* proto */

/* "axon/_dumper.py":806
 *                     self._pretty_dump_tuple_sequence(item, offset1, use_offset)
 *             elif tp is list:
 *                 if len(item) <= self.nsize and all(is_simple_type(self, x) for x in item):             # <<<<<<<<<<<<<<
 *                     self.write("\n")
 *                     self.write(offset1)
 */

static PyObject *__pyx_pf_4axon_7_dumper_6Dumper_19pretty_dump_content_6genexpr(PyObject *__pyx_self) {
  struct __pyx_obj_4axon_7_dumper___pyx_scope_struct_5_genexpr *__pyx_cur_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("genexpr", 0);
  __pyx_cur_scope = (struct __pyx_obj_4axon_7_dumper___pyx_scope_struct_5_genexpr *)__pyx_tp_new_4axon_7_dumper___pyx_scope_struct_5_genexpr(__pyx_ptype_4axon_7_dumper___pyx_scope_struct_5_genexpr, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __Pyx_RefNannyFinishContext();
    return NULL;
  }
  __Pyx_GOTREF(__pyx_cur_scope);
  __pyx_cur_scope->__pyx_outer_scope = (struct __pyx_obj_4axon_7_dumper___pyx_scope_struct_2_pretty_dump_content *) __pyx_self;
  __Pyx_INCREF(((PyObject *)__pyx_cur_scope->__pyx_outer_scope));
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_outer_scope);
  {
    __pyx_GeneratorObject *gen = __Pyx_Generator_New((__pyx_generator_body_t) __pyx_gb_4axon_7_dumper_6Dumper_19pretty_dump_content_8generator2, (PyObject *) __pyx_cur_scope); if (unlikely(!gen)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 806; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_DECREF(__pyx_cur_scope);
    __Pyx_RefNannyFinishContext();
    return (PyObject *) gen;
  }

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("axon._dumper.Dumper.pretty_dump_content.genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_DECREF(((PyObject *)__pyx_cur_scope));
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_gb_4axon_7_dumper_6Dumper_19pretty_dump_content_8generator2(__pyx_GeneratorObject *__pyx_generator, PyObject *__pyx_sent_value) /* generator body */
{
  struct __pyx_obj_4axon_7_dumper___pyx_scope_struct_5_genexpr *__pyx_cur_scope = ((struct __pyx_obj_4axon_7_dumper___pyx_scope_struct_5_genexpr *)__pyx_generator->closure);
  PyObject *__pyx_r = NULL;
  PyObject *__pyx_t_1 = NULL;
  Py_ssize_t __pyx_t_2;
  PyObject *(*__pyx_t_3)(PyObject *);
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("None", 0);
  switch (__pyx_generator->resume_label) {
    case 0: goto __pyx_L3_first_run;
    case 1: goto __pyx_L6_resume_from_yield;
    default: /* CPython raises the right error here */
    __Pyx_RefNannyFinishContext();
    return NULL;
  }
  __pyx_L3_first_run:;
  if (unlikely(!__pyx_sent_value)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 806; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (unlikely(!__pyx_cur_scope->__pyx_outer_scope->__pyx_v_item)) { __Pyx_RaiseClosureNameError("item"); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 806; __pyx_clineno = __LINE__; goto __pyx_L1_error;} }
  if (PyList_CheckExact(__pyx_cur_scope->__pyx_outer_scope->__pyx_v_item) || PyTuple_CheckExact(__pyx_cur_scope->__pyx_outer_scope->__pyx_v_item)) {
    __pyx_t_1 = __pyx_cur_scope->__pyx_outer_scope->__pyx_v_item; __Pyx_INCREF(__pyx_t_1); __pyx_t_2 = 0;
    __pyx_t_3 = NULL;
  } else {
    __pyx_t_2 = -1; __pyx_t_1 = PyObject_GetIter(__pyx_cur_scope->__pyx_outer_scope->__pyx_v_item); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 806; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = Py_TYPE(__pyx_t_1)->tp_iternext;
  }
  for (;;) {
    if (!__pyx_t_3 && PyList_CheckExact(__pyx_t_1)) {
      if (__pyx_t_2 >= PyList_GET_SIZE(__pyx_t_1)) break;
      #if CYTHON_COMPILING_IN_CPYTHON
      __pyx_t_4 = PyList_GET_ITEM(__pyx_t_1, __pyx_t_2); __Pyx_INCREF(__pyx_t_4); __pyx_t_2++; if (unlikely(0 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 806; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      #else
      __pyx_t_4 = PySequence_ITEM(__pyx_t_1, __pyx_t_2); __pyx_t_2++; if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 806; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      #endif
    } else if (!__pyx_t_3 && PyTuple_CheckExact(__pyx_t_1)) {
      if (__pyx_t_2 >= PyTuple_GET_SIZE(__pyx_t_1)) break;
      #if CYTHON_COMPILING_IN_CPYTHON
      __pyx_t_4 = PyTuple_GET_ITEM(__pyx_t_1, __pyx_t_2); __Pyx_INCREF(__pyx_t_4); __pyx_t_2++; if (unlikely(0 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 806; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      #else
      __pyx_t_4 = PySequence_ITEM(__pyx_t_1, __pyx_t_2); __pyx_t_2++; if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 806; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      #endif
    } else {
      __pyx_t_4 = __pyx_t_3(__pyx_t_1);
      if (unlikely(!__pyx_t_4)) {
        if (PyErr_Occurred()) {
          if (likely(PyErr_ExceptionMatches(PyExc_StopIteration))) PyErr_Clear();
          else {__pyx_filename = __pyx_f[0]; __pyx_lineno = 806; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_4);
    }
    __Pyx_XGOTREF(__pyx_cur_scope->__pyx_v_x);
    __Pyx_XDECREF(__pyx_cur_scope->__pyx_v_x);
    __Pyx_GIVEREF(__pyx_t_4);
    __pyx_cur_scope->__pyx_v_x = __pyx_t_4;
    __pyx_t_4 = 0;
    if (unlikely(!__pyx_cur_scope->__pyx_outer_scope->__pyx_v_self)) { __Pyx_RaiseClosureNameError("self"); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 806; __pyx_clineno = __LINE__; goto __pyx_L1_error;} }
    __pyx_t_4 = ((PyObject *)__pyx_cur_scope->__pyx_outer_scope->__pyx_v_self);
    __Pyx_INCREF(__pyx_t_4);
    __pyx_t_5 = __Pyx_PyBool_FromLong(__pyx_f_4axon_7_dumper_is_simple_type(((struct Dumper *)__pyx_t_4), __pyx_cur_scope->__pyx_v_x)); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 806; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_r = __pyx_t_5;
    __pyx_t_5 = 0;
    __Pyx_XGIVEREF(__pyx_t_1);
    __pyx_cur_scope->__pyx_t_0 = __pyx_t_1;
    __pyx_cur_scope->__pyx_t_1 = __pyx_t_2;
    __pyx_cur_scope->__pyx_t_2 = __pyx_t_3;
    __Pyx_XGIVEREF(__pyx_r);
    __Pyx_RefNannyFinishContext();
    /* return from generator, yielding value */
    __pyx_generator->resume_label = 1;
    return __pyx_r;
    __pyx_L6_resume_from_yield:;
    __pyx_t_1 = __pyx_cur_scope->__pyx_t_0;
    __pyx_cur_scope->__pyx_t_0 = 0;
    __Pyx_XGOTREF(__pyx_t_1);
    __pyx_t_2 = __pyx_cur_scope->__pyx_t_1;
    __pyx_t_3 = __pyx_cur_scope->__pyx_t_2;
    if (unlikely(!__pyx_sent_value)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 806; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  PyErr_SetNone(PyExc_StopIteration);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_r);
  __pyx_generator->resume_label = -1;
  __Pyx_Generator_clear((PyObject*)__pyx_generator);
  __Pyx_RefNannyFinishContext();
  return NULL;
}

/* "axon/_dumper.py":780
 *         self.write('}')
 *     #
 *     def pretty_dump_content(self, items, offset):             # <<<<<<<<<<<<<<
 *         offset1 = offset + '  '
 *         use_offset = 1
 */

static PyObject *__pyx_pf_4axon_7_dumper_6Dumper_6pretty_dump_content(struct Dumper *__pyx_v_self, PyObject *__pyx_v_items, PyObject *__pyx_v_offset) {
  struct __pyx_obj_4axon_7_dumper___pyx_scope_struct_2_pretty_dump_content *__pyx_cur_scope;
  PyObject *__pyx_v_offset1 = NULL;
  long __pyx_v_use_offset;
  CYTHON_UNUSED PyObject *__pyx_v_n = NULL;
  PyObject *__pyx_v_tp = NULL;
  PyObject *__pyx_v_v = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  Py_ssize_t __pyx_t_2;
  PyObject *(*__pyx_t_3)(PyObject *);
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_t_6;
  Py_ssize_t __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  int __pyx_t_9;
  int __pyx_t_10;
  PyObject *(*__pyx_t_11)(PyObject *);
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("pretty_dump_content", 0);
  __pyx_cur_scope = (struct __pyx_obj_4axon_7_dumper___pyx_scope_struct_2_pretty_dump_content *)__pyx_tp_new_4axon_7_dumper___pyx_scope_struct_2_pretty_dump_content(__pyx_ptype_4axon_7_dumper___pyx_scope_struct_2_pretty_dump_content, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __Pyx_RefNannyFinishContext();
    return NULL;
  }
  __Pyx_GOTREF(__pyx_cur_scope);
  __pyx_cur_scope->__pyx_v_self = __pyx_v_self;
  __Pyx_INCREF((PyObject *)__pyx_cur_scope->__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_cur_scope->__pyx_v_self);

  /* "axon/_dumper.py":781
 *     #
 *     def pretty_dump_content(self, items, offset):
 *         offset1 = offset + '  '             # <<<<<<<<<<<<<<
 *         use_offset = 1
 *         n = len(items)
 */
  __pyx_t_1 = PyNumber_Add(__pyx_v_offset, ((PyObject *)__pyx_kp_u_43)); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 781; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_offset1 = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "axon/_dumper.py":782
 *     def pretty_dump_content(self, items, offset):
 *         offset1 = offset + '  '
 *         use_offset = 1             # <<<<<<<<<<<<<<
 *         n = len(items)
 * 
 */
  __pyx_v_use_offset = 1;

  /* "axon/_dumper.py":783
 *         offset1 = offset + '  '
 *         use_offset = 1
 *         n = len(items)             # <<<<<<<<<<<<<<
 * 
 *         for item in items:
 */
  __pyx_t_2 = PyObject_Length(__pyx_v_items); if (unlikely(__pyx_t_2 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 783; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_t_1 = PyInt_FromSsize_t(__pyx_t_2); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 783; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_n = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "axon/_dumper.py":785
 *         n = len(items)
 * 
 *         for item in items:             # <<<<<<<<<<<<<<
 * 
 *             if item is None:
 */
  if (PyList_CheckExact(__pyx_v_items) || PyTuple_CheckExact(__pyx_v_items)) {
    __pyx_t_1 = __pyx_v_items; __Pyx_INCREF(__pyx_t_1); __pyx_t_2 = 0;
    __pyx_t_3 = NULL;
  } else {
    __pyx_t_2 = -1; __pyx_t_1 = PyObject_GetIter(__pyx_v_items); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 785; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = Py_TYPE(__pyx_t_1)->tp_iternext;
  }
  for (;;) {
    if (!__pyx_t_3 && PyList_CheckExact(__pyx_t_1)) {
      if (__pyx_t_2 >= PyList_GET_SIZE(__pyx_t_1)) break;
      #if CYTHON_COMPILING_IN_CPYTHON
      __pyx_t_4 = PyList_GET_ITEM(__pyx_t_1, __pyx_t_2); __Pyx_INCREF(__pyx_t_4); __pyx_t_2++; if (unlikely(0 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 785; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      #else
      __pyx_t_4 = PySequence_ITEM(__pyx_t_1, __pyx_t_2); __pyx_t_2++; if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 785; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      #endif
    } else if (!__pyx_t_3 && PyTuple_CheckExact(__pyx_t_1)) {
      if (__pyx_t_2 >= PyTuple_GET_SIZE(__pyx_t_1)) break;
      #if CYTHON_COMPILING_IN_CPYTHON
      __pyx_t_4 = PyTuple_GET_ITEM(__pyx_t_1, __pyx_t_2); __Pyx_INCREF(__pyx_t_4); __pyx_t_2++; if (unlikely(0 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 785; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      #else
      __pyx_t_4 = PySequence_ITEM(__pyx_t_1, __pyx_t_2); __pyx_t_2++; if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 785; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      #endif
    } else {
      __pyx_t_4 = __pyx_t_3(__pyx_t_1);
      if (unlikely(!__pyx_t_4)) {
        if (PyErr_Occurred()) {
          if (likely(PyErr_ExceptionMatches(PyExc_StopIteration))) PyErr_Clear();
          else {__pyx_filename = __pyx_f[0]; __pyx_lineno = 785; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_4);
    }
    __Pyx_XGOTREF(__pyx_cur_scope->__pyx_v_item);
    __Pyx_XDECREF(__pyx_cur_scope->__pyx_v_item);
    __Pyx_GIVEREF(__pyx_t_4);
    __pyx_cur_scope->__pyx_v_item = __pyx_t_4;
    __pyx_t_4 = 0;

    /* "axon/_dumper.py":787
 *         for item in items:
 * 
 *             if item is None:             # <<<<<<<<<<<<<<
 *                 continue
 * 
 */
    __pyx_t_5 = (__pyx_cur_scope->__pyx_v_item == Py_None);
    __pyx_t_6 = (__pyx_t_5 != 0);
    if (__pyx_t_6) {

      /* "axon/_dumper.py":788
 * 
 *             if item is None:
 *                 continue             # <<<<<<<<<<<<<<
 * 
 *             tp = type(item)
 */
      goto __pyx_L3_continue;
      goto __pyx_L5;
    }
    __pyx_L5:;

    /* "axon/_dumper.py":790
 *                 continue
 * 
 *             tp = type(item)             # <<<<<<<<<<<<<<
 *             if tp is dict:
 *                 if len(item) <= self.nsize and all(is_simple_type(self, x) for x in item.values()):
 */
    __Pyx_INCREF(((PyObject *)Py_TYPE(__pyx_cur_scope->__pyx_v_item)));
    __Pyx_XDECREF(((PyObject *)__pyx_v_tp));
    __pyx_v_tp = ((PyObject*)((PyObject *)Py_TYPE(__pyx_cur_scope->__pyx_v_item)));

    /* "axon/_dumper.py":791
 * 
 *             tp = type(item)
 *             if tp is dict:             # <<<<<<<<<<<<<<
 *                 if len(item) <= self.nsize and all(is_simple_type(self, x) for x in item.values()):
 *                     self.write("\n")
 */
    __pyx_t_6 = (__pyx_v_tp == ((PyObject*)(&PyDict_Type)));
    __pyx_t_5 = (__pyx_t_6 != 0);
    if (__pyx_t_5) {

      /* "axon/_dumper.py":792
 *             tp = type(item)
 *             if tp is dict:
 *                 if len(item) <= self.nsize and all(is_simple_type(self, x) for x in item.values()):             # <<<<<<<<<<<<<<
 *                     self.write("\n")
 *                     self.write(offset1)
 */
      __pyx_t_4 = __pyx_cur_scope->__pyx_v_item;
      __Pyx_INCREF(__pyx_t_4);
      __pyx_t_7 = PyObject_Length(__pyx_t_4); if (unlikely(__pyx_t_7 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 792; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_5 = (__pyx_t_7 <= __pyx_cur_scope->__pyx_v_self->nsize);
      if (__pyx_t_5) {
        __pyx_t_4 = __pyx_pf_4axon_7_dumper_6Dumper_19pretty_dump_content_genexpr(((PyObject*)__pyx_cur_scope)); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 792; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_4);
        __pyx_t_8 = PyTuple_New(1); if (unlikely(!__pyx_t_8)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 792; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_8);
        PyTuple_SET_ITEM(__pyx_t_8, 0, __pyx_t_4);
        __Pyx_GIVEREF(__pyx_t_4);
        __pyx_t_4 = 0;
        __pyx_t_4 = PyObject_Call(__pyx_builtin_all, ((PyObject *)__pyx_t_8), NULL); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 792; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(((PyObject *)__pyx_t_8)); __pyx_t_8 = 0;
        __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely(__pyx_t_6 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 792; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __pyx_t_9 = __pyx_t_6;
      } else {
        __pyx_t_9 = __pyx_t_5;
      }
      if (__pyx_t_9) {

        /* "axon/_dumper.py":793
 *             if tp is dict:
 *                 if len(item) <= self.nsize and all(is_simple_type(self, x) for x in item.values()):
 *                     self.write("\n")             # <<<<<<<<<<<<<<
 *                     self.write(offset1)
 *                     self._dump_attr_sequence(item)
 */
        __pyx_t_4 = PyObject_Call(__pyx_cur_scope->__pyx_v_self->write, ((PyObject *)__pyx_k_tuple_96), NULL); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 793; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

        /* "axon/_dumper.py":794
 *                 if len(item) <= self.nsize and all(is_simple_type(self, x) for x in item.values()):
 *                     self.write("\n")
 *                     self.write(offset1)             # <<<<<<<<<<<<<<
 *                     self._dump_attr_sequence(item)
 *                 else:
 */
        __pyx_t_4 = PyTuple_New(1); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 794; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_INCREF(__pyx_v_offset1);
        PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_v_offset1);
        __Pyx_GIVEREF(__pyx_v_offset1);
        __pyx_t_8 = PyObject_Call(__pyx_cur_scope->__pyx_v_self->write, ((PyObject *)__pyx_t_4), NULL); if (unlikely(!__pyx_t_8)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 794; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_DECREF(((PyObject *)__pyx_t_4)); __pyx_t_4 = 0;
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

        /* "axon/_dumper.py":795
 *                     self.write("\n")
 *                     self.write(offset1)
 *                     self._dump_attr_sequence(item)             # <<<<<<<<<<<<<<
 *                 else:
 *                     self._pretty_dump_attr_sequence(item, offset1, use_offset)
 */
        if (!(likely(PyDict_CheckExact(__pyx_cur_scope->__pyx_v_item))||((__pyx_cur_scope->__pyx_v_item) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected dict, got %.200s", Py_TYPE(__pyx_cur_scope->__pyx_v_item)->tp_name), 0))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 795; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __pyx_t_8 = __pyx_cur_scope->__pyx_v_item;
        __Pyx_INCREF(__pyx_t_8);
        __pyx_t_10 = __pyx_f_4axon_7_dumper_6Dumper__dump_attr_sequence(__pyx_cur_scope->__pyx_v_self, ((PyObject*)__pyx_t_8)); if (unlikely(__pyx_t_10 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 795; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        goto __pyx_L7;
      }
      /*else*/ {

        /* "axon/_dumper.py":797
 *                     self._dump_attr_sequence(item)
 *                 else:
 *                     self._pretty_dump_attr_sequence(item, offset1, use_offset)             # <<<<<<<<<<<<<<
 *             elif tp is tuple:
 *                 if len(item) <= self.nsize and all(is_simple_type(self, x) for x in item):
 */
        if (!(likely(PyDict_CheckExact(__pyx_cur_scope->__pyx_v_item))||((__pyx_cur_scope->__pyx_v_item) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected dict, got %.200s", Py_TYPE(__pyx_cur_scope->__pyx_v_item)->tp_name), 0))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 797; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __pyx_t_8 = __pyx_cur_scope->__pyx_v_item;
        __Pyx_INCREF(__pyx_t_8);
        if (!(likely(PyUnicode_CheckExact(__pyx_v_offset1))||((__pyx_v_offset1) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected unicode, got %.200s", Py_TYPE(__pyx_v_offset1)->tp_name), 0))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 797; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __pyx_t_10 = __pyx_f_4axon_7_dumper_6Dumper__pretty_dump_attr_sequence(__pyx_cur_scope->__pyx_v_self, ((PyObject*)__pyx_t_8), ((PyObject*)__pyx_v_offset1), __pyx_v_use_offset); if (unlikely(__pyx_t_10 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 797; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      }
      __pyx_L7:;
      goto __pyx_L6;
    }

    /* "axon/_dumper.py":798
 *                 else:
 *                     self._pretty_dump_attr_sequence(item, offset1, use_offset)
 *             elif tp is tuple:             # <<<<<<<<<<<<<<
 *                 if len(item) <= self.nsize and all(is_simple_type(self, x) for x in item):
 *                     self.write("\n")
 */
    __pyx_t_9 = (__pyx_v_tp == ((PyObject*)(&PyTuple_Type)));
    __pyx_t_5 = (__pyx_t_9 != 0);
    if (__pyx_t_5) {

      /* "axon/_dumper.py":799
 *                     self._pretty_dump_attr_sequence(item, offset1, use_offset)
 *             elif tp is tuple:
 *                 if len(item) <= self.nsize and all(is_simple_type(self, x) for x in item):             # <<<<<<<<<<<<<<
 *                     self.write("\n")
 *                     self.write(offset1)
 */
      __pyx_t_8 = __pyx_cur_scope->__pyx_v_item;
      __Pyx_INCREF(__pyx_t_8);
      __pyx_t_7 = PyObject_Length(__pyx_t_8); if (unlikely(__pyx_t_7 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 799; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_t_5 = (__pyx_t_7 <= __pyx_cur_scope->__pyx_v_self->nsize);
      if (__pyx_t_5) {
        __pyx_t_8 = __pyx_pf_4axon_7_dumper_6Dumper_19pretty_dump_content_3genexpr(((PyObject*)__pyx_cur_scope)); if (unlikely(!__pyx_t_8)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 799; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_8);
        __pyx_t_4 = PyTuple_New(1); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 799; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_4);
        PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_8);
        __Pyx_GIVEREF(__pyx_t_8);
        __pyx_t_8 = 0;
        __pyx_t_8 = PyObject_Call(__pyx_builtin_all, ((PyObject *)__pyx_t_4), NULL); if (unlikely(!__pyx_t_8)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 799; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_DECREF(((PyObject *)__pyx_t_4)); __pyx_t_4 = 0;
        __pyx_t_9 = __Pyx_PyObject_IsTrue(__pyx_t_8); if (unlikely(__pyx_t_9 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 799; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        __pyx_t_6 = __pyx_t_9;
      } else {
        __pyx_t_6 = __pyx_t_5;
      }
      if (__pyx_t_6) {

        /* "axon/_dumper.py":800
 *             elif tp is tuple:
 *                 if len(item) <= self.nsize and all(is_simple_type(self, x) for x in item):
 *                     self.write("\n")             # <<<<<<<<<<<<<<
 *                     self.write(offset1)
 *                     self._dump_tuple_sequence(item)
 */
        __pyx_t_8 = PyObject_Call(__pyx_cur_scope->__pyx_v_self->write, ((PyObject *)__pyx_k_tuple_97), NULL); if (unlikely(!__pyx_t_8)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 800; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

        /* "axon/_dumper.py":801
 *                 if len(item) <= self.nsize and all(is_simple_type(self, x) for x in item):
 *                     self.write("\n")
 *                     self.write(offset1)             # <<<<<<<<<<<<<<
 *                     self._dump_tuple_sequence(item)
 *                 else:
 */
        __pyx_t_8 = PyTuple_New(1); if (unlikely(!__pyx_t_8)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 801; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_INCREF(__pyx_v_offset1);
        PyTuple_SET_ITEM(__pyx_t_8, 0, __pyx_v_offset1);
        __Pyx_GIVEREF(__pyx_v_offset1);
        __pyx_t_4 = PyObject_Call(__pyx_cur_scope->__pyx_v_self->write, ((PyObject *)__pyx_t_8), NULL); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 801; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(((PyObject *)__pyx_t_8)); __pyx_t_8 = 0;
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

        /* "axon/_dumper.py":802
 *                     self.write("\n")
 *                     self.write(offset1)
 *                     self._dump_tuple_sequence(item)             # <<<<<<<<<<<<<<
 *                 else:
 *                     self._pretty_dump_tuple_sequence(item, offset1, use_offset)
 */
        if (!(likely(PyTuple_CheckExact(__pyx_cur_scope->__pyx_v_item))||((__pyx_cur_scope->__pyx_v_item) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected tuple, got %.200s", Py_TYPE(__pyx_cur_scope->__pyx_v_item)->tp_name), 0))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 802; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __pyx_t_4 = __pyx_cur_scope->__pyx_v_item;
        __Pyx_INCREF(__pyx_t_4);
        __pyx_t_10 = __pyx_f_4axon_7_dumper_6Dumper__dump_tuple_sequence(__pyx_cur_scope->__pyx_v_self, ((PyObject*)__pyx_t_4)); if (unlikely(__pyx_t_10 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 802; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        goto __pyx_L8;
      }
      /*else*/ {

        /* "axon/_dumper.py":804
 *                     self._dump_tuple_sequence(item)
 *                 else:
 *                     self._pretty_dump_tuple_sequence(item, offset1, use_offset)             # <<<<<<<<<<<<<<
 *             elif tp is list:
 *                 if len(item) <= self.nsize and all(is_simple_type(self, x) for x in item):
 */
        if (!(likely(PyTuple_CheckExact(__pyx_cur_scope->__pyx_v_item))||((__pyx_cur_scope->__pyx_v_item) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected tuple, got %.200s", Py_TYPE(__pyx_cur_scope->__pyx_v_item)->tp_name), 0))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 804; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __pyx_t_4 = __pyx_cur_scope->__pyx_v_item;
        __Pyx_INCREF(__pyx_t_4);
        if (!(likely(PyUnicode_CheckExact(__pyx_v_offset1))||((__pyx_v_offset1) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected unicode, got %.200s", Py_TYPE(__pyx_v_offset1)->tp_name), 0))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 804; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __pyx_t_10 = __pyx_f_4axon_7_dumper_6Dumper__pretty_dump_tuple_sequence(__pyx_cur_scope->__pyx_v_self, ((PyObject*)__pyx_t_4), ((PyObject*)__pyx_v_offset1), __pyx_v_use_offset); if (unlikely(__pyx_t_10 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 804; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      }
      __pyx_L8:;
      goto __pyx_L6;
    }

    /* "axon/_dumper.py":805
 *                 else:
 *                     self._pretty_dump_tuple_sequence(item, offset1, use_offset)
 *             elif tp is list:             # <<<<<<<<<<<<<<
 *                 if len(item) <= self.nsize and all(is_simple_type(self, x) for x in item):
 *                     self.write("\n")
 */
    __pyx_t_6 = (__pyx_v_tp == ((PyObject*)(&PyList_Type)));
    __pyx_t_5 = (__pyx_t_6 != 0);
    if (__pyx_t_5) {

      /* "axon/_dumper.py":806
 *                     self._pretty_dump_tuple_sequence(item, offset1, use_offset)
 *             elif tp is list:
 *                 if len(item) <= self.nsize and all(is_simple_type(self, x) for x in item):             # <<<<<<<<<<<<<<
 *                     self.write("\n")
 *                     self.write(offset1)
 */
      __pyx_t_4 = __pyx_cur_scope->__pyx_v_item;
      __Pyx_INCREF(__pyx_t_4);
      __pyx_t_7 = PyObject_Length(__pyx_t_4); if (unlikely(__pyx_t_7 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 806; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_5 = (__pyx_t_7 <= __pyx_cur_scope->__pyx_v_self->nsize);
      if (__pyx_t_5) {
        __pyx_t_4 = __pyx_pf_4axon_7_dumper_6Dumper_19pretty_dump_content_6genexpr(((PyObject*)__pyx_cur_scope)); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 806; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_4);
        __pyx_t_8 = PyTuple_New(1); if (unlikely(!__pyx_t_8)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 806; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_8);
        PyTuple_SET_ITEM(__pyx_t_8, 0, __pyx_t_4);
        __Pyx_GIVEREF(__pyx_t_4);
        __pyx_t_4 = 0;
        __pyx_t_4 = PyObject_Call(__pyx_builtin_all, ((PyObject *)__pyx_t_8), NULL); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 806; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(((PyObject *)__pyx_t_8)); __pyx_t_8 = 0;
        __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely(__pyx_t_6 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 806; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __pyx_t_9 = __pyx_t_6;
      } else {
        __pyx_t_9 = __pyx_t_5;
      }
      if (__pyx_t_9) {

        /* "axon/_dumper.py":807
 *             elif tp is list:
 *                 if len(item) <= self.nsize and all(is_simple_type(self, x) for x in item):
 *                     self.write("\n")             # <<<<<<<<<<<<<<
 *                     self.write(offset1)
 *                     self._dump_list_sequence(item)
 */
        __pyx_t_4 = PyObject_Call(__pyx_cur_scope->__pyx_v_self->write, ((PyObject *)__pyx_k_tuple_98), NULL); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 807; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

        /* "axon/_dumper.py":808
 *                 if len(item) <= self.nsize and all(is_simple_type(self, x) for x in item):
 *                     self.write("\n")
 *                     self.write(offset1)             # <<<<<<<<<<<<<<
 *                     self._dump_list_sequence(item)
 *                 else:
 */
        __pyx_t_4 = PyTuple_New(1); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 808; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_INCREF(__pyx_v_offset1);
        PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_v_offset1);
        __Pyx_GIVEREF(__pyx_v_offset1);
        __pyx_t_8 = PyObject_Call(__pyx_cur_scope->__pyx_v_self->write, ((PyObject *)__pyx_t_4), NULL); if (unlikely(!__pyx_t_8)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 808; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_DECREF(((PyObject *)__pyx_t_4)); __pyx_t_4 = 0;
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

        /* "axon/_dumper.py":809
 *                     self.write("\n")
 *                     self.write(offset1)
 *                     self._dump_list_sequence(item)             # <<<<<<<<<<<<<<
 *                 else:
 *                     self._pretty_dump_list_sequence(item, offset1, use_offset)
 */
        if (!(likely(PyList_CheckExact(__pyx_cur_scope->__pyx_v_item))||((__pyx_cur_scope->__pyx_v_item) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected list, got %.200s", Py_TYPE(__pyx_cur_scope->__pyx_v_item)->tp_name), 0))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 809; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __pyx_t_8 = __pyx_cur_scope->__pyx_v_item;
        __Pyx_INCREF(__pyx_t_8);
        __pyx_t_10 = __pyx_f_4axon_7_dumper_6Dumper__dump_list_sequence(__pyx_cur_scope->__pyx_v_self, ((PyObject*)__pyx_t_8)); if (unlikely(__pyx_t_10 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 809; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        goto __pyx_L9;
      }
      /*else*/ {

        /* "axon/_dumper.py":811
 *                     self._dump_list_sequence(item)
 *                 else:
 *                     self._pretty_dump_list_sequence(item, offset1, use_offset)             # <<<<<<<<<<<<<<
 *             else:
 *                 for v in item:
 */
        if (!(likely(PyList_CheckExact(__pyx_cur_scope->__pyx_v_item))||((__pyx_cur_scope->__pyx_v_item) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected list, got %.200s", Py_TYPE(__pyx_cur_scope->__pyx_v_item)->tp_name), 0))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 811; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __pyx_t_8 = __pyx_cur_scope->__pyx_v_item;
        __Pyx_INCREF(__pyx_t_8);
        if (!(likely(PyUnicode_CheckExact(__pyx_v_offset1))||((__pyx_v_offset1) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected unicode, got %.200s", Py_TYPE(__pyx_v_offset1)->tp_name), 0))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 811; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __pyx_t_10 = __pyx_f_4axon_7_dumper_6Dumper__pretty_dump_list_sequence(__pyx_cur_scope->__pyx_v_self, ((PyObject*)__pyx_t_8), ((PyObject*)__pyx_v_offset1), __pyx_v_use_offset); if (unlikely(__pyx_t_10 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 811; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      }
      __pyx_L9:;
      goto __pyx_L6;
    }
    /*else*/ {

      /* "axon/_dumper.py":813
 *                     self._pretty_dump_list_sequence(item, offset1, use_offset)
 *             else:
 *                 for v in item:             # <<<<<<<<<<<<<<
 *                     self.write('\n')
 *                     self._pretty_dump(v, offset1, use_offset)
 */
      if (PyList_CheckExact(__pyx_cur_scope->__pyx_v_item) || PyTuple_CheckExact(__pyx_cur_scope->__pyx_v_item)) {
        __pyx_t_8 = __pyx_cur_scope->__pyx_v_item; __Pyx_INCREF(__pyx_t_8); __pyx_t_7 = 0;
        __pyx_t_11 = NULL;
      } else {
        __pyx_t_7 = -1; __pyx_t_8 = PyObject_GetIter(__pyx_cur_scope->__pyx_v_item); if (unlikely(!__pyx_t_8)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 813; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_8);
        __pyx_t_11 = Py_TYPE(__pyx_t_8)->tp_iternext;
      }
      for (;;) {
        if (!__pyx_t_11 && PyList_CheckExact(__pyx_t_8)) {
          if (__pyx_t_7 >= PyList_GET_SIZE(__pyx_t_8)) break;
          #if CYTHON_COMPILING_IN_CPYTHON
          __pyx_t_4 = PyList_GET_ITEM(__pyx_t_8, __pyx_t_7); __Pyx_INCREF(__pyx_t_4); __pyx_t_7++; if (unlikely(0 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 813; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
          #else
          __pyx_t_4 = PySequence_ITEM(__pyx_t_8, __pyx_t_7); __pyx_t_7++; if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 813; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
          #endif
        } else if (!__pyx_t_11 && PyTuple_CheckExact(__pyx_t_8)) {
          if (__pyx_t_7 >= PyTuple_GET_SIZE(__pyx_t_8)) break;
          #if CYTHON_COMPILING_IN_CPYTHON
          __pyx_t_4 = PyTuple_GET_ITEM(__pyx_t_8, __pyx_t_7); __Pyx_INCREF(__pyx_t_4); __pyx_t_7++; if (unlikely(0 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 813; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
          #else
          __pyx_t_4 = PySequence_ITEM(__pyx_t_8, __pyx_t_7); __pyx_t_7++; if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 813; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
          #endif
        } else {
          __pyx_t_4 = __pyx_t_11(__pyx_t_8);
          if (unlikely(!__pyx_t_4)) {
            if (PyErr_Occurred()) {
              if (likely(PyErr_ExceptionMatches(PyExc_StopIteration))) PyErr_Clear();
              else {__pyx_filename = __pyx_f[0]; __pyx_lineno = 813; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
            }
            break;
          }
          __Pyx_GOTREF(__pyx_t_4);
        }
        __Pyx_XDECREF(__pyx_v_v);
        __pyx_v_v = __pyx_t_4;
        __pyx_t_4 = 0;

        /* "axon/_dumper.py":814
 *             else:
 *                 for v in item:
 *                     self.write('\n')             # <<<<<<<<<<<<<<
 *                     self._pretty_dump(v, offset1, use_offset)
 *     #
 */
        __pyx_t_4 = PyObject_Call(__pyx_cur_scope->__pyx_v_self->write, ((PyObject *)__pyx_k_tuple_99), NULL); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 814; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

        /* "axon/_dumper.py":815
 *                 for v in item:
 *                     self.write('\n')
 *                     self._pretty_dump(v, offset1, use_offset)             # <<<<<<<<<<<<<<
 *     #
 *     def pretty_dump_collection(self, name, collection, offset):
 */
        if (!(likely(PyUnicode_CheckExact(__pyx_v_offset1))||((__pyx_v_offset1) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected unicode, got %.200s", Py_TYPE(__pyx_v_offset1)->tp_name), 0))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 815; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __pyx_t_10 = __pyx_f_4axon_7_dumper_6Dumper__pretty_dump(__pyx_cur_scope->__pyx_v_self, __pyx_v_v, ((PyObject*)__pyx_v_offset1), __pyx_v_use_offset); if (unlikely(__pyx_t_10 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 815; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      }
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    }
    __pyx_L6:;
    __pyx_L3_continue:;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("axon._dumper.Dumper.pretty_dump_content", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_offset1);
  __Pyx_XDECREF(__pyx_v_n);
  __Pyx_XDECREF(__pyx_v_tp);
  __Pyx_XDECREF(__pyx_v_v);
  __Pyx_DECREF(((PyObject *)__pyx_cur_scope));
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_4axon_7_dumper_6Dumper_9pretty_dump_collection(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyObject *__pyx_pw_4axon_7_dumper_6Dumper_9pretty_dump_collection(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_name = 0;
  PyObject *__pyx_v_collection = 0;
  PyObject *__pyx_v_offset = 0;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("pretty_dump_collection (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s__name,&__pyx_n_s__collection,&__pyx_n_s__offset,0};
    PyObject* values[3] = {0,0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s__name)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s__collection)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("pretty_dump_collection", 1, 3, 3, 1); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 817; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
        }
        case  2:
        if (likely((values[2] = PyDict_GetItem(__pyx_kwds, __pyx_n_s__offset)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("pretty_dump_collection", 1, 3, 3, 2); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 817; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "pretty_dump_collection") < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 817; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 3) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
      values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
    }
    __pyx_v_name = values[0];
    __pyx_v_collection = values[1];
    __pyx_v_offset = values[2];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("pretty_dump_collection", 1, 3, 3, PyTuple_GET_SIZE(__pyx_args)); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 817; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  __pyx_L3_error:;
  __Pyx_AddTraceback("axon._dumper.Dumper.pretty_dump_collection", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_4axon_7_dumper_6Dumper_8pretty_dump_collection(((struct Dumper *)__pyx_v_self), __pyx_v_name, __pyx_v_collection, __pyx_v_offset);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_dumper.py":817
 *                     self._pretty_dump(v, offset1, use_offset)
 *     #
 *     def pretty_dump_collection(self, name, collection, offset):             # <<<<<<<<<<<<<<
 *         new_offset = offset + '  '
 *         N = len(collection)
 */

static PyObject *__pyx_pf_4axon_7_dumper_6Dumper_8pretty_dump_collection(struct Dumper *__pyx_v_self, PyObject *__pyx_v_name, PyObject *__pyx_v_collection, PyObject *__pyx_v_offset) {
  PyObject *__pyx_v_new_offset = NULL;
  CYTHON_UNUSED PyObject *__pyx_v_N = NULL;
  PyObject *__pyx_v_i = NULL;
  PyObject *__pyx_v_o = NULL;
  int __pyx_v_v;
  PyObject *__pyx_v_otype = NULL;
  PyObject *__pyx_v_reducer = NULL;
  PyObject *__pyx_v_items = NULL;
  PyObject *__pyx_v_n = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  Py_ssize_t __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *(*__pyx_t_4)(PyObject *);
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  int __pyx_t_8;
  Py_ssize_t __pyx_t_9;
  int __pyx_t_10;
  PyObject *__pyx_t_11 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("pretty_dump_collection", 0);

  /* "axon/_dumper.py":818
 *     #
 *     def pretty_dump_collection(self, name, collection, offset):
 *         new_offset = offset + '  '             # <<<<<<<<<<<<<<
 *         N = len(collection)
 * 
 */
  __pyx_t_1 = PyNumber_Add(__pyx_v_offset, ((PyObject *)__pyx_kp_u_43)); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 818; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_new_offset = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "axon/_dumper.py":819
 *     def pretty_dump_collection(self, name, collection, offset):
 *         new_offset = offset + '  '
 *         N = len(collection)             # <<<<<<<<<<<<<<
 * 
 *         for i, o in enumerate(collection):
 */
  __pyx_t_2 = PyObject_Length(__pyx_v_collection); if (unlikely(__pyx_t_2 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 819; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_t_1 = PyInt_FromSsize_t(__pyx_t_2); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 819; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_N = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "axon/_dumper.py":821
 *         N = len(collection)
 * 
 *         for i, o in enumerate(collection):             # <<<<<<<<<<<<<<
 *             self.write('\n')
 *             self.write(new_offset)
 */
  __Pyx_INCREF(__pyx_int_0);
  __pyx_t_1 = __pyx_int_0;
  if (PyList_CheckExact(__pyx_v_collection) || PyTuple_CheckExact(__pyx_v_collection)) {
    __pyx_t_3 = __pyx_v_collection; __Pyx_INCREF(__pyx_t_3); __pyx_t_2 = 0;
    __pyx_t_4 = NULL;
  } else {
    __pyx_t_2 = -1; __pyx_t_3 = PyObject_GetIter(__pyx_v_collection); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 821; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = Py_TYPE(__pyx_t_3)->tp_iternext;
  }
  for (;;) {
    if (!__pyx_t_4 && PyList_CheckExact(__pyx_t_3)) {
      if (__pyx_t_2 >= PyList_GET_SIZE(__pyx_t_3)) break;
      #if CYTHON_COMPILING_IN_CPYTHON
      __pyx_t_5 = PyList_GET_ITEM(__pyx_t_3, __pyx_t_2); __Pyx_INCREF(__pyx_t_5); __pyx_t_2++; if (unlikely(0 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 821; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      #else
      __pyx_t_5 = PySequence_ITEM(__pyx_t_3, __pyx_t_2); __pyx_t_2++; if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 821; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      #endif
    } else if (!__pyx_t_4 && PyTuple_CheckExact(__pyx_t_3)) {
      if (__pyx_t_2 >= PyTuple_GET_SIZE(__pyx_t_3)) break;
      #if CYTHON_COMPILING_IN_CPYTHON
      __pyx_t_5 = PyTuple_GET_ITEM(__pyx_t_3, __pyx_t_2); __Pyx_INCREF(__pyx_t_5); __pyx_t_2++; if (unlikely(0 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 821; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      #else
      __pyx_t_5 = PySequence_ITEM(__pyx_t_3, __pyx_t_2); __pyx_t_2++; if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 821; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      #endif
    } else {
      __pyx_t_5 = __pyx_t_4(__pyx_t_3);
      if (unlikely(!__pyx_t_5)) {
        if (PyErr_Occurred()) {
          if (likely(PyErr_ExceptionMatches(PyExc_StopIteration))) PyErr_Clear();
          else {__pyx_filename = __pyx_f[0]; __pyx_lineno = 821; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_5);
    }
    __Pyx_XDECREF(__pyx_v_o);
    __pyx_v_o = __pyx_t_5;
    __pyx_t_5 = 0;
    __Pyx_INCREF(__pyx_t_1);
    __Pyx_XDECREF(__pyx_v_i);
    __pyx_v_i = __pyx_t_1;
    __pyx_t_5 = PyNumber_Add(__pyx_t_1, __pyx_int_1); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 821; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_1);
    __pyx_t_1 = __pyx_t_5;
    __pyx_t_5 = 0;

    /* "axon/_dumper.py":822
 * 
 *         for i, o in enumerate(collection):
 *             self.write('\n')             # <<<<<<<<<<<<<<
 *             self.write(new_offset)
 *             if self.crossref:
 */
    __pyx_t_5 = PyObject_Call(__pyx_v_self->write, ((PyObject *)__pyx_k_tuple_100), NULL); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 822; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

    /* "axon/_dumper.py":823
 *         for i, o in enumerate(collection):
 *             self.write('\n')
 *             self.write(new_offset)             # <<<<<<<<<<<<<<
 *             if self.crossref:
 *                 v = self._dump_label(o)
 */
    __pyx_t_5 = PyTuple_New(1); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 823; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_INCREF(__pyx_v_new_offset);
    PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_v_new_offset);
    __Pyx_GIVEREF(__pyx_v_new_offset);
    __pyx_t_6 = PyObject_Call(__pyx_v_self->write, ((PyObject *)__pyx_t_5), NULL); if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 823; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(((PyObject *)__pyx_t_5)); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

    /* "axon/_dumper.py":824
 *             self.write('\n')
 *             self.write(new_offset)
 *             if self.crossref:             # <<<<<<<<<<<<<<
 *                 v = self._dump_label(o)
 *                 if v == 1:
 */
    __pyx_t_7 = (__pyx_v_self->crossref != 0);
    if (__pyx_t_7) {

      /* "axon/_dumper.py":825
 *             self.write(new_offset)
 *             if self.crossref:
 *                 v = self._dump_label(o)             # <<<<<<<<<<<<<<
 *                 if v == 1:
 *                     return 0
 */
      __pyx_v_v = __pyx_f_4axon_7_dumper_6Dumper__dump_label(__pyx_v_self, __pyx_v_o);

      /* "axon/_dumper.py":826
 *             if self.crossref:
 *                 v = self._dump_label(o)
 *                 if v == 1:             # <<<<<<<<<<<<<<
 *                     return 0
 * 
 */
      __pyx_t_7 = ((__pyx_v_v == 1) != 0);
      if (__pyx_t_7) {

        /* "axon/_dumper.py":827
 *                 v = self._dump_label(o)
 *                 if v == 1:
 *                     return 0             # <<<<<<<<<<<<<<
 * 
 *             if self.pretty == 1:
 */
        __Pyx_XDECREF(__pyx_r);
        __Pyx_INCREF(__pyx_int_0);
        __pyx_r = __pyx_int_0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        goto __pyx_L0;
        goto __pyx_L6;
      }
      __pyx_L6:;
      goto __pyx_L5;
    }
    __pyx_L5:;

    /* "axon/_dumper.py":831
 *             if self.pretty == 1:
 *                 self.write('{')
 *             elif self.pretty == 2:             # <<<<<<<<<<<<<<
 *                 self.write(':')
 * 
 */
    switch (__pyx_v_self->pretty) {

      /* "axon/_dumper.py":829
 *                     return 0
 * 
 *             if self.pretty == 1:             # <<<<<<<<<<<<<<
 *                 self.write('{')
 *             elif self.pretty == 2:
 */
      case 1:

      /* "axon/_dumper.py":830
 * 
 *             if self.pretty == 1:
 *                 self.write('{')             # <<<<<<<<<<<<<<
 *             elif self.pretty == 2:
 *                 self.write(':')
 */
      __pyx_t_6 = PyObject_Call(__pyx_v_self->write, ((PyObject *)__pyx_k_tuple_101), NULL); if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 830; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      break;

      /* "axon/_dumper.py":831
 *             if self.pretty == 1:
 *                 self.write('{')
 *             elif self.pretty == 2:             # <<<<<<<<<<<<<<
 *                 self.write(':')
 * 
 */
      case 2:

      /* "axon/_dumper.py":832
 *                 self.write('{')
 *             elif self.pretty == 2:
 *                 self.write(':')             # <<<<<<<<<<<<<<
 * 
 *             otype = type(o)
 */
      __pyx_t_6 = PyObject_Call(__pyx_v_self->write, ((PyObject *)__pyx_k_tuple_102), NULL); if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 832; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      break;
    }

    /* "axon/_dumper.py":834
 *                 self.write(':')
 * 
 *             otype = type(o)             # <<<<<<<<<<<<<<
 *             reducer = self.c_type_reducers.get(otype, None)
 *             if reducer is None:
 */
    __Pyx_INCREF(((PyObject *)Py_TYPE(__pyx_v_o)));
    __Pyx_XDECREF(((PyObject *)__pyx_v_otype));
    __pyx_v_otype = ((PyObject*)((PyObject *)Py_TYPE(__pyx_v_o)));

    /* "axon/_dumper.py":835
 * 
 *             otype = type(o)
 *             reducer = self.c_type_reducers.get(otype, None)             # <<<<<<<<<<<<<<
 *             if reducer is None:
 *                 raise TypeError('There is no reducer for this type: ' + repr(otype))
 */
    if (unlikely(((PyObject *)__pyx_v_self->c_type_reducers) == Py_None)) {
      PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%s'", "get");
      {__pyx_filename = __pyx_f[0]; __pyx_lineno = 835; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    }
    __pyx_t_6 = __Pyx_PyDict_GetItemDefault(((PyObject *)__pyx_v_self->c_type_reducers), ((PyObject *)__pyx_v_otype), Py_None); if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 835; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_XDECREF(__pyx_v_reducer);
    __pyx_v_reducer = __pyx_t_6;
    __pyx_t_6 = 0;

    /* "axon/_dumper.py":836
 *             otype = type(o)
 *             reducer = self.c_type_reducers.get(otype, None)
 *             if reducer is None:             # <<<<<<<<<<<<<<
 *                 raise TypeError('There is no reducer for this type: ' + repr(otype))
 *             else:
 */
    __pyx_t_7 = (__pyx_v_reducer == Py_None);
    __pyx_t_8 = (__pyx_t_7 != 0);
    if (__pyx_t_8) {

      /* "axon/_dumper.py":837
 *             reducer = self.c_type_reducers.get(otype, None)
 *             if reducer is None:
 *                 raise TypeError('There is no reducer for this type: ' + repr(otype))             # <<<<<<<<<<<<<<
 *             else:
 *                 items = reducer(o)
 */
      __pyx_t_6 = PyObject_Repr(((PyObject *)__pyx_v_otype)); if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 837; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_5 = PyNumber_Add(((PyObject *)__pyx_kp_u_42), __pyx_t_6); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 837; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_t_6 = PyTuple_New(1); if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 837; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_6);
      PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_5);
      __Pyx_GIVEREF(__pyx_t_5);
      __pyx_t_5 = 0;
      __pyx_t_5 = PyObject_Call(__pyx_builtin_TypeError, ((PyObject *)__pyx_t_6), NULL); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 837; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(((PyObject *)__pyx_t_6)); __pyx_t_6 = 0;
      __Pyx_Raise(__pyx_t_5, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      {__pyx_filename = __pyx_f[0]; __pyx_lineno = 837; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      goto __pyx_L7;
    }
    /*else*/ {

      /* "axon/_dumper.py":839
 *                 raise TypeError('There is no reducer for this type: ' + repr(otype))
 *             else:
 *                 items = reducer(o)             # <<<<<<<<<<<<<<
 *                 n = len(items)
 * 
 */
      __pyx_t_5 = PyTuple_New(1); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 839; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_INCREF(__pyx_v_o);
      PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_v_o);
      __Pyx_GIVEREF(__pyx_v_o);
      __pyx_t_6 = PyObject_Call(__pyx_v_reducer, ((PyObject *)__pyx_t_5), NULL); if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 839; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(((PyObject *)__pyx_t_5)); __pyx_t_5 = 0;
      __Pyx_XDECREF(__pyx_v_items);
      __pyx_v_items = __pyx_t_6;
      __pyx_t_6 = 0;

      /* "axon/_dumper.py":840
 *             else:
 *                 items = reducer(o)
 *                 n = len(items)             # <<<<<<<<<<<<<<
 * 
 *                 if name != items[0]:
 */
      __pyx_t_9 = PyObject_Length(__pyx_v_items); if (unlikely(__pyx_t_9 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 840; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __pyx_t_6 = PyInt_FromSsize_t(__pyx_t_9); if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 840; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_XDECREF(__pyx_v_n);
      __pyx_v_n = __pyx_t_6;
      __pyx_t_6 = 0;

      /* "axon/_dumper.py":842
 *                 n = len(items)
 * 
 *                 if name != items[0]:             # <<<<<<<<<<<<<<
 *                     raise ValueError("Invalid name for collection %s-th item" % i)
 * 
 */
      __pyx_t_6 = __Pyx_GetItemInt(__pyx_v_items, 0, sizeof(long), PyInt_FromLong, 0, 0, 0); if (!__pyx_t_6) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 842; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_5 = PyObject_RichCompare(__pyx_v_name, __pyx_t_6, Py_NE); __Pyx_XGOTREF(__pyx_t_5); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 842; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_t_8 = __Pyx_PyObject_IsTrue(__pyx_t_5); if (unlikely(__pyx_t_8 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 842; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (__pyx_t_8) {

        /* "axon/_dumper.py":843
 * 
 *                 if name != items[0]:
 *                     raise ValueError("Invalid name for collection %s-th item" % i)             # <<<<<<<<<<<<<<
 * 
 *                 if n < 1 or n > 3:
 */
        __pyx_t_5 = PyNumber_Remainder(((PyObject *)__pyx_kp_u_86), __pyx_v_i); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 843; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(((PyObject *)__pyx_t_5));
        __pyx_t_6 = PyTuple_New(1); if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 843; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_6);
        PyTuple_SET_ITEM(__pyx_t_6, 0, ((PyObject *)__pyx_t_5));
        __Pyx_GIVEREF(((PyObject *)__pyx_t_5));
        __pyx_t_5 = 0;
        __pyx_t_5 = PyObject_Call(__pyx_builtin_ValueError, ((PyObject *)__pyx_t_6), NULL); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 843; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(((PyObject *)__pyx_t_6)); __pyx_t_6 = 0;
        __Pyx_Raise(__pyx_t_5, 0, 0, 0);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        {__pyx_filename = __pyx_f[0]; __pyx_lineno = 843; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        goto __pyx_L8;
      }
      __pyx_L8:;

      /* "axon/_dumper.py":845
 *                     raise ValueError("Invalid name for collection %s-th item" % i)
 * 
 *                 if n < 1 or n > 3:             # <<<<<<<<<<<<<<
 *                     raise ValueError('Reducer returns invalid number of items: %s' % n)
 *                 elif n > 1:
 */
      __pyx_t_5 = PyObject_RichCompare(__pyx_v_n, __pyx_int_1, Py_LT); __Pyx_XGOTREF(__pyx_t_5); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 845; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __pyx_t_8 = __Pyx_PyObject_IsTrue(__pyx_t_5); if (unlikely(__pyx_t_8 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 845; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (!__pyx_t_8) {
        __pyx_t_5 = PyObject_RichCompare(__pyx_v_n, __pyx_int_3, Py_GT); __Pyx_XGOTREF(__pyx_t_5); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 845; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __pyx_t_7 = __Pyx_PyObject_IsTrue(__pyx_t_5); if (unlikely(__pyx_t_7 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 845; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        __pyx_t_10 = __pyx_t_7;
      } else {
        __pyx_t_10 = __pyx_t_8;
      }
      if (__pyx_t_10) {

        /* "axon/_dumper.py":846
 * 
 *                 if n < 1 or n > 3:
 *                     raise ValueError('Reducer returns invalid number of items: %s' % n)             # <<<<<<<<<<<<<<
 *                 elif n > 1:
 *                     self.pretty_dump_content(items[1:], new_offset)
 */
        __pyx_t_5 = PyNumber_Remainder(((PyObject *)__pyx_kp_u_87), __pyx_v_n); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 846; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(((PyObject *)__pyx_t_5));
        __pyx_t_6 = PyTuple_New(1); if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 846; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_6);
        PyTuple_SET_ITEM(__pyx_t_6, 0, ((PyObject *)__pyx_t_5));
        __Pyx_GIVEREF(((PyObject *)__pyx_t_5));
        __pyx_t_5 = 0;
        __pyx_t_5 = PyObject_Call(__pyx_builtin_ValueError, ((PyObject *)__pyx_t_6), NULL); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 846; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(((PyObject *)__pyx_t_6)); __pyx_t_6 = 0;
        __Pyx_Raise(__pyx_t_5, 0, 0, 0);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        {__pyx_filename = __pyx_f[0]; __pyx_lineno = 846; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        goto __pyx_L9;
      }

      /* "axon/_dumper.py":847
 *                 if n < 1 or n > 3:
 *                     raise ValueError('Reducer returns invalid number of items: %s' % n)
 *                 elif n > 1:             # <<<<<<<<<<<<<<
 *                     self.pretty_dump_content(items[1:], new_offset)
 * 
 */
      __pyx_t_5 = PyObject_RichCompare(__pyx_v_n, __pyx_int_1, Py_GT); __Pyx_XGOTREF(__pyx_t_5); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 847; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __pyx_t_10 = __Pyx_PyObject_IsTrue(__pyx_t_5); if (unlikely(__pyx_t_10 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 847; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (__pyx_t_10) {

        /* "axon/_dumper.py":848
 *                     raise ValueError('Reducer returns invalid number of items: %s' % n)
 *                 elif n > 1:
 *                     self.pretty_dump_content(items[1:], new_offset)             # <<<<<<<<<<<<<<
 * 
 *             if self.pretty == 1:
 */
        __pyx_t_5 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s__pretty_dump_content); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 848; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_5);
        __pyx_t_6 = __Pyx_PyObject_GetSlice(__pyx_v_items, 1, 0, NULL, NULL, &__pyx_k_slice_103, 1, 0, 0); if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 848; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_6);
        __pyx_t_11 = PyTuple_New(2); if (unlikely(!__pyx_t_11)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 848; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_11);
        PyTuple_SET_ITEM(__pyx_t_11, 0, __pyx_t_6);
        __Pyx_GIVEREF(__pyx_t_6);
        __Pyx_INCREF(__pyx_v_new_offset);
        PyTuple_SET_ITEM(__pyx_t_11, 1, __pyx_v_new_offset);
        __Pyx_GIVEREF(__pyx_v_new_offset);
        __pyx_t_6 = 0;
        __pyx_t_6 = PyObject_Call(__pyx_t_5, ((PyObject *)__pyx_t_11), NULL); if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 848; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_DECREF(((PyObject *)__pyx_t_11)); __pyx_t_11 = 0;
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        goto __pyx_L9;
      }
      __pyx_L9:;
    }
    __pyx_L7:;

    /* "axon/_dumper.py":850
 *                     self.pretty_dump_content(items[1:], new_offset)
 * 
 *             if self.pretty == 1:             # <<<<<<<<<<<<<<
 *                 self.write('}')
 * 
 */
    __pyx_t_10 = ((__pyx_v_self->pretty == 1) != 0);
    if (__pyx_t_10) {

      /* "axon/_dumper.py":851
 * 
 *             if self.pretty == 1:
 *                 self.write('}')             # <<<<<<<<<<<<<<
 * 
 *     #
 */
      __pyx_t_6 = PyObject_Call(__pyx_v_self->write, ((PyObject *)__pyx_k_tuple_104), NULL); if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 851; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      goto __pyx_L10;
    }
    __pyx_L10:;
  }
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_AddTraceback("axon._dumper.Dumper.pretty_dump_collection", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_new_offset);
  __Pyx_XDECREF(__pyx_v_N);
  __Pyx_XDECREF(__pyx_v_i);
  __Pyx_XDECREF(__pyx_v_o);
  __Pyx_XDECREF(__pyx_v_otype);
  __Pyx_XDECREF(__pyx_v_reducer);
  __Pyx_XDECREF(__pyx_v_items);
  __Pyx_XDECREF(__pyx_v_n);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_dumper.py":854
 * 
 *     #
 *     def _pretty_dump_with_reducer(self, reducer, o, offset):             # <<<<<<<<<<<<<<
 * 
 *         results = reducer(o)
 */

static int __pyx_f_4axon_7_dumper_6Dumper__pretty_dump_with_reducer(struct Dumper *__pyx_v_self, PyObject *__pyx_v_reducer, PyObject *__pyx_v_o, PyObject *__pyx_v_offset) {
  PyObject *__pyx_v_name = 0;
  int __pyx_v_n;
  PyObject *__pyx_v_results = NULL;
  long __pyx_v_is_collection;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  Py_ssize_t __pyx_t_3;
  int __pyx_t_4;
  int __pyx_t_5;
  int __pyx_t_6;
  int __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_pretty_dump_with_reducer", 0);

  /* "axon/_dumper.py":856
 *     def _pretty_dump_with_reducer(self, reducer, o, offset):
 * 
 *         results = reducer(o)             # <<<<<<<<<<<<<<
 *         n = len(results)
 * 
 */
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 856; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_v_o);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_o);
  __Pyx_GIVEREF(__pyx_v_o);
  __pyx_t_2 = PyObject_Call(__pyx_v_reducer, ((PyObject *)__pyx_t_1), NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 856; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(((PyObject *)__pyx_t_1)); __pyx_t_1 = 0;
  __pyx_v_results = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "axon/_dumper.py":857
 * 
 *         results = reducer(o)
 *         n = len(results)             # <<<<<<<<<<<<<<
 * 
 *         name = c_as_unicode(results[0])
 */
  __pyx_t_3 = PyObject_Length(__pyx_v_results); if (unlikely(__pyx_t_3 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 857; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_v_n = __pyx_t_3;

  /* "axon/_dumper.py":859
 *         n = len(results)
 * 
 *         name = c_as_unicode(results[0])             # <<<<<<<<<<<<<<
 * 
 *         if name.endswith('*'):
 */
  __pyx_t_2 = __Pyx_GetItemInt(__pyx_v_results, 0, sizeof(long), PyInt_FromLong, 0, 0, 0); if (!__pyx_t_2) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 859; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = ((PyObject *)__pyx_f_4axon_8_objects_c_as_unicode(__pyx_t_2)); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 859; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_name = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "axon/_dumper.py":861
 *         name = c_as_unicode(results[0])
 * 
 *         if name.endswith('*'):             # <<<<<<<<<<<<<<
 *             is_collection = 1
 *             name = c_unicode_substr(name, 0, c_unicode_length(name)-1)
 */
  if (unlikely(((PyObject *)__pyx_v_name) == Py_None)) {
    PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%s'", "endswith");
    {__pyx_filename = __pyx_f[0]; __pyx_lineno = 861; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }
  __pyx_t_4 = __Pyx_PyUnicode_Tailmatch(((PyObject *)__pyx_v_name), ((PyObject *)__pyx_kp_u_1), 0, PY_SSIZE_T_MAX, 1); if (unlikely(__pyx_t_4 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 861; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if ((__pyx_t_4 != 0)) {

    /* "axon/_dumper.py":862
 * 
 *         if name.endswith('*'):
 *             is_collection = 1             # <<<<<<<<<<<<<<
 *             name = c_unicode_substr(name, 0, c_unicode_length(name)-1)
 *         else:
 */
    __pyx_v_is_collection = 1;

    /* "axon/_dumper.py":863
 *         if name.endswith('*'):
 *             is_collection = 1
 *             name = c_unicode_substr(name, 0, c_unicode_length(name)-1)             # <<<<<<<<<<<<<<
 *         else:
 *             is_collection = 0
 */
    __pyx_t_1 = ((PyObject *)c_unicode_substr(__pyx_v_name, 0, (c_unicode_length(__pyx_v_name) - 1))); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 863; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(((PyObject *)__pyx_v_name));
    __pyx_v_name = ((PyObject*)__pyx_t_1);
    __pyx_t_1 = 0;
    goto __pyx_L3;
  }
  /*else*/ {

    /* "axon/_dumper.py":865
 *             name = c_unicode_substr(name, 0, c_unicode_length(name)-1)
 *         else:
 *             is_collection = 0             # <<<<<<<<<<<<<<
 * 
 *         self.write(_dump_name(name, self.quote))
 */
    __pyx_v_is_collection = 0;
  }
  __pyx_L3:;

  /* "axon/_dumper.py":867
 *             is_collection = 0
 * 
 *         self.write(_dump_name(name, self.quote))             # <<<<<<<<<<<<<<
 * 
 *         if is_collection:
 */
  __pyx_t_1 = ((PyObject *)__pyx_f_4axon_7_dumper__dump_name(((PyObject *)__pyx_v_name), __pyx_v_self->quote)); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 867; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 867; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __pyx_t_1 = 0;
  __pyx_t_1 = PyObject_Call(__pyx_v_self->write, ((PyObject *)__pyx_t_2), NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 867; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(((PyObject *)__pyx_t_2)); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "axon/_dumper.py":869
 *         self.write(_dump_name(name, self.quote))
 * 
 *         if is_collection:             # <<<<<<<<<<<<<<
 *             self.write('*')
 * 
 */
  __pyx_t_4 = (__pyx_v_is_collection != 0);
  if (__pyx_t_4) {

    /* "axon/_dumper.py":870
 * 
 *         if is_collection:
 *             self.write('*')             # <<<<<<<<<<<<<<
 * 
 *         if not is_collection and (n < 1 or n > 3):
 */
    __pyx_t_1 = PyObject_Call(__pyx_v_self->write, ((PyObject *)__pyx_k_tuple_105), NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 870; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    goto __pyx_L4;
  }
  __pyx_L4:;

  /* "axon/_dumper.py":872
 *             self.write('*')
 * 
 *         if not is_collection and (n < 1 or n > 3):             # <<<<<<<<<<<<<<
 *             raise ValueError('Reducer returns invalid number of items: %s' % n)
 * 
 */
  __pyx_t_4 = ((!(__pyx_v_is_collection != 0)) != 0);
  if (__pyx_t_4) {
    __pyx_t_5 = ((__pyx_v_n < 1) != 0);
    if (!__pyx_t_5) {
      __pyx_t_6 = ((__pyx_v_n > 3) != 0);
      __pyx_t_7 = __pyx_t_6;
    } else {
      __pyx_t_7 = __pyx_t_5;
    }
    __pyx_t_5 = __pyx_t_7;
  } else {
    __pyx_t_5 = __pyx_t_4;
  }
  if (__pyx_t_5) {

    /* "axon/_dumper.py":873
 * 
 *         if not is_collection and (n < 1 or n > 3):
 *             raise ValueError('Reducer returns invalid number of items: %s' % n)             # <<<<<<<<<<<<<<
 * 
 *         if n == 1:
 */
    __pyx_t_1 = PyInt_FromLong(__pyx_v_n); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 873; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = PyNumber_Remainder(((PyObject *)__pyx_kp_u_87), __pyx_t_1); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 873; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(((PyObject *)__pyx_t_2));
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 873; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_t_2));
    __Pyx_GIVEREF(((PyObject *)__pyx_t_2));
    __pyx_t_2 = 0;
    __pyx_t_2 = PyObject_Call(__pyx_builtin_ValueError, ((PyObject *)__pyx_t_1), NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 873; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(((PyObject *)__pyx_t_1)); __pyx_t_1 = 0;
    __Pyx_Raise(__pyx_t_2, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    {__pyx_filename = __pyx_f[0]; __pyx_lineno = 873; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    goto __pyx_L5;
  }
  __pyx_L5:;

  /* "axon/_dumper.py":875
 *             raise ValueError('Reducer returns invalid number of items: %s' % n)
 * 
 *         if n == 1:             # <<<<<<<<<<<<<<
 *             if self.pretty == 2:
 *                 self.write(':\n')
 */
  __pyx_t_5 = ((__pyx_v_n == 1) != 0);
  if (__pyx_t_5) {

    /* "axon/_dumper.py":876
 * 
 *         if n == 1:
 *             if self.pretty == 2:             # <<<<<<<<<<<<<<
 *                 self.write(':\n')
 *                 self.write(offset)
 */
    __pyx_t_5 = ((__pyx_v_self->pretty == 2) != 0);
    if (__pyx_t_5) {

      /* "axon/_dumper.py":877
 *         if n == 1:
 *             if self.pretty == 2:
 *                 self.write(':\n')             # <<<<<<<<<<<<<<
 *                 self.write(offset)
 *                 self.write('  ...')
 */
      __pyx_t_2 = PyObject_Call(__pyx_v_self->write, ((PyObject *)__pyx_k_tuple_107), NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 877; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

      /* "axon/_dumper.py":878
 *             if self.pretty == 2:
 *                 self.write(':\n')
 *                 self.write(offset)             # <<<<<<<<<<<<<<
 *                 self.write('  ...')
 *             else:
 */
      __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 878; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_INCREF(((PyObject *)__pyx_v_offset));
      PyTuple_SET_ITEM(__pyx_t_2, 0, ((PyObject *)__pyx_v_offset));
      __Pyx_GIVEREF(((PyObject *)__pyx_v_offset));
      __pyx_t_1 = PyObject_Call(__pyx_v_self->write, ((PyObject *)__pyx_t_2), NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 878; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(((PyObject *)__pyx_t_2)); __pyx_t_2 = 0;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "axon/_dumper.py":879
 *                 self.write(':\n')
 *                 self.write(offset)
 *                 self.write('  ...')             # <<<<<<<<<<<<<<
 *             else:
 *                 self.write('{}')
 */
      __pyx_t_1 = PyObject_Call(__pyx_v_self->write, ((PyObject *)__pyx_k_tuple_109), NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 879; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      goto __pyx_L7;
    }
    /*else*/ {

      /* "axon/_dumper.py":881
 *                 self.write('  ...')
 *             else:
 *                 self.write('{}')             # <<<<<<<<<<<<<<
 *             return 0
 * 
 */
      __pyx_t_1 = PyObject_Call(__pyx_v_self->write, ((PyObject *)__pyx_k_tuple_110), NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 881; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    }
    __pyx_L7:;

    /* "axon/_dumper.py":882
 *             else:
 *                 self.write('{}')
 *             return 0             # <<<<<<<<<<<<<<
 * 
 *         if self.pretty == 1:
 */
    __pyx_r = 0;
    goto __pyx_L0;
    goto __pyx_L6;
  }
  __pyx_L6:;

  /* "axon/_dumper.py":886
 *         if self.pretty == 1:
 *             self.write(' {')
 *         elif self.pretty == 2:             # <<<<<<<<<<<<<<
 *             self.write(':')
 * 
 */
  switch (__pyx_v_self->pretty) {

    /* "axon/_dumper.py":884
 *             return 0
 * 
 *         if self.pretty == 1:             # <<<<<<<<<<<<<<
 *             self.write(' {')
 *         elif self.pretty == 2:
 */
    case 1:

    /* "axon/_dumper.py":885
 * 
 *         if self.pretty == 1:
 *             self.write(' {')             # <<<<<<<<<<<<<<
 *         elif self.pretty == 2:
 *             self.write(':')
 */
    __pyx_t_1 = PyObject_Call(__pyx_v_self->write, ((PyObject *)__pyx_k_tuple_112), NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 885; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    break;

    /* "axon/_dumper.py":886
 *         if self.pretty == 1:
 *             self.write(' {')
 *         elif self.pretty == 2:             # <<<<<<<<<<<<<<
 *             self.write(':')
 * 
 */
    case 2:

    /* "axon/_dumper.py":887
 *             self.write(' {')
 *         elif self.pretty == 2:
 *             self.write(':')             # <<<<<<<<<<<<<<
 * 
 *         #if self.crossref:
 */
    __pyx_t_1 = PyObject_Call(__pyx_v_self->write, ((PyObject *)__pyx_k_tuple_113), NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 887; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    break;
  }

  /* "axon/_dumper.py":892
 *         #    self._pretty_dump_crossref(o)
 * 
 *         if is_collection:             # <<<<<<<<<<<<<<
 *             self.pretty_dump_collection(name, results[1], offset)
 *         else:
 */
  __pyx_t_5 = (__pyx_v_is_collection != 0);
  if (__pyx_t_5) {

    /* "axon/_dumper.py":893
 * 
 *         if is_collection:
 *             self.pretty_dump_collection(name, results[1], offset)             # <<<<<<<<<<<<<<
 *         else:
 *             self.pretty_dump_content(results[1:], offset)
 */
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_114); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 893; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = __Pyx_GetItemInt(__pyx_v_results, 1, sizeof(long), PyInt_FromLong, 0, 0, 0); if (!__pyx_t_2) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 893; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_8 = PyTuple_New(3); if (unlikely(!__pyx_t_8)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 893; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_8);
    __Pyx_INCREF(((PyObject *)__pyx_v_name));
    PyTuple_SET_ITEM(__pyx_t_8, 0, ((PyObject *)__pyx_v_name));
    __Pyx_GIVEREF(((PyObject *)__pyx_v_name));
    PyTuple_SET_ITEM(__pyx_t_8, 1, __pyx_t_2);
    __Pyx_GIVEREF(__pyx_t_2);
    __Pyx_INCREF(((PyObject *)__pyx_v_offset));
    PyTuple_SET_ITEM(__pyx_t_8, 2, ((PyObject *)__pyx_v_offset));
    __Pyx_GIVEREF(((PyObject *)__pyx_v_offset));
    __pyx_t_2 = 0;
    __pyx_t_2 = PyObject_Call(__pyx_t_1, ((PyObject *)__pyx_t_8), NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 893; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(((PyObject *)__pyx_t_8)); __pyx_t_8 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    goto __pyx_L8;
  }
  /*else*/ {

    /* "axon/_dumper.py":895
 *             self.pretty_dump_collection(name, results[1], offset)
 *         else:
 *             self.pretty_dump_content(results[1:], offset)             # <<<<<<<<<<<<<<
 * 
 *         if self.pretty == 1:
 */
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s__pretty_dump_content); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 895; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_8 = __Pyx_PyObject_GetSlice(__pyx_v_results, 1, 0, NULL, NULL, &__pyx_k_slice_115, 1, 0, 0); if (unlikely(!__pyx_t_8)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 895; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_8);
    __pyx_t_1 = PyTuple_New(2); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 895; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_t_8);
    __Pyx_GIVEREF(__pyx_t_8);
    __Pyx_INCREF(((PyObject *)__pyx_v_offset));
    PyTuple_SET_ITEM(__pyx_t_1, 1, ((PyObject *)__pyx_v_offset));
    __Pyx_GIVEREF(((PyObject *)__pyx_v_offset));
    __pyx_t_8 = 0;
    __pyx_t_8 = PyObject_Call(__pyx_t_2, ((PyObject *)__pyx_t_1), NULL); if (unlikely(!__pyx_t_8)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 895; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_8);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(((PyObject *)__pyx_t_1)); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  }
  __pyx_L8:;

  /* "axon/_dumper.py":897
 *             self.pretty_dump_content(results[1:], offset)
 * 
 *         if self.pretty == 1:             # <<<<<<<<<<<<<<
 *             self.write('}')
 *         #elif self.pretty == 2:
 */
  __pyx_t_5 = ((__pyx_v_self->pretty == 1) != 0);
  if (__pyx_t_5) {

    /* "axon/_dumper.py":898
 * 
 *         if self.pretty == 1:
 *             self.write('}')             # <<<<<<<<<<<<<<
 *         #elif self.pretty == 2:
 *         #    self.write('\n')
 */
    __pyx_t_8 = PyObject_Call(__pyx_v_self->write, ((PyObject *)__pyx_k_tuple_116), NULL); if (unlikely(!__pyx_t_8)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 898; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_8);
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    goto __pyx_L9;
  }
  __pyx_L9:;

  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("axon._dumper.Dumper._pretty_dump_with_reducer", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_name);
  __Pyx_XDECREF(__pyx_v_results);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_4axon_7_dumper_6Dumper_11dump(PyObject *__pyx_v_self, PyObject *__pyx_v_seq); /*proto*/
static char __pyx_doc_4axon_7_dumper_6Dumper_10dump[] = "\n        Main dumping method.\n\n        :param seq:\n\n            Sequence of values to dump\n\n        :param pretty:\n\n            Flag indicates whether to use pretty dumping mode. Default is `False` (i.e. no pretty dumping)\n\n        ";
static PyObject *__pyx_pw_4axon_7_dumper_6Dumper_11dump(PyObject *__pyx_v_self, PyObject *__pyx_v_seq) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("dump (wrapper)", 0);
  __pyx_r = __pyx_pf_4axon_7_dumper_6Dumper_10dump(((struct Dumper *)__pyx_v_self), ((PyObject *)__pyx_v_seq));
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_dumper.py":903
 *         #    self.write(offset)
 *     #
 *     def dump(self, seq):             # <<<<<<<<<<<<<<
 *         '''
 *         Main dumping method.
 */

static PyObject *__pyx_pf_4axon_7_dumper_6Dumper_10dump(struct Dumper *__pyx_v_self, PyObject *__pyx_v_seq) {
  PyObject *__pyx_v_iterseq = NULL;
  PyObject *__pyx_v_v = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_t_3;
  Py_ssize_t __pyx_t_4;
  PyObject *(*__pyx_t_5)(PyObject *);
  PyObject *__pyx_t_6 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("dump", 0);

  /* "axon/_dumper.py":917
 *         '''
 * 
 *         if self.crossref:             # <<<<<<<<<<<<<<
 *             self.crossref_dict = {}
 *             self.collect(seq)
 */
  __pyx_t_1 = (__pyx_v_self->crossref != 0);
  if (__pyx_t_1) {

    /* "axon/_dumper.py":918
 * 
 *         if self.crossref:
 *             self.crossref_dict = {}             # <<<<<<<<<<<<<<
 *             self.collect(seq)
 *             self.apply_crossref()
 */
    __pyx_t_2 = PyDict_New(); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 918; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(((PyObject *)__pyx_t_2));
    __Pyx_GIVEREF(((PyObject *)__pyx_t_2));
    __Pyx_GOTREF(__pyx_v_self->crossref_dict);
    __Pyx_DECREF(((PyObject *)__pyx_v_self->crossref_dict));
    __pyx_v_self->crossref_dict = ((PyObject*)__pyx_t_2);
    __pyx_t_2 = 0;

    /* "axon/_dumper.py":919
 *         if self.crossref:
 *             self.crossref_dict = {}
 *             self.collect(seq)             # <<<<<<<<<<<<<<
 *             self.apply_crossref()
 * 
 */
    __pyx_t_3 = __pyx_f_4axon_7_dumper_6Dumper_collect(__pyx_v_self, __pyx_v_seq); if (unlikely(__pyx_t_3 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 919; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

    /* "axon/_dumper.py":920
 *             self.crossref_dict = {}
 *             self.collect(seq)
 *             self.apply_crossref()             # <<<<<<<<<<<<<<
 * 
 *         iterseq = iter(seq)
 */
    __pyx_f_4axon_7_dumper_6Dumper_apply_crossref(__pyx_v_self);
    goto __pyx_L3;
  }
  __pyx_L3:;

  /* "axon/_dumper.py":922
 *             self.apply_crossref()
 * 
 *         iterseq = iter(seq)             # <<<<<<<<<<<<<<
 *         v = next(iterseq)
 * 
 */
  __pyx_t_2 = PyObject_GetIter(__pyx_v_seq); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 922; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_v_iterseq = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "axon/_dumper.py":923
 * 
 *         iterseq = iter(seq)
 *         v = next(iterseq)             # <<<<<<<<<<<<<<
 * 
 *         if self.pretty:
 */
  __pyx_t_2 = __Pyx_PyIter_Next(__pyx_v_iterseq); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 923; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_v_v = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "axon/_dumper.py":925
 *         v = next(iterseq)
 * 
 *         if self.pretty:             # <<<<<<<<<<<<<<
 *             self._pretty_dump(v, '', 1)
 *         else:
 */
  __pyx_t_1 = (__pyx_v_self->pretty != 0);
  if (__pyx_t_1) {

    /* "axon/_dumper.py":926
 * 
 *         if self.pretty:
 *             self._pretty_dump(v, '', 1)             # <<<<<<<<<<<<<<
 *         else:
 *             self._dump(v)
 */
    __pyx_t_3 = __pyx_f_4axon_7_dumper_6Dumper__pretty_dump(__pyx_v_self, __pyx_v_v, __pyx_kp_u_44, 1); if (unlikely(__pyx_t_3 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 926; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    goto __pyx_L4;
  }
  /*else*/ {

    /* "axon/_dumper.py":928
 *             self._pretty_dump(v, '', 1)
 *         else:
 *             self._dump(v)             # <<<<<<<<<<<<<<
 * 
 *         if self.pretty:
 */
    __pyx_t_3 = __pyx_f_4axon_7_dumper_6Dumper__dump(__pyx_v_self, __pyx_v_v); if (unlikely(__pyx_t_3 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 928; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }
  __pyx_L4:;

  /* "axon/_dumper.py":930
 *             self._dump(v)
 * 
 *         if self.pretty:             # <<<<<<<<<<<<<<
 *             for v in iterseq:
 *                 self.write('\n')
 */
  __pyx_t_1 = (__pyx_v_self->pretty != 0);
  if (__pyx_t_1) {

    /* "axon/_dumper.py":931
 * 
 *         if self.pretty:
 *             for v in iterseq:             # <<<<<<<<<<<<<<
 *                 self.write('\n')
 *                 self._pretty_dump(v, '', 1)
 */
    if (PyList_CheckExact(__pyx_v_iterseq) || PyTuple_CheckExact(__pyx_v_iterseq)) {
      __pyx_t_2 = __pyx_v_iterseq; __Pyx_INCREF(__pyx_t_2); __pyx_t_4 = 0;
      __pyx_t_5 = NULL;
    } else {
      __pyx_t_4 = -1; __pyx_t_2 = PyObject_GetIter(__pyx_v_iterseq); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 931; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_5 = Py_TYPE(__pyx_t_2)->tp_iternext;
    }
    for (;;) {
      if (!__pyx_t_5 && PyList_CheckExact(__pyx_t_2)) {
        if (__pyx_t_4 >= PyList_GET_SIZE(__pyx_t_2)) break;
        #if CYTHON_COMPILING_IN_CPYTHON
        __pyx_t_6 = PyList_GET_ITEM(__pyx_t_2, __pyx_t_4); __Pyx_INCREF(__pyx_t_6); __pyx_t_4++; if (unlikely(0 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 931; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        #else
        __pyx_t_6 = PySequence_ITEM(__pyx_t_2, __pyx_t_4); __pyx_t_4++; if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 931; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        #endif
      } else if (!__pyx_t_5 && PyTuple_CheckExact(__pyx_t_2)) {
        if (__pyx_t_4 >= PyTuple_GET_SIZE(__pyx_t_2)) break;
        #if CYTHON_COMPILING_IN_CPYTHON
        __pyx_t_6 = PyTuple_GET_ITEM(__pyx_t_2, __pyx_t_4); __Pyx_INCREF(__pyx_t_6); __pyx_t_4++; if (unlikely(0 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 931; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        #else
        __pyx_t_6 = PySequence_ITEM(__pyx_t_2, __pyx_t_4); __pyx_t_4++; if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 931; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        #endif
      } else {
        __pyx_t_6 = __pyx_t_5(__pyx_t_2);
        if (unlikely(!__pyx_t_6)) {
          if (PyErr_Occurred()) {
            if (likely(PyErr_ExceptionMatches(PyExc_StopIteration))) PyErr_Clear();
            else {__pyx_filename = __pyx_f[0]; __pyx_lineno = 931; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
          }
          break;
        }
        __Pyx_GOTREF(__pyx_t_6);
      }
      __Pyx_DECREF(__pyx_v_v);
      __pyx_v_v = __pyx_t_6;
      __pyx_t_6 = 0;

      /* "axon/_dumper.py":932
 *         if self.pretty:
 *             for v in iterseq:
 *                 self.write('\n')             # <<<<<<<<<<<<<<
 *                 self._pretty_dump(v, '', 1)
 *         else:
 */
      __pyx_t_6 = PyObject_Call(__pyx_v_self->write, ((PyObject *)__pyx_k_tuple_117), NULL); if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 932; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

      /* "axon/_dumper.py":933
 *             for v in iterseq:
 *                 self.write('\n')
 *                 self._pretty_dump(v, '', 1)             # <<<<<<<<<<<<<<
 *         else:
 *             for v in iterseq:
 */
      __pyx_t_3 = __pyx_f_4axon_7_dumper_6Dumper__pretty_dump(__pyx_v_self, __pyx_v_v, __pyx_kp_u_44, 1); if (unlikely(__pyx_t_3 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 933; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    }
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    goto __pyx_L5;
  }
  /*else*/ {

    /* "axon/_dumper.py":935
 *                 self._pretty_dump(v, '', 1)
 *         else:
 *             for v in iterseq:             # <<<<<<<<<<<<<<
 *                 self.write(' ')
 *                 #self.size = 0
 */
    if (PyList_CheckExact(__pyx_v_iterseq) || PyTuple_CheckExact(__pyx_v_iterseq)) {
      __pyx_t_2 = __pyx_v_iterseq; __Pyx_INCREF(__pyx_t_2); __pyx_t_4 = 0;
      __pyx_t_5 = NULL;
    } else {
      __pyx_t_4 = -1; __pyx_t_2 = PyObject_GetIter(__pyx_v_iterseq); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 935; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_5 = Py_TYPE(__pyx_t_2)->tp_iternext;
    }
    for (;;) {
      if (!__pyx_t_5 && PyList_CheckExact(__pyx_t_2)) {
        if (__pyx_t_4 >= PyList_GET_SIZE(__pyx_t_2)) break;
        #if CYTHON_COMPILING_IN_CPYTHON
        __pyx_t_6 = PyList_GET_ITEM(__pyx_t_2, __pyx_t_4); __Pyx_INCREF(__pyx_t_6); __pyx_t_4++; if (unlikely(0 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 935; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        #else
        __pyx_t_6 = PySequence_ITEM(__pyx_t_2, __pyx_t_4); __pyx_t_4++; if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 935; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        #endif
      } else if (!__pyx_t_5 && PyTuple_CheckExact(__pyx_t_2)) {
        if (__pyx_t_4 >= PyTuple_GET_SIZE(__pyx_t_2)) break;
        #if CYTHON_COMPILING_IN_CPYTHON
        __pyx_t_6 = PyTuple_GET_ITEM(__pyx_t_2, __pyx_t_4); __Pyx_INCREF(__pyx_t_6); __pyx_t_4++; if (unlikely(0 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 935; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        #else
        __pyx_t_6 = PySequence_ITEM(__pyx_t_2, __pyx_t_4); __pyx_t_4++; if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 935; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        #endif
      } else {
        __pyx_t_6 = __pyx_t_5(__pyx_t_2);
        if (unlikely(!__pyx_t_6)) {
          if (PyErr_Occurred()) {
            if (likely(PyErr_ExceptionMatches(PyExc_StopIteration))) PyErr_Clear();
            else {__pyx_filename = __pyx_f[0]; __pyx_lineno = 935; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
          }
          break;
        }
        __Pyx_GOTREF(__pyx_t_6);
      }
      __Pyx_DECREF(__pyx_v_v);
      __pyx_v_v = __pyx_t_6;
      __pyx_t_6 = 0;

      /* "axon/_dumper.py":936
 *         else:
 *             for v in iterseq:
 *                 self.write(' ')             # <<<<<<<<<<<<<<
 *                 #self.size = 0
 *                 self._dump(v)
 */
      __pyx_t_6 = PyObject_Call(__pyx_v_self->write, ((PyObject *)__pyx_k_tuple_118), NULL); if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 936; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

      /* "axon/_dumper.py":938
 *                 self.write(' ')
 *                 #self.size = 0
 *                 self._dump(v)             # <<<<<<<<<<<<<<
 *     #
 *     def apply_crossref(self):
 */
      __pyx_t_3 = __pyx_f_4axon_7_dumper_6Dumper__dump(__pyx_v_self, __pyx_v_v); if (unlikely(__pyx_t_3 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 938; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    }
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_L5:;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("axon._dumper.Dumper.dump", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_iterseq);
  __Pyx_XDECREF(__pyx_v_v);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_dumper.py":940
 *                 self._dump(v)
 *     #
 *     def apply_crossref(self):             # <<<<<<<<<<<<<<
 *         crossref_set = set()
 *         crossref_set2 = set()
 */

static void __pyx_f_4axon_7_dumper_6Dumper_apply_crossref(struct Dumper *__pyx_v_self) {
  struct __pyx_obj_4axon_7_dumper_PyInt *__pyx_v_count = 0;
  int __pyx_v_i;
  PyObject *__pyx_v_crossref_dict = 0;
  PyObject *__pyx_v_crossref_set = 0;
  PyObject *__pyx_v_crossref_set2 = NULL;
  PyObject *__pyx_v_o_ref = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  Py_ssize_t __pyx_t_2;
  Py_ssize_t __pyx_t_3;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  int __pyx_t_8;
  int __pyx_t_9;
  PyObject *(*__pyx_t_10)(PyObject *);
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("apply_crossref", 0);

  /* "axon/_dumper.py":941
 *     #
 *     def apply_crossref(self):
 *         crossref_set = set()             # <<<<<<<<<<<<<<
 *         crossref_set2 = set()
 *         for o_ref, count in self.crossref_dict.items():
 */
  __pyx_t_1 = PySet_New(0); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 941; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(((PyObject *)__pyx_t_1));
  __pyx_v_crossref_set = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "axon/_dumper.py":942
 *     def apply_crossref(self):
 *         crossref_set = set()
 *         crossref_set2 = set()             # <<<<<<<<<<<<<<
 *         for o_ref, count in self.crossref_dict.items():
 *             if count.val > 1:
 */
  __pyx_t_1 = PySet_New(0); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 942; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(((PyObject *)__pyx_t_1));
  __pyx_v_crossref_set2 = ((PyObject *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "axon/_dumper.py":943
 *         crossref_set = set()
 *         crossref_set2 = set()
 *         for o_ref, count in self.crossref_dict.items():             # <<<<<<<<<<<<<<
 *             if count.val > 1:
 *                 crossref_set.add(o_ref)
 */
  __pyx_t_2 = 0;
  if (unlikely(((PyObject *)__pyx_v_self->crossref_dict) == Py_None)) {
    PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%s'", "items");
    {__pyx_filename = __pyx_f[0]; __pyx_lineno = 943; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }
  __pyx_t_5 = __Pyx_dict_iterator(((PyObject *)__pyx_v_self->crossref_dict), 1, ((PyObject *)__pyx_n_s__items), (&__pyx_t_3), (&__pyx_t_4)); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 943; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_1);
  __pyx_t_1 = __pyx_t_5;
  __pyx_t_5 = 0;
  while (1) {
    __pyx_t_7 = __Pyx_dict_iter_next(__pyx_t_1, __pyx_t_3, &__pyx_t_2, &__pyx_t_5, &__pyx_t_6, NULL, __pyx_t_4);
    if (unlikely(__pyx_t_7 == 0)) break;
    if (unlikely(__pyx_t_7 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 943; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_GOTREF(__pyx_t_6);
    if (!(likely(((__pyx_t_6) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_6, __pyx_ptype_4axon_7_dumper_PyInt))))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 943; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_XDECREF(__pyx_v_o_ref);
    __pyx_v_o_ref = __pyx_t_5;
    __pyx_t_5 = 0;
    __Pyx_XDECREF(((PyObject *)__pyx_v_count));
    __pyx_v_count = ((struct __pyx_obj_4axon_7_dumper_PyInt *)__pyx_t_6);
    __pyx_t_6 = 0;

    /* "axon/_dumper.py":944
 *         crossref_set2 = set()
 *         for o_ref, count in self.crossref_dict.items():
 *             if count.val > 1:             # <<<<<<<<<<<<<<
 *                 crossref_set.add(o_ref)
 * 
 */
    __pyx_t_8 = ((__pyx_v_count->val > 1) != 0);
    if (__pyx_t_8) {

      /* "axon/_dumper.py":945
 *         for o_ref, count in self.crossref_dict.items():
 *             if count.val > 1:
 *                 crossref_set.add(o_ref)             # <<<<<<<<<<<<<<
 * 
 *         crossref_dict = {}
 */
      __pyx_t_9 = PySet_Add(__pyx_v_crossref_set, __pyx_v_o_ref); if (unlikely(__pyx_t_9 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 945; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      goto __pyx_L5;
    }
    __pyx_L5:;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "axon/_dumper.py":947
 *                 crossref_set.add(o_ref)
 * 
 *         crossref_dict = {}             # <<<<<<<<<<<<<<
 *         i = 0
 *         for o_ref in crossref_set:
 */
  __pyx_t_1 = PyDict_New(); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 947; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(((PyObject *)__pyx_t_1));
  __pyx_v_crossref_dict = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "axon/_dumper.py":948
 * 
 *         crossref_dict = {}
 *         i = 0             # <<<<<<<<<<<<<<
 *         for o_ref in crossref_set:
 *             i += 1
 */
  __pyx_v_i = 0;

  /* "axon/_dumper.py":949
 *         crossref_dict = {}
 *         i = 0
 *         for o_ref in crossref_set:             # <<<<<<<<<<<<<<
 *             i += 1
 *             crossref_dict[o_ref] = unicode(i)
 */
  __pyx_t_1 = PyObject_GetIter(((PyObject *)__pyx_v_crossref_set)); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 949; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_10 = Py_TYPE(__pyx_t_1)->tp_iternext;
  for (;;) {
    {
      __pyx_t_6 = __pyx_t_10(__pyx_t_1);
      if (unlikely(!__pyx_t_6)) {
        if (PyErr_Occurred()) {
          if (likely(PyErr_ExceptionMatches(PyExc_StopIteration))) PyErr_Clear();
          else {__pyx_filename = __pyx_f[0]; __pyx_lineno = 949; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_6);
    }
    __Pyx_XDECREF(__pyx_v_o_ref);
    __pyx_v_o_ref = __pyx_t_6;
    __pyx_t_6 = 0;

    /* "axon/_dumper.py":950
 *         i = 0
 *         for o_ref in crossref_set:
 *             i += 1             # <<<<<<<<<<<<<<
 *             crossref_dict[o_ref] = unicode(i)
 * 
 */
    __pyx_v_i = (__pyx_v_i + 1);

    /* "axon/_dumper.py":951
 *         for o_ref in crossref_set:
 *             i += 1
 *             crossref_dict[o_ref] = unicode(i)             # <<<<<<<<<<<<<<
 * 
 *         self.crossref_set = crossref_set
 */
    __pyx_t_6 = PyInt_FromLong(__pyx_v_i); if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 951; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_5 = PyTuple_New(1); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 951; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_5);
    PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_6);
    __Pyx_GIVEREF(__pyx_t_6);
    __pyx_t_6 = 0;
    __pyx_t_6 = PyObject_Call(((PyObject *)((PyObject*)(&PyUnicode_Type))), ((PyObject *)__pyx_t_5), NULL); if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 951; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(((PyObject *)__pyx_t_5)); __pyx_t_5 = 0;
    if (PyDict_SetItem(((PyObject *)__pyx_v_crossref_dict), __pyx_v_o_ref, __pyx_t_6) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 951; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "axon/_dumper.py":953
 *             crossref_dict[o_ref] = unicode(i)
 * 
 *         self.crossref_set = crossref_set             # <<<<<<<<<<<<<<
 *         self.crossref_set2 = crossref_set2
 *         self.crossref_dict = crossref_dict
 */
  __Pyx_INCREF(((PyObject *)__pyx_v_crossref_set));
  __Pyx_GIVEREF(((PyObject *)__pyx_v_crossref_set));
  __Pyx_GOTREF(__pyx_v_self->crossref_set);
  __Pyx_DECREF(((PyObject *)__pyx_v_self->crossref_set));
  __pyx_v_self->crossref_set = __pyx_v_crossref_set;

  /* "axon/_dumper.py":954
 * 
 *         self.crossref_set = crossref_set
 *         self.crossref_set2 = crossref_set2             # <<<<<<<<<<<<<<
 *         self.crossref_dict = crossref_dict
 *         crossref_dict = None
 */
  if (!(likely(PySet_CheckExact(__pyx_v_crossref_set2))||(PyErr_Format(PyExc_TypeError, "Expected set, got %.200s", Py_TYPE(__pyx_v_crossref_set2)->tp_name), 0))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 954; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_INCREF(__pyx_v_crossref_set2);
  __Pyx_GIVEREF(__pyx_v_crossref_set2);
  __Pyx_GOTREF(__pyx_v_self->crossref_set2);
  __Pyx_DECREF(((PyObject *)__pyx_v_self->crossref_set2));
  __pyx_v_self->crossref_set2 = ((PyObject*)__pyx_v_crossref_set2);

  /* "axon/_dumper.py":955
 *         self.crossref_set = crossref_set
 *         self.crossref_set2 = crossref_set2
 *         self.crossref_dict = crossref_dict             # <<<<<<<<<<<<<<
 *         crossref_dict = None
 *         crossref_set = None
 */
  __Pyx_INCREF(((PyObject *)__pyx_v_crossref_dict));
  __Pyx_GIVEREF(((PyObject *)__pyx_v_crossref_dict));
  __Pyx_GOTREF(__pyx_v_self->crossref_dict);
  __Pyx_DECREF(((PyObject *)__pyx_v_self->crossref_dict));
  __pyx_v_self->crossref_dict = __pyx_v_crossref_dict;

  /* "axon/_dumper.py":956
 *         self.crossref_set2 = crossref_set2
 *         self.crossref_dict = crossref_dict
 *         crossref_dict = None             # <<<<<<<<<<<<<<
 *         crossref_set = None
 *         crossref_set2 = None
 */
  __Pyx_INCREF(Py_None);
  __Pyx_DECREF(((PyObject *)__pyx_v_crossref_dict));
  __pyx_v_crossref_dict = ((PyObject*)Py_None);

  /* "axon/_dumper.py":957
 *         self.crossref_dict = crossref_dict
 *         crossref_dict = None
 *         crossref_set = None             # <<<<<<<<<<<<<<
 *         crossref_set2 = None
 *     #
 */
  __Pyx_INCREF(Py_None);
  __Pyx_DECREF(((PyObject *)__pyx_v_crossref_set));
  __pyx_v_crossref_set = ((PyObject*)Py_None);

  /* "axon/_dumper.py":958
 *         crossref_dict = None
 *         crossref_set = None
 *         crossref_set2 = None             # <<<<<<<<<<<<<<
 *     #
 *     def _collect(self, o):
 */
  __Pyx_INCREF(Py_None);
  __Pyx_DECREF(__pyx_v_crossref_set2);
  __pyx_v_crossref_set2 = Py_None;

  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_WriteUnraisable("axon._dumper.Dumper.apply_crossref", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_count);
  __Pyx_XDECREF(__pyx_v_crossref_dict);
  __Pyx_XDECREF(__pyx_v_crossref_set);
  __Pyx_XDECREF(__pyx_v_crossref_set2);
  __Pyx_XDECREF(__pyx_v_o_ref);
  __Pyx_RefNannyFinishContext();
}

/* "axon/_dumper.py":960
 *         crossref_set2 = None
 *     #
 *     def _collect(self, o):             # <<<<<<<<<<<<<<
 * 
 *         if type(o) in simple_types:
 */

static int __pyx_f_4axon_7_dumper_6Dumper__collect(struct Dumper *__pyx_v_self, PyObject *__pyx_v_o) {
  struct __pyx_obj_4axon_7_dumper_PyInt *__pyx_v_count = 0;
  PyObject *__pyx_v_ref_o = NULL;
  PyObject *__pyx_v_otype = NULL;
  PyObject *__pyx_v_reducer = NULL;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_collect", 0);

  /* "axon/_dumper.py":962
 *     def _collect(self, o):
 * 
 *         if type(o) in simple_types:             # <<<<<<<<<<<<<<
 *             return 0
 * 
 */
  __pyx_t_1 = (__Pyx_PySequence_Contains(((PyObject *)Py_TYPE(__pyx_v_o)), ((PyObject *)__pyx_v_4axon_7_dumper_simple_types), Py_EQ)); if (unlikely(__pyx_t_1 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 962; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_t_2 = (__pyx_t_1 != 0);
  if (__pyx_t_2) {

    /* "axon/_dumper.py":963
 * 
 *         if type(o) in simple_types:
 *             return 0             # <<<<<<<<<<<<<<
 * 
 *         ref_o = id(o)
 */
    __pyx_r = 0;
    goto __pyx_L0;
    goto __pyx_L3;
  }
  __pyx_L3:;

  /* "axon/_dumper.py":965
 *             return 0
 * 
 *         ref_o = id(o)             # <<<<<<<<<<<<<<
 *         count = self.crossref_dict.get(ref_o, None)
 *         if count is None:
 */
  __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 965; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_INCREF(__pyx_v_o);
  PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_v_o);
  __Pyx_GIVEREF(__pyx_v_o);
  __pyx_t_4 = PyObject_Call(__pyx_builtin_id, ((PyObject *)__pyx_t_3), NULL); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 965; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(((PyObject *)__pyx_t_3)); __pyx_t_3 = 0;
  __pyx_v_ref_o = __pyx_t_4;
  __pyx_t_4 = 0;

  /* "axon/_dumper.py":966
 * 
 *         ref_o = id(o)
 *         count = self.crossref_dict.get(ref_o, None)             # <<<<<<<<<<<<<<
 *         if count is None:
 *             count = PyInt(1)
 */
  if (unlikely(((PyObject *)__pyx_v_self->crossref_dict) == Py_None)) {
    PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%s'", "get");
    {__pyx_filename = __pyx_f[0]; __pyx_lineno = 966; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }
  __pyx_t_4 = __Pyx_PyDict_GetItemDefault(((PyObject *)__pyx_v_self->crossref_dict), __pyx_v_ref_o, Py_None); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 966; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_4);
  if (!(likely(((__pyx_t_4) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_4, __pyx_ptype_4axon_7_dumper_PyInt))))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 966; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_v_count = ((struct __pyx_obj_4axon_7_dumper_PyInt *)__pyx_t_4);
  __pyx_t_4 = 0;

  /* "axon/_dumper.py":967
 *         ref_o = id(o)
 *         count = self.crossref_dict.get(ref_o, None)
 *         if count is None:             # <<<<<<<<<<<<<<
 *             count = PyInt(1)
 *             self.crossref_dict[ref_o] = count
 */
  __pyx_t_2 = (((PyObject *)__pyx_v_count) == Py_None);
  __pyx_t_1 = (__pyx_t_2 != 0);
  if (__pyx_t_1) {

    /* "axon/_dumper.py":968
 *         count = self.crossref_dict.get(ref_o, None)
 *         if count is None:
 *             count = PyInt(1)             # <<<<<<<<<<<<<<
 *             self.crossref_dict[ref_o] = count
 *         else:
 */
    __pyx_t_4 = PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_4axon_7_dumper_PyInt)), ((PyObject *)__pyx_k_tuple_119), NULL); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 968; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(((PyObject *)__pyx_v_count));
    __pyx_v_count = ((struct __pyx_obj_4axon_7_dumper_PyInt *)__pyx_t_4);
    __pyx_t_4 = 0;

    /* "axon/_dumper.py":969
 *         if count is None:
 *             count = PyInt(1)
 *             self.crossref_dict[ref_o] = count             # <<<<<<<<<<<<<<
 *         else:
 *             count.val += 1
 */
    if (unlikely(((PyObject *)__pyx_v_self->crossref_dict) == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      {__pyx_filename = __pyx_f[0]; __pyx_lineno = 969; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    }
    if (PyDict_SetItem(((PyObject *)__pyx_v_self->crossref_dict), __pyx_v_ref_o, ((PyObject *)__pyx_v_count)) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 969; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    goto __pyx_L4;
  }
  /*else*/ {

    /* "axon/_dumper.py":971
 *             self.crossref_dict[ref_o] = count
 *         else:
 *             count.val += 1             # <<<<<<<<<<<<<<
 *             self.crossref_dict[ref_o] = count
 *             return 0
 */
    __pyx_v_count->val = (__pyx_v_count->val + 1);

    /* "axon/_dumper.py":972
 *         else:
 *             count.val += 1
 *             self.crossref_dict[ref_o] = count             # <<<<<<<<<<<<<<
 *             return 0
 * 
 */
    if (unlikely(((PyObject *)__pyx_v_self->crossref_dict) == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      {__pyx_filename = __pyx_f[0]; __pyx_lineno = 972; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    }
    if (PyDict_SetItem(((PyObject *)__pyx_v_self->crossref_dict), __pyx_v_ref_o, ((PyObject *)__pyx_v_count)) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 972; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

    /* "axon/_dumper.py":973
 *             count.val += 1
 *             self.crossref_dict[ref_o] = count
 *             return 0             # <<<<<<<<<<<<<<
 * 
 *         otype = type(o)
 */
    __pyx_r = 0;
    goto __pyx_L0;
  }
  __pyx_L4:;

  /* "axon/_dumper.py":975
 *             return 0
 * 
 *         otype = type(o)             # <<<<<<<<<<<<<<
 *         if otype is list:
 *             self._collect_list(o)
 */
  __Pyx_INCREF(((PyObject *)Py_TYPE(__pyx_v_o)));
  __pyx_v_otype = ((PyObject*)((PyObject *)Py_TYPE(__pyx_v_o)));

  /* "axon/_dumper.py":976
 * 
 *         otype = type(o)
 *         if otype is list:             # <<<<<<<<<<<<<<
 *             self._collect_list(o)
 *         elif otype is dict:
 */
  __pyx_t_1 = (__pyx_v_otype == ((PyObject*)(&PyList_Type)));
  __pyx_t_2 = (__pyx_t_1 != 0);
  if (__pyx_t_2) {

    /* "axon/_dumper.py":977
 *         otype = type(o)
 *         if otype is list:
 *             self._collect_list(o)             # <<<<<<<<<<<<<<
 *         elif otype is dict:
 *             self._collect_dict(o)
 */
    if (!(likely(PyList_CheckExact(__pyx_v_o))||((__pyx_v_o) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected list, got %.200s", Py_TYPE(__pyx_v_o)->tp_name), 0))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 977; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __pyx_t_5 = __pyx_f_4axon_7_dumper_6Dumper__collect_list(__pyx_v_self, ((PyObject*)__pyx_v_o)); if (unlikely(__pyx_t_5 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 977; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    goto __pyx_L5;
  }

  /* "axon/_dumper.py":978
 *         if otype is list:
 *             self._collect_list(o)
 *         elif otype is dict:             # <<<<<<<<<<<<<<
 *             self._collect_dict(o)
 *         elif otype is tuple:
 */
  __pyx_t_2 = (__pyx_v_otype == ((PyObject*)(&PyDict_Type)));
  __pyx_t_1 = (__pyx_t_2 != 0);
  if (__pyx_t_1) {

    /* "axon/_dumper.py":979
 *             self._collect_list(o)
 *         elif otype is dict:
 *             self._collect_dict(o)             # <<<<<<<<<<<<<<
 *         elif otype is tuple:
 *             self._collect_tuple(o)
 */
    if (!(likely(PyDict_CheckExact(__pyx_v_o))||((__pyx_v_o) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected dict, got %.200s", Py_TYPE(__pyx_v_o)->tp_name), 0))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 979; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __pyx_t_5 = __pyx_f_4axon_7_dumper_6Dumper__collect_dict(__pyx_v_self, ((PyObject*)__pyx_v_o)); if (unlikely(__pyx_t_5 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 979; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    goto __pyx_L5;
  }

  /* "axon/_dumper.py":980
 *         elif otype is dict:
 *             self._collect_dict(o)
 *         elif otype is tuple:             # <<<<<<<<<<<<<<
 *             self._collect_tuple(o)
 *         elif otype is set:
 */
  __pyx_t_1 = (__pyx_v_otype == ((PyObject*)(&PyTuple_Type)));
  __pyx_t_2 = (__pyx_t_1 != 0);
  if (__pyx_t_2) {

    /* "axon/_dumper.py":981
 *             self._collect_dict(o)
 *         elif otype is tuple:
 *             self._collect_tuple(o)             # <<<<<<<<<<<<<<
 *         elif otype is set:
 *             self._collect_set(o)
 */
    if (!(likely(PyTuple_CheckExact(__pyx_v_o))||((__pyx_v_o) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected tuple, got %.200s", Py_TYPE(__pyx_v_o)->tp_name), 0))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 981; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __pyx_t_5 = __pyx_f_4axon_7_dumper_6Dumper__collect_tuple(__pyx_v_self, ((PyObject*)__pyx_v_o)); if (unlikely(__pyx_t_5 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 981; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    goto __pyx_L5;
  }

  /* "axon/_dumper.py":982
 *         elif otype is tuple:
 *             self._collect_tuple(o)
 *         elif otype is set:             # <<<<<<<<<<<<<<
 *             self._collect_set(o)
 *         else:
 */
  __pyx_t_2 = (__pyx_v_otype == ((PyObject*)(&PySet_Type)));
  __pyx_t_1 = (__pyx_t_2 != 0);
  if (__pyx_t_1) {

    /* "axon/_dumper.py":983
 *             self._collect_tuple(o)
 *         elif otype is set:
 *             self._collect_set(o)             # <<<<<<<<<<<<<<
 *         else:
 *             reducer = self.c_type_reducers.get(otype, None)
 */
    if (!(likely(PySet_CheckExact(__pyx_v_o))||((__pyx_v_o) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected set, got %.200s", Py_TYPE(__pyx_v_o)->tp_name), 0))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 983; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __pyx_t_5 = __pyx_f_4axon_7_dumper_6Dumper__collect_set(__pyx_v_self, ((PyObject*)__pyx_v_o)); if (unlikely(__pyx_t_5 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 983; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    goto __pyx_L5;
  }
  /*else*/ {

    /* "axon/_dumper.py":985
 *             self._collect_set(o)
 *         else:
 *             reducer = self.c_type_reducers.get(otype, None)             # <<<<<<<<<<<<<<
 *             if reducer is None:
 *                 raise TypeError('There is no reducer for this type: ' + repr(otype))
 */
    if (unlikely(((PyObject *)__pyx_v_self->c_type_reducers) == Py_None)) {
      PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%s'", "get");
      {__pyx_filename = __pyx_f[0]; __pyx_lineno = 985; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    }
    __pyx_t_4 = __Pyx_PyDict_GetItemDefault(((PyObject *)__pyx_v_self->c_type_reducers), ((PyObject *)__pyx_v_otype), Py_None); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 985; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_v_reducer = __pyx_t_4;
    __pyx_t_4 = 0;

    /* "axon/_dumper.py":986
 *         else:
 *             reducer = self.c_type_reducers.get(otype, None)
 *             if reducer is None:             # <<<<<<<<<<<<<<
 *                 raise TypeError('There is no reducer for this type: ' + repr(otype))
 *             else:
 */
    __pyx_t_1 = (__pyx_v_reducer == Py_None);
    __pyx_t_2 = (__pyx_t_1 != 0);
    if (__pyx_t_2) {

      /* "axon/_dumper.py":987
 *             reducer = self.c_type_reducers.get(otype, None)
 *             if reducer is None:
 *                 raise TypeError('There is no reducer for this type: ' + repr(otype))             # <<<<<<<<<<<<<<
 *             else:
 *                 self._collect_with_reducer(reducer, o)
 */
      __pyx_t_4 = PyObject_Repr(((PyObject *)__pyx_v_otype)); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 987; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_3 = PyNumber_Add(((PyObject *)__pyx_kp_u_42), __pyx_t_4); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 987; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_4 = PyTuple_New(1); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 987; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_4);
      PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_3);
      __Pyx_GIVEREF(__pyx_t_3);
      __pyx_t_3 = 0;
      __pyx_t_3 = PyObject_Call(__pyx_builtin_TypeError, ((PyObject *)__pyx_t_4), NULL); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 987; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(((PyObject *)__pyx_t_4)); __pyx_t_4 = 0;
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      {__pyx_filename = __pyx_f[0]; __pyx_lineno = 987; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      goto __pyx_L6;
    }
    /*else*/ {

      /* "axon/_dumper.py":989
 *                 raise TypeError('There is no reducer for this type: ' + repr(otype))
 *             else:
 *                 self._collect_with_reducer(reducer, o)             # <<<<<<<<<<<<<<
 *     #
 *     def _collect_list(self, lst):
 */
      __pyx_t_5 = __pyx_f_4axon_7_dumper_6Dumper__collect_with_reducer(__pyx_v_self, __pyx_v_reducer, __pyx_v_o); if (unlikely(__pyx_t_5 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 989; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    }
    __pyx_L6:;
  }
  __pyx_L5:;

  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("axon._dumper.Dumper._collect", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_count);
  __Pyx_XDECREF(__pyx_v_ref_o);
  __Pyx_XDECREF(__pyx_v_otype);
  __Pyx_XDECREF(__pyx_v_reducer);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_dumper.py":991
 *                 self._collect_with_reducer(reducer, o)
 *     #
 *     def _collect_list(self, lst):             # <<<<<<<<<<<<<<
 *         for v in lst:
 *             self._collect(v)
 */

static int __pyx_f_4axon_7_dumper_6Dumper__collect_list(struct Dumper *__pyx_v_self, PyObject *__pyx_v_lst) {
  PyObject *__pyx_v_v = NULL;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  Py_ssize_t __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_collect_list", 0);

  /* "axon/_dumper.py":992
 *     #
 *     def _collect_list(self, lst):
 *         for v in lst:             # <<<<<<<<<<<<<<
 *             self._collect(v)
 *     #
 */
  if (unlikely(((PyObject *)__pyx_v_lst) == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not iterable");
    {__pyx_filename = __pyx_f[0]; __pyx_lineno = 992; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }
  __pyx_t_1 = ((PyObject *)__pyx_v_lst); __Pyx_INCREF(__pyx_t_1); __pyx_t_2 = 0;
  for (;;) {
    if (__pyx_t_2 >= PyList_GET_SIZE(__pyx_t_1)) break;
    #if CYTHON_COMPILING_IN_CPYTHON
    __pyx_t_3 = PyList_GET_ITEM(__pyx_t_1, __pyx_t_2); __Pyx_INCREF(__pyx_t_3); __pyx_t_2++; if (unlikely(0 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 992; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    #else
    __pyx_t_3 = PySequence_ITEM(__pyx_t_1, __pyx_t_2); __pyx_t_2++; if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 992; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    #endif
    __Pyx_XDECREF(__pyx_v_v);
    __pyx_v_v = __pyx_t_3;
    __pyx_t_3 = 0;

    /* "axon/_dumper.py":993
 *     def _collect_list(self, lst):
 *         for v in lst:
 *             self._collect(v)             # <<<<<<<<<<<<<<
 *     #
 *     def _collect_tuple(self, lst):
 */
    __pyx_t_4 = __pyx_f_4axon_7_dumper_6Dumper__collect(__pyx_v_self, __pyx_v_v); if (unlikely(__pyx_t_4 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 993; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("axon._dumper.Dumper._collect_list", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_v);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_dumper.py":995
 *             self._collect(v)
 *     #
 *     def _collect_tuple(self, lst):             # <<<<<<<<<<<<<<
 *         for v in lst:
 *             self._collect(v)
 */

static int __pyx_f_4axon_7_dumper_6Dumper__collect_tuple(struct Dumper *__pyx_v_self, PyObject *__pyx_v_lst) {
  PyObject *__pyx_v_v = NULL;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  Py_ssize_t __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_collect_tuple", 0);

  /* "axon/_dumper.py":996
 *     #
 *     def _collect_tuple(self, lst):
 *         for v in lst:             # <<<<<<<<<<<<<<
 *             self._collect(v)
 *     #
 */
  if (unlikely(((PyObject *)__pyx_v_lst) == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not iterable");
    {__pyx_filename = __pyx_f[0]; __pyx_lineno = 996; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }
  __pyx_t_1 = ((PyObject *)__pyx_v_lst); __Pyx_INCREF(__pyx_t_1); __pyx_t_2 = 0;
  for (;;) {
    if (__pyx_t_2 >= PyTuple_GET_SIZE(__pyx_t_1)) break;
    #if CYTHON_COMPILING_IN_CPYTHON
    __pyx_t_3 = PyTuple_GET_ITEM(__pyx_t_1, __pyx_t_2); __Pyx_INCREF(__pyx_t_3); __pyx_t_2++; if (unlikely(0 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 996; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    #else
    __pyx_t_3 = PySequence_ITEM(__pyx_t_1, __pyx_t_2); __pyx_t_2++; if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 996; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    #endif
    __Pyx_XDECREF(__pyx_v_v);
    __pyx_v_v = __pyx_t_3;
    __pyx_t_3 = 0;

    /* "axon/_dumper.py":997
 *     def _collect_tuple(self, lst):
 *         for v in lst:
 *             self._collect(v)             # <<<<<<<<<<<<<<
 *     #
 *     def _collect_set(self, lst):
 */
    __pyx_t_4 = __pyx_f_4axon_7_dumper_6Dumper__collect(__pyx_v_self, __pyx_v_v); if (unlikely(__pyx_t_4 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 997; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("axon._dumper.Dumper._collect_tuple", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_v);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_dumper.py":999
 *             self._collect(v)
 *     #
 *     def _collect_set(self, lst):             # <<<<<<<<<<<<<<
 *         for v in lst:
 *             self._collect(v)
 */

static int __pyx_f_4axon_7_dumper_6Dumper__collect_set(struct Dumper *__pyx_v_self, PyObject *__pyx_v_lst) {
  PyObject *__pyx_v_v = NULL;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *(*__pyx_t_2)(PyObject *);
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_collect_set", 0);

  /* "axon/_dumper.py":1000
 *     #
 *     def _collect_set(self, lst):
 *         for v in lst:             # <<<<<<<<<<<<<<
 *             self._collect(v)
 *     #
 */
  __pyx_t_1 = PyObject_GetIter(((PyObject *)__pyx_v_lst)); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1000; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = Py_TYPE(__pyx_t_1)->tp_iternext;
  for (;;) {
    {
      __pyx_t_3 = __pyx_t_2(__pyx_t_1);
      if (unlikely(!__pyx_t_3)) {
        if (PyErr_Occurred()) {
          if (likely(PyErr_ExceptionMatches(PyExc_StopIteration))) PyErr_Clear();
          else {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1000; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_3);
    }
    __Pyx_XDECREF(__pyx_v_v);
    __pyx_v_v = __pyx_t_3;
    __pyx_t_3 = 0;

    /* "axon/_dumper.py":1001
 *     def _collect_set(self, lst):
 *         for v in lst:
 *             self._collect(v)             # <<<<<<<<<<<<<<
 *     #
 *     def _collect_dict(self, d):
 */
    __pyx_t_4 = __pyx_f_4axon_7_dumper_6Dumper__collect(__pyx_v_self, __pyx_v_v); if (unlikely(__pyx_t_4 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1001; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("axon._dumper.Dumper._collect_set", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_v);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_dumper.py":1003
 *             self._collect(v)
 *     #
 *     def _collect_dict(self, d):             # <<<<<<<<<<<<<<
 *         for v in d.values():
 *             self._collect(v)
 */

static int __pyx_f_4axon_7_dumper_6Dumper__collect_dict(struct Dumper *__pyx_v_self, PyObject *__pyx_v_d) {
  PyObject *__pyx_v_v = NULL;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  Py_ssize_t __pyx_t_2;
  Py_ssize_t __pyx_t_3;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_collect_dict", 0);

  /* "axon/_dumper.py":1004
 *     #
 *     def _collect_dict(self, d):
 *         for v in d.values():             # <<<<<<<<<<<<<<
 *             self._collect(v)
 *     #
 */
  __pyx_t_2 = 0;
  if (unlikely(((PyObject *)__pyx_v_d) == Py_None)) {
    PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%s'", "values");
    {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1004; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }
  __pyx_t_5 = __Pyx_dict_iterator(((PyObject *)__pyx_v_d), 1, ((PyObject *)__pyx_n_s__values), (&__pyx_t_3), (&__pyx_t_4)); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1004; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_1);
  __pyx_t_1 = __pyx_t_5;
  __pyx_t_5 = 0;
  while (1) {
    __pyx_t_6 = __Pyx_dict_iter_next(__pyx_t_1, __pyx_t_3, &__pyx_t_2, NULL, &__pyx_t_5, NULL, __pyx_t_4);
    if (unlikely(__pyx_t_6 == 0)) break;
    if (unlikely(__pyx_t_6 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1004; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_XDECREF(__pyx_v_v);
    __pyx_v_v = __pyx_t_5;
    __pyx_t_5 = 0;

    /* "axon/_dumper.py":1005
 *     def _collect_dict(self, d):
 *         for v in d.values():
 *             self._collect(v)             # <<<<<<<<<<<<<<
 *     #
 *     def _collect_with_reducer(self, reducer, o):
 */
    __pyx_t_6 = __pyx_f_4axon_7_dumper_6Dumper__collect(__pyx_v_self, __pyx_v_v); if (unlikely(__pyx_t_6 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1005; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("axon._dumper.Dumper._collect_dict", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_v);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_dumper.py":1007
 *             self._collect(v)
 *     #
 *     def _collect_with_reducer(self, reducer, o):             # <<<<<<<<<<<<<<
 * 
 *         results = reducer(o)
 */

static int __pyx_f_4axon_7_dumper_6Dumper__collect_with_reducer(struct Dumper *__pyx_v_self, PyObject *__pyx_v_reducer, PyObject *__pyx_v_o) {
  int __pyx_v_n;
  PyObject *__pyx_v_results = NULL;
  long __pyx_v_i;
  PyObject *__pyx_v_results_i = NULL;
  PyObject *__pyx_v_tp = NULL;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  Py_ssize_t __pyx_t_3;
  int __pyx_t_4;
  int __pyx_t_5;
  long __pyx_t_6;
  int __pyx_t_7;
  int __pyx_t_8;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_collect_with_reducer", 0);

  /* "axon/_dumper.py":1009
 *     def _collect_with_reducer(self, reducer, o):
 * 
 *         results = reducer(o)             # <<<<<<<<<<<<<<
 *         n = len(results)
 * 
 */
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1009; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_v_o);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_o);
  __Pyx_GIVEREF(__pyx_v_o);
  __pyx_t_2 = PyObject_Call(__pyx_v_reducer, ((PyObject *)__pyx_t_1), NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1009; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(((PyObject *)__pyx_t_1)); __pyx_t_1 = 0;
  __pyx_v_results = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "axon/_dumper.py":1010
 * 
 *         results = reducer(o)
 *         n = len(results)             # <<<<<<<<<<<<<<
 * 
 *         if n == 1:
 */
  __pyx_t_3 = PyObject_Length(__pyx_v_results); if (unlikely(__pyx_t_3 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1010; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_v_n = __pyx_t_3;

  /* "axon/_dumper.py":1012
 *         n = len(results)
 * 
 *         if n == 1:             # <<<<<<<<<<<<<<
 *             return 0
 * 
 */
  __pyx_t_4 = ((__pyx_v_n == 1) != 0);
  if (__pyx_t_4) {

    /* "axon/_dumper.py":1013
 * 
 *         if n == 1:
 *             return 0             # <<<<<<<<<<<<<<
 * 
 *         for i in range(1, n):
 */
    __pyx_r = 0;
    goto __pyx_L0;
    goto __pyx_L3;
  }
  __pyx_L3:;

  /* "axon/_dumper.py":1015
 *             return 0
 * 
 *         for i in range(1, n):             # <<<<<<<<<<<<<<
 *             results_i = results[i]
 *             tp = type(results_i)
 */
  __pyx_t_5 = __pyx_v_n;
  for (__pyx_t_6 = 1; __pyx_t_6 < __pyx_t_5; __pyx_t_6+=1) {
    __pyx_v_i = __pyx_t_6;

    /* "axon/_dumper.py":1016
 * 
 *         for i in range(1, n):
 *             results_i = results[i]             # <<<<<<<<<<<<<<
 *             tp = type(results_i)
 *             if tp is list:
 */
    __pyx_t_2 = __Pyx_GetItemInt(__pyx_v_results, __pyx_v_i, sizeof(long), PyInt_FromLong, 0, 0, 0); if (!__pyx_t_2) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1016; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_XDECREF(__pyx_v_results_i);
    __pyx_v_results_i = __pyx_t_2;
    __pyx_t_2 = 0;

    /* "axon/_dumper.py":1017
 *         for i in range(1, n):
 *             results_i = results[i]
 *             tp = type(results_i)             # <<<<<<<<<<<<<<
 *             if tp is list:
 *                 self._collect_list(results_i)
 */
    __Pyx_INCREF(((PyObject *)Py_TYPE(__pyx_v_results_i)));
    __Pyx_XDECREF(((PyObject *)__pyx_v_tp));
    __pyx_v_tp = ((PyObject*)((PyObject *)Py_TYPE(__pyx_v_results_i)));

    /* "axon/_dumper.py":1018
 *             results_i = results[i]
 *             tp = type(results_i)
 *             if tp is list:             # <<<<<<<<<<<<<<
 *                 self._collect_list(results_i)
 *             elif tp is dict:
 */
    __pyx_t_4 = (__pyx_v_tp == ((PyObject*)(&PyList_Type)));
    __pyx_t_7 = (__pyx_t_4 != 0);
    if (__pyx_t_7) {

      /* "axon/_dumper.py":1019
 *             tp = type(results_i)
 *             if tp is list:
 *                 self._collect_list(results_i)             # <<<<<<<<<<<<<<
 *             elif tp is dict:
 *                 self._collect_dict(results_i)
 */
      if (!(likely(PyList_CheckExact(__pyx_v_results_i))||((__pyx_v_results_i) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected list, got %.200s", Py_TYPE(__pyx_v_results_i)->tp_name), 0))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1019; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __pyx_t_8 = __pyx_f_4axon_7_dumper_6Dumper__collect_list(__pyx_v_self, ((PyObject*)__pyx_v_results_i)); if (unlikely(__pyx_t_8 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1019; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      goto __pyx_L6;
    }

    /* "axon/_dumper.py":1020
 *             if tp is list:
 *                 self._collect_list(results_i)
 *             elif tp is dict:             # <<<<<<<<<<<<<<
 *                 self._collect_dict(results_i)
 *             elif tp is tuple:
 */
    __pyx_t_7 = (__pyx_v_tp == ((PyObject*)(&PyDict_Type)));
    __pyx_t_4 = (__pyx_t_7 != 0);
    if (__pyx_t_4) {

      /* "axon/_dumper.py":1021
 *                 self._collect_list(results_i)
 *             elif tp is dict:
 *                 self._collect_dict(results_i)             # <<<<<<<<<<<<<<
 *             elif tp is tuple:
 *                 self._collect_tuple(results_i)
 */
      if (!(likely(PyDict_CheckExact(__pyx_v_results_i))||((__pyx_v_results_i) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected dict, got %.200s", Py_TYPE(__pyx_v_results_i)->tp_name), 0))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1021; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __pyx_t_8 = __pyx_f_4axon_7_dumper_6Dumper__collect_dict(__pyx_v_self, ((PyObject*)__pyx_v_results_i)); if (unlikely(__pyx_t_8 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1021; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      goto __pyx_L6;
    }

    /* "axon/_dumper.py":1022
 *             elif tp is dict:
 *                 self._collect_dict(results_i)
 *             elif tp is tuple:             # <<<<<<<<<<<<<<
 *                 self._collect_tuple(results_i)
 *             elif tp is set:
 */
    __pyx_t_4 = (__pyx_v_tp == ((PyObject*)(&PyTuple_Type)));
    __pyx_t_7 = (__pyx_t_4 != 0);
    if (__pyx_t_7) {

      /* "axon/_dumper.py":1023
 *                 self._collect_dict(results_i)
 *             elif tp is tuple:
 *                 self._collect_tuple(results_i)             # <<<<<<<<<<<<<<
 *             elif tp is set:
 *                 self._collect_set(results_i)
 */
      if (!(likely(PyTuple_CheckExact(__pyx_v_results_i))||((__pyx_v_results_i) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected tuple, got %.200s", Py_TYPE(__pyx_v_results_i)->tp_name), 0))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1023; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __pyx_t_8 = __pyx_f_4axon_7_dumper_6Dumper__collect_tuple(__pyx_v_self, ((PyObject*)__pyx_v_results_i)); if (unlikely(__pyx_t_8 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1023; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      goto __pyx_L6;
    }

    /* "axon/_dumper.py":1024
 *             elif tp is tuple:
 *                 self._collect_tuple(results_i)
 *             elif tp is set:             # <<<<<<<<<<<<<<
 *                 self._collect_set(results_i)
 *     #
 */
    __pyx_t_7 = (__pyx_v_tp == ((PyObject*)(&PySet_Type)));
    __pyx_t_4 = (__pyx_t_7 != 0);
    if (__pyx_t_4) {

      /* "axon/_dumper.py":1025
 *                 self._collect_tuple(results_i)
 *             elif tp is set:
 *                 self._collect_set(results_i)             # <<<<<<<<<<<<<<
 *     #
 *     def collect(self, values):
 */
      if (!(likely(PySet_CheckExact(__pyx_v_results_i))||((__pyx_v_results_i) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected set, got %.200s", Py_TYPE(__pyx_v_results_i)->tp_name), 0))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1025; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __pyx_t_8 = __pyx_f_4axon_7_dumper_6Dumper__collect_set(__pyx_v_self, ((PyObject*)__pyx_v_results_i)); if (unlikely(__pyx_t_8 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1025; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      goto __pyx_L6;
    }
    __pyx_L6:;
  }

  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("axon._dumper.Dumper._collect_with_reducer", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_results);
  __Pyx_XDECREF(__pyx_v_results_i);
  __Pyx_XDECREF(__pyx_v_tp);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_dumper.py":1027
 *                 self._collect_set(results_i)
 *     #
 *     def collect(self, values):             # <<<<<<<<<<<<<<
 *         for v in values:
 *             self._collect(v)
 */

static int __pyx_f_4axon_7_dumper_6Dumper_collect(struct Dumper *__pyx_v_self, PyObject *__pyx_v_values) {
  PyObject *__pyx_v_v = NULL;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  Py_ssize_t __pyx_t_2;
  PyObject *(*__pyx_t_3)(PyObject *);
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("collect", 0);

  /* "axon/_dumper.py":1028
 *     #
 *     def collect(self, values):
 *         for v in values:             # <<<<<<<<<<<<<<
 *             self._collect(v)
 * 
 */
  if (PyList_CheckExact(__pyx_v_values) || PyTuple_CheckExact(__pyx_v_values)) {
    __pyx_t_1 = __pyx_v_values; __Pyx_INCREF(__pyx_t_1); __pyx_t_2 = 0;
    __pyx_t_3 = NULL;
  } else {
    __pyx_t_2 = -1; __pyx_t_1 = PyObject_GetIter(__pyx_v_values); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1028; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = Py_TYPE(__pyx_t_1)->tp_iternext;
  }
  for (;;) {
    if (!__pyx_t_3 && PyList_CheckExact(__pyx_t_1)) {
      if (__pyx_t_2 >= PyList_GET_SIZE(__pyx_t_1)) break;
      #if CYTHON_COMPILING_IN_CPYTHON
      __pyx_t_4 = PyList_GET_ITEM(__pyx_t_1, __pyx_t_2); __Pyx_INCREF(__pyx_t_4); __pyx_t_2++; if (unlikely(0 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1028; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      #else
      __pyx_t_4 = PySequence_ITEM(__pyx_t_1, __pyx_t_2); __pyx_t_2++; if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1028; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      #endif
    } else if (!__pyx_t_3 && PyTuple_CheckExact(__pyx_t_1)) {
      if (__pyx_t_2 >= PyTuple_GET_SIZE(__pyx_t_1)) break;
      #if CYTHON_COMPILING_IN_CPYTHON
      __pyx_t_4 = PyTuple_GET_ITEM(__pyx_t_1, __pyx_t_2); __Pyx_INCREF(__pyx_t_4); __pyx_t_2++; if (unlikely(0 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1028; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      #else
      __pyx_t_4 = PySequence_ITEM(__pyx_t_1, __pyx_t_2); __pyx_t_2++; if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1028; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      #endif
    } else {
      __pyx_t_4 = __pyx_t_3(__pyx_t_1);
      if (unlikely(!__pyx_t_4)) {
        if (PyErr_Occurred()) {
          if (likely(PyErr_ExceptionMatches(PyExc_StopIteration))) PyErr_Clear();
          else {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1028; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_4);
    }
    __Pyx_XDECREF(__pyx_v_v);
    __pyx_v_v = __pyx_t_4;
    __pyx_t_4 = 0;

    /* "axon/_dumper.py":1029
 *     def collect(self, values):
 *         for v in values:
 *             self._collect(v)             # <<<<<<<<<<<<<<
 * 
 * 
 */
    __pyx_t_5 = __pyx_f_4axon_7_dumper_6Dumper__collect(__pyx_v_self, __pyx_v_v); if (unlikely(__pyx_t_5 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1029; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("axon._dumper.Dumper.collect", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_v);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_objects.pxd":34
 * #        return <object>val
 * 
 * cdef inline dict c_as_dict(object ob):             # <<<<<<<<<<<<<<
 *     if type(ob) is dict:
 *         return <dict>ob
 */

static CYTHON_INLINE PyObject *__pyx_f_4axon_8_objects_c_as_dict(PyObject *__pyx_v_ob) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("c_as_dict", 0);

  /* "axon/_objects.pxd":35
 * 
 * cdef inline dict c_as_dict(object ob):
 *     if type(ob) is dict:             # <<<<<<<<<<<<<<
 *         return <dict>ob
 *     elif ob is None:
 */
  __pyx_t_1 = (((PyObject *)Py_TYPE(__pyx_v_ob)) == ((PyObject *)((PyObject*)(&PyDict_Type))));
  __pyx_t_2 = (__pyx_t_1 != 0);
  if (__pyx_t_2) {

    /* "axon/_objects.pxd":36
 * cdef inline dict c_as_dict(object ob):
 *     if type(ob) is dict:
 *         return <dict>ob             # <<<<<<<<<<<<<<
 *     elif ob is None:
 *         return {}
 */
    __Pyx_XDECREF(((PyObject *)__pyx_r));
    __Pyx_INCREF(((PyObject *)((PyObject*)__pyx_v_ob)));
    __pyx_r = ((PyObject*)__pyx_v_ob);
    goto __pyx_L0;
    goto __pyx_L3;
  }

  /* "axon/_objects.pxd":37
 *     if type(ob) is dict:
 *         return <dict>ob
 *     elif ob is None:             # <<<<<<<<<<<<<<
 *         return {}
 *     else:
 */
  __pyx_t_2 = (__pyx_v_ob == Py_None);
  __pyx_t_1 = (__pyx_t_2 != 0);
  if (__pyx_t_1) {

    /* "axon/_objects.pxd":38
 *         return <dict>ob
 *     elif ob is None:
 *         return {}             # <<<<<<<<<<<<<<
 *     else:
 *         return dict(ob)
 */
    __Pyx_XDECREF(((PyObject *)__pyx_r));
    __pyx_t_3 = PyDict_New(); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[2]; __pyx_lineno = 38; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(((PyObject *)__pyx_t_3));
    __pyx_r = ((PyObject*)__pyx_t_3);
    __pyx_t_3 = 0;
    goto __pyx_L0;
    goto __pyx_L3;
  }
  /*else*/ {

    /* "axon/_objects.pxd":40
 *         return {}
 *     else:
 *         return dict(ob)             # <<<<<<<<<<<<<<
 * 
 * cdef inline list c_as_list(object ob):
 */
    __Pyx_XDECREF(((PyObject *)__pyx_r));
    __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[2]; __pyx_lineno = 40; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_INCREF(__pyx_v_ob);
    PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_v_ob);
    __Pyx_GIVEREF(__pyx_v_ob);
    __pyx_t_4 = PyObject_Call(((PyObject *)((PyObject*)(&PyDict_Type))), ((PyObject *)__pyx_t_3), NULL); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[2]; __pyx_lineno = 40; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(((PyObject *)__pyx_t_3)); __pyx_t_3 = 0;
    __pyx_r = ((PyObject*)__pyx_t_4);
    __pyx_t_4 = 0;
    goto __pyx_L0;
  }
  __pyx_L3:;

  __pyx_r = ((PyObject*)Py_None); __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("axon._objects.c_as_dict", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_objects.pxd":42
 *         return dict(ob)
 * 
 * cdef inline list c_as_list(object ob):             # <<<<<<<<<<<<<<
 *     if type(ob) is list:
 *         return <list>ob
 */

static CYTHON_INLINE PyObject *__pyx_f_4axon_8_objects_c_as_list(PyObject *__pyx_v_ob) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("c_as_list", 0);

  /* "axon/_objects.pxd":43
 * 
 * cdef inline list c_as_list(object ob):
 *     if type(ob) is list:             # <<<<<<<<<<<<<<
 *         return <list>ob
 *     elif ob is None:
 */
  __pyx_t_1 = (((PyObject *)Py_TYPE(__pyx_v_ob)) == ((PyObject *)((PyObject*)(&PyList_Type))));
  __pyx_t_2 = (__pyx_t_1 != 0);
  if (__pyx_t_2) {

    /* "axon/_objects.pxd":44
 * cdef inline list c_as_list(object ob):
 *     if type(ob) is list:
 *         return <list>ob             # <<<<<<<<<<<<<<
 *     elif ob is None:
 *         return []
 */
    __Pyx_XDECREF(((PyObject *)__pyx_r));
    __Pyx_INCREF(((PyObject *)((PyObject*)__pyx_v_ob)));
    __pyx_r = ((PyObject*)__pyx_v_ob);
    goto __pyx_L0;
    goto __pyx_L3;
  }

  /* "axon/_objects.pxd":45
 *     if type(ob) is list:
 *         return <list>ob
 *     elif ob is None:             # <<<<<<<<<<<<<<
 *         return []
 *     else:
 */
  __pyx_t_2 = (__pyx_v_ob == Py_None);
  __pyx_t_1 = (__pyx_t_2 != 0);
  if (__pyx_t_1) {

    /* "axon/_objects.pxd":46
 *         return <list>ob
 *     elif ob is None:
 *         return []             # <<<<<<<<<<<<<<
 *     else:
 *         return list(ob)
 */
    __Pyx_XDECREF(((PyObject *)__pyx_r));
    __pyx_t_3 = PyList_New(0); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[2]; __pyx_lineno = 46; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_r = ((PyObject*)__pyx_t_3);
    __pyx_t_3 = 0;
    goto __pyx_L0;
    goto __pyx_L3;
  }
  /*else*/ {

    /* "axon/_objects.pxd":48
 *         return []
 *     else:
 *         return list(ob)             # <<<<<<<<<<<<<<
 * 
 * cdef inline tuple c_as_tuple(object ob):
 */
    __Pyx_XDECREF(((PyObject *)__pyx_r));
    __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[2]; __pyx_lineno = 48; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_INCREF(__pyx_v_ob);
    PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_v_ob);
    __Pyx_GIVEREF(__pyx_v_ob);
    __pyx_t_4 = PyObject_Call(((PyObject *)((PyObject*)(&PyList_Type))), ((PyObject *)__pyx_t_3), NULL); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[2]; __pyx_lineno = 48; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(((PyObject *)__pyx_t_3)); __pyx_t_3 = 0;
    __pyx_r = ((PyObject*)__pyx_t_4);
    __pyx_t_4 = 0;
    goto __pyx_L0;
  }
  __pyx_L3:;

  __pyx_r = ((PyObject*)Py_None); __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("axon._objects.c_as_list", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_objects.pxd":50
 *         return list(ob)
 * 
 * cdef inline tuple c_as_tuple(object ob):             # <<<<<<<<<<<<<<
 *     if type(ob) is tuple:
 *         return <tuple>ob
 */

static CYTHON_INLINE PyObject *__pyx_f_4axon_8_objects_c_as_tuple(PyObject *__pyx_v_ob) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("c_as_tuple", 0);

  /* "axon/_objects.pxd":51
 * 
 * cdef inline tuple c_as_tuple(object ob):
 *     if type(ob) is tuple:             # <<<<<<<<<<<<<<
 *         return <tuple>ob
 *     elif ob is None:
 */
  __pyx_t_1 = (((PyObject *)Py_TYPE(__pyx_v_ob)) == ((PyObject *)((PyObject*)(&PyTuple_Type))));
  __pyx_t_2 = (__pyx_t_1 != 0);
  if (__pyx_t_2) {

    /* "axon/_objects.pxd":52
 * cdef inline tuple c_as_tuple(object ob):
 *     if type(ob) is tuple:
 *         return <tuple>ob             # <<<<<<<<<<<<<<
 *     elif ob is None:
 *         return ()
 */
    __Pyx_XDECREF(((PyObject *)__pyx_r));
    __Pyx_INCREF(((PyObject *)((PyObject*)__pyx_v_ob)));
    __pyx_r = ((PyObject*)__pyx_v_ob);
    goto __pyx_L0;
    goto __pyx_L3;
  }

  /* "axon/_objects.pxd":53
 *     if type(ob) is tuple:
 *         return <tuple>ob
 *     elif ob is None:             # <<<<<<<<<<<<<<
 *         return ()
 *     else:
 */
  __pyx_t_2 = (__pyx_v_ob == Py_None);
  __pyx_t_1 = (__pyx_t_2 != 0);
  if (__pyx_t_1) {

    /* "axon/_objects.pxd":54
 *         return <tuple>ob
 *     elif ob is None:
 *         return ()             # <<<<<<<<<<<<<<
 *     else:
 *         return tuple(ob)
 */
    __Pyx_XDECREF(((PyObject *)__pyx_r));
    __Pyx_INCREF(((PyObject *)__pyx_empty_tuple));
    __pyx_r = __pyx_empty_tuple;
    goto __pyx_L0;
    goto __pyx_L3;
  }
  /*else*/ {

    /* "axon/_objects.pxd":56
 *         return ()
 *     else:
 *         return tuple(ob)             # <<<<<<<<<<<<<<
 * 
 * cdef inline unicode c_as_unicode(object ob):
 */
    __Pyx_XDECREF(((PyObject *)__pyx_r));
    __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[2]; __pyx_lineno = 56; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_INCREF(__pyx_v_ob);
    PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_v_ob);
    __Pyx_GIVEREF(__pyx_v_ob);
    __pyx_t_4 = PyObject_Call(((PyObject *)((PyObject*)(&PyTuple_Type))), ((PyObject *)__pyx_t_3), NULL); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[2]; __pyx_lineno = 56; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(((PyObject *)__pyx_t_3)); __pyx_t_3 = 0;
    __pyx_r = ((PyObject*)__pyx_t_4);
    __pyx_t_4 = 0;
    goto __pyx_L0;
  }
  __pyx_L3:;

  __pyx_r = ((PyObject*)Py_None); __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("axon._objects.c_as_tuple", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_objects.pxd":58
 *         return tuple(ob)
 * 
 * cdef inline unicode c_as_unicode(object ob):             # <<<<<<<<<<<<<<
 *     tp = type(ob)
 *     if tp is unicode:
 */

static CYTHON_INLINE PyObject *__pyx_f_4axon_8_objects_c_as_unicode(PyObject *__pyx_v_ob) {
  PyObject *__pyx_v_tp = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("c_as_unicode", 0);

  /* "axon/_objects.pxd":59
 * 
 * cdef inline unicode c_as_unicode(object ob):
 *     tp = type(ob)             # <<<<<<<<<<<<<<
 *     if tp is unicode:
 *         return <unicode>ob
 */
  __Pyx_INCREF(((PyObject *)Py_TYPE(__pyx_v_ob)));
  __pyx_v_tp = ((PyObject*)((PyObject *)Py_TYPE(__pyx_v_ob)));

  /* "axon/_objects.pxd":60
 * cdef inline unicode c_as_unicode(object ob):
 *     tp = type(ob)
 *     if tp is unicode:             # <<<<<<<<<<<<<<
 *         return <unicode>ob
 *     elif tp == c_str_type:
 */
  __pyx_t_1 = (__pyx_v_tp == ((PyObject*)(&PyUnicode_Type)));
  __pyx_t_2 = (__pyx_t_1 != 0);
  if (__pyx_t_2) {

    /* "axon/_objects.pxd":61
 *     tp = type(ob)
 *     if tp is unicode:
 *         return <unicode>ob             # <<<<<<<<<<<<<<
 *     elif tp == c_str_type:
 *         return unicode(ob)
 */
    __Pyx_XDECREF(((PyObject *)__pyx_r));
    __Pyx_INCREF(((PyObject *)((PyObject*)__pyx_v_ob)));
    __pyx_r = ((PyObject*)__pyx_v_ob);
    goto __pyx_L0;
    goto __pyx_L3;
  }

  /* "axon/_objects.pxd":62
 *     if tp is unicode:
 *         return <unicode>ob
 *     elif tp == c_str_type:             # <<<<<<<<<<<<<<
 *         return unicode(ob)
 *     elif ob is None:
 */
  __pyx_t_3 = PyObject_RichCompare(((PyObject *)__pyx_v_tp), __pyx_v_4axon_8_objects_c_str_type, Py_EQ); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[2]; __pyx_lineno = 62; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely(__pyx_t_2 < 0)) {__pyx_filename = __pyx_f[2]; __pyx_lineno = 62; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (__pyx_t_2) {

    /* "axon/_objects.pxd":63
 *         return <unicode>ob
 *     elif tp == c_str_type:
 *         return unicode(ob)             # <<<<<<<<<<<<<<
 *     elif ob is None:
 *         return unicode('')
 */
    __Pyx_XDECREF(((PyObject *)__pyx_r));
    __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[2]; __pyx_lineno = 63; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_INCREF(__pyx_v_ob);
    PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_v_ob);
    __Pyx_GIVEREF(__pyx_v_ob);
    __pyx_t_4 = PyObject_Call(((PyObject *)((PyObject*)(&PyUnicode_Type))), ((PyObject *)__pyx_t_3), NULL); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[2]; __pyx_lineno = 63; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(((PyObject *)__pyx_t_3)); __pyx_t_3 = 0;
    __pyx_r = ((PyObject*)__pyx_t_4);
    __pyx_t_4 = 0;
    goto __pyx_L0;
    goto __pyx_L3;
  }

  /* "axon/_objects.pxd":64
 *     elif tp == c_str_type:
 *         return unicode(ob)
 *     elif ob is None:             # <<<<<<<<<<<<<<
 *         return unicode('')
 *     else:
 */
  __pyx_t_2 = (__pyx_v_ob == Py_None);
  __pyx_t_1 = (__pyx_t_2 != 0);
  if (__pyx_t_1) {

    /* "axon/_objects.pxd":65
 *         return unicode(ob)
 *     elif ob is None:
 *         return unicode('')             # <<<<<<<<<<<<<<
 *     else:
 *         raise TypeError('This object %r is not unicode compatible' % ob)
 */
    __Pyx_XDECREF(((PyObject *)__pyx_r));
    __pyx_t_4 = PyObject_Call(((PyObject *)((PyObject*)(&PyUnicode_Type))), ((PyObject *)__pyx_k_tuple_120), NULL); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[2]; __pyx_lineno = 65; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_r = ((PyObject*)__pyx_t_4);
    __pyx_t_4 = 0;
    goto __pyx_L0;
    goto __pyx_L3;
  }
  /*else*/ {

    /* "axon/_objects.pxd":67
 *         return unicode('')
 *     else:
 *         raise TypeError('This object %r is not unicode compatible' % ob)             # <<<<<<<<<<<<<<
 * 
 * cdef inline unicode c_as_name(object name):
 */
    __pyx_t_4 = PyNumber_Remainder(((PyObject *)__pyx_kp_u_121), __pyx_v_ob); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[2]; __pyx_lineno = 67; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(((PyObject *)__pyx_t_4));
    __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[2]; __pyx_lineno = 67; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_3, 0, ((PyObject *)__pyx_t_4));
    __Pyx_GIVEREF(((PyObject *)__pyx_t_4));
    __pyx_t_4 = 0;
    __pyx_t_4 = PyObject_Call(__pyx_builtin_TypeError, ((PyObject *)__pyx_t_3), NULL); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[2]; __pyx_lineno = 67; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(((PyObject *)__pyx_t_3)); __pyx_t_3 = 0;
    __Pyx_Raise(__pyx_t_4, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    {__pyx_filename = __pyx_f[2]; __pyx_lineno = 67; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }
  __pyx_L3:;

  __pyx_r = ((PyObject*)Py_None); __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("axon._objects.c_as_unicode", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_tp);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_objects.pxd":69
 *         raise TypeError('This object %r is not unicode compatible' % ob)
 * 
 * cdef inline unicode c_as_name(object name):             # <<<<<<<<<<<<<<
 *     n = name_cache.get(name, None)
 *     if n is None:
 */

static CYTHON_INLINE PyObject *__pyx_f_4axon_8_objects_c_as_name(PyObject *__pyx_v_name) {
  PyObject *__pyx_v_n = NULL;
  PyObject *__pyx_v_uname = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("c_as_name", 0);

  /* "axon/_objects.pxd":70
 * 
 * cdef inline unicode c_as_name(object name):
 *     n = name_cache.get(name, None)             # <<<<<<<<<<<<<<
 *     if n is None:
 *         uname = c_as_unicode(name)
 */
  if (unlikely(((PyObject *)__pyx_v_4axon_8_objects_name_cache) == Py_None)) {
    PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%s'", "get");
    {__pyx_filename = __pyx_f[2]; __pyx_lineno = 70; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }
  __pyx_t_1 = __Pyx_PyDict_GetItemDefault(((PyObject *)__pyx_v_4axon_8_objects_name_cache), __pyx_v_name, Py_None); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[2]; __pyx_lineno = 70; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_n = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "axon/_objects.pxd":71
 * cdef inline unicode c_as_name(object name):
 *     n = name_cache.get(name, None)
 *     if n is None:             # <<<<<<<<<<<<<<
 *         uname = c_as_unicode(name)
 *         name_cache[name] = uname
 */
  __pyx_t_2 = (__pyx_v_n == Py_None);
  __pyx_t_3 = (__pyx_t_2 != 0);
  if (__pyx_t_3) {

    /* "axon/_objects.pxd":72
 *     n = name_cache.get(name, None)
 *     if n is None:
 *         uname = c_as_unicode(name)             # <<<<<<<<<<<<<<
 *         name_cache[name] = uname
 *     elif name is None:
 */
    __pyx_t_1 = ((PyObject *)__pyx_f_4axon_8_objects_c_as_unicode(__pyx_v_name)); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[2]; __pyx_lineno = 72; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_v_uname = __pyx_t_1;
    __pyx_t_1 = 0;

    /* "axon/_objects.pxd":73
 *     if n is None:
 *         uname = c_as_unicode(name)
 *         name_cache[name] = uname             # <<<<<<<<<<<<<<
 *     elif name is None:
 *         uname = empty_name
 */
    if (unlikely(((PyObject *)__pyx_v_4axon_8_objects_name_cache) == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      {__pyx_filename = __pyx_f[2]; __pyx_lineno = 73; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    }
    if (PyDict_SetItem(((PyObject *)__pyx_v_4axon_8_objects_name_cache), __pyx_v_name, __pyx_v_uname) < 0) {__pyx_filename = __pyx_f[2]; __pyx_lineno = 73; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    goto __pyx_L3;
  }

  /* "axon/_objects.pxd":74
 *         uname = c_as_unicode(name)
 *         name_cache[name] = uname
 *     elif name is None:             # <<<<<<<<<<<<<<
 *         uname = empty_name
 *     else:
 */
  __pyx_t_3 = (__pyx_v_name == Py_None);
  __pyx_t_2 = (__pyx_t_3 != 0);
  if (__pyx_t_2) {

    /* "axon/_objects.pxd":75
 *         name_cache[name] = uname
 *     elif name is None:
 *         uname = empty_name             # <<<<<<<<<<<<<<
 *     else:
 *         uname = n
 */
    __Pyx_INCREF(((PyObject *)__pyx_v_4axon_8_objects_empty_name));
    __pyx_v_uname = ((PyObject *)__pyx_v_4axon_8_objects_empty_name);
    goto __pyx_L3;
  }
  /*else*/ {

    /* "axon/_objects.pxd":77
 *         uname = empty_name
 *     else:
 *         uname = n             # <<<<<<<<<<<<<<
 *     return uname
 * 
 */
    __Pyx_INCREF(__pyx_v_n);
    __pyx_v_uname = __pyx_v_n;
  }
  __pyx_L3:;

  /* "axon/_objects.pxd":78
 *     else:
 *         uname = n
 *     return uname             # <<<<<<<<<<<<<<
 * 
 * cdef inline object py_as_name(object name):
 */
  __Pyx_XDECREF(((PyObject *)__pyx_r));
  if (!(likely(PyUnicode_CheckExact(__pyx_v_uname))||((__pyx_v_uname) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected unicode, got %.200s", Py_TYPE(__pyx_v_uname)->tp_name), 0))) {__pyx_filename = __pyx_f[2]; __pyx_lineno = 78; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_INCREF(__pyx_v_uname);
  __pyx_r = ((PyObject*)__pyx_v_uname);
  goto __pyx_L0;

  __pyx_r = ((PyObject*)Py_None); __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("axon._objects.c_as_name", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_n);
  __Pyx_XDECREF(__pyx_v_uname);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_objects.pxd":80
 *     return uname
 * 
 * cdef inline object py_as_name(object name):             # <<<<<<<<<<<<<<
 *     n = name_cache.get(name, None)
 *     if n is None:
 */

static CYTHON_INLINE PyObject *__pyx_f_4axon_8_objects_py_as_name(PyObject *__pyx_v_name) {
  PyObject *__pyx_v_n = NULL;
  PyObject *__pyx_v_uname = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("py_as_name", 0);

  /* "axon/_objects.pxd":81
 * 
 * cdef inline object py_as_name(object name):
 *     n = name_cache.get(name, None)             # <<<<<<<<<<<<<<
 *     if n is None:
 *         uname = c_as_unicode(name)
 */
  if (unlikely(((PyObject *)__pyx_v_4axon_8_objects_name_cache) == Py_None)) {
    PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%s'", "get");
    {__pyx_filename = __pyx_f[2]; __pyx_lineno = 81; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }
  __pyx_t_1 = __Pyx_PyDict_GetItemDefault(((PyObject *)__pyx_v_4axon_8_objects_name_cache), __pyx_v_name, Py_None); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[2]; __pyx_lineno = 81; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_n = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "axon/_objects.pxd":82
 * cdef inline object py_as_name(object name):
 *     n = name_cache.get(name, None)
 *     if n is None:             # <<<<<<<<<<<<<<
 *         uname = c_as_unicode(name)
 *         name_cache[name] = uname
 */
  __pyx_t_2 = (__pyx_v_n == Py_None);
  __pyx_t_3 = (__pyx_t_2 != 0);
  if (__pyx_t_3) {

    /* "axon/_objects.pxd":83
 *     n = name_cache.get(name, None)
 *     if n is None:
 *         uname = c_as_unicode(name)             # <<<<<<<<<<<<<<
 *         name_cache[name] = uname
 *     elif name is None:
 */
    __pyx_t_1 = ((PyObject *)__pyx_f_4axon_8_objects_c_as_unicode(__pyx_v_name)); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[2]; __pyx_lineno = 83; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_v_uname = __pyx_t_1;
    __pyx_t_1 = 0;

    /* "axon/_objects.pxd":84
 *     if n is None:
 *         uname = c_as_unicode(name)
 *         name_cache[name] = uname             # <<<<<<<<<<<<<<
 *     elif name is None:
 *         uname = empty_name
 */
    if (unlikely(((PyObject *)__pyx_v_4axon_8_objects_name_cache) == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      {__pyx_filename = __pyx_f[2]; __pyx_lineno = 84; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    }
    if (PyDict_SetItem(((PyObject *)__pyx_v_4axon_8_objects_name_cache), __pyx_v_name, __pyx_v_uname) < 0) {__pyx_filename = __pyx_f[2]; __pyx_lineno = 84; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    goto __pyx_L3;
  }

  /* "axon/_objects.pxd":85
 *         uname = c_as_unicode(name)
 *         name_cache[name] = uname
 *     elif name is None:             # <<<<<<<<<<<<<<
 *         uname = empty_name
 *     else:
 */
  __pyx_t_3 = (__pyx_v_name == Py_None);
  __pyx_t_2 = (__pyx_t_3 != 0);
  if (__pyx_t_2) {

    /* "axon/_objects.pxd":86
 *         name_cache[name] = uname
 *     elif name is None:
 *         uname = empty_name             # <<<<<<<<<<<<<<
 *     else:
 *         uname = n
 */
    __Pyx_INCREF(((PyObject *)__pyx_v_4axon_8_objects_empty_name));
    __pyx_v_uname = ((PyObject *)__pyx_v_4axon_8_objects_empty_name);
    goto __pyx_L3;
  }
  /*else*/ {

    /* "axon/_objects.pxd":88
 *         uname = empty_name
 *     else:
 *         uname = n             # <<<<<<<<<<<<<<
 *     return uname
 * 
 */
    __Pyx_INCREF(__pyx_v_n);
    __pyx_v_uname = __pyx_v_n;
  }
  __pyx_L3:;

  /* "axon/_objects.pxd":89
 *     else:
 *         uname = n
 *     return uname             # <<<<<<<<<<<<<<
 * 
 * # ----------------------------------------
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_uname);
  __pyx_r = __pyx_v_uname;
  goto __pyx_L0;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("axon._objects.py_as_name", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_n);
  __Pyx_XDECREF(__pyx_v_uname);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_tp_new_4axon_7_dumper_PyPointer(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  o = (*t->tp_alloc)(t, 0);
  if (unlikely(!o)) return 0;
  return o;
}

static void __pyx_tp_dealloc_4axon_7_dumper_PyPointer(PyObject *o) {
  (*Py_TYPE(o)->tp_free)(o);
}

static PyMethodDef __pyx_methods_4axon_7_dumper_PyPointer[] = {
  {0, 0, 0, 0}
};

static PyTypeObject __pyx_type_4axon_7_dumper_PyPointer = {
  PyVarObject_HEAD_INIT(0, 0)
  __Pyx_NAMESTR("axon._dumper.PyPointer"), /*tp_name*/
  sizeof(struct __pyx_obj_4axon_7_dumper_PyPointer), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_4axon_7_dumper_PyPointer, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #else
  0, /*reserved*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE, /*tp_flags*/
  0, /*tp_doc*/
  0, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_4axon_7_dumper_PyPointer, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_4axon_7_dumper_PyPointer, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  #if PY_VERSION_HEX >= 0x02060000
  0, /*tp_version_tag*/
  #endif
};

static struct __pyx_obj_4axon_7_dumper___pyx_scope_struct_2_pretty_dump_content *__pyx_freelist_4axon_7_dumper___pyx_scope_struct_2_pretty_dump_content[8];
static int __pyx_freecount_4axon_7_dumper___pyx_scope_struct_2_pretty_dump_content = 0;

static PyObject *__pyx_tp_new_4axon_7_dumper___pyx_scope_struct_2_pretty_dump_content(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  struct __pyx_obj_4axon_7_dumper___pyx_scope_struct_2_pretty_dump_content *p;
  PyObject *o;
  if (likely((__pyx_freecount_4axon_7_dumper___pyx_scope_struct_2_pretty_dump_content > 0) & (t->tp_basicsize == sizeof(struct __pyx_obj_4axon_7_dumper___pyx_scope_struct_2_pretty_dump_content)))) {
    o = (PyObject*)__pyx_freelist_4axon_7_dumper___pyx_scope_struct_2_pretty_dump_content[--__pyx_freecount_4axon_7_dumper___pyx_scope_struct_2_pretty_dump_content];
    memset(o, 0, sizeof(struct __pyx_obj_4axon_7_dumper___pyx_scope_struct_2_pretty_dump_content));
    PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  p = ((struct __pyx_obj_4axon_7_dumper___pyx_scope_struct_2_pretty_dump_content *)o);
  p->__pyx_v_item = 0;
  p->__pyx_v_self = 0;
  return o;
}

static void __pyx_tp_dealloc_4axon_7_dumper___pyx_scope_struct_2_pretty_dump_content(PyObject *o) {
  struct __pyx_obj_4axon_7_dumper___pyx_scope_struct_2_pretty_dump_content *p = (struct __pyx_obj_4axon_7_dumper___pyx_scope_struct_2_pretty_dump_content *)o;
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_v_item);
  Py_CLEAR(p->__pyx_v_self);
  if ((__pyx_freecount_4axon_7_dumper___pyx_scope_struct_2_pretty_dump_content < 8) & (Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_4axon_7_dumper___pyx_scope_struct_2_pretty_dump_content))) {
    __pyx_freelist_4axon_7_dumper___pyx_scope_struct_2_pretty_dump_content[__pyx_freecount_4axon_7_dumper___pyx_scope_struct_2_pretty_dump_content++] = ((struct __pyx_obj_4axon_7_dumper___pyx_scope_struct_2_pretty_dump_content *)o);
  } else {
    (*Py_TYPE(o)->tp_free)(o);
  }
}

static int __pyx_tp_traverse_4axon_7_dumper___pyx_scope_struct_2_pretty_dump_content(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_4axon_7_dumper___pyx_scope_struct_2_pretty_dump_content *p = (struct __pyx_obj_4axon_7_dumper___pyx_scope_struct_2_pretty_dump_content *)o;
  if (p->__pyx_v_item) {
    e = (*v)(p->__pyx_v_item, a); if (e) return e;
  }
  if (p->__pyx_v_self) {
    e = (*v)(((PyObject*)p->__pyx_v_self), a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_4axon_7_dumper___pyx_scope_struct_2_pretty_dump_content(PyObject *o) {
  struct __pyx_obj_4axon_7_dumper___pyx_scope_struct_2_pretty_dump_content *p = (struct __pyx_obj_4axon_7_dumper___pyx_scope_struct_2_pretty_dump_content *)o;
  PyObject* tmp;
  tmp = ((PyObject*)p->__pyx_v_item);
  p->__pyx_v_item = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->__pyx_v_self);
  p->__pyx_v_self = ((struct Dumper *)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyMethodDef __pyx_methods_4axon_7_dumper___pyx_scope_struct_2_pretty_dump_content[] = {
  {0, 0, 0, 0}
};

static PyTypeObject __pyx_type_4axon_7_dumper___pyx_scope_struct_2_pretty_dump_content = {
  PyVarObject_HEAD_INIT(0, 0)
  __Pyx_NAMESTR("axon._dumper.__pyx_scope_struct_2_pretty_dump_content"), /*tp_name*/
  sizeof(struct __pyx_obj_4axon_7_dumper___pyx_scope_struct_2_pretty_dump_content), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_4axon_7_dumper___pyx_scope_struct_2_pretty_dump_content, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #else
  0, /*reserved*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_4axon_7_dumper___pyx_scope_struct_2_pretty_dump_content, /*tp_traverse*/
  __pyx_tp_clear_4axon_7_dumper___pyx_scope_struct_2_pretty_dump_content, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_4axon_7_dumper___pyx_scope_struct_2_pretty_dump_content, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_4axon_7_dumper___pyx_scope_struct_2_pretty_dump_content, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  #if PY_VERSION_HEX >= 0x02060000
  0, /*tp_version_tag*/
  #endif
};

static struct __pyx_obj_4axon_7_dumper___pyx_scope_struct_5_genexpr *__pyx_freelist_4axon_7_dumper___pyx_scope_struct_5_genexpr[8];
static int __pyx_freecount_4axon_7_dumper___pyx_scope_struct_5_genexpr = 0;

static PyObject *__pyx_tp_new_4axon_7_dumper___pyx_scope_struct_5_genexpr(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  struct __pyx_obj_4axon_7_dumper___pyx_scope_struct_5_genexpr *p;
  PyObject *o;
  if (likely((__pyx_freecount_4axon_7_dumper___pyx_scope_struct_5_genexpr > 0) & (t->tp_basicsize == sizeof(struct __pyx_obj_4axon_7_dumper___pyx_scope_struct_5_genexpr)))) {
    o = (PyObject*)__pyx_freelist_4axon_7_dumper___pyx_scope_struct_5_genexpr[--__pyx_freecount_4axon_7_dumper___pyx_scope_struct_5_genexpr];
    memset(o, 0, sizeof(struct __pyx_obj_4axon_7_dumper___pyx_scope_struct_5_genexpr));
    PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  p = ((struct __pyx_obj_4axon_7_dumper___pyx_scope_struct_5_genexpr *)o);
  p->__pyx_outer_scope = 0;
  p->__pyx_v_x = 0;
  p->__pyx_t_0 = 0;
  return o;
}

static void __pyx_tp_dealloc_4axon_7_dumper___pyx_scope_struct_5_genexpr(PyObject *o) {
  struct __pyx_obj_4axon_7_dumper___pyx_scope_struct_5_genexpr *p = (struct __pyx_obj_4axon_7_dumper___pyx_scope_struct_5_genexpr *)o;
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_outer_scope);
  Py_CLEAR(p->__pyx_v_x);
  Py_CLEAR(p->__pyx_t_0);
  if ((__pyx_freecount_4axon_7_dumper___pyx_scope_struct_5_genexpr < 8) & (Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_4axon_7_dumper___pyx_scope_struct_5_genexpr))) {
    __pyx_freelist_4axon_7_dumper___pyx_scope_struct_5_genexpr[__pyx_freecount_4axon_7_dumper___pyx_scope_struct_5_genexpr++] = ((struct __pyx_obj_4axon_7_dumper___pyx_scope_struct_5_genexpr *)o);
  } else {
    (*Py_TYPE(o)->tp_free)(o);
  }
}

static int __pyx_tp_traverse_4axon_7_dumper___pyx_scope_struct_5_genexpr(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_4axon_7_dumper___pyx_scope_struct_5_genexpr *p = (struct __pyx_obj_4axon_7_dumper___pyx_scope_struct_5_genexpr *)o;
  if (p->__pyx_outer_scope) {
    e = (*v)(((PyObject*)p->__pyx_outer_scope), a); if (e) return e;
  }
  if (p->__pyx_v_x) {
    e = (*v)(p->__pyx_v_x, a); if (e) return e;
  }
  if (p->__pyx_t_0) {
    e = (*v)(p->__pyx_t_0, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_4axon_7_dumper___pyx_scope_struct_5_genexpr(PyObject *o) {
  struct __pyx_obj_4axon_7_dumper___pyx_scope_struct_5_genexpr *p = (struct __pyx_obj_4axon_7_dumper___pyx_scope_struct_5_genexpr *)o;
  PyObject* tmp;
  tmp = ((PyObject*)p->__pyx_outer_scope);
  p->__pyx_outer_scope = ((struct __pyx_obj_4axon_7_dumper___pyx_scope_struct_2_pretty_dump_content *)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->__pyx_v_x);
  p->__pyx_v_x = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->__pyx_t_0);
  p->__pyx_t_0 = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyMethodDef __pyx_methods_4axon_7_dumper___pyx_scope_struct_5_genexpr[] = {
  {0, 0, 0, 0}
};

static PyTypeObject __pyx_type_4axon_7_dumper___pyx_scope_struct_5_genexpr = {
  PyVarObject_HEAD_INIT(0, 0)
  __Pyx_NAMESTR("axon._dumper.__pyx_scope_struct_5_genexpr"), /*tp_name*/
  sizeof(struct __pyx_obj_4axon_7_dumper___pyx_scope_struct_5_genexpr), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_4axon_7_dumper___pyx_scope_struct_5_genexpr, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #else
  0, /*reserved*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_4axon_7_dumper___pyx_scope_struct_5_genexpr, /*tp_traverse*/
  __pyx_tp_clear_4axon_7_dumper___pyx_scope_struct_5_genexpr, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_4axon_7_dumper___pyx_scope_struct_5_genexpr, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_4axon_7_dumper___pyx_scope_struct_5_genexpr, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  #if PY_VERSION_HEX >= 0x02060000
  0, /*tp_version_tag*/
  #endif
};
static struct __pyx_vtabstruct_4axon_7_dumper_SimpleDumpers __pyx_vtable_4axon_7_dumper_SimpleDumpers;

static PyObject *__pyx_tp_new_4axon_7_dumper_SimpleDumpers(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  struct SimpleDumpers *p;
  PyObject *o;
  o = (*t->tp_alloc)(t, 0);
  if (unlikely(!o)) return 0;
  p = ((struct SimpleDumpers *)o);
  p->__pyx_vtab = __pyx_vtabptr_4axon_7_dumper_SimpleDumpers;
  p->mapping = ((PyObject*)Py_None); Py_INCREF(Py_None);
  return o;
}

static void __pyx_tp_dealloc_4axon_7_dumper_SimpleDumpers(PyObject *o) {
  struct SimpleDumpers *p = (struct SimpleDumpers *)o;
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->mapping);
  (*Py_TYPE(o)->tp_free)(o);
}

static int __pyx_tp_traverse_4axon_7_dumper_SimpleDumpers(PyObject *o, visitproc v, void *a) {
  int e;
  struct SimpleDumpers *p = (struct SimpleDumpers *)o;
  if (p->mapping) {
    e = (*v)(p->mapping, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_4axon_7_dumper_SimpleDumpers(PyObject *o) {
  struct SimpleDumpers *p = (struct SimpleDumpers *)o;
  PyObject* tmp;
  tmp = ((PyObject*)p->mapping);
  p->mapping = ((PyObject*)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyObject *__pyx_getprop_4axon_7_dumper_13SimpleDumpers_mapping(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_4axon_7_dumper_13SimpleDumpers_7mapping_1__get__(o);
}

static int __pyx_setprop_4axon_7_dumper_13SimpleDumpers_mapping(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_4axon_7_dumper_13SimpleDumpers_7mapping_3__set__(o, v);
  }
  else {
    return __pyx_pw_4axon_7_dumper_13SimpleDumpers_7mapping_5__del__(o);
  }
}

static PyMethodDef __pyx_methods_4axon_7_dumper_SimpleDumpers[] = {
  {0, 0, 0, 0}
};

static struct PyGetSetDef __pyx_getsets_4axon_7_dumper_SimpleDumpers[] = {
  {(char *)"mapping", __pyx_getprop_4axon_7_dumper_13SimpleDumpers_mapping, __pyx_setprop_4axon_7_dumper_13SimpleDumpers_mapping, 0, 0},
  {0, 0, 0, 0, 0}
};

DL_EXPORT(PyTypeObject) SimpleDumpersType = {
  PyVarObject_HEAD_INIT(0, 0)
  __Pyx_NAMESTR("axon._dumper.SimpleDumpers"), /*tp_name*/
  sizeof(struct SimpleDumpers), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_4axon_7_dumper_SimpleDumpers, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #else
  0, /*reserved*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_4axon_7_dumper_SimpleDumpers, /*tp_traverse*/
  __pyx_tp_clear_4axon_7_dumper_SimpleDumpers, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_4axon_7_dumper_SimpleDumpers, /*tp_methods*/
  0, /*tp_members*/
  __pyx_getsets_4axon_7_dumper_SimpleDumpers, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  __pyx_pw_4axon_7_dumper_13SimpleDumpers_1__init__, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_4axon_7_dumper_SimpleDumpers, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  #if PY_VERSION_HEX >= 0x02060000
  0, /*tp_version_tag*/
  #endif
};

static struct __pyx_obj_4axon_7_dumper___pyx_scope_struct_3_genexpr *__pyx_freelist_4axon_7_dumper___pyx_scope_struct_3_genexpr[8];
static int __pyx_freecount_4axon_7_dumper___pyx_scope_struct_3_genexpr = 0;

static PyObject *__pyx_tp_new_4axon_7_dumper___pyx_scope_struct_3_genexpr(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  struct __pyx_obj_4axon_7_dumper___pyx_scope_struct_3_genexpr *p;
  PyObject *o;
  if (likely((__pyx_freecount_4axon_7_dumper___pyx_scope_struct_3_genexpr > 0) & (t->tp_basicsize == sizeof(struct __pyx_obj_4axon_7_dumper___pyx_scope_struct_3_genexpr)))) {
    o = (PyObject*)__pyx_freelist_4axon_7_dumper___pyx_scope_struct_3_genexpr[--__pyx_freecount_4axon_7_dumper___pyx_scope_struct_3_genexpr];
    memset(o, 0, sizeof(struct __pyx_obj_4axon_7_dumper___pyx_scope_struct_3_genexpr));
    PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  p = ((struct __pyx_obj_4axon_7_dumper___pyx_scope_struct_3_genexpr *)o);
  p->__pyx_outer_scope = 0;
  p->__pyx_v_x = 0;
  p->__pyx_t_0 = 0;
  return o;
}

static void __pyx_tp_dealloc_4axon_7_dumper___pyx_scope_struct_3_genexpr(PyObject *o) {
  struct __pyx_obj_4axon_7_dumper___pyx_scope_struct_3_genexpr *p = (struct __pyx_obj_4axon_7_dumper___pyx_scope_struct_3_genexpr *)o;
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_outer_scope);
  Py_CLEAR(p->__pyx_v_x);
  Py_CLEAR(p->__pyx_t_0);
  if ((__pyx_freecount_4axon_7_dumper___pyx_scope_struct_3_genexpr < 8) & (Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_4axon_7_dumper___pyx_scope_struct_3_genexpr))) {
    __pyx_freelist_4axon_7_dumper___pyx_scope_struct_3_genexpr[__pyx_freecount_4axon_7_dumper___pyx_scope_struct_3_genexpr++] = ((struct __pyx_obj_4axon_7_dumper___pyx_scope_struct_3_genexpr *)o);
  } else {
    (*Py_TYPE(o)->tp_free)(o);
  }
}

static int __pyx_tp_traverse_4axon_7_dumper___pyx_scope_struct_3_genexpr(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_4axon_7_dumper___pyx_scope_struct_3_genexpr *p = (struct __pyx_obj_4axon_7_dumper___pyx_scope_struct_3_genexpr *)o;
  if (p->__pyx_outer_scope) {
    e = (*v)(((PyObject*)p->__pyx_outer_scope), a); if (e) return e;
  }
  if (p->__pyx_v_x) {
    e = (*v)(p->__pyx_v_x, a); if (e) return e;
  }
  if (p->__pyx_t_0) {
    e = (*v)(p->__pyx_t_0, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_4axon_7_dumper___pyx_scope_struct_3_genexpr(PyObject *o) {
  struct __pyx_obj_4axon_7_dumper___pyx_scope_struct_3_genexpr *p = (struct __pyx_obj_4axon_7_dumper___pyx_scope_struct_3_genexpr *)o;
  PyObject* tmp;
  tmp = ((PyObject*)p->__pyx_outer_scope);
  p->__pyx_outer_scope = ((struct __pyx_obj_4axon_7_dumper___pyx_scope_struct_2_pretty_dump_content *)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->__pyx_v_x);
  p->__pyx_v_x = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->__pyx_t_0);
  p->__pyx_t_0 = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyMethodDef __pyx_methods_4axon_7_dumper___pyx_scope_struct_3_genexpr[] = {
  {0, 0, 0, 0}
};

static PyTypeObject __pyx_type_4axon_7_dumper___pyx_scope_struct_3_genexpr = {
  PyVarObject_HEAD_INIT(0, 0)
  __Pyx_NAMESTR("axon._dumper.__pyx_scope_struct_3_genexpr"), /*tp_name*/
  sizeof(struct __pyx_obj_4axon_7_dumper___pyx_scope_struct_3_genexpr), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_4axon_7_dumper___pyx_scope_struct_3_genexpr, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #else
  0, /*reserved*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_4axon_7_dumper___pyx_scope_struct_3_genexpr, /*tp_traverse*/
  __pyx_tp_clear_4axon_7_dumper___pyx_scope_struct_3_genexpr, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_4axon_7_dumper___pyx_scope_struct_3_genexpr, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_4axon_7_dumper___pyx_scope_struct_3_genexpr, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  #if PY_VERSION_HEX >= 0x02060000
  0, /*tp_version_tag*/
  #endif
};

static struct __pyx_obj_4axon_7_dumper___pyx_scope_struct_1_dump_as_str *__pyx_freelist_4axon_7_dumper___pyx_scope_struct_1_dump_as_str[8];
static int __pyx_freecount_4axon_7_dumper___pyx_scope_struct_1_dump_as_str = 0;

static PyObject *__pyx_tp_new_4axon_7_dumper___pyx_scope_struct_1_dump_as_str(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  struct __pyx_obj_4axon_7_dumper___pyx_scope_struct_1_dump_as_str *p;
  PyObject *o;
  if (likely((__pyx_freecount_4axon_7_dumper___pyx_scope_struct_1_dump_as_str > 0) & (t->tp_basicsize == sizeof(struct __pyx_obj_4axon_7_dumper___pyx_scope_struct_1_dump_as_str)))) {
    o = (PyObject*)__pyx_freelist_4axon_7_dumper___pyx_scope_struct_1_dump_as_str[--__pyx_freecount_4axon_7_dumper___pyx_scope_struct_1_dump_as_str];
    memset(o, 0, sizeof(struct __pyx_obj_4axon_7_dumper___pyx_scope_struct_1_dump_as_str));
    PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  p = ((struct __pyx_obj_4axon_7_dumper___pyx_scope_struct_1_dump_as_str *)o);
  p->__pyx_v_tp = 0;
  return o;
}

static void __pyx_tp_dealloc_4axon_7_dumper___pyx_scope_struct_1_dump_as_str(PyObject *o) {
  struct __pyx_obj_4axon_7_dumper___pyx_scope_struct_1_dump_as_str *p = (struct __pyx_obj_4axon_7_dumper___pyx_scope_struct_1_dump_as_str *)o;
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_v_tp);
  if ((__pyx_freecount_4axon_7_dumper___pyx_scope_struct_1_dump_as_str < 8) & (Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_4axon_7_dumper___pyx_scope_struct_1_dump_as_str))) {
    __pyx_freelist_4axon_7_dumper___pyx_scope_struct_1_dump_as_str[__pyx_freecount_4axon_7_dumper___pyx_scope_struct_1_dump_as_str++] = ((struct __pyx_obj_4axon_7_dumper___pyx_scope_struct_1_dump_as_str *)o);
  } else {
    (*Py_TYPE(o)->tp_free)(o);
  }
}

static int __pyx_tp_traverse_4axon_7_dumper___pyx_scope_struct_1_dump_as_str(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_4axon_7_dumper___pyx_scope_struct_1_dump_as_str *p = (struct __pyx_obj_4axon_7_dumper___pyx_scope_struct_1_dump_as_str *)o;
  if (p->__pyx_v_tp) {
    e = (*v)(p->__pyx_v_tp, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_4axon_7_dumper___pyx_scope_struct_1_dump_as_str(PyObject *o) {
  struct __pyx_obj_4axon_7_dumper___pyx_scope_struct_1_dump_as_str *p = (struct __pyx_obj_4axon_7_dumper___pyx_scope_struct_1_dump_as_str *)o;
  PyObject* tmp;
  tmp = ((PyObject*)p->__pyx_v_tp);
  p->__pyx_v_tp = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyMethodDef __pyx_methods_4axon_7_dumper___pyx_scope_struct_1_dump_as_str[] = {
  {0, 0, 0, 0}
};

static PyTypeObject __pyx_type_4axon_7_dumper___pyx_scope_struct_1_dump_as_str = {
  PyVarObject_HEAD_INIT(0, 0)
  __Pyx_NAMESTR("axon._dumper.__pyx_scope_struct_1_dump_as_str"), /*tp_name*/
  sizeof(struct __pyx_obj_4axon_7_dumper___pyx_scope_struct_1_dump_as_str), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_4axon_7_dumper___pyx_scope_struct_1_dump_as_str, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #else
  0, /*reserved*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_4axon_7_dumper___pyx_scope_struct_1_dump_as_str, /*tp_traverse*/
  __pyx_tp_clear_4axon_7_dumper___pyx_scope_struct_1_dump_as_str, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_4axon_7_dumper___pyx_scope_struct_1_dump_as_str, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_4axon_7_dumper___pyx_scope_struct_1_dump_as_str, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  #if PY_VERSION_HEX >= 0x02060000
  0, /*tp_version_tag*/
  #endif
};

static PyObject *__pyx_tp_new_4axon_7_dumper_PyInt(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  o = (*t->tp_alloc)(t, 0);
  if (unlikely(!o)) return 0;
  return o;
}

static void __pyx_tp_dealloc_4axon_7_dumper_PyInt(PyObject *o) {
  (*Py_TYPE(o)->tp_free)(o);
}

static PyMethodDef __pyx_methods_4axon_7_dumper_PyInt[] = {
  {0, 0, 0, 0}
};

static PyTypeObject __pyx_type_4axon_7_dumper_PyInt = {
  PyVarObject_HEAD_INIT(0, 0)
  __Pyx_NAMESTR("axon._dumper.PyInt"), /*tp_name*/
  sizeof(struct __pyx_obj_4axon_7_dumper_PyInt), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_4axon_7_dumper_PyInt, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #else
  0, /*reserved*/
  #endif
  __pyx_pw_4axon_7_dumper_5PyInt_3__repr__, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE, /*tp_flags*/
  0, /*tp_doc*/
  0, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_4axon_7_dumper_PyInt, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  __pyx_pw_4axon_7_dumper_5PyInt_1__init__, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_4axon_7_dumper_PyInt, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  #if PY_VERSION_HEX >= 0x02060000
  0, /*tp_version_tag*/
  #endif
};

static struct __pyx_obj_4axon_7_dumper___pyx_scope_struct_4_genexpr *__pyx_freelist_4axon_7_dumper___pyx_scope_struct_4_genexpr[8];
static int __pyx_freecount_4axon_7_dumper___pyx_scope_struct_4_genexpr = 0;

static PyObject *__pyx_tp_new_4axon_7_dumper___pyx_scope_struct_4_genexpr(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  struct __pyx_obj_4axon_7_dumper___pyx_scope_struct_4_genexpr *p;
  PyObject *o;
  if (likely((__pyx_freecount_4axon_7_dumper___pyx_scope_struct_4_genexpr > 0) & (t->tp_basicsize == sizeof(struct __pyx_obj_4axon_7_dumper___pyx_scope_struct_4_genexpr)))) {
    o = (PyObject*)__pyx_freelist_4axon_7_dumper___pyx_scope_struct_4_genexpr[--__pyx_freecount_4axon_7_dumper___pyx_scope_struct_4_genexpr];
    memset(o, 0, sizeof(struct __pyx_obj_4axon_7_dumper___pyx_scope_struct_4_genexpr));
    PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  p = ((struct __pyx_obj_4axon_7_dumper___pyx_scope_struct_4_genexpr *)o);
  p->__pyx_outer_scope = 0;
  p->__pyx_v_x = 0;
  p->__pyx_t_0 = 0;
  return o;
}

static void __pyx_tp_dealloc_4axon_7_dumper___pyx_scope_struct_4_genexpr(PyObject *o) {
  struct __pyx_obj_4axon_7_dumper___pyx_scope_struct_4_genexpr *p = (struct __pyx_obj_4axon_7_dumper___pyx_scope_struct_4_genexpr *)o;
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_outer_scope);
  Py_CLEAR(p->__pyx_v_x);
  Py_CLEAR(p->__pyx_t_0);
  if ((__pyx_freecount_4axon_7_dumper___pyx_scope_struct_4_genexpr < 8) & (Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_4axon_7_dumper___pyx_scope_struct_4_genexpr))) {
    __pyx_freelist_4axon_7_dumper___pyx_scope_struct_4_genexpr[__pyx_freecount_4axon_7_dumper___pyx_scope_struct_4_genexpr++] = ((struct __pyx_obj_4axon_7_dumper___pyx_scope_struct_4_genexpr *)o);
  } else {
    (*Py_TYPE(o)->tp_free)(o);
  }
}

static int __pyx_tp_traverse_4axon_7_dumper___pyx_scope_struct_4_genexpr(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_4axon_7_dumper___pyx_scope_struct_4_genexpr *p = (struct __pyx_obj_4axon_7_dumper___pyx_scope_struct_4_genexpr *)o;
  if (p->__pyx_outer_scope) {
    e = (*v)(((PyObject*)p->__pyx_outer_scope), a); if (e) return e;
  }
  if (p->__pyx_v_x) {
    e = (*v)(p->__pyx_v_x, a); if (e) return e;
  }
  if (p->__pyx_t_0) {
    e = (*v)(p->__pyx_t_0, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_4axon_7_dumper___pyx_scope_struct_4_genexpr(PyObject *o) {
  struct __pyx_obj_4axon_7_dumper___pyx_scope_struct_4_genexpr *p = (struct __pyx_obj_4axon_7_dumper___pyx_scope_struct_4_genexpr *)o;
  PyObject* tmp;
  tmp = ((PyObject*)p->__pyx_outer_scope);
  p->__pyx_outer_scope = ((struct __pyx_obj_4axon_7_dumper___pyx_scope_struct_2_pretty_dump_content *)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->__pyx_v_x);
  p->__pyx_v_x = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->__pyx_t_0);
  p->__pyx_t_0 = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyMethodDef __pyx_methods_4axon_7_dumper___pyx_scope_struct_4_genexpr[] = {
  {0, 0, 0, 0}
};

static PyTypeObject __pyx_type_4axon_7_dumper___pyx_scope_struct_4_genexpr = {
  PyVarObject_HEAD_INIT(0, 0)
  __Pyx_NAMESTR("axon._dumper.__pyx_scope_struct_4_genexpr"), /*tp_name*/
  sizeof(struct __pyx_obj_4axon_7_dumper___pyx_scope_struct_4_genexpr), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_4axon_7_dumper___pyx_scope_struct_4_genexpr, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #else
  0, /*reserved*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_4axon_7_dumper___pyx_scope_struct_4_genexpr, /*tp_traverse*/
  __pyx_tp_clear_4axon_7_dumper___pyx_scope_struct_4_genexpr, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_4axon_7_dumper___pyx_scope_struct_4_genexpr, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_4axon_7_dumper___pyx_scope_struct_4_genexpr, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  #if PY_VERSION_HEX >= 0x02060000
  0, /*tp_version_tag*/
  #endif
};

static struct __pyx_obj_4axon_7_dumper___pyx_scope_struct__reduce *__pyx_freelist_4axon_7_dumper___pyx_scope_struct__reduce[8];
static int __pyx_freecount_4axon_7_dumper___pyx_scope_struct__reduce = 0;

static PyObject *__pyx_tp_new_4axon_7_dumper___pyx_scope_struct__reduce(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  struct __pyx_obj_4axon_7_dumper___pyx_scope_struct__reduce *p;
  PyObject *o;
  if (likely((__pyx_freecount_4axon_7_dumper___pyx_scope_struct__reduce > 0) & (t->tp_basicsize == sizeof(struct __pyx_obj_4axon_7_dumper___pyx_scope_struct__reduce)))) {
    o = (PyObject*)__pyx_freelist_4axon_7_dumper___pyx_scope_struct__reduce[--__pyx_freecount_4axon_7_dumper___pyx_scope_struct__reduce];
    memset(o, 0, sizeof(struct __pyx_obj_4axon_7_dumper___pyx_scope_struct__reduce));
    PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  p = ((struct __pyx_obj_4axon_7_dumper___pyx_scope_struct__reduce *)o);
  p->__pyx_v_type_ = 0;
  return o;
}

static void __pyx_tp_dealloc_4axon_7_dumper___pyx_scope_struct__reduce(PyObject *o) {
  struct __pyx_obj_4axon_7_dumper___pyx_scope_struct__reduce *p = (struct __pyx_obj_4axon_7_dumper___pyx_scope_struct__reduce *)o;
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_v_type_);
  if ((__pyx_freecount_4axon_7_dumper___pyx_scope_struct__reduce < 8) & (Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_4axon_7_dumper___pyx_scope_struct__reduce))) {
    __pyx_freelist_4axon_7_dumper___pyx_scope_struct__reduce[__pyx_freecount_4axon_7_dumper___pyx_scope_struct__reduce++] = ((struct __pyx_obj_4axon_7_dumper___pyx_scope_struct__reduce *)o);
  } else {
    (*Py_TYPE(o)->tp_free)(o);
  }
}

static int __pyx_tp_traverse_4axon_7_dumper___pyx_scope_struct__reduce(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_4axon_7_dumper___pyx_scope_struct__reduce *p = (struct __pyx_obj_4axon_7_dumper___pyx_scope_struct__reduce *)o;
  if (p->__pyx_v_type_) {
    e = (*v)(p->__pyx_v_type_, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_4axon_7_dumper___pyx_scope_struct__reduce(PyObject *o) {
  struct __pyx_obj_4axon_7_dumper___pyx_scope_struct__reduce *p = (struct __pyx_obj_4axon_7_dumper___pyx_scope_struct__reduce *)o;
  PyObject* tmp;
  tmp = ((PyObject*)p->__pyx_v_type_);
  p->__pyx_v_type_ = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyMethodDef __pyx_methods_4axon_7_dumper___pyx_scope_struct__reduce[] = {
  {0, 0, 0, 0}
};

static PyTypeObject __pyx_type_4axon_7_dumper___pyx_scope_struct__reduce = {
  PyVarObject_HEAD_INIT(0, 0)
  __Pyx_NAMESTR("axon._dumper.__pyx_scope_struct__reduce"), /*tp_name*/
  sizeof(struct __pyx_obj_4axon_7_dumper___pyx_scope_struct__reduce), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_4axon_7_dumper___pyx_scope_struct__reduce, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #else
  0, /*reserved*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_4axon_7_dumper___pyx_scope_struct__reduce, /*tp_traverse*/
  __pyx_tp_clear_4axon_7_dumper___pyx_scope_struct__reduce, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_4axon_7_dumper___pyx_scope_struct__reduce, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_4axon_7_dumper___pyx_scope_struct__reduce, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  #if PY_VERSION_HEX >= 0x02060000
  0, /*tp_version_tag*/
  #endif
};
static struct __pyx_vtabstruct_4axon_7_dumper_Dumper __pyx_vtable_4axon_7_dumper_Dumper;

static PyObject *__pyx_tp_new_4axon_7_dumper_Dumper(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  struct Dumper *p;
  PyObject *o;
  o = (*t->tp_alloc)(t, 0);
  if (unlikely(!o)) return 0;
  p = ((struct Dumper *)o);
  p->__pyx_vtab = __pyx_vtabptr_4axon_7_dumper_Dumper;
  p->c_simple_dumpers = ((PyObject*)Py_None); Py_INCREF(Py_None);
  p->c_type_reducers = ((PyObject*)Py_None); Py_INCREF(Py_None);
  p->write = Py_None; Py_INCREF(Py_None);
  p->crossref_dict = ((PyObject*)Py_None); Py_INCREF(Py_None);
  p->crossref_set = ((PyObject*)Py_None); Py_INCREF(Py_None);
  p->crossref_set2 = ((PyObject*)Py_None); Py_INCREF(Py_None);
  return o;
}

static void __pyx_tp_dealloc_4axon_7_dumper_Dumper(PyObject *o) {
  struct Dumper *p = (struct Dumper *)o;
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->c_simple_dumpers);
  Py_CLEAR(p->c_type_reducers);
  Py_CLEAR(p->write);
  Py_CLEAR(p->crossref_dict);
  Py_CLEAR(p->crossref_set);
  Py_CLEAR(p->crossref_set2);
  (*Py_TYPE(o)->tp_free)(o);
}

static int __pyx_tp_traverse_4axon_7_dumper_Dumper(PyObject *o, visitproc v, void *a) {
  int e;
  struct Dumper *p = (struct Dumper *)o;
  if (p->c_simple_dumpers) {
    e = (*v)(p->c_simple_dumpers, a); if (e) return e;
  }
  if (p->c_type_reducers) {
    e = (*v)(p->c_type_reducers, a); if (e) return e;
  }
  if (p->write) {
    e = (*v)(p->write, a); if (e) return e;
  }
  if (p->crossref_dict) {
    e = (*v)(p->crossref_dict, a); if (e) return e;
  }
  if (p->crossref_set) {
    e = (*v)(p->crossref_set, a); if (e) return e;
  }
  if (p->crossref_set2) {
    e = (*v)(p->crossref_set2, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_4axon_7_dumper_Dumper(PyObject *o) {
  struct Dumper *p = (struct Dumper *)o;
  PyObject* tmp;
  tmp = ((PyObject*)p->c_simple_dumpers);
  p->c_simple_dumpers = ((PyObject*)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->c_type_reducers);
  p->c_type_reducers = ((PyObject*)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->write);
  p->write = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->crossref_dict);
  p->crossref_dict = ((PyObject*)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->crossref_set);
  p->crossref_set = ((PyObject*)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->crossref_set2);
  p->crossref_set2 = ((PyObject*)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyMethodDef __pyx_methods_4axon_7_dumper_Dumper[] = {
  {__Pyx_NAMESTR("dump_tuple"), (PyCFunction)__pyx_pw_4axon_7_dumper_6Dumper_3dump_tuple, METH_O, __Pyx_DOCSTR(0)},
  {__Pyx_NAMESTR("pretty_dump_tuple"), (PyCFunction)__pyx_pw_4axon_7_dumper_6Dumper_5pretty_dump_tuple, METH_VARARGS|METH_KEYWORDS, __Pyx_DOCSTR(0)},
  {__Pyx_NAMESTR("pretty_dump_content"), (PyCFunction)__pyx_pw_4axon_7_dumper_6Dumper_7pretty_dump_content, METH_VARARGS|METH_KEYWORDS, __Pyx_DOCSTR(0)},
  {__Pyx_NAMESTR("pretty_dump_collection"), (PyCFunction)__pyx_pw_4axon_7_dumper_6Dumper_9pretty_dump_collection, METH_VARARGS|METH_KEYWORDS, __Pyx_DOCSTR(0)},
  {__Pyx_NAMESTR("dump"), (PyCFunction)__pyx_pw_4axon_7_dumper_6Dumper_11dump, METH_O, __Pyx_DOCSTR(__pyx_doc_4axon_7_dumper_6Dumper_10dump)},
  {0, 0, 0, 0}
};

DL_EXPORT(PyTypeObject) DumperType = {
  PyVarObject_HEAD_INIT(0, 0)
  __Pyx_NAMESTR("axon._dumper.Dumper"), /*tp_name*/
  sizeof(struct Dumper), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_4axon_7_dumper_Dumper, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #else
  0, /*reserved*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  __Pyx_DOCSTR("\n    Dumper class\n    "), /*tp_doc*/
  __pyx_tp_traverse_4axon_7_dumper_Dumper, /*tp_traverse*/
  __pyx_tp_clear_4axon_7_dumper_Dumper, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_4axon_7_dumper_Dumper, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  __pyx_pw_4axon_7_dumper_6Dumper_1__init__, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_4axon_7_dumper_Dumper, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  #if PY_VERSION_HEX >= 0x02060000
  0, /*tp_version_tag*/
  #endif
};

static PyMethodDef __pyx_methods[] = {
  {__Pyx_NAMESTR("mapping_reduce"), (PyCFunction)__pyx_pw_4axon_7_dumper_1mapping_reduce, METH_O, __Pyx_DOCSTR(0)},
  {__Pyx_NAMESTR("element_reduce"), (PyCFunction)__pyx_pw_4axon_7_dumper_3element_reduce, METH_O, __Pyx_DOCSTR(0)},
  {__Pyx_NAMESTR("sequence_reduce"), (PyCFunction)__pyx_pw_4axon_7_dumper_5sequence_reduce, METH_O, __Pyx_DOCSTR(0)},
  {__Pyx_NAMESTR("collection_reduce"), (PyCFunction)__pyx_pw_4axon_7_dumper_7collection_reduce, METH_O, __Pyx_DOCSTR(0)},
  {__Pyx_NAMESTR("instance_reduce"), (PyCFunction)__pyx_pw_4axon_7_dumper_9instance_reduce, METH_O, __Pyx_DOCSTR(0)},
  {__Pyx_NAMESTR("empty_reduce"), (PyCFunction)__pyx_pw_4axon_7_dumper_11empty_reduce, METH_O, __Pyx_DOCSTR(0)},
  {__Pyx_NAMESTR("set_reduce"), (PyCFunction)__pyx_pw_4axon_7_dumper_13set_reduce, METH_O, __Pyx_DOCSTR(0)},
  {__Pyx_NAMESTR("tuple_reduce"), (PyCFunction)__pyx_pw_4axon_7_dumper_15tuple_reduce, METH_O, __Pyx_DOCSTR(0)},
  {__Pyx_NAMESTR("dict_reduce"), (PyCFunction)__pyx_pw_4axon_7_dumper_17dict_reduce, METH_O, __Pyx_DOCSTR(0)},
  {__Pyx_NAMESTR("list_reduce"), (PyCFunction)__pyx_pw_4axon_7_dumper_19list_reduce, METH_O, __Pyx_DOCSTR(0)},
  {0, 0, 0, 0}
};

#if PY_MAJOR_VERSION >= 3
static struct PyModuleDef __pyx_moduledef = {
  #if PY_VERSION_HEX < 0x03020000
    { PyObject_HEAD_INIT(NULL) NULL, 0, NULL },
  #else
    PyModuleDef_HEAD_INIT,
  #endif
    __Pyx_NAMESTR("_dumper"),
    0, /* m_doc */
    -1, /* m_size */
    __pyx_methods /* m_methods */,
    NULL, /* m_reload */
    NULL, /* m_traverse */
    NULL, /* m_clear */
    NULL /* m_free */
};
#endif

static __Pyx_StringTabEntry __pyx_string_tab[] = {
  {&__pyx_n_s_1, __pyx_k_1, sizeof(__pyx_k_1), 0, 0, 1, 1},
  {&__pyx_kp_u_1, __pyx_k_1, sizeof(__pyx_k_1), 0, 1, 0, 0},
  {&__pyx_kp_u_10, __pyx_k_10, sizeof(__pyx_k_10), 0, 1, 0, 0},
  {&__pyx_kp_u_106, __pyx_k_106, sizeof(__pyx_k_106), 0, 1, 0, 0},
  {&__pyx_kp_u_108, __pyx_k_108, sizeof(__pyx_k_108), 0, 1, 0, 0},
  {&__pyx_kp_u_11, __pyx_k_11, sizeof(__pyx_k_11), 0, 1, 0, 0},
  {&__pyx_kp_u_111, __pyx_k_111, sizeof(__pyx_k_111), 0, 1, 0, 0},
  {&__pyx_n_s_114, __pyx_k_114, sizeof(__pyx_k_114), 0, 0, 1, 1},
  {&__pyx_kp_u_12, __pyx_k_12, sizeof(__pyx_k_12), 0, 1, 0, 0},
  {&__pyx_kp_u_121, __pyx_k_121, sizeof(__pyx_k_121), 0, 1, 0, 0},
  {&__pyx_n_s_122, __pyx_k_122, sizeof(__pyx_k_122), 0, 0, 1, 1},
  {&__pyx_n_s_123, __pyx_k_123, sizeof(__pyx_k_123), 0, 0, 1, 1},
  {&__pyx_kp_u_13, __pyx_k_13, sizeof(__pyx_k_13), 0, 1, 0, 0},
  {&__pyx_kp_u_14, __pyx_k_14, sizeof(__pyx_k_14), 0, 1, 0, 0},
  {&__pyx_kp_u_15, __pyx_k_15, sizeof(__pyx_k_15), 0, 1, 0, 0},
  {&__pyx_kp_u_16, __pyx_k_16, sizeof(__pyx_k_16), 0, 1, 0, 0},
  {&__pyx_kp_u_17, __pyx_k_17, sizeof(__pyx_k_17), 0, 1, 0, 0},
  {&__pyx_kp_u_18, __pyx_k_18, sizeof(__pyx_k_18), 0, 1, 0, 0},
  {&__pyx_kp_u_19, __pyx_k_19, sizeof(__pyx_k_19), 0, 1, 0, 0},
  {&__pyx_kp_u_20, __pyx_k_20, sizeof(__pyx_k_20), 0, 1, 0, 0},
  {&__pyx_kp_u_21, __pyx_k_21, sizeof(__pyx_k_21), 0, 1, 0, 0},
  {&__pyx_kp_u_22, __pyx_k_22, sizeof(__pyx_k_22), 0, 1, 0, 0},
  {&__pyx_n_s_25, __pyx_k_25, sizeof(__pyx_k_25), 0, 0, 1, 1},
  {&__pyx_kp_u_26, __pyx_k_26, sizeof(__pyx_k_26), 0, 1, 0, 0},
  {&__pyx_kp_u_27, __pyx_k_27, sizeof(__pyx_k_27), 0, 1, 0, 0},
  {&__pyx_kp_u_30, __pyx_k_30, sizeof(__pyx_k_30), 0, 1, 0, 0},
  {&__pyx_kp_u_32, __pyx_k_32, sizeof(__pyx_k_32), 0, 1, 0, 0},
  {&__pyx_kp_u_34, __pyx_k_34, sizeof(__pyx_k_34), 0, 1, 0, 0},
  {&__pyx_kp_s_4, __pyx_k_4, sizeof(__pyx_k_4), 0, 0, 1, 0},
  {&__pyx_kp_u_40, __pyx_k_40, sizeof(__pyx_k_40), 0, 1, 0, 0},
  {&__pyx_kp_u_42, __pyx_k_42, sizeof(__pyx_k_42), 0, 1, 0, 0},
  {&__pyx_kp_u_43, __pyx_k_43, sizeof(__pyx_k_43), 0, 1, 0, 0},
  {&__pyx_kp_u_44, __pyx_k_44, sizeof(__pyx_k_44), 0, 1, 0, 0},
  {&__pyx_kp_u_46, __pyx_k_46, sizeof(__pyx_k_46), 0, 1, 0, 0},
  {&__pyx_n_s_5, __pyx_k_5, sizeof(__pyx_k_5), 0, 0, 1, 1},
  {&__pyx_kp_u_53, __pyx_k_53, sizeof(__pyx_k_53), 0, 1, 0, 0},
  {&__pyx_kp_u_55, __pyx_k_55, sizeof(__pyx_k_55), 0, 1, 0, 0},
  {&__pyx_kp_u_57, __pyx_k_57, sizeof(__pyx_k_57), 0, 1, 0, 0},
  {&__pyx_kp_u_59, __pyx_k_59, sizeof(__pyx_k_59), 0, 1, 0, 0},
  {&__pyx_n_s_6, __pyx_k_6, sizeof(__pyx_k_6), 0, 0, 1, 1},
  {&__pyx_kp_u_61, __pyx_k_61, sizeof(__pyx_k_61), 0, 1, 0, 0},
  {&__pyx_kp_u_63, __pyx_k_63, sizeof(__pyx_k_63), 0, 1, 0, 0},
  {&__pyx_kp_u_67, __pyx_k_67, sizeof(__pyx_k_67), 0, 1, 0, 0},
  {&__pyx_kp_u_7, __pyx_k_7, sizeof(__pyx_k_7), 0, 1, 0, 0},
  {&__pyx_kp_u_8, __pyx_k_8, sizeof(__pyx_k_8), 0, 1, 0, 0},
  {&__pyx_kp_u_86, __pyx_k_86, sizeof(__pyx_k_86), 0, 1, 0, 0},
  {&__pyx_kp_u_87, __pyx_k_87, sizeof(__pyx_k_87), 0, 1, 0, 0},
  {&__pyx_kp_u_9, __pyx_k_9, sizeof(__pyx_k_9), 0, 1, 0, 0},
  {&__pyx_kp_u_91, __pyx_k_91, sizeof(__pyx_k_91), 0, 1, 0, 0},
  {&__pyx_kp_u__0, __pyx_k__0, sizeof(__pyx_k__0), 0, 1, 0, 0},
  {&__pyx_n_s__Decimal, __pyx_k__Decimal, sizeof(__pyx_k__Decimal), 0, 0, 1, 1},
  {&__pyx_n_s__TypeError, __pyx_k__TypeError, sizeof(__pyx_k__TypeError), 0, 0, 1, 1},
  {&__pyx_n_s__ValueError, __pyx_k__ValueError, sizeof(__pyx_k__ValueError), 0, 0, 1, 1},
  {&__pyx_n_s____import__, __pyx_k____import__, sizeof(__pyx_k____import__), 0, 0, 1, 1},
  {&__pyx_n_s____main__, __pyx_k____main__, sizeof(__pyx_k____main__), 0, 0, 1, 1},
  {&__pyx_n_s____pyx_capi__, __pyx_k____pyx_capi__, sizeof(__pyx_k____pyx_capi__), 0, 0, 1, 1},
  {&__pyx_n_s____pyx_vtable__, __pyx_k____pyx_vtable__, sizeof(__pyx_k____pyx_vtable__), 0, 0, 1, 1},
  {&__pyx_n_s____test__, __pyx_k____test__, sizeof(__pyx_k____test__), 0, 0, 1, 1},
  {&__pyx_n_s___c_type_reducers, __pyx_k___c_type_reducers, sizeof(__pyx_k___c_type_reducers), 0, 0, 1, 1},
  {&__pyx_n_s___decimal, __pyx_k___decimal, sizeof(__pyx_k___decimal), 0, 0, 1, 1},
  {&__pyx_n_s___decimal2str, __pyx_k___decimal2str, sizeof(__pyx_k___decimal2str), 0, 0, 1, 1},
  {&__pyx_n_s___dict_name, __pyx_k___dict_name, sizeof(__pyx_k___dict_name), 0, 0, 1, 1},
  {&__pyx_n_s___dump_as_str, __pyx_k___dump_as_str, sizeof(__pyx_k___dump_as_str), 0, 0, 1, 1},
  {&__pyx_n_s___factory, __pyx_k___factory, sizeof(__pyx_k___factory), 0, 0, 1, 1},
  {&__pyx_n_s___list_name, __pyx_k___list_name, sizeof(__pyx_k___list_name), 0, 0, 1, 1},
  {&__pyx_n_s___set_name, __pyx_k___set_name, sizeof(__pyx_k___set_name), 0, 0, 1, 1},
  {&__pyx_n_s___simple_types, __pyx_k___simple_types, sizeof(__pyx_k___simple_types), 0, 0, 1, 1},
  {&__pyx_n_s___tuple_name, __pyx_k___tuple_name, sizeof(__pyx_k___tuple_name), 0, 0, 1, 1},
  {&__pyx_n_s__all, __pyx_k__all, sizeof(__pyx_k__all), 0, 0, 1, 1},
  {&__pyx_n_s__args, __pyx_k__args, sizeof(__pyx_k__args), 0, 0, 1, 1},
  {&__pyx_n_u__ascii, __pyx_k__ascii, sizeof(__pyx_k__ascii), 0, 1, 0, 1},
  {&__pyx_n_s__base64, __pyx_k__base64, sizeof(__pyx_k__base64), 0, 0, 1, 1},
  {&__pyx_n_s__bool_type, __pyx_k__bool_type, sizeof(__pyx_k__bool_type), 0, 0, 1, 1},
  {&__pyx_n_s__bytes_type, __pyx_k__bytes_type, sizeof(__pyx_k__bytes_type), 0, 0, 1, 1},
  {&__pyx_n_s__c_all_names, __pyx_k__c_all_names, sizeof(__pyx_k__c_all_names), 0, 0, 1, 1},
  {&__pyx_n_s__c_factory_dict, __pyx_k__c_factory_dict, sizeof(__pyx_k__c_factory_dict), 0, 0, 1, 1},
  {&__pyx_n_s__c_reduce_dict, __pyx_k__c_reduce_dict, sizeof(__pyx_k__c_reduce_dict), 0, 0, 1, 1},
  {&__pyx_n_s__c_simple_dumpers, __pyx_k__c_simple_dumpers, sizeof(__pyx_k__c_simple_dumpers), 0, 0, 1, 1},
  {&__pyx_n_s__cdecimal, __pyx_k__cdecimal, sizeof(__pyx_k__cdecimal), 0, 0, 1, 1},
  {&__pyx_n_s__close, __pyx_k__close, sizeof(__pyx_k__close), 0, 0, 1, 1},
  {&__pyx_n_s__collection, __pyx_k__collection, sizeof(__pyx_k__collection), 0, 0, 1, 1},
  {&__pyx_n_s__collection_reduce, __pyx_k__collection_reduce, sizeof(__pyx_k__collection_reduce), 0, 0, 1, 1},
  {&__pyx_n_s__crossref, __pyx_k__crossref, sizeof(__pyx_k__crossref), 0, 0, 1, 1},
  {&__pyx_n_s__date, __pyx_k__date, sizeof(__pyx_k__date), 0, 0, 1, 1},
  {&__pyx_n_s__date_type, __pyx_k__date_type, sizeof(__pyx_k__date_type), 0, 0, 1, 1},
  {&__pyx_n_s__datetime, __pyx_k__datetime, sizeof(__pyx_k__datetime), 0, 0, 1, 1},
  {&__pyx_n_s__datetime_type, __pyx_k__datetime_type, sizeof(__pyx_k__datetime_type), 0, 0, 1, 1},
  {&__pyx_n_s__day, __pyx_k__day, sizeof(__pyx_k__day), 0, 0, 1, 1},
  {&__pyx_n_s__decimal, __pyx_k__decimal, sizeof(__pyx_k__decimal), 0, 0, 1, 1},
  {&__pyx_n_s__decimal_type, __pyx_k__decimal_type, sizeof(__pyx_k__decimal_type), 0, 0, 1, 1},
  {&__pyx_n_s__decodebytes, __pyx_k__decodebytes, sizeof(__pyx_k__decodebytes), 0, 0, 1, 1},
  {&__pyx_n_s__decodestring, __pyx_k__decodestring, sizeof(__pyx_k__decodestring), 0, 0, 1, 1},
  {&__pyx_n_u__dict, __pyx_k__dict, sizeof(__pyx_k__dict), 0, 1, 0, 1},
  {&__pyx_n_s__dict_reduce, __pyx_k__dict_reduce, sizeof(__pyx_k__dict_reduce), 0, 0, 1, 1},
  {&__pyx_n_s__dump_as_str, __pyx_k__dump_as_str, sizeof(__pyx_k__dump_as_str), 0, 0, 1, 1},
  {&__pyx_n_s__dump_tuple, __pyx_k__dump_tuple, sizeof(__pyx_k__dump_tuple), 0, 0, 1, 1},
  {&__pyx_n_s__element_reduce, __pyx_k__element_reduce, sizeof(__pyx_k__element_reduce), 0, 0, 1, 1},
  {&__pyx_n_s__empty_reduce, __pyx_k__empty_reduce, sizeof(__pyx_k__empty_reduce), 0, 0, 1, 1},
  {&__pyx_n_s__encodebytes, __pyx_k__encodebytes, sizeof(__pyx_k__encodebytes), 0, 0, 1, 1},
  {&__pyx_n_s__encodestring, __pyx_k__encodestring, sizeof(__pyx_k__encodestring), 0, 0, 1, 1},
  {&__pyx_n_s__enumerate, __pyx_k__enumerate, sizeof(__pyx_k__enumerate), 0, 0, 1, 1},
  {&__pyx_n_s__factory_func, __pyx_k__factory_func, sizeof(__pyx_k__factory_func), 0, 0, 1, 1},
  {&__pyx_n_u__false, __pyx_k__false, sizeof(__pyx_k__false), 0, 1, 0, 1},
  {&__pyx_n_s__fd, __pyx_k__fd, sizeof(__pyx_k__fd), 0, 0, 1, 1},
  {&__pyx_n_s__float_type, __pyx_k__float_type, sizeof(__pyx_k__float_type), 0, 0, 1, 1},
  {&__pyx_n_s__func, __pyx_k__func, sizeof(__pyx_k__func), 0, 0, 1, 1},
  {&__pyx_n_s__get, __pyx_k__get, sizeof(__pyx_k__get), 0, 0, 1, 1},
  {&__pyx_n_s__getcontext, __pyx_k__getcontext, sizeof(__pyx_k__getcontext), 0, 0, 1, 1},
  {&__pyx_n_s__hour, __pyx_k__hour, sizeof(__pyx_k__hour), 0, 0, 1, 1},
  {&__pyx_n_s__id, __pyx_k__id, sizeof(__pyx_k__id), 0, 0, 1, 1},
  {&__pyx_n_s__instance_reduce, __pyx_k__instance_reduce, sizeof(__pyx_k__instance_reduce), 0, 0, 1, 1},
  {&__pyx_n_s__int_type, __pyx_k__int_type, sizeof(__pyx_k__int_type), 0, 0, 1, 1},
  {&__pyx_n_s__is_finite, __pyx_k__is_finite, sizeof(__pyx_k__is_finite), 0, 0, 1, 1},
  {&__pyx_n_s__is_infinite, __pyx_k__is_infinite, sizeof(__pyx_k__is_infinite), 0, 0, 1, 1},
  {&__pyx_n_s__is_nan, __pyx_k__is_nan, sizeof(__pyx_k__is_nan), 0, 0, 1, 1},
  {&__pyx_n_s__is_signed, __pyx_k__is_signed, sizeof(__pyx_k__is_signed), 0, 0, 1, 1},
  {&__pyx_n_s__items, __pyx_k__items, sizeof(__pyx_k__items), 0, 0, 1, 1},
  {&__pyx_n_s__keys, __pyx_k__keys, sizeof(__pyx_k__keys), 0, 0, 1, 1},
  {&__pyx_n_s__l, __pyx_k__l, sizeof(__pyx_k__l), 0, 0, 1, 1},
  {&__pyx_n_u__list, __pyx_k__list, sizeof(__pyx_k__list), 0, 1, 0, 1},
  {&__pyx_n_s__list_reduce, __pyx_k__list_reduce, sizeof(__pyx_k__list_reduce), 0, 0, 1, 1},
  {&__pyx_n_s__long_type, __pyx_k__long_type, sizeof(__pyx_k__long_type), 0, 0, 1, 1},
  {&__pyx_n_s__mapping_reduce, __pyx_k__mapping_reduce, sizeof(__pyx_k__mapping_reduce), 0, 0, 1, 1},
  {&__pyx_n_s__microsecond, __pyx_k__microsecond, sizeof(__pyx_k__microsecond), 0, 0, 1, 1},
  {&__pyx_n_s__minute, __pyx_k__minute, sizeof(__pyx_k__minute), 0, 0, 1, 1},
  {&__pyx_n_s__month, __pyx_k__month, sizeof(__pyx_k__month), 0, 0, 1, 1},
  {&__pyx_n_s__name, __pyx_k__name, sizeof(__pyx_k__name), 0, 0, 1, 1},
  {&__pyx_n_s__nsize, __pyx_k__nsize, sizeof(__pyx_k__nsize), 0, 0, 1, 1},
  {&__pyx_n_u__null, __pyx_k__null, sizeof(__pyx_k__null), 0, 1, 0, 1},
  {&__pyx_n_s__offset, __pyx_k__offset, sizeof(__pyx_k__offset), 0, 0, 1, 1},
  {&__pyx_n_s__pretty, __pyx_k__pretty, sizeof(__pyx_k__pretty), 0, 0, 1, 1},
  {&__pyx_n_s__pretty_dump_content, __pyx_k__pretty_dump_content, sizeof(__pyx_k__pretty_dump_content), 0, 0, 1, 1},
  {&__pyx_n_s__pretty_dump_tuple, __pyx_k__pretty_dump_tuple, sizeof(__pyx_k__pretty_dump_tuple), 0, 0, 1, 1},
  {&__pyx_n_s__quote, __pyx_k__quote, sizeof(__pyx_k__quote), 0, 0, 1, 1},
  {&__pyx_n_s__range, __pyx_k__range, sizeof(__pyx_k__range), 0, 0, 1, 1},
  {&__pyx_n_s__reduce, __pyx_k__reduce, sizeof(__pyx_k__reduce), 0, 0, 1, 1},
  {&__pyx_n_s__reduce_func, __pyx_k__reduce_func, sizeof(__pyx_k__reduce_func), 0, 0, 1, 1},
  {&__pyx_n_s__remove, __pyx_k__remove, sizeof(__pyx_k__remove), 0, 0, 1, 1},
  {&__pyx_n_s__reset_reduce, __pyx_k__reset_reduce, sizeof(__pyx_k__reset_reduce), 0, 0, 1, 1},
  {&__pyx_n_s__second, __pyx_k__second, sizeof(__pyx_k__second), 0, 0, 1, 1},
  {&__pyx_n_s__send, __pyx_k__send, sizeof(__pyx_k__send), 0, 0, 1, 1},
  {&__pyx_n_s__sequence_reduce, __pyx_k__sequence_reduce, sizeof(__pyx_k__sequence_reduce), 0, 0, 1, 1},
  {&__pyx_n_u__set, __pyx_k__set, sizeof(__pyx_k__set), 0, 1, 0, 1},
  {&__pyx_n_s__set_reduce, __pyx_k__set_reduce, sizeof(__pyx_k__set_reduce), 0, 0, 1, 1},
  {&__pyx_n_s__simple_types, __pyx_k__simple_types, sizeof(__pyx_k__simple_types), 0, 0, 1, 1},
  {&__pyx_n_s__sorted, __pyx_k__sorted, sizeof(__pyx_k__sorted), 0, 0, 1, 1},
  {&__pyx_n_s__str_type, __pyx_k__str_type, sizeof(__pyx_k__str_type), 0, 0, 1, 1},
  {&__pyx_n_s__throw, __pyx_k__throw, sizeof(__pyx_k__throw), 0, 0, 1, 1},
  {&__pyx_n_s__time, __pyx_k__time, sizeof(__pyx_k__time), 0, 0, 1, 1},
  {&__pyx_n_s__time_type, __pyx_k__time_type, sizeof(__pyx_k__time_type), 0, 0, 1, 1},
  {&__pyx_n_s__to_eng_string, __pyx_k__to_eng_string, sizeof(__pyx_k__to_eng_string), 0, 0, 1, 1},
  {&__pyx_n_s__tp, __pyx_k__tp, sizeof(__pyx_k__tp), 0, 0, 1, 1},
  {&__pyx_n_u__true, __pyx_k__true, sizeof(__pyx_k__true), 0, 1, 0, 1},
  {&__pyx_n_u__tuple, __pyx_k__tuple, sizeof(__pyx_k__tuple), 0, 1, 0, 1},
  {&__pyx_n_s__tuple_reduce, __pyx_k__tuple_reduce, sizeof(__pyx_k__tuple_reduce), 0, 0, 1, 1},
  {&__pyx_n_s__type_, __pyx_k__type_, sizeof(__pyx_k__type_), 0, 0, 1, 1},
  {&__pyx_n_s__types, __pyx_k__types, sizeof(__pyx_k__types), 0, 0, 1, 1},
  {&__pyx_n_s__tzinfo, __pyx_k__tzinfo, sizeof(__pyx_k__tzinfo), 0, 0, 1, 1},
  {&__pyx_n_s__unicode_type, __pyx_k__unicode_type, sizeof(__pyx_k__unicode_type), 0, 0, 1, 1},
  {&__pyx_n_s__update, __pyx_k__update, sizeof(__pyx_k__update), 0, 0, 1, 1},
  {&__pyx_n_s__use_offset, __pyx_k__use_offset, sizeof(__pyx_k__use_offset), 0, 0, 1, 1},
  {&__pyx_n_s__val, __pyx_k__val, sizeof(__pyx_k__val), 0, 0, 1, 1},
  {&__pyx_n_s__values, __pyx_k__values, sizeof(__pyx_k__values), 0, 0, 1, 1},
  {&__pyx_n_s__w, __pyx_k__w, sizeof(__pyx_k__w), 0, 0, 1, 1},
  {&__pyx_n_s__write, __pyx_k__write, sizeof(__pyx_k__write), 0, 0, 1, 1},
  {&__pyx_n_s__year, __pyx_k__year, sizeof(__pyx_k__year), 0, 0, 1, 1},
  {0, 0, 0, 0, 0, 0, 0}
};
static int __Pyx_InitCachedBuiltins(void) {
  __pyx_builtin_id = __Pyx_GetBuiltinName(__pyx_n_s__id); if (!__pyx_builtin_id) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 367; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_builtin_TypeError = __Pyx_GetBuiltinName(__pyx_n_s__TypeError); if (!__pyx_builtin_TypeError) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 462; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_builtin_all = __Pyx_GetBuiltinName(__pyx_n_s__all); if (!__pyx_builtin_all) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 485; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_builtin_sorted = __Pyx_GetBuiltinName(__pyx_n_s__sorted); if (!__pyx_builtin_sorted) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 523; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_builtin_enumerate = __Pyx_GetBuiltinName(__pyx_n_s__enumerate); if (!__pyx_builtin_enumerate) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 693; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_builtin_ValueError = __Pyx_GetBuiltinName(__pyx_n_s__ValueError); if (!__pyx_builtin_ValueError) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 736; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_builtin_range = __Pyx_GetBuiltinName(__pyx_n_s__range); if (!__pyx_builtin_range) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1015; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  return 0;
  __pyx_L1_error:;
  return -1;
}

static int __Pyx_InitCachedConstants(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_InitCachedConstants", 0);

  /* "axon/_dumper.py":105
 * def reduce(type_, reduce_func = None):
 *     if reduce_func is None:
 *         def _factory(factory_func):             # <<<<<<<<<<<<<<
 *             c_reduce_dict[type_] = factory_func
 *             return factory_func
 */
  __pyx_k_tuple_2 = PyTuple_Pack(1, ((PyObject *)__pyx_n_s__factory_func)); if (unlikely(!__pyx_k_tuple_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 105; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_2);
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_2));
  __pyx_k_codeobj_3 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_k_tuple_2, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_4, __pyx_n_s___factory, 105, __pyx_empty_bytes); if (unlikely(!__pyx_k_codeobj_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 105; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

  /* "axon/_dumper.py":312
 * def dump_as_str(tp=None):
 *     if tp is None:
 *         def _dump_as_str(func):             # <<<<<<<<<<<<<<
 *             c_simple_dumpers[tp] = func
 *             return func
 */
  __pyx_k_tuple_23 = PyTuple_Pack(1, ((PyObject *)__pyx_n_s__func)); if (unlikely(!__pyx_k_tuple_23)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 312; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_23);
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_23));
  __pyx_k_codeobj_24 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_k_tuple_23, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_4, __pyx_n_s___dump_as_str, 312, __pyx_empty_bytes); if (unlikely(!__pyx_k_codeobj_24)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 312; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

  /* "axon/_dumper.py":401
 *         o_id = id(o)
 *         if o_id in self.crossref_set:
 *             self.write(' &')             # <<<<<<<<<<<<<<
 * 
 *             label = self.crossref_dict[o_id]
 */
  __pyx_k_tuple_31 = PyTuple_Pack(1, ((PyObject *)__pyx_kp_u_30)); if (unlikely(!__pyx_k_tuple_31)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 401; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_31);
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_31));

  /* "axon/_dumper.py":405
 *             label = self.crossref_dict[o_id]
 *             self.write(label)
 *             self.write(' ')             # <<<<<<<<<<<<<<
 *             self.crossref_set2.add(o_id)
 *     #
 */
  __pyx_k_tuple_33 = PyTuple_Pack(1, ((PyObject *)__pyx_kp_u_32)); if (unlikely(!__pyx_k_tuple_33)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 405; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_33);
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_33));

  /* "axon/_dumper.py":411
 *         o_id = id(o)
 *         if o_id in self.crossref_set:
 *             self.write('&')             # <<<<<<<<<<<<<<
 * 
 *             label = self.crossref_dict[o_id]
 */
  __pyx_k_tuple_35 = PyTuple_Pack(1, ((PyObject *)__pyx_kp_u_34)); if (unlikely(!__pyx_k_tuple_35)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 411; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_35);
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_35));

  /* "axon/_dumper.py":415
 *             label = self.crossref_dict[o_id]
 *             self.write(label)
 *             self.write(' ')             # <<<<<<<<<<<<<<
 *             self.crossref_set2.add(o_id)
 *     #
 */
  __pyx_k_tuple_36 = PyTuple_Pack(1, ((PyObject *)__pyx_kp_u_32)); if (unlikely(!__pyx_k_tuple_36)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 415; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_36);
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_36));

  /* "axon/_dumper.py":421
 *         o_id = id(o)
 *         if  o_id in self.crossref_set2:
 *             self.write('*')             # <<<<<<<<<<<<<<
 * #
 *             label = self.crossref_dict[o_id]
 */
  __pyx_k_tuple_37 = PyTuple_Pack(1, ((PyObject *)__pyx_kp_u_1)); if (unlikely(!__pyx_k_tuple_37)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 421; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_37);
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_37));

  /* "axon/_dumper.py":427
 *             return 1
 *         elif  o_id in self.crossref_set:
 *             self.write('&')             # <<<<<<<<<<<<<<
 * #
 *             label = self.crossref_dict[o_id]
 */
  __pyx_k_tuple_38 = PyTuple_Pack(1, ((PyObject *)__pyx_kp_u_34)); if (unlikely(!__pyx_k_tuple_38)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 427; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_38);
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_38));

  /* "axon/_dumper.py":431
 *             label = self.crossref_dict[o_id]
 *             self.write(label)
 *             self.write(' ')             # <<<<<<<<<<<<<<
 *             self.crossref_set2.add(o_id)
 *             self.crossref_set.remove(o_id)
 */
  __pyx_k_tuple_39 = PyTuple_Pack(1, ((PyObject *)__pyx_kp_u_32)); if (unlikely(!__pyx_k_tuple_39)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 431; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_39);
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_39));

  /* "axon/_dumper.py":441
 * 
 *         if self.size > self.max_size:
 *             self.write('\n')             # <<<<<<<<<<<<<<
 *             self.size = 0
 * 
 */
  __pyx_k_tuple_41 = PyTuple_Pack(1, ((PyObject *)__pyx_kp_u_40)); if (unlikely(!__pyx_k_tuple_41)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 441; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_41);
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_41));

  /* "axon/_dumper.py":529
 *         for k,v in items:
 *             if i > 0:
 *                 self.write(' ')             # <<<<<<<<<<<<<<
 * 
 *             text = c_as_unicode(k)
 */
  __pyx_k_tuple_45 = PyTuple_Pack(1, ((PyObject *)__pyx_kp_u_32)); if (unlikely(!__pyx_k_tuple_45)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 529; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_45);
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_45));

  /* "axon/_dumper.py":535
 *             self.size += len(text)
 * 
 *             self.write(':')             # <<<<<<<<<<<<<<
 *             self._dump(v)
 *             i += 1
 */
  __pyx_k_tuple_47 = PyTuple_Pack(1, ((PyObject *)__pyx_kp_u_46)); if (unlikely(!__pyx_k_tuple_47)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 535; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_47);
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_47));

  /* "axon/_dumper.py":549
 *         for k,v in items:
 *             if i > 0:
 *                 self.write(' ')             # <<<<<<<<<<<<<<
 * 
 *             text = c_as_unicode(k)
 */
  __pyx_k_tuple_48 = PyTuple_Pack(1, ((PyObject *)__pyx_kp_u_32)); if (unlikely(!__pyx_k_tuple_48)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 549; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_48);
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_48));

  /* "axon/_dumper.py":555
 *             self.size += len(text)
 * 
 *             self.write(':')             # <<<<<<<<<<<<<<
 *             self._dump(v)
 *             i += 1
 */
  __pyx_k_tuple_49 = PyTuple_Pack(1, ((PyObject *)__pyx_kp_u_46)); if (unlikely(!__pyx_k_tuple_49)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 555; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_49);
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_49));

  /* "axon/_dumper.py":564
 *         for v in l:
 *             if i > 0:
 *                 self.write(' ')             # <<<<<<<<<<<<<<
 *             self._dump(v)
 *             i += 1
 */
  __pyx_k_tuple_50 = PyTuple_Pack(1, ((PyObject *)__pyx_kp_u_32)); if (unlikely(!__pyx_k_tuple_50)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 564; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_50);
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_50));

  /* "axon/_dumper.py":573
 *         for v in l:
 *             if i > 0:
 *                 self.write(' ')             # <<<<<<<<<<<<<<
 *             self._dump(v)
 *             i += 1
 */
  __pyx_k_tuple_51 = PyTuple_Pack(1, ((PyObject *)__pyx_kp_u_32)); if (unlikely(!__pyx_k_tuple_51)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 573; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_51);
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_51));

  /* "axon/_dumper.py":582
 *         for v in l:
 *             if i > 0:
 *                 self.write(' ')             # <<<<<<<<<<<<<<
 *             self._dump(v)
 *             i += 1
 */
  __pyx_k_tuple_52 = PyTuple_Pack(1, ((PyObject *)__pyx_kp_u_32)); if (unlikely(!__pyx_k_tuple_52)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 582; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_52);
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_52));

  /* "axon/_dumper.py":587
 *     #
 *     def dump_list(self, l):
 *         self.write('[')             # <<<<<<<<<<<<<<
 *         self._dump_list_sequence(l)
 *         self.write(']')
 */
  __pyx_k_tuple_54 = PyTuple_Pack(1, ((PyObject *)__pyx_kp_u_53)); if (unlikely(!__pyx_k_tuple_54)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 587; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_54);
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_54));

  /* "axon/_dumper.py":589
 *         self.write('[')
 *         self._dump_list_sequence(l)
 *         self.write(']')             # <<<<<<<<<<<<<<
 *     #
 * #    def dump_set(self, l):
 */
  __pyx_k_tuple_56 = PyTuple_Pack(1, ((PyObject *)__pyx_kp_u_55)); if (unlikely(!__pyx_k_tuple_56)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 589; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_56);
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_56));

  /* "axon/_dumper.py":600
 *     #
 *     def dump_dict(self, d):
 *         self.write('{')             # <<<<<<<<<<<<<<
 *         self._dump_dict_sequence(d)
 *         self.write('}')
 */
  __pyx_k_tuple_58 = PyTuple_Pack(1, ((PyObject *)__pyx_kp_u_57)); if (unlikely(!__pyx_k_tuple_58)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 600; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_58);
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_58));

  /* "axon/_dumper.py":602
 *         self.write('{')
 *         self._dump_dict_sequence(d)
 *         self.write('}')             # <<<<<<<<<<<<<<
 *     #
 *     def dump_tuple(self, d):
 */
  __pyx_k_tuple_60 = PyTuple_Pack(1, ((PyObject *)__pyx_kp_u_59)); if (unlikely(!__pyx_k_tuple_60)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 602; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_60);
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_60));

  /* "axon/_dumper.py":605
 *     #
 *     def dump_tuple(self, d):
 *         self.write('(')             # <<<<<<<<<<<<<<
 *         self._dump_tuple_sequence(d)
 *         self.write(')')
 */
  __pyx_k_tuple_62 = PyTuple_Pack(1, ((PyObject *)__pyx_kp_u_61)); if (unlikely(!__pyx_k_tuple_62)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 605; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_62);
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_62));

  /* "axon/_dumper.py":607
 *         self.write('(')
 *         self._dump_tuple_sequence(d)
 *         self.write(')')             # <<<<<<<<<<<<<<
 *     #
 *     def _pretty_dump_dict_sequence(self, d, w, use_offset):
 */
  __pyx_k_tuple_64 = PyTuple_Pack(1, ((PyObject *)__pyx_kp_u_63)); if (unlikely(!__pyx_k_tuple_64)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 607; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_64);
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_64));

  /* "axon/_dumper.py":617
 *         for k,v in items:
 *             if use_offset:
 *                 self.write('\n')             # <<<<<<<<<<<<<<
 *                 self.write(w)
 *             else:
 */
  __pyx_k_tuple_65 = PyTuple_Pack(1, ((PyObject *)__pyx_kp_u_40)); if (unlikely(!__pyx_k_tuple_65)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 617; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_65);
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_65));

  /* "axon/_dumper.py":621
 *             else:
 *                 use_offset = 0
 *                 self.write(' ')             # <<<<<<<<<<<<<<
 *                 use_offset = 1
 * 
 */
  __pyx_k_tuple_66 = PyTuple_Pack(1, ((PyObject *)__pyx_kp_u_32)); if (unlikely(!__pyx_k_tuple_66)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 621; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_66);
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_66));

  /* "axon/_dumper.py":626
 *             text = c_as_unicode(k)
 *             self.write(_dump_name(text, self.quote))
 *             self.write(': ')             # <<<<<<<<<<<<<<
 *             self._pretty_dump(v, w, 0)
 *     #
 */
  __pyx_k_tuple_68 = PyTuple_Pack(1, ((PyObject *)__pyx_kp_u_67)); if (unlikely(!__pyx_k_tuple_68)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 626; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_68);
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_68));

  /* "axon/_dumper.py":637
 *         for k,v in items:
 *             if use_offset:
 *                 self.write('\n')             # <<<<<<<<<<<<<<
 *                 self.write(w)
 *             else:
 */
  __pyx_k_tuple_69 = PyTuple_Pack(1, ((PyObject *)__pyx_kp_u_40)); if (unlikely(!__pyx_k_tuple_69)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 637; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_69);
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_69));

  /* "axon/_dumper.py":641
 *             else:
 *                 use_offset = 0
 *                 self.write(' ')             # <<<<<<<<<<<<<<
 *                 use_offset = 1
 * 
 */
  __pyx_k_tuple_70 = PyTuple_Pack(1, ((PyObject *)__pyx_kp_u_32)); if (unlikely(!__pyx_k_tuple_70)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 641; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_70);
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_70));

  /* "axon/_dumper.py":646
 *             text = c_as_unicode(k)
 *             self.write(_dump_name(text, self.quote))
 *             self.write(': ')             # <<<<<<<<<<<<<<
 *             self._pretty_dump(v, w, 0)
 *     #
 */
  __pyx_k_tuple_71 = PyTuple_Pack(1, ((PyObject *)__pyx_kp_u_67)); if (unlikely(!__pyx_k_tuple_71)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 646; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_71);
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_71));

  /* "axon/_dumper.py":652
 *         for v in l:
 *             if use_offset:
 *                 self.write('\n')             # <<<<<<<<<<<<<<
 *                 self._pretty_dump(v, w, 1)
 *             else:
 */
  __pyx_k_tuple_72 = PyTuple_Pack(1, ((PyObject *)__pyx_kp_u_40)); if (unlikely(!__pyx_k_tuple_72)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 652; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_72);
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_72));

  /* "axon/_dumper.py":655
 *                 self._pretty_dump(v, w, 1)
 *             else:
 *                 self.write(' ')             # <<<<<<<<<<<<<<
 *                 self._pretty_dump(v, w, 0)
 *                 use_offset = 1
 */
  __pyx_k_tuple_73 = PyTuple_Pack(1, ((PyObject *)__pyx_kp_u_32)); if (unlikely(!__pyx_k_tuple_73)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 655; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_73);
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_73));

  /* "axon/_dumper.py":662
 *         for v in l:
 *             if use_offset:
 *                 self.write('\n')             # <<<<<<<<<<<<<<
 *                 self._pretty_dump(v, w, 1)
 *             else:
 */
  __pyx_k_tuple_74 = PyTuple_Pack(1, ((PyObject *)__pyx_kp_u_40)); if (unlikely(!__pyx_k_tuple_74)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 662; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_74);
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_74));

  /* "axon/_dumper.py":665
 *                 self._pretty_dump(v, w, 1)
 *             else:
 *                 self.write(' ')             # <<<<<<<<<<<<<<
 *                 self._pretty_dump(v, w, 0)
 *                 use_offset = 1
 */
  __pyx_k_tuple_75 = PyTuple_Pack(1, ((PyObject *)__pyx_kp_u_32)); if (unlikely(!__pyx_k_tuple_75)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 665; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_75);
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_75));

  /* "axon/_dumper.py":670
 *     #
 *     def pretty_dump_list(self, l, w, use_offset):
 *         self.write('[')             # <<<<<<<<<<<<<<
 *         self._pretty_dump_list_sequence(l, w, use_offset)
 *         self.write(']')
 */
  __pyx_k_tuple_76 = PyTuple_Pack(1, ((PyObject *)__pyx_kp_u_53)); if (unlikely(!__pyx_k_tuple_76)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 670; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_76);
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_76));

  /* "axon/_dumper.py":672
 *         self.write('[')
 *         self._pretty_dump_list_sequence(l, w, use_offset)
 *         self.write(']')             # <<<<<<<<<<<<<<
 *     #
 * #    def pretty_dump_set(self, l, w, use_offset):
 */
  __pyx_k_tuple_77 = PyTuple_Pack(1, ((PyObject *)__pyx_kp_u_55)); if (unlikely(!__pyx_k_tuple_77)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 672; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_77);
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_77));

  /* "axon/_dumper.py":683
 *     #
 *     def pretty_dump_dict(self, d, w, use_offset):
 *         self.write('{')             # <<<<<<<<<<<<<<
 *         self._pretty_dump_dict_sequence(d, w, use_offset)
 *         self.write('}')
 */
  __pyx_k_tuple_78 = PyTuple_Pack(1, ((PyObject *)__pyx_kp_u_57)); if (unlikely(!__pyx_k_tuple_78)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 683; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_78);
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_78));

  /* "axon/_dumper.py":685
 *         self.write('{')
 *         self._pretty_dump_dict_sequence(d, w, use_offset)
 *         self.write('}')             # <<<<<<<<<<<<<<
 *     #
 *     def pretty_dump_tuple(self, l, w, use_offset):
 */
  __pyx_k_tuple_79 = PyTuple_Pack(1, ((PyObject *)__pyx_kp_u_59)); if (unlikely(!__pyx_k_tuple_79)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 685; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_79);
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_79));

  /* "axon/_dumper.py":688
 *     #
 *     def pretty_dump_tuple(self, l, w, use_offset):
 *         self.write('(')             # <<<<<<<<<<<<<<
 *         self._pretty_dump_tuple_sequence(l, w, 0)
 *         self.write(')')
 */
  __pyx_k_tuple_80 = PyTuple_Pack(1, ((PyObject *)__pyx_kp_u_61)); if (unlikely(!__pyx_k_tuple_80)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 688; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_80);
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_80));

  /* "axon/_dumper.py":690
 *         self.write('(')
 *         self._pretty_dump_tuple_sequence(l, w, 0)
 *         self.write(')')             # <<<<<<<<<<<<<<
 *     #
 *     def dump_content(self, items):
 */
  __pyx_k_tuple_81 = PyTuple_Pack(1, ((PyObject *)__pyx_kp_u_63)); if (unlikely(!__pyx_k_tuple_81)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 690; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_81);
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_81));

  /* "axon/_dumper.py":699
 * 
 *             if i == 1:
 *                 self.write(' ')             # <<<<<<<<<<<<<<
 * 
 *             tp = type(item)
 */
  __pyx_k_tuple_82 = PyTuple_Pack(1, ((PyObject *)__pyx_kp_u_32)); if (unlikely(!__pyx_k_tuple_82)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 699; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_82);
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_82));

  /* "axon/_dumper.py":713
 *                 for j, v in enumerate(item):
 *                     if j > 0:
 *                         self.write(' ')             # <<<<<<<<<<<<<<
 *                     self._dump(v)
 *     #
 */
  __pyx_k_tuple_83 = PyTuple_Pack(1, ((PyObject *)__pyx_kp_u_32)); if (unlikely(!__pyx_k_tuple_83)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 713; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_83);
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_83));

  /* "axon/_dumper.py":720
 *         for i, o in enumerate(collection):
 *             if self.crossref:
 *                 self.write(' ')             # <<<<<<<<<<<<<<
 *                 v =  self._dump_label(o)
 *                 if v == 1:
 */
  __pyx_k_tuple_84 = PyTuple_Pack(1, ((PyObject *)__pyx_kp_u_32)); if (unlikely(!__pyx_k_tuple_84)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 720; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_84);
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_84));

  /* "axon/_dumper.py":725
 *                     return 0
 * 
 *             self.write('{')             # <<<<<<<<<<<<<<
 * 
 *             otype = type(o)
 */
  __pyx_k_tuple_85 = PyTuple_Pack(1, ((PyObject *)__pyx_kp_u_57)); if (unlikely(!__pyx_k_tuple_85)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 725; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_85);
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_85));

  /* "axon/_dumper.py":741
 *                     raise ValueError('Reducer returns invalid number of items: %s' % n)
 *                 elif n > 1:
 *                     self.dump_content(items[1:])             # <<<<<<<<<<<<<<
 * 
 *                 self.write('}')
 */
  __pyx_k_slice_88 = PySlice_New(__pyx_int_1, Py_None, Py_None); if (unlikely(!__pyx_k_slice_88)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 741; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_slice_88);
  __Pyx_GIVEREF(__pyx_k_slice_88);

  /* "axon/_dumper.py":743
 *                     self.dump_content(items[1:])
 * 
 *                 self.write('}')             # <<<<<<<<<<<<<<
 *     #
 *     def _dump_with_reducer(self, reducer, o):
 */
  __pyx_k_tuple_89 = PyTuple_Pack(1, ((PyObject *)__pyx_kp_u_59)); if (unlikely(!__pyx_k_tuple_89)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 743; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_89);
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_89));

  /* "axon/_dumper.py":762
 * 
 *         if is_collection:
 *             self.write('*')             # <<<<<<<<<<<<<<
 * 
 *         if not is_collection and (n < 1 or n > 3):
 */
  __pyx_k_tuple_90 = PyTuple_Pack(1, ((PyObject *)__pyx_kp_u_1)); if (unlikely(!__pyx_k_tuple_90)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 762; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_90);
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_90));

  /* "axon/_dumper.py":768
 * 
 *         if n == 1:
 *             self.write('{}')             # <<<<<<<<<<<<<<
 *             return 0
 * 
 */
  __pyx_k_tuple_92 = PyTuple_Pack(1, ((PyObject *)__pyx_kp_u_91)); if (unlikely(!__pyx_k_tuple_92)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 768; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_92);
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_92));

  /* "axon/_dumper.py":771
 *             return 0
 * 
 *         self.write('{')             # <<<<<<<<<<<<<<
 * 
 *         if is_collection:
 */
  __pyx_k_tuple_93 = PyTuple_Pack(1, ((PyObject *)__pyx_kp_u_57)); if (unlikely(!__pyx_k_tuple_93)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 771; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_93);
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_93));

  /* "axon/_dumper.py":776
 *             self.dump_collection(name, results[1])
 *         else:
 *             self.dump_content(results[1:])             # <<<<<<<<<<<<<<
 * 
 *         self.write('}')
 */
  __pyx_k_slice_94 = PySlice_New(__pyx_int_1, Py_None, Py_None); if (unlikely(!__pyx_k_slice_94)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 776; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_slice_94);
  __Pyx_GIVEREF(__pyx_k_slice_94);

  /* "axon/_dumper.py":778
 *             self.dump_content(results[1:])
 * 
 *         self.write('}')             # <<<<<<<<<<<<<<
 *     #
 *     def pretty_dump_content(self, items, offset):
 */
  __pyx_k_tuple_95 = PyTuple_Pack(1, ((PyObject *)__pyx_kp_u_59)); if (unlikely(!__pyx_k_tuple_95)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 778; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_95);
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_95));

  /* "axon/_dumper.py":793
 *             if tp is dict:
 *                 if len(item) <= self.nsize and all(is_simple_type(self, x) for x in item.values()):
 *                     self.write("\n")             # <<<<<<<<<<<<<<
 *                     self.write(offset1)
 *                     self._dump_attr_sequence(item)
 */
  __pyx_k_tuple_96 = PyTuple_Pack(1, ((PyObject *)__pyx_kp_u_40)); if (unlikely(!__pyx_k_tuple_96)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 793; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_96);
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_96));

  /* "axon/_dumper.py":800
 *             elif tp is tuple:
 *                 if len(item) <= self.nsize and all(is_simple_type(self, x) for x in item):
 *                     self.write("\n")             # <<<<<<<<<<<<<<
 *                     self.write(offset1)
 *                     self._dump_tuple_sequence(item)
 */
  __pyx_k_tuple_97 = PyTuple_Pack(1, ((PyObject *)__pyx_kp_u_40)); if (unlikely(!__pyx_k_tuple_97)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 800; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_97);
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_97));

  /* "axon/_dumper.py":807
 *             elif tp is list:
 *                 if len(item) <= self.nsize and all(is_simple_type(self, x) for x in item):
 *                     self.write("\n")             # <<<<<<<<<<<<<<
 *                     self.write(offset1)
 *                     self._dump_list_sequence(item)
 */
  __pyx_k_tuple_98 = PyTuple_Pack(1, ((PyObject *)__pyx_kp_u_40)); if (unlikely(!__pyx_k_tuple_98)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 807; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_98);
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_98));

  /* "axon/_dumper.py":814
 *             else:
 *                 for v in item:
 *                     self.write('\n')             # <<<<<<<<<<<<<<
 *                     self._pretty_dump(v, offset1, use_offset)
 *     #
 */
  __pyx_k_tuple_99 = PyTuple_Pack(1, ((PyObject *)__pyx_kp_u_40)); if (unlikely(!__pyx_k_tuple_99)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 814; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_99);
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_99));

  /* "axon/_dumper.py":822
 * 
 *         for i, o in enumerate(collection):
 *             self.write('\n')             # <<<<<<<<<<<<<<
 *             self.write(new_offset)
 *             if self.crossref:
 */
  __pyx_k_tuple_100 = PyTuple_Pack(1, ((PyObject *)__pyx_kp_u_40)); if (unlikely(!__pyx_k_tuple_100)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 822; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_100);
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_100));

  /* "axon/_dumper.py":830
 * 
 *             if self.pretty == 1:
 *                 self.write('{')             # <<<<<<<<<<<<<<
 *             elif self.pretty == 2:
 *                 self.write(':')
 */
  __pyx_k_tuple_101 = PyTuple_Pack(1, ((PyObject *)__pyx_kp_u_57)); if (unlikely(!__pyx_k_tuple_101)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 830; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_101);
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_101));

  /* "axon/_dumper.py":832
 *                 self.write('{')
 *             elif self.pretty == 2:
 *                 self.write(':')             # <<<<<<<<<<<<<<
 * 
 *             otype = type(o)
 */
  __pyx_k_tuple_102 = PyTuple_Pack(1, ((PyObject *)__pyx_kp_u_46)); if (unlikely(!__pyx_k_tuple_102)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 832; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_102);
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_102));

  /* "axon/_dumper.py":848
 *                     raise ValueError('Reducer returns invalid number of items: %s' % n)
 *                 elif n > 1:
 *                     self.pretty_dump_content(items[1:], new_offset)             # <<<<<<<<<<<<<<
 * 
 *             if self.pretty == 1:
 */
  __pyx_k_slice_103 = PySlice_New(__pyx_int_1, Py_None, Py_None); if (unlikely(!__pyx_k_slice_103)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 848; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_slice_103);
  __Pyx_GIVEREF(__pyx_k_slice_103);

  /* "axon/_dumper.py":851
 * 
 *             if self.pretty == 1:
 *                 self.write('}')             # <<<<<<<<<<<<<<
 * 
 *     #
 */
  __pyx_k_tuple_104 = PyTuple_Pack(1, ((PyObject *)__pyx_kp_u_59)); if (unlikely(!__pyx_k_tuple_104)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 851; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_104);
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_104));

  /* "axon/_dumper.py":870
 * 
 *         if is_collection:
 *             self.write('*')             # <<<<<<<<<<<<<<
 * 
 *         if not is_collection and (n < 1 or n > 3):
 */
  __pyx_k_tuple_105 = PyTuple_Pack(1, ((PyObject *)__pyx_kp_u_1)); if (unlikely(!__pyx_k_tuple_105)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 870; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_105);
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_105));

  /* "axon/_dumper.py":877
 *         if n == 1:
 *             if self.pretty == 2:
 *                 self.write(':\n')             # <<<<<<<<<<<<<<
 *                 self.write(offset)
 *                 self.write('  ...')
 */
  __pyx_k_tuple_107 = PyTuple_Pack(1, ((PyObject *)__pyx_kp_u_106)); if (unlikely(!__pyx_k_tuple_107)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 877; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_107);
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_107));

  /* "axon/_dumper.py":879
 *                 self.write(':\n')
 *                 self.write(offset)
 *                 self.write('  ...')             # <<<<<<<<<<<<<<
 *             else:
 *                 self.write('{}')
 */
  __pyx_k_tuple_109 = PyTuple_Pack(1, ((PyObject *)__pyx_kp_u_108)); if (unlikely(!__pyx_k_tuple_109)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 879; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_109);
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_109));

  /* "axon/_dumper.py":881
 *                 self.write('  ...')
 *             else:
 *                 self.write('{}')             # <<<<<<<<<<<<<<
 *             return 0
 * 
 */
  __pyx_k_tuple_110 = PyTuple_Pack(1, ((PyObject *)__pyx_kp_u_91)); if (unlikely(!__pyx_k_tuple_110)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 881; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_110);
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_110));

  /* "axon/_dumper.py":885
 * 
 *         if self.pretty == 1:
 *             self.write(' {')             # <<<<<<<<<<<<<<
 *         elif self.pretty == 2:
 *             self.write(':')
 */
  __pyx_k_tuple_112 = PyTuple_Pack(1, ((PyObject *)__pyx_kp_u_111)); if (unlikely(!__pyx_k_tuple_112)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 885; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_112);
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_112));

  /* "axon/_dumper.py":887
 *             self.write(' {')
 *         elif self.pretty == 2:
 *             self.write(':')             # <<<<<<<<<<<<<<
 * 
 *         #if self.crossref:
 */
  __pyx_k_tuple_113 = PyTuple_Pack(1, ((PyObject *)__pyx_kp_u_46)); if (unlikely(!__pyx_k_tuple_113)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 887; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_113);
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_113));

  /* "axon/_dumper.py":895
 *             self.pretty_dump_collection(name, results[1], offset)
 *         else:
 *             self.pretty_dump_content(results[1:], offset)             # <<<<<<<<<<<<<<
 * 
 *         if self.pretty == 1:
 */
  __pyx_k_slice_115 = PySlice_New(__pyx_int_1, Py_None, Py_None); if (unlikely(!__pyx_k_slice_115)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 895; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_slice_115);
  __Pyx_GIVEREF(__pyx_k_slice_115);

  /* "axon/_dumper.py":898
 * 
 *         if self.pretty == 1:
 *             self.write('}')             # <<<<<<<<<<<<<<
 *         #elif self.pretty == 2:
 *         #    self.write('\n')
 */
  __pyx_k_tuple_116 = PyTuple_Pack(1, ((PyObject *)__pyx_kp_u_59)); if (unlikely(!__pyx_k_tuple_116)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 898; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_116);
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_116));

  /* "axon/_dumper.py":932
 *         if self.pretty:
 *             for v in iterseq:
 *                 self.write('\n')             # <<<<<<<<<<<<<<
 *                 self._pretty_dump(v, '', 1)
 *         else:
 */
  __pyx_k_tuple_117 = PyTuple_Pack(1, ((PyObject *)__pyx_kp_u_40)); if (unlikely(!__pyx_k_tuple_117)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 932; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_117);
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_117));

  /* "axon/_dumper.py":936
 *         else:
 *             for v in iterseq:
 *                 self.write(' ')             # <<<<<<<<<<<<<<
 *                 #self.size = 0
 *                 self._dump(v)
 */
  __pyx_k_tuple_118 = PyTuple_Pack(1, ((PyObject *)__pyx_kp_u_32)); if (unlikely(!__pyx_k_tuple_118)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 936; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_118);
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_118));

  /* "axon/_dumper.py":968
 *         count = self.crossref_dict.get(ref_o, None)
 *         if count is None:
 *             count = PyInt(1)             # <<<<<<<<<<<<<<
 *             self.crossref_dict[ref_o] = count
 *         else:
 */
  __pyx_k_tuple_119 = PyTuple_Pack(1, __pyx_int_1); if (unlikely(!__pyx_k_tuple_119)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 968; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_119);
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_119));

  /* "axon/_objects.pxd":65
 *         return unicode(ob)
 *     elif ob is None:
 *         return unicode('')             # <<<<<<<<<<<<<<
 *     else:
 *         raise TypeError('This object %r is not unicode compatible' % ob)
 */
  __pyx_k_tuple_120 = PyTuple_Pack(1, ((PyObject *)__pyx_kp_u_44)); if (unlikely(!__pyx_k_tuple_120)) {__pyx_filename = __pyx_f[2]; __pyx_lineno = 65; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_120);
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_120));

  /* "axon/_dumper.py":96
 * #
 * 
 * def reset_reduce():             # <<<<<<<<<<<<<<
 *     c_reduce_dict = _c_type_reducers.copy()
 * 
 */
  __pyx_k_tuple_124 = PyTuple_Pack(1, ((PyObject *)__pyx_n_s__c_reduce_dict)); if (unlikely(!__pyx_k_tuple_124)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 96; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_124);
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_124));
  __pyx_k_codeobj_125 = (PyObject*)__Pyx_PyCode_New(0, 0, 1, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_k_tuple_124, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_4, __pyx_n_s__reset_reduce, 96, __pyx_empty_bytes); if (unlikely(!__pyx_k_codeobj_125)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 96; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

  /* "axon/_dumper.py":103
 * #        self.__dict__.update(kw)
 * 
 * def reduce(type_, reduce_func = None):             # <<<<<<<<<<<<<<
 *     if reduce_func is None:
 *         def _factory(factory_func):
 */
  __pyx_k_tuple_126 = PyTuple_Pack(4, ((PyObject *)__pyx_n_s__type_), ((PyObject *)__pyx_n_s__reduce_func), ((PyObject *)__pyx_n_s___factory), ((PyObject *)__pyx_n_s___factory)); if (unlikely(!__pyx_k_tuple_126)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 103; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_126);
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_126));
  __pyx_k_codeobj_127 = (PyObject*)__Pyx_PyCode_New(2, 0, 4, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_k_tuple_126, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_4, __pyx_n_s__reduce, 103, __pyx_empty_bytes); if (unlikely(!__pyx_k_codeobj_127)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 103; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_k_tuple_128 = PyTuple_Pack(1, ((PyObject *)Py_None)); if (unlikely(!__pyx_k_tuple_128)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 103; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_128);
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_128));

  /* "axon/_dumper.py":310
 *             self.mapping.update(sd.mapping)
 * 
 * def dump_as_str(tp=None):             # <<<<<<<<<<<<<<
 *     if tp is None:
 *         def _dump_as_str(func):
 */
  __pyx_k_tuple_129 = PyTuple_Pack(3, ((PyObject *)__pyx_n_s__tp), ((PyObject *)__pyx_n_s___dump_as_str), ((PyObject *)__pyx_n_s___dump_as_str)); if (unlikely(!__pyx_k_tuple_129)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 310; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_129);
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_129));
  __pyx_k_codeobj_130 = (PyObject*)__Pyx_PyCode_New(1, 0, 3, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_k_tuple_129, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_4, __pyx_n_s__dump_as_str, 310, __pyx_empty_bytes); if (unlikely(!__pyx_k_codeobj_130)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 310; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_k_tuple_131 = PyTuple_Pack(1, ((PyObject *)Py_None)); if (unlikely(!__pyx_k_tuple_131)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 310; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_131);
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_131));
  __Pyx_RefNannyFinishContext();
  return 0;
  __pyx_L1_error:;
  __Pyx_RefNannyFinishContext();
  return -1;
}

static int __Pyx_InitGlobals(void) {
  if (__Pyx_InitStrings(__pyx_string_tab) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  __pyx_int_0 = PyInt_FromLong(0); if (unlikely(!__pyx_int_0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  __pyx_int_1 = PyInt_FromLong(1); if (unlikely(!__pyx_int_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  __pyx_int_3 = PyInt_FromLong(3); if (unlikely(!__pyx_int_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  return 0;
  __pyx_L1_error:;
  return -1;
}

#if PY_MAJOR_VERSION < 3
PyMODINIT_FUNC init_dumper(void); /*proto*/
PyMODINIT_FUNC init_dumper(void)
#else
PyMODINIT_FUNC PyInit__dumper(void); /*proto*/
PyMODINIT_FUNC PyInit__dumper(void)
#endif
{
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannyDeclarations
  #if CYTHON_REFNANNY
  __Pyx_RefNanny = __Pyx_RefNannyImportAPI("refnanny");
  if (!__Pyx_RefNanny) {
      PyErr_Clear();
      __Pyx_RefNanny = __Pyx_RefNannyImportAPI("Cython.Runtime.refnanny");
      if (!__Pyx_RefNanny)
          Py_FatalError("failed to import 'refnanny' module");
  }
  #endif
  __Pyx_RefNannySetupContext("PyMODINIT_FUNC PyInit__dumper(void)", 0);
  if ( __Pyx_check_binary_version() < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_empty_tuple = PyTuple_New(0); if (unlikely(!__pyx_empty_tuple)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_empty_bytes = PyBytes_FromStringAndSize("", 0); if (unlikely(!__pyx_empty_bytes)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  #ifdef __Pyx_CyFunction_USED
  if (__Pyx_CyFunction_init() < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  #endif
  #ifdef __Pyx_FusedFunction_USED
  if (__pyx_FusedFunction_init() < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  #endif
  #ifdef __Pyx_Generator_USED
  if (__pyx_Generator_init() < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  #endif
  /*--- Library function declarations ---*/
  /*--- Threads initialization code ---*/
  #if defined(__PYX_FORCE_INIT_THREADS) && __PYX_FORCE_INIT_THREADS
  #ifdef WITH_THREAD /* Python build with threading support? */
  PyEval_InitThreads();
  #endif
  #endif
  /*--- Module creation code ---*/
  #if PY_MAJOR_VERSION < 3
  __pyx_m = Py_InitModule4(__Pyx_NAMESTR("_dumper"), __pyx_methods, 0, 0, PYTHON_API_VERSION); Py_XINCREF(__pyx_m);
  #else
  __pyx_m = PyModule_Create(&__pyx_moduledef);
  #endif
  if (unlikely(!__pyx_m)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_d = PyModule_GetDict(__pyx_m); if (unlikely(!__pyx_d)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  Py_INCREF(__pyx_d);
  #if PY_MAJOR_VERSION >= 3
  {
    PyObject *modules = PyImport_GetModuleDict(); if (unlikely(!modules)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    if (!PyDict_GetItemString(modules, "axon._dumper")) {
      if (unlikely(PyDict_SetItemString(modules, "axon._dumper", __pyx_m) < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    }
  }
  #endif
  __pyx_b = PyImport_AddModule(__Pyx_NAMESTR(__Pyx_BUILTIN_MODULE_NAME)); if (unlikely(!__pyx_b)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  #if CYTHON_COMPILING_IN_PYPY
  Py_INCREF(__pyx_b);
  #endif
  if (__Pyx_SetAttrString(__pyx_m, "__builtins__", __pyx_b) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  /*--- Initialize various global constants etc. ---*/
  if (unlikely(__Pyx_InitGlobals() < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  #if PY_MAJOR_VERSION < 3 && (__PYX_DEFAULT_STRING_ENCODING_IS_ASCII || __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT)
  if (__Pyx_init_sys_getdefaultencoding_params() < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  #endif
  if (__pyx_module_is_main_axon___dumper) {
    if (__Pyx_SetAttrString(__pyx_m, "__name__", __pyx_n_s____main__) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  }
  /*--- Builtin init code ---*/
  if (unlikely(__Pyx_InitCachedBuiltins() < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  /*--- Constants init code ---*/
  if (unlikely(__Pyx_InitCachedConstants() < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  /*--- Global init code ---*/
  c_reduce_dict = ((PyObject*)Py_None); Py_INCREF(Py_None);
  __pyx_v_4axon_7_dumper_c_all_names = ((PyObject*)Py_None); Py_INCREF(Py_None);
  __pyx_v_4axon_7_dumper__set_name = ((PyObject*)Py_None); Py_INCREF(Py_None);
  __pyx_v_4axon_7_dumper__tuple_name = ((PyObject*)Py_None); Py_INCREF(Py_None);
  __pyx_v_4axon_7_dumper__list_name = ((PyObject*)Py_None); Py_INCREF(Py_None);
  __pyx_v_4axon_7_dumper__dict_name = ((PyObject*)Py_None); Py_INCREF(Py_None);
  __pyx_v_4axon_7_dumper__c_type_reducers = ((PyObject*)Py_None); Py_INCREF(Py_None);
  __pyx_v_4axon_7_dumper_c_factory_dict = ((PyObject*)Py_None); Py_INCREF(Py_None);
  __pyx_v_4axon_7_dumper_c_simple_dumpers = ((PyObject*)Py_None); Py_INCREF(Py_None);
  __pyx_v_4axon_7_dumper_simple_types = ((PyObject*)Py_None); Py_INCREF(Py_None);
  __pyx_v_4axon_7_dumper__simple_types = ((PyObject*)Py_None); Py_INCREF(Py_None);
  /*--- Variable export code ---*/
  if (__Pyx_ExportVoidPtr(__pyx_n_s__c_reduce_dict, (void *)&c_reduce_dict, "PyObject *") < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__Pyx_ExportVoidPtr(__pyx_n_s__c_all_names, (void *)&__pyx_v_4axon_7_dumper_c_all_names, "PyObject *") < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__Pyx_ExportVoidPtr(__pyx_n_s___set_name, (void *)&__pyx_v_4axon_7_dumper__set_name, "PyObject *") < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__Pyx_ExportVoidPtr(__pyx_n_s___tuple_name, (void *)&__pyx_v_4axon_7_dumper__tuple_name, "PyObject *") < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__Pyx_ExportVoidPtr(__pyx_n_s___list_name, (void *)&__pyx_v_4axon_7_dumper__list_name, "PyObject *") < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__Pyx_ExportVoidPtr(__pyx_n_s___dict_name, (void *)&__pyx_v_4axon_7_dumper__dict_name, "PyObject *") < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__Pyx_ExportVoidPtr(__pyx_n_s___c_type_reducers, (void *)&__pyx_v_4axon_7_dumper__c_type_reducers, "PyObject *") < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__Pyx_ExportVoidPtr(__pyx_n_s__c_factory_dict, (void *)&__pyx_v_4axon_7_dumper_c_factory_dict, "PyObject *") < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__Pyx_ExportVoidPtr(__pyx_n_s__c_simple_dumpers, (void *)&__pyx_v_4axon_7_dumper_c_simple_dumpers, "PyObject *") < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__Pyx_ExportVoidPtr(__pyx_n_s__simple_types, (void *)&__pyx_v_4axon_7_dumper_simple_types, "PyObject *") < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__Pyx_ExportVoidPtr(__pyx_n_s___simple_types, (void *)&__pyx_v_4axon_7_dumper__simple_types, "PyObject *") < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  /*--- Function export code ---*/
  if (__Pyx_ExportFunction("mapping_reduce", (void (*)(void))__pyx_f_4axon_7_dumper_mapping_reduce, "PyObject *(struct MappingObject *, int __pyx_skip_dispatch)") < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__Pyx_ExportFunction("element_reduce", (void (*)(void))__pyx_f_4axon_7_dumper_element_reduce, "PyObject *(struct ElementObject *, int __pyx_skip_dispatch)") < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__Pyx_ExportFunction("sequence_reduce", (void (*)(void))__pyx_f_4axon_7_dumper_sequence_reduce, "PyObject *(struct SequenceObject *, int __pyx_skip_dispatch)") < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__Pyx_ExportFunction("collection_reduce", (void (*)(void))__pyx_f_4axon_7_dumper_collection_reduce, "PyObject *(struct CollectionObject *, int __pyx_skip_dispatch)") < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__Pyx_ExportFunction("instance_reduce", (void (*)(void))__pyx_f_4axon_7_dumper_instance_reduce, "PyObject *(struct InstanceObject *, int __pyx_skip_dispatch)") < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__Pyx_ExportFunction("empty_reduce", (void (*)(void))__pyx_f_4axon_7_dumper_empty_reduce, "PyObject *(struct EmptyObject *, int __pyx_skip_dispatch)") < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__Pyx_ExportFunction("set_reduce", (void (*)(void))__pyx_f_4axon_7_dumper_set_reduce, "PyObject *(PyObject *, int __pyx_skip_dispatch)") < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__Pyx_ExportFunction("tuple_reduce", (void (*)(void))__pyx_f_4axon_7_dumper_tuple_reduce, "PyObject *(PyObject *, int __pyx_skip_dispatch)") < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__Pyx_ExportFunction("dict_reduce", (void (*)(void))__pyx_f_4axon_7_dumper_dict_reduce, "PyObject *(PyObject *, int __pyx_skip_dispatch)") < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__Pyx_ExportFunction("list_reduce", (void (*)(void))__pyx_f_4axon_7_dumper_list_reduce, "PyObject *(PyObject *, int __pyx_skip_dispatch)") < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__Pyx_ExportFunction("c_new_pyptr", (void (*)(void))__pyx_f_4axon_7_dumper_c_new_pyptr, "struct __pyx_obj_4axon_7_dumper_PyPointer *(PyObject *(*)(PyObject *))") < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__Pyx_ExportFunction("_dump_unicode", (void (*)(void))__pyx_f_4axon_7_dumper__dump_unicode, "PyObject *(PyObject *)") < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__Pyx_ExportFunction("_dump_str", (void (*)(void))__pyx_f_4axon_7_dumper__dump_str, "PyObject *(PyObject *)") < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__Pyx_ExportFunction("_dump_bool", (void (*)(void))__pyx_f_4axon_7_dumper__dump_bool, "PyObject *(PyObject *)") < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__Pyx_ExportFunction("_dump_date", (void (*)(void))__pyx_f_4axon_7_dumper__dump_date, "PyObject *(PyObject *)") < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__Pyx_ExportFunction("_dump_tzinfo", (void (*)(void))__pyx_f_4axon_7_dumper__dump_tzinfo, "PyObject *(PyObject *)") < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__Pyx_ExportFunction("_dump_time", (void (*)(void))__pyx_f_4axon_7_dumper__dump_time, "PyObject *(PyObject *)") < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__Pyx_ExportFunction("_dump_datetime", (void (*)(void))__pyx_f_4axon_7_dumper__dump_datetime, "PyObject *(PyObject *)") < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__Pyx_ExportFunction("_dump_none", (void (*)(void))__pyx_f_4axon_7_dumper__dump_none, "PyObject *(PyObject *)") < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__Pyx_ExportFunction("_dump_int", (void (*)(void))__pyx_f_4axon_7_dumper__dump_int, "PyObject *(PyObject *)") < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__Pyx_ExportFunction("_dump_bytes", (void (*)(void))__pyx_f_4axon_7_dumper__dump_bytes, "PyObject *(PyObject *)") < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__Pyx_ExportFunction("_dump_long", (void (*)(void))__pyx_f_4axon_7_dumper__dump_long, "PyObject *(PyObject *)") < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__Pyx_ExportFunction("_dump_float", (void (*)(void))__pyx_f_4axon_7_dumper__dump_float, "PyObject *(PyObject *)") < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__Pyx_ExportFunction("_dump_decimal", (void (*)(void))__pyx_f_4axon_7_dumper__dump_decimal, "PyObject *(PyObject *)") < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__Pyx_ExportFunction("_dump_undef", (void (*)(void))__pyx_f_4axon_7_dumper__dump_undef, "PyObject *(PyObject *)") < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__Pyx_ExportFunction("dump_default", (void (*)(void))__pyx_f_4axon_7_dumper_dump_default, "PyObject *(PyObject *)") < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__Pyx_ExportFunction("_dump_name", (void (*)(void))__pyx_f_4axon_7_dumper__dump_name, "PyObject *(PyObject *, int)") < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__Pyx_ExportFunction("is_simple_type", (void (*)(void))__pyx_f_4axon_7_dumper_is_simple_type, "int (struct Dumper *, PyObject *)") < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  /*--- Type init code ---*/
  if (PyType_Ready(&__pyx_type_4axon_7_dumper_PyPointer) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 120; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__Pyx_SetAttrString(__pyx_m, "PyPointer", (PyObject *)&__pyx_type_4axon_7_dumper_PyPointer) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 120; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_ptype_4axon_7_dumper_PyPointer = &__pyx_type_4axon_7_dumper_PyPointer;
  if (PyType_Ready(&__pyx_type_4axon_7_dumper___pyx_scope_struct_2_pretty_dump_content) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 780; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_ptype_4axon_7_dumper___pyx_scope_struct_2_pretty_dump_content = &__pyx_type_4axon_7_dumper___pyx_scope_struct_2_pretty_dump_content;
  if (PyType_Ready(&__pyx_type_4axon_7_dumper___pyx_scope_struct_5_genexpr) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 806; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_ptype_4axon_7_dumper___pyx_scope_struct_5_genexpr = &__pyx_type_4axon_7_dumper___pyx_scope_struct_5_genexpr;
  __pyx_vtabptr_4axon_7_dumper_SimpleDumpers = &__pyx_vtable_4axon_7_dumper_SimpleDumpers;
  __pyx_vtable_4axon_7_dumper_SimpleDumpers.add = (void (*)(struct SimpleDumpers *, PyObject *, PyObject *(*)(PyObject *)))__pyx_f_4axon_7_dumper_13SimpleDumpers_add;
  __pyx_vtable_4axon_7_dumper_SimpleDumpers.update = (void (*)(struct SimpleDumpers *, PyObject *))__pyx_f_4axon_7_dumper_13SimpleDumpers_update;
  if (PyType_Ready(&SimpleDumpersType) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 292; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__Pyx_SetVtable(SimpleDumpersType.tp_dict, __pyx_vtabptr_4axon_7_dumper_SimpleDumpers) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 292; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__Pyx_SetAttrString(__pyx_m, "SimpleDumpers", (PyObject *)&SimpleDumpersType) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 292; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_ptype_4axon_7_dumper_SimpleDumpers = &SimpleDumpersType;
  if (PyType_Ready(&__pyx_type_4axon_7_dumper___pyx_scope_struct_3_genexpr) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 792; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_ptype_4axon_7_dumper___pyx_scope_struct_3_genexpr = &__pyx_type_4axon_7_dumper___pyx_scope_struct_3_genexpr;
  if (PyType_Ready(&__pyx_type_4axon_7_dumper___pyx_scope_struct_1_dump_as_str) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 310; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_ptype_4axon_7_dumper___pyx_scope_struct_1_dump_as_str = &__pyx_type_4axon_7_dumper___pyx_scope_struct_1_dump_as_str;
  if (PyType_Ready(&__pyx_type_4axon_7_dumper_PyInt) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 30; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__Pyx_SetAttrString(__pyx_m, "PyInt", (PyObject *)&__pyx_type_4axon_7_dumper_PyInt) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 30; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_ptype_4axon_7_dumper_PyInt = &__pyx_type_4axon_7_dumper_PyInt;
  if (PyType_Ready(&__pyx_type_4axon_7_dumper___pyx_scope_struct_4_genexpr) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 799; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_ptype_4axon_7_dumper___pyx_scope_struct_4_genexpr = &__pyx_type_4axon_7_dumper___pyx_scope_struct_4_genexpr;
  if (PyType_Ready(&__pyx_type_4axon_7_dumper___pyx_scope_struct__reduce) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 103; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_ptype_4axon_7_dumper___pyx_scope_struct__reduce = &__pyx_type_4axon_7_dumper___pyx_scope_struct__reduce;
  __pyx_vtabptr_4axon_7_dumper_Dumper = &__pyx_vtable_4axon_7_dumper_Dumper;
  __pyx_vtable_4axon_7_dumper_Dumper._pretty_dump_crossref = (void (*)(struct Dumper *, PyObject *))__pyx_f_4axon_7_dumper_6Dumper__pretty_dump_crossref;
  __pyx_vtable_4axon_7_dumper_Dumper._dump_crossref = (void (*)(struct Dumper *, PyObject *))__pyx_f_4axon_7_dumper_6Dumper__dump_crossref;
  __pyx_vtable_4axon_7_dumper_Dumper._dump_label = (int (*)(struct Dumper *, PyObject *))__pyx_f_4axon_7_dumper_6Dumper__dump_label;
  __pyx_vtable_4axon_7_dumper_Dumper._dump = (int (*)(struct Dumper *, PyObject *))__pyx_f_4axon_7_dumper_6Dumper__dump;
  __pyx_vtable_4axon_7_dumper_Dumper._dump_value = (void (*)(struct Dumper *, PyObject *, PyObject *))__pyx_f_4axon_7_dumper_6Dumper__dump_value;
  __pyx_vtable_4axon_7_dumper_Dumper._dump_dict_sequence = (int (*)(struct Dumper *, PyObject *))__pyx_f_4axon_7_dumper_6Dumper__dump_dict_sequence;
  __pyx_vtable_4axon_7_dumper_Dumper._dump_attr_sequence = (int (*)(struct Dumper *, PyObject *))__pyx_f_4axon_7_dumper_6Dumper__dump_attr_sequence;
  __pyx_vtable_4axon_7_dumper_Dumper._dump_list_sequence = (int (*)(struct Dumper *, PyObject *))__pyx_f_4axon_7_dumper_6Dumper__dump_list_sequence;
  __pyx_vtable_4axon_7_dumper_Dumper._dump_set_sequence = (int (*)(struct Dumper *, PyObject *))__pyx_f_4axon_7_dumper_6Dumper__dump_set_sequence;
  __pyx_vtable_4axon_7_dumper_Dumper._dump_tuple_sequence = (int (*)(struct Dumper *, PyObject *))__pyx_f_4axon_7_dumper_6Dumper__dump_tuple_sequence;
  __pyx_vtable_4axon_7_dumper_Dumper.dump_list = (int (*)(struct Dumper *, PyObject *))__pyx_f_4axon_7_dumper_6Dumper_dump_list;
  __pyx_vtable_4axon_7_dumper_Dumper.dump_dict = (int (*)(struct Dumper *, PyObject *))__pyx_f_4axon_7_dumper_6Dumper_dump_dict;
  __pyx_vtable_4axon_7_dumper_Dumper._pretty_dump_dict_sequence = (int (*)(struct Dumper *, PyObject *, PyObject *, int))__pyx_f_4axon_7_dumper_6Dumper__pretty_dump_dict_sequence;
  __pyx_vtable_4axon_7_dumper_Dumper._pretty_dump_attr_sequence = (int (*)(struct Dumper *, PyObject *, PyObject *, int))__pyx_f_4axon_7_dumper_6Dumper__pretty_dump_attr_sequence;
  __pyx_vtable_4axon_7_dumper_Dumper._pretty_dump_list_sequence = (int (*)(struct Dumper *, PyObject *, PyObject *, int))__pyx_f_4axon_7_dumper_6Dumper__pretty_dump_list_sequence;
  __pyx_vtable_4axon_7_dumper_Dumper._pretty_dump_tuple_sequence = (int (*)(struct Dumper *, PyObject *, PyObject *, int))__pyx_f_4axon_7_dumper_6Dumper__pretty_dump_tuple_sequence;
  __pyx_vtable_4axon_7_dumper_Dumper.pretty_dump_list = (int (*)(struct Dumper *, PyObject *, PyObject *, int))__pyx_f_4axon_7_dumper_6Dumper_pretty_dump_list;
  __pyx_vtable_4axon_7_dumper_Dumper.pretty_dump_dict = (int (*)(struct Dumper *, PyObject *, PyObject *, int))__pyx_f_4axon_7_dumper_6Dumper_pretty_dump_dict;
  __pyx_vtable_4axon_7_dumper_Dumper.dump_collection = (int (*)(struct Dumper *, PyObject *, PyObject *))__pyx_f_4axon_7_dumper_6Dumper_dump_collection;
  __pyx_vtable_4axon_7_dumper_Dumper.dump_content = (int (*)(struct Dumper *, PyObject *))__pyx_f_4axon_7_dumper_6Dumper_dump_content;
  __pyx_vtable_4axon_7_dumper_Dumper._dump_with_reducer = (int (*)(struct Dumper *, PyObject *, PyObject *))__pyx_f_4axon_7_dumper_6Dumper__dump_with_reducer;
  __pyx_vtable_4axon_7_dumper_Dumper._pretty_dump = (int (*)(struct Dumper *, PyObject *, PyObject *, int))__pyx_f_4axon_7_dumper_6Dumper__pretty_dump;
  __pyx_vtable_4axon_7_dumper_Dumper._pretty_dump_with_reducer = (int (*)(struct Dumper *, PyObject *, PyObject *, PyObject *))__pyx_f_4axon_7_dumper_6Dumper__pretty_dump_with_reducer;
  __pyx_vtable_4axon_7_dumper_Dumper.apply_crossref = (void (*)(struct Dumper *))__pyx_f_4axon_7_dumper_6Dumper_apply_crossref;
  __pyx_vtable_4axon_7_dumper_Dumper._collect = (int (*)(struct Dumper *, PyObject *))__pyx_f_4axon_7_dumper_6Dumper__collect;
  __pyx_vtable_4axon_7_dumper_Dumper._collect_list = (int (*)(struct Dumper *, PyObject *))__pyx_f_4axon_7_dumper_6Dumper__collect_list;
  __pyx_vtable_4axon_7_dumper_Dumper._collect_tuple = (int (*)(struct Dumper *, PyObject *))__pyx_f_4axon_7_dumper_6Dumper__collect_tuple;
  __pyx_vtable_4axon_7_dumper_Dumper._collect_set = (int (*)(struct Dumper *, PyObject *))__pyx_f_4axon_7_dumper_6Dumper__collect_set;
  __pyx_vtable_4axon_7_dumper_Dumper._collect_dict = (int (*)(struct Dumper *, PyObject *))__pyx_f_4axon_7_dumper_6Dumper__collect_dict;
  __pyx_vtable_4axon_7_dumper_Dumper._collect_with_reducer = (int (*)(struct Dumper *, PyObject *, PyObject *))__pyx_f_4axon_7_dumper_6Dumper__collect_with_reducer;
  __pyx_vtable_4axon_7_dumper_Dumper.collect = (int (*)(struct Dumper *, PyObject *))__pyx_f_4axon_7_dumper_6Dumper_collect;
  if (PyType_Ready(&DumperType) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 370; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__Pyx_SetVtable(DumperType.tp_dict, __pyx_vtabptr_4axon_7_dumper_Dumper) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 370; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__Pyx_SetAttrString(__pyx_m, "Dumper", (PyObject *)&DumperType) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 370; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_ptype_4axon_7_dumper_Dumper = &DumperType;
  /*--- Type import code ---*/
  __pyx_ptype_4axon_8_objects_Undefined = __Pyx_ImportType("axon._objects", "Undefined", sizeof(struct UndefinedObject), 1); if (unlikely(!__pyx_ptype_4axon_8_objects_Undefined)) {__pyx_filename = __pyx_f[2]; __pyx_lineno = 107; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_ptype_4axon_8_objects_rdict = __Pyx_ImportType("axon._objects", "rdict", sizeof(struct ReadonlyDict), 1); if (unlikely(!__pyx_ptype_4axon_8_objects_rdict)) {__pyx_filename = __pyx_f[2]; __pyx_lineno = 114; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_ptype_4axon_8_objects_rlist = __Pyx_ImportType("axon._objects", "rlist", sizeof(struct ReadonlyList), 1); if (unlikely(!__pyx_ptype_4axon_8_objects_rlist)) {__pyx_filename = __pyx_f[2]; __pyx_lineno = 121; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_ptype_4axon_8_objects_NamedValue = __Pyx_ImportType("axon._objects", "NamedValue", sizeof(struct __pyx_obj_4axon_8_objects_NamedValue), 1); if (unlikely(!__pyx_ptype_4axon_8_objects_NamedValue)) {__pyx_filename = __pyx_f[2]; __pyx_lineno = 127; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_ptype_4axon_8_objects_Attribute = __Pyx_ImportType("axon._objects", "Attribute", sizeof(struct Attribute), 1); if (unlikely(!__pyx_ptype_4axon_8_objects_Attribute)) {__pyx_filename = __pyx_f[2]; __pyx_lineno = 137; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_ptype_4axon_8_objects_Attrs = __Pyx_ImportType("axon._objects", "Attrs", sizeof(struct __pyx_obj_4axon_8_objects_Attrs), 1); if (unlikely(!__pyx_ptype_4axon_8_objects_Attrs)) {__pyx_filename = __pyx_f[2]; __pyx_lineno = 146; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_ptype_4axon_8_objects_Empty = __Pyx_ImportType("axon._objects", "Empty", sizeof(struct EmptyObject), 1); if (unlikely(!__pyx_ptype_4axon_8_objects_Empty)) {__pyx_filename = __pyx_f[2]; __pyx_lineno = 156; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_ptype_4axon_8_objects_Sequence = __Pyx_ImportType("axon._objects", "Sequence", sizeof(struct SequenceObject), 1); if (unlikely(!__pyx_ptype_4axon_8_objects_Sequence)) {__pyx_filename = __pyx_f[2]; __pyx_lineno = 163; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_ptype_4axon_8_objects_Collection = __Pyx_ImportType("axon._objects", "Collection", sizeof(struct CollectionObject), 1); if (unlikely(!__pyx_ptype_4axon_8_objects_Collection)) {__pyx_filename = __pyx_f[2]; __pyx_lineno = 172; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_ptype_4axon_8_objects_Mapping = __Pyx_ImportType("axon._objects", "Mapping", sizeof(struct MappingObject), 1); if (unlikely(!__pyx_ptype_4axon_8_objects_Mapping)) {__pyx_filename = __pyx_f[2]; __pyx_lineno = 181; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_ptype_4axon_8_objects_Element = __Pyx_ImportType("axon._objects", "Element", sizeof(struct ElementObject), 1); if (unlikely(!__pyx_ptype_4axon_8_objects_Element)) {__pyx_filename = __pyx_f[2]; __pyx_lineno = 190; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_ptype_4axon_8_objects_Instance = __Pyx_ImportType("axon._objects", "Instance", sizeof(struct InstanceObject), 1); if (unlikely(!__pyx_ptype_4axon_8_objects_Instance)) {__pyx_filename = __pyx_f[2]; __pyx_lineno = 199; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_ptype_4axon_8_objects_StringReader = __Pyx_ImportType("axon._objects", "StringReader", sizeof(struct __pyx_obj_4axon_8_objects_StringReader), 1); if (unlikely(!__pyx_ptype_4axon_8_objects_StringReader)) {__pyx_filename = __pyx_f[2]; __pyx_lineno = 227; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_vtabptr_4axon_8_objects_StringReader = (struct __pyx_vtabstruct_4axon_8_objects_StringReader*)__Pyx_GetVtable(__pyx_ptype_4axon_8_objects_StringReader->tp_dict); if (unlikely(!__pyx_vtabptr_4axon_8_objects_StringReader)) {__pyx_filename = __pyx_f[2]; __pyx_lineno = 227; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  /*--- Variable import code ---*/
  __pyx_t_1 = __Pyx_ImportModule("axon._objects"); if (!__pyx_t_1) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__Pyx_ImportVoidPtr(__pyx_t_1, "_decimal2str", (void **)&__pyx_vp_4axon_8_objects__decimal2str, "PyObject *") < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__Pyx_ImportVoidPtr(__pyx_t_1, "empty_name", (void **)&__pyx_vp_4axon_8_objects_empty_name, "PyObject *") < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__Pyx_ImportVoidPtr(__pyx_t_1, "c_undescore", (void **)&__pyx_vp_4axon_8_objects_c_undescore, "PyObject *") < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__Pyx_ImportVoidPtr(__pyx_t_1, "c_undefined", (void **)&__pyx_vp_4axon_8_objects_c_undefined, "PyObject *") < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__Pyx_ImportVoidPtr(__pyx_t_1, "name_cache", (void **)&__pyx_vp_4axon_8_objects_name_cache, "PyObject *") < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__Pyx_ImportVoidPtr(__pyx_t_1, "c_str_type", (void **)&__pyx_vp_4axon_8_objects_c_str_type, "PyObject *") < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__Pyx_ImportVoidPtr(__pyx_t_1, "c_empty_dict", (void **)&__pyx_vp_4axon_8_objects_c_empty_dict, "struct ReadonlyDict *") < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__Pyx_ImportVoidPtr(__pyx_t_1, "c_empty_list", (void **)&__pyx_vp_4axon_8_objects_c_empty_list, "struct ReadonlyList *") < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__Pyx_ImportVoidPtr(__pyx_t_1, "NAME_IS_EMPTY", (void **)&__pyx_vp_4axon_8_objects_NAME_IS_EMPTY, "PyObject *") < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  Py_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  /*--- Function import code ---*/
  /*--- Execution code ---*/

  /* "axon/_dumper.py":10
 * # {{LICENCE}}
 * 
 * import axon.types as types             # <<<<<<<<<<<<<<
 * #from axon.types import unicode_type, str_type, int_type, long_type
 * #from axon.types import bool_type, float_type, bytes_type
 */
  __pyx_t_2 = PyList_New(1); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 10; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(((PyObject *)__pyx_n_s_1));
  PyList_SET_ITEM(__pyx_t_2, 0, ((PyObject *)__pyx_n_s_1));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s_1));
  __pyx_t_3 = __Pyx_Import(((PyObject *)__pyx_n_s_122), ((PyObject *)__pyx_t_2), 0); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 10; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(((PyObject *)__pyx_t_2)); __pyx_t_2 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s__types, __pyx_t_3) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 10; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "axon/_dumper.py":14
 * #from axon.types import bool_type, float_type, bytes_type
 * 
 * try:             # <<<<<<<<<<<<<<
 *     import cdecimal as _decimal
 * 
 */
  {
    __Pyx_ExceptionSave(&__pyx_t_4, &__pyx_t_5, &__pyx_t_6);
    __Pyx_XGOTREF(__pyx_t_4);
    __Pyx_XGOTREF(__pyx_t_5);
    __Pyx_XGOTREF(__pyx_t_6);
    /*try:*/ {

      /* "axon/_dumper.py":15
 * 
 * try:
 *     import cdecimal as _decimal             # <<<<<<<<<<<<<<
 * 
 * except:
 */
      __pyx_t_3 = __Pyx_Import(((PyObject *)__pyx_n_s__cdecimal), 0, 0); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 15; __pyx_clineno = __LINE__; goto __pyx_L2_error;}
      __Pyx_GOTREF(__pyx_t_3);
      if (PyDict_SetItem(__pyx_d, __pyx_n_s___decimal, __pyx_t_3) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 15; __pyx_clineno = __LINE__; goto __pyx_L2_error;}
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    }
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    goto __pyx_L9_try_end;
    __pyx_L2_error:;
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "axon/_dumper.py":17
 *     import cdecimal as _decimal
 * 
 * except:             # <<<<<<<<<<<<<<
 *     import decimal as _decimal
 * 
 */
    /*except:*/ {
      __Pyx_AddTraceback("axon._dumper", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_3, &__pyx_t_2, &__pyx_t_7) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 17; __pyx_clineno = __LINE__; goto __pyx_L4_except_error;}
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_GOTREF(__pyx_t_7);

      /* "axon/_dumper.py":18
 * 
 * except:
 *     import decimal as _decimal             # <<<<<<<<<<<<<<
 * 
 * default_decimal_context = _decimal.getcontext()
 */
      __pyx_t_8 = __Pyx_Import(((PyObject *)__pyx_n_s__decimal), 0, 0); if (unlikely(!__pyx_t_8)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 18; __pyx_clineno = __LINE__; goto __pyx_L4_except_error;}
      __Pyx_GOTREF(__pyx_t_8);
      if (PyDict_SetItem(__pyx_d, __pyx_n_s___decimal, __pyx_t_8) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 18; __pyx_clineno = __LINE__; goto __pyx_L4_except_error;}
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      goto __pyx_L3_exception_handled;
    }
    __pyx_L4_except_error:;
    __Pyx_XGIVEREF(__pyx_t_4);
    __Pyx_XGIVEREF(__pyx_t_5);
    __Pyx_XGIVEREF(__pyx_t_6);
    __Pyx_ExceptionReset(__pyx_t_4, __pyx_t_5, __pyx_t_6);
    goto __pyx_L1_error;
    __pyx_L3_exception_handled:;
    __Pyx_XGIVEREF(__pyx_t_4);
    __Pyx_XGIVEREF(__pyx_t_5);
    __Pyx_XGIVEREF(__pyx_t_6);
    __Pyx_ExceptionReset(__pyx_t_4, __pyx_t_5, __pyx_t_6);
    __pyx_L9_try_end:;
  }

  /* "axon/_dumper.py":20
 *     import decimal as _decimal
 * 
 * default_decimal_context = _decimal.getcontext()             # <<<<<<<<<<<<<<
 * _decimal2str = default_decimal_context.to_eng_string
 * 
 */
  __pyx_t_7 = __Pyx_GetModuleGlobalName(__pyx_n_s___decimal); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 20; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s__getcontext); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 20; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = PyObject_Call(__pyx_t_2, ((PyObject *)__pyx_empty_tuple), NULL); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 20; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_123, __pyx_t_7) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 20; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "axon/_dumper.py":21
 * 
 * default_decimal_context = _decimal.getcontext()
 * _decimal2str = default_decimal_context.to_eng_string             # <<<<<<<<<<<<<<
 * 
 * import datetime
 */
  __pyx_t_7 = __Pyx_GetModuleGlobalName(__pyx_n_s_123); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 21; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s__to_eng_string); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 21; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s___decimal2str, __pyx_t_2) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 21; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "axon/_dumper.py":23
 * _decimal2str = default_decimal_context.to_eng_string
 * 
 * import datetime             # <<<<<<<<<<<<<<
 * 
 * try:
 */
  __pyx_t_2 = __Pyx_Import(((PyObject *)__pyx_n_s__datetime), 0, 0); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 23; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s__datetime, __pyx_t_2) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 23; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "axon/_dumper.py":25
 * import datetime
 * 
 * try:             # <<<<<<<<<<<<<<
 *     from base64 import encodebytes, decodebytes
 * except:
 */
  {
    __Pyx_ExceptionSave(&__pyx_t_6, &__pyx_t_5, &__pyx_t_4);
    __Pyx_XGOTREF(__pyx_t_6);
    __Pyx_XGOTREF(__pyx_t_5);
    __Pyx_XGOTREF(__pyx_t_4);
    /*try:*/ {

      /* "axon/_dumper.py":26
 * 
 * try:
 *     from base64 import encodebytes, decodebytes             # <<<<<<<<<<<<<<
 * except:
 *     from base64 import encodestring as encodebytes, decodestring as decodebytes
 */
      __pyx_t_2 = PyList_New(2); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 26; __pyx_clineno = __LINE__; goto __pyx_L12_error;}
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_INCREF(((PyObject *)__pyx_n_s__encodebytes));
      PyList_SET_ITEM(__pyx_t_2, 0, ((PyObject *)__pyx_n_s__encodebytes));
      __Pyx_GIVEREF(((PyObject *)__pyx_n_s__encodebytes));
      __Pyx_INCREF(((PyObject *)__pyx_n_s__decodebytes));
      PyList_SET_ITEM(__pyx_t_2, 1, ((PyObject *)__pyx_n_s__decodebytes));
      __Pyx_GIVEREF(((PyObject *)__pyx_n_s__decodebytes));
      __pyx_t_7 = __Pyx_Import(((PyObject *)__pyx_n_s__base64), ((PyObject *)__pyx_t_2), 0); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 26; __pyx_clineno = __LINE__; goto __pyx_L12_error;}
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(((PyObject *)__pyx_t_2)); __pyx_t_2 = 0;
      __pyx_t_2 = __Pyx_ImportFrom(__pyx_t_7, __pyx_n_s__encodebytes); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 26; __pyx_clineno = __LINE__; goto __pyx_L12_error;}
      __Pyx_GOTREF(__pyx_t_2);
      if (PyDict_SetItem(__pyx_d, __pyx_n_s__encodebytes, __pyx_t_2) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 26; __pyx_clineno = __LINE__; goto __pyx_L12_error;}
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __pyx_t_2 = __Pyx_ImportFrom(__pyx_t_7, __pyx_n_s__decodebytes); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 26; __pyx_clineno = __LINE__; goto __pyx_L12_error;}
      __Pyx_GOTREF(__pyx_t_2);
      if (PyDict_SetItem(__pyx_d, __pyx_n_s__decodebytes, __pyx_t_2) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 26; __pyx_clineno = __LINE__; goto __pyx_L12_error;}
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    }
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    goto __pyx_L19_try_end;
    __pyx_L12_error:;
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;

    /* "axon/_dumper.py":27
 * try:
 *     from base64 import encodebytes, decodebytes
 * except:             # <<<<<<<<<<<<<<
 *     from base64 import encodestring as encodebytes, decodestring as decodebytes
 * 
 */
    /*except:*/ {
      __Pyx_AddTraceback("axon._dumper", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_7, &__pyx_t_2, &__pyx_t_3) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 27; __pyx_clineno = __LINE__; goto __pyx_L14_except_error;}
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_GOTREF(__pyx_t_3);

      /* "axon/_dumper.py":28
 *     from base64 import encodebytes, decodebytes
 * except:
 *     from base64 import encodestring as encodebytes, decodestring as decodebytes             # <<<<<<<<<<<<<<
 * 
 * class PyInt:
 */
      __pyx_t_8 = PyList_New(2); if (unlikely(!__pyx_t_8)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 28; __pyx_clineno = __LINE__; goto __pyx_L14_except_error;}
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_INCREF(((PyObject *)__pyx_n_s__encodestring));
      PyList_SET_ITEM(__pyx_t_8, 0, ((PyObject *)__pyx_n_s__encodestring));
      __Pyx_GIVEREF(((PyObject *)__pyx_n_s__encodestring));
      __Pyx_INCREF(((PyObject *)__pyx_n_s__decodestring));
      PyList_SET_ITEM(__pyx_t_8, 1, ((PyObject *)__pyx_n_s__decodestring));
      __Pyx_GIVEREF(((PyObject *)__pyx_n_s__decodestring));
      __pyx_t_9 = __Pyx_Import(((PyObject *)__pyx_n_s__base64), ((PyObject *)__pyx_t_8), 0); if (unlikely(!__pyx_t_9)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 28; __pyx_clineno = __LINE__; goto __pyx_L14_except_error;}
      __Pyx_GOTREF(__pyx_t_9);
      __Pyx_DECREF(((PyObject *)__pyx_t_8)); __pyx_t_8 = 0;
      __pyx_t_8 = __Pyx_ImportFrom(__pyx_t_9, __pyx_n_s__encodestring); if (unlikely(!__pyx_t_8)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 28; __pyx_clineno = __LINE__; goto __pyx_L14_except_error;}
      __Pyx_GOTREF(__pyx_t_8);
      if (PyDict_SetItem(__pyx_d, __pyx_n_s__encodebytes, __pyx_t_8) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 28; __pyx_clineno = __LINE__; goto __pyx_L14_except_error;}
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_t_8 = __Pyx_ImportFrom(__pyx_t_9, __pyx_n_s__decodestring); if (unlikely(!__pyx_t_8)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 28; __pyx_clineno = __LINE__; goto __pyx_L14_except_error;}
      __Pyx_GOTREF(__pyx_t_8);
      if (PyDict_SetItem(__pyx_d, __pyx_n_s__decodebytes, __pyx_t_8) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 28; __pyx_clineno = __LINE__; goto __pyx_L14_except_error;}
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      goto __pyx_L13_exception_handled;
    }
    __pyx_L14_except_error:;
    __Pyx_XGIVEREF(__pyx_t_6);
    __Pyx_XGIVEREF(__pyx_t_5);
    __Pyx_XGIVEREF(__pyx_t_4);
    __Pyx_ExceptionReset(__pyx_t_6, __pyx_t_5, __pyx_t_4);
    goto __pyx_L1_error;
    __pyx_L13_exception_handled:;
    __Pyx_XGIVEREF(__pyx_t_6);
    __Pyx_XGIVEREF(__pyx_t_5);
    __Pyx_XGIVEREF(__pyx_t_4);
    __Pyx_ExceptionReset(__pyx_t_6, __pyx_t_5, __pyx_t_4);
    __pyx_L19_try_end:;
  }

  /* "axon/_dumper.py":61
 * #
 * 
 * _set_name = 'set'             # <<<<<<<<<<<<<<
 * _tuple_name = 'tuple'
 * _list_name = 'list'
 */
  __Pyx_INCREF(((PyObject *)__pyx_n_u__set));
  __Pyx_XGOTREF(((PyObject *)__pyx_v_4axon_7_dumper__set_name));
  __Pyx_DECREF(((PyObject *)__pyx_v_4axon_7_dumper__set_name));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_u__set));
  __pyx_v_4axon_7_dumper__set_name = __pyx_n_u__set;

  /* "axon/_dumper.py":62
 * 
 * _set_name = 'set'
 * _tuple_name = 'tuple'             # <<<<<<<<<<<<<<
 * _list_name = 'list'
 * _dict_name = 'dict'
 */
  __Pyx_INCREF(((PyObject *)__pyx_n_u__tuple));
  __Pyx_XGOTREF(((PyObject *)__pyx_v_4axon_7_dumper__tuple_name));
  __Pyx_DECREF(((PyObject *)__pyx_v_4axon_7_dumper__tuple_name));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_u__tuple));
  __pyx_v_4axon_7_dumper__tuple_name = __pyx_n_u__tuple;

  /* "axon/_dumper.py":63
 * _set_name = 'set'
 * _tuple_name = 'tuple'
 * _list_name = 'list'             # <<<<<<<<<<<<<<
 * _dict_name = 'dict'
 * 
 */
  __Pyx_INCREF(((PyObject *)__pyx_n_u__list));
  __Pyx_XGOTREF(((PyObject *)__pyx_v_4axon_7_dumper__list_name));
  __Pyx_DECREF(((PyObject *)__pyx_v_4axon_7_dumper__list_name));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_u__list));
  __pyx_v_4axon_7_dumper__list_name = __pyx_n_u__list;

  /* "axon/_dumper.py":64
 * _tuple_name = 'tuple'
 * _list_name = 'list'
 * _dict_name = 'dict'             # <<<<<<<<<<<<<<
 * 
 * def set_reduce(o):
 */
  __Pyx_INCREF(((PyObject *)__pyx_n_u__dict));
  __Pyx_XGOTREF(((PyObject *)__pyx_v_4axon_7_dumper__dict_name));
  __Pyx_DECREF(((PyObject *)__pyx_v_4axon_7_dumper__dict_name));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_u__dict));
  __pyx_v_4axon_7_dumper__dict_name = __pyx_n_u__dict;

  /* "axon/_dumper.py":78
 *     return _list_name, o
 * 
 * _c_type_reducers = {             # <<<<<<<<<<<<<<
 *     Mapping: mapping_reduce,
 *     Element: element_reduce,
 */
  __pyx_t_3 = PyDict_New(); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 78; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(((PyObject *)__pyx_t_3));

  /* "axon/_dumper.py":79
 * 
 * _c_type_reducers = {
 *     Mapping: mapping_reduce,             # <<<<<<<<<<<<<<
 *     Element: element_reduce,
 *     Sequence: sequence_reduce,
 */
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s__mapping_reduce); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 79; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_3, ((PyObject *)((PyObject*)__pyx_ptype_4axon_8_objects_Mapping)), __pyx_t_2) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 78; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "axon/_dumper.py":80
 * _c_type_reducers = {
 *     Mapping: mapping_reduce,
 *     Element: element_reduce,             # <<<<<<<<<<<<<<
 *     Sequence: sequence_reduce,
 *     Instance: instance_reduce,
 */
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s__element_reduce); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 80; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_3, ((PyObject *)((PyObject*)__pyx_ptype_4axon_8_objects_Element)), __pyx_t_2) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 78; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "axon/_dumper.py":81
 *     Mapping: mapping_reduce,
 *     Element: element_reduce,
 *     Sequence: sequence_reduce,             # <<<<<<<<<<<<<<
 *     Instance: instance_reduce,
 *     Collection: collection_reduce,
 */
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s__sequence_reduce); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 81; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_3, ((PyObject *)((PyObject*)__pyx_ptype_4axon_8_objects_Sequence)), __pyx_t_2) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 78; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "axon/_dumper.py":82
 *     Element: element_reduce,
 *     Sequence: sequence_reduce,
 *     Instance: instance_reduce,             # <<<<<<<<<<<<<<
 *     Collection: collection_reduce,
 *     Empty: empty_reduce,
 */
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s__instance_reduce); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 82; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_3, ((PyObject *)((PyObject*)__pyx_ptype_4axon_8_objects_Instance)), __pyx_t_2) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 78; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "axon/_dumper.py":83
 *     Sequence: sequence_reduce,
 *     Instance: instance_reduce,
 *     Collection: collection_reduce,             # <<<<<<<<<<<<<<
 *     Empty: empty_reduce,
 *     set: set_reduce,
 */
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s__collection_reduce); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 83; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_3, ((PyObject *)((PyObject*)__pyx_ptype_4axon_8_objects_Collection)), __pyx_t_2) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 78; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "axon/_dumper.py":84
 *     Instance: instance_reduce,
 *     Collection: collection_reduce,
 *     Empty: empty_reduce,             # <<<<<<<<<<<<<<
 *     set: set_reduce,
 *     tuple: tuple_reduce,
 */
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s__empty_reduce); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 84; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_3, ((PyObject *)((PyObject*)__pyx_ptype_4axon_8_objects_Empty)), __pyx_t_2) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 78; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "axon/_dumper.py":85
 *     Collection: collection_reduce,
 *     Empty: empty_reduce,
 *     set: set_reduce,             # <<<<<<<<<<<<<<
 *     tuple: tuple_reduce,
 *     list: list_reduce,
 */
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s__set_reduce); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 85; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_3, ((PyObject *)((PyObject*)(&PySet_Type))), __pyx_t_2) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 78; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "axon/_dumper.py":86
 *     Empty: empty_reduce,
 *     set: set_reduce,
 *     tuple: tuple_reduce,             # <<<<<<<<<<<<<<
 *     list: list_reduce,
 *     dict: dict_reduce,
 */
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s__tuple_reduce); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 86; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_3, ((PyObject *)((PyObject*)(&PyTuple_Type))), __pyx_t_2) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 78; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "axon/_dumper.py":87
 *     set: set_reduce,
 *     tuple: tuple_reduce,
 *     list: list_reduce,             # <<<<<<<<<<<<<<
 *     dict: dict_reduce,
 * }
 */
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s__list_reduce); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 87; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_3, ((PyObject *)((PyObject*)(&PyList_Type))), __pyx_t_2) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 78; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "axon/_dumper.py":88
 *     tuple: tuple_reduce,
 *     list: list_reduce,
 *     dict: dict_reduce,             # <<<<<<<<<<<<<<
 * }
 * 
 */
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s__dict_reduce); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 88; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_3, ((PyObject *)((PyObject*)(&PyDict_Type))), __pyx_t_2) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 78; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_XGOTREF(((PyObject *)__pyx_v_4axon_7_dumper__c_type_reducers));
  __Pyx_DECREF(((PyObject *)__pyx_v_4axon_7_dumper__c_type_reducers));
  __Pyx_GIVEREF(((PyObject *)__pyx_t_3));
  __pyx_v_4axon_7_dumper__c_type_reducers = ((PyObject*)__pyx_t_3);
  __pyx_t_3 = 0;

  /* "axon/_dumper.py":92
 * 
 * #
 * c_reduce_dict = _c_type_reducers.copy()             # <<<<<<<<<<<<<<
 * 
 * #
 */
  if (unlikely(((PyObject *)__pyx_v_4axon_7_dumper__c_type_reducers) == Py_None)) {
    PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%s'", "copy");
    {__pyx_filename = __pyx_f[0]; __pyx_lineno = 92; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }
  __pyx_t_3 = ((PyObject *)PyDict_Copy(__pyx_v_4axon_7_dumper__c_type_reducers)); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 92; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_XGOTREF(((PyObject *)c_reduce_dict));
  __Pyx_DECREF(((PyObject *)c_reduce_dict));
  __Pyx_GIVEREF(__pyx_t_3);
  c_reduce_dict = ((PyObject*)__pyx_t_3);
  __pyx_t_3 = 0;

  /* "axon/_dumper.py":96
 * #
 * 
 * def reset_reduce():             # <<<<<<<<<<<<<<
 *     c_reduce_dict = _c_type_reducers.copy()
 * 
 */
  __pyx_t_3 = __Pyx_CyFunction_NewEx(&__pyx_mdef_4axon_7_dumper_21reset_reduce, 0, __pyx_n_s__reset_reduce, NULL, __pyx_n_s_6, ((PyObject *)__pyx_k_codeobj_125)); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 96; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s__reset_reduce, __pyx_t_3) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 96; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "axon/_dumper.py":103
 * #        self.__dict__.update(kw)
 * 
 * def reduce(type_, reduce_func = None):             # <<<<<<<<<<<<<<
 *     if reduce_func is None:
 *         def _factory(factory_func):
 */
  __pyx_t_3 = __Pyx_CyFunction_NewEx(&__pyx_mdef_4axon_7_dumper_23reduce, 0, __pyx_n_s__reduce, NULL, __pyx_n_s_6, ((PyObject *)__pyx_k_codeobj_127)); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 103; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_3, ((PyObject *)__pyx_k_tuple_128));
  if (PyDict_SetItem(__pyx_d, __pyx_n_s__reduce, __pyx_t_3) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 103; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "axon/_dumper.py":270
 *     return unicode(v)
 * 
 * c_simple_dumpers = {             # <<<<<<<<<<<<<<
 *     types.int_type: c_new_pyptr(_dump_int),
 *     types.long_type: c_new_pyptr(_dump_long),
 */
  __pyx_t_3 = PyDict_New(); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 270; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(((PyObject *)__pyx_t_3));

  /* "axon/_dumper.py":271
 * 
 * c_simple_dumpers = {
 *     types.int_type: c_new_pyptr(_dump_int),             # <<<<<<<<<<<<<<
 *     types.long_type: c_new_pyptr(_dump_long),
 *     types.float_type: c_new_pyptr(_dump_float),
 */
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s__types); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 271; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s__int_type); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 271; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = ((PyObject *)__pyx_f_4axon_7_dumper_c_new_pyptr(__pyx_f_4axon_7_dumper__dump_int)); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 271; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_3, __pyx_t_7, __pyx_t_2) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 270; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "axon/_dumper.py":272
 * c_simple_dumpers = {
 *     types.int_type: c_new_pyptr(_dump_int),
 *     types.long_type: c_new_pyptr(_dump_long),             # <<<<<<<<<<<<<<
 *     types.float_type: c_new_pyptr(_dump_float),
 * 
 */
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s__types); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 272; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s__long_type); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 272; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = ((PyObject *)__pyx_f_4axon_7_dumper_c_new_pyptr(__pyx_f_4axon_7_dumper__dump_long)); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 272; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_3, __pyx_t_7, __pyx_t_2) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 270; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "axon/_dumper.py":273
 *     types.int_type: c_new_pyptr(_dump_int),
 *     types.long_type: c_new_pyptr(_dump_long),
 *     types.float_type: c_new_pyptr(_dump_float),             # <<<<<<<<<<<<<<
 * 
 *     types.str_type: c_new_pyptr(_dump_str),
 */
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s__types); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 273; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s__float_type); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 273; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = ((PyObject *)__pyx_f_4axon_7_dumper_c_new_pyptr(__pyx_f_4axon_7_dumper__dump_float)); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 273; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_3, __pyx_t_7, __pyx_t_2) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 270; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "axon/_dumper.py":275
 *     types.float_type: c_new_pyptr(_dump_float),
 * 
 *     types.str_type: c_new_pyptr(_dump_str),             # <<<<<<<<<<<<<<
 *     types.unicode_type: c_new_pyptr(_dump_unicode),
 * 
 */
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s__types); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 275; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s__str_type); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 275; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = ((PyObject *)__pyx_f_4axon_7_dumper_c_new_pyptr(__pyx_f_4axon_7_dumper__dump_str)); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 275; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_3, __pyx_t_7, __pyx_t_2) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 270; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "axon/_dumper.py":276
 * 
 *     types.str_type: c_new_pyptr(_dump_str),
 *     types.unicode_type: c_new_pyptr(_dump_unicode),             # <<<<<<<<<<<<<<
 * 
 *     types.bytes_type: c_new_pyptr(_dump_bytes),
 */
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s__types); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 276; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s__unicode_type); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 276; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = ((PyObject *)__pyx_f_4axon_7_dumper_c_new_pyptr(__pyx_f_4axon_7_dumper__dump_unicode)); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 276; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_3, __pyx_t_7, __pyx_t_2) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 270; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "axon/_dumper.py":278
 *     types.unicode_type: c_new_pyptr(_dump_unicode),
 * 
 *     types.bytes_type: c_new_pyptr(_dump_bytes),             # <<<<<<<<<<<<<<
 *     types.bool_type: c_new_pyptr(_dump_bool),
 * 
 */
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s__types); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 278; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s__bytes_type); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 278; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = ((PyObject *)__pyx_f_4axon_7_dumper_c_new_pyptr(__pyx_f_4axon_7_dumper__dump_bytes)); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 278; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_3, __pyx_t_7, __pyx_t_2) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 270; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "axon/_dumper.py":279
 * 
 *     types.bytes_type: c_new_pyptr(_dump_bytes),
 *     types.bool_type: c_new_pyptr(_dump_bool),             # <<<<<<<<<<<<<<
 * 
 *     _decimal.Decimal: c_new_pyptr(_dump_decimal),
 */
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s__types); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 279; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s__bool_type); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 279; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = ((PyObject *)__pyx_f_4axon_7_dumper_c_new_pyptr(__pyx_f_4axon_7_dumper__dump_bool)); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 279; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_3, __pyx_t_7, __pyx_t_2) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 270; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "axon/_dumper.py":281
 *     types.bool_type: c_new_pyptr(_dump_bool),
 * 
 *     _decimal.Decimal: c_new_pyptr(_dump_decimal),             # <<<<<<<<<<<<<<
 *     datetime.date: c_new_pyptr(_dump_date),
 *     datetime.time: c_new_pyptr(_dump_time),
 */
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s___decimal); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 281; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s__Decimal); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 281; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = ((PyObject *)__pyx_f_4axon_7_dumper_c_new_pyptr(__pyx_f_4axon_7_dumper__dump_decimal)); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 281; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_3, __pyx_t_7, __pyx_t_2) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 270; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "axon/_dumper.py":282
 * 
 *     _decimal.Decimal: c_new_pyptr(_dump_decimal),
 *     datetime.date: c_new_pyptr(_dump_date),             # <<<<<<<<<<<<<<
 *     datetime.time: c_new_pyptr(_dump_time),
 *     datetime.datetime: c_new_pyptr(_dump_datetime),
 */
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s__datetime); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 282; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s__date); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 282; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = ((PyObject *)__pyx_f_4axon_7_dumper_c_new_pyptr(__pyx_f_4axon_7_dumper__dump_date)); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 282; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_3, __pyx_t_7, __pyx_t_2) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 270; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "axon/_dumper.py":283
 *     _decimal.Decimal: c_new_pyptr(_dump_decimal),
 *     datetime.date: c_new_pyptr(_dump_date),
 *     datetime.time: c_new_pyptr(_dump_time),             # <<<<<<<<<<<<<<
 *     datetime.datetime: c_new_pyptr(_dump_datetime),
 * 
 */
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s__datetime); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 283; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s__time); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 283; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = ((PyObject *)__pyx_f_4axon_7_dumper_c_new_pyptr(__pyx_f_4axon_7_dumper__dump_time)); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 283; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_3, __pyx_t_7, __pyx_t_2) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 270; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "axon/_dumper.py":284
 *     datetime.date: c_new_pyptr(_dump_date),
 *     datetime.time: c_new_pyptr(_dump_time),
 *     datetime.datetime: c_new_pyptr(_dump_datetime),             # <<<<<<<<<<<<<<
 * 
 *     Undefined: c_new_pyptr(_dump_undef),
 */
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s__datetime); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 284; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s__datetime); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 284; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = ((PyObject *)__pyx_f_4axon_7_dumper_c_new_pyptr(__pyx_f_4axon_7_dumper__dump_datetime)); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 284; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_3, __pyx_t_7, __pyx_t_2) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 270; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "axon/_dumper.py":286
 *     datetime.datetime: c_new_pyptr(_dump_datetime),
 * 
 *     Undefined: c_new_pyptr(_dump_undef),             # <<<<<<<<<<<<<<
 *     type(None): c_new_pyptr(_dump_none),
 * }
 */
  __pyx_t_2 = ((PyObject *)__pyx_f_4axon_7_dumper_c_new_pyptr(__pyx_f_4axon_7_dumper__dump_undef)); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 286; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_3, ((PyObject *)((PyObject*)__pyx_ptype_4axon_8_objects_Undefined)), __pyx_t_2) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 270; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "axon/_dumper.py":287
 * 
 *     Undefined: c_new_pyptr(_dump_undef),
 *     type(None): c_new_pyptr(_dump_none),             # <<<<<<<<<<<<<<
 * }
 * 
 */
  __pyx_t_2 = ((PyObject *)__pyx_f_4axon_7_dumper_c_new_pyptr(__pyx_f_4axon_7_dumper__dump_none)); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 287; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_3, ((PyObject *)Py_TYPE(Py_None)), __pyx_t_2) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 270; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_XGOTREF(((PyObject *)__pyx_v_4axon_7_dumper_c_simple_dumpers));
  __Pyx_DECREF(((PyObject *)__pyx_v_4axon_7_dumper_c_simple_dumpers));
  __Pyx_GIVEREF(((PyObject *)__pyx_t_3));
  __pyx_v_4axon_7_dumper_c_simple_dumpers = ((PyObject*)__pyx_t_3);
  __pyx_t_3 = 0;

  /* "axon/_dumper.py":290
 * }
 * 
 * simple_types = set(c_simple_dumpers.keys())             # <<<<<<<<<<<<<<
 * 
 * class SimpleDumpers:
 */
  if (unlikely(((PyObject *)__pyx_v_4axon_7_dumper_c_simple_dumpers) == Py_None)) {
    PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%s'", "keys");
    {__pyx_filename = __pyx_f[0]; __pyx_lineno = 290; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }
  __pyx_t_3 = __Pyx_PyDict_Keys(__pyx_v_4axon_7_dumper_c_simple_dumpers); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 290; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 290; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_3);
  __pyx_t_3 = 0;
  __pyx_t_3 = PyObject_Call(((PyObject *)((PyObject*)(&PySet_Type))), ((PyObject *)__pyx_t_2), NULL); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 290; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(((PyObject *)__pyx_t_2)); __pyx_t_2 = 0;
  __Pyx_XGOTREF(((PyObject *)__pyx_v_4axon_7_dumper_simple_types));
  __Pyx_DECREF(((PyObject *)__pyx_v_4axon_7_dumper_simple_types));
  __Pyx_GIVEREF(__pyx_t_3);
  __pyx_v_4axon_7_dumper_simple_types = ((PyObject*)__pyx_t_3);
  __pyx_t_3 = 0;

  /* "axon/_dumper.py":310
 *             self.mapping.update(sd.mapping)
 * 
 * def dump_as_str(tp=None):             # <<<<<<<<<<<<<<
 *     if tp is None:
 *         def _dump_as_str(func):
 */
  __pyx_t_3 = __Pyx_CyFunction_NewEx(&__pyx_mdef_4axon_7_dumper_25dump_as_str, 0, __pyx_n_s__dump_as_str, NULL, __pyx_n_s_6, ((PyObject *)__pyx_k_codeobj_130)); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 310; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_3, ((PyObject *)__pyx_k_tuple_131));
  if (PyDict_SetItem(__pyx_d, __pyx_n_s__dump_as_str, __pyx_t_3) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 310; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "axon/_dumper.py":361
 *         return text
 * 
 * _simple_types = {             # <<<<<<<<<<<<<<
 *     types.unicode_type, types.str_type, types.int_type, types.long_type,
 *     types.float_type, types.decimal_type, types.bool_type,
 */
  __pyx_t_3 = PySet_New(0); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 361; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(((PyObject *)__pyx_t_3));

  /* "axon/_dumper.py":362
 * 
 * _simple_types = {
 *     types.unicode_type, types.str_type, types.int_type, types.long_type,             # <<<<<<<<<<<<<<
 *     types.float_type, types.decimal_type, types.bool_type,
 *     types.date_type, types.time_type, types.datetime_type}
 */
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s__types); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 362; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s__unicode_type); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 362; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (PySet_Add(__pyx_t_3, __pyx_t_7) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 361; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = __Pyx_GetModuleGlobalName(__pyx_n_s__types); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 362; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s__str_type); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 362; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  if (PySet_Add(__pyx_t_3, __pyx_t_2) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 361; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s__types); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 362; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s__int_type); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 362; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (PySet_Add(__pyx_t_3, __pyx_t_7) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 361; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = __Pyx_GetModuleGlobalName(__pyx_n_s__types); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 362; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s__long_type); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 362; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  if (PySet_Add(__pyx_t_3, __pyx_t_2) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 361; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "axon/_dumper.py":363
 * _simple_types = {
 *     types.unicode_type, types.str_type, types.int_type, types.long_type,
 *     types.float_type, types.decimal_type, types.bool_type,             # <<<<<<<<<<<<<<
 *     types.date_type, types.time_type, types.datetime_type}
 * 
 */
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s__types); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 363; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s__float_type); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 363; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (PySet_Add(__pyx_t_3, __pyx_t_7) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 361; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = __Pyx_GetModuleGlobalName(__pyx_n_s__types); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 363; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s__decimal_type); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 363; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  if (PySet_Add(__pyx_t_3, __pyx_t_2) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 361; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s__types); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 363; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s__bool_type); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 363; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (PySet_Add(__pyx_t_3, __pyx_t_7) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 361; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "axon/_dumper.py":364
 *     types.unicode_type, types.str_type, types.int_type, types.long_type,
 *     types.float_type, types.decimal_type, types.bool_type,
 *     types.date_type, types.time_type, types.datetime_type}             # <<<<<<<<<<<<<<
 * 
 * def is_simple_type(self, o):
 */
  __pyx_t_7 = __Pyx_GetModuleGlobalName(__pyx_n_s__types); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 364; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s__date_type); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 364; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  if (PySet_Add(__pyx_t_3, __pyx_t_2) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 361; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s__types); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 364; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s__time_type); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 364; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (PySet_Add(__pyx_t_3, __pyx_t_7) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 361; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = __Pyx_GetModuleGlobalName(__pyx_n_s__types); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 364; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s__datetime_type); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 364; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  if (PySet_Add(__pyx_t_3, __pyx_t_2) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 361; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_XGOTREF(((PyObject *)__pyx_v_4axon_7_dumper__simple_types));
  __Pyx_DECREF(((PyObject *)__pyx_v_4axon_7_dumper__simple_types));
  __Pyx_GIVEREF(((PyObject *)__pyx_t_3));
  __pyx_v_4axon_7_dumper__simple_types = ((PyObject*)__pyx_t_3);
  __pyx_t_3 = 0;

  /* "axon/_dumper.py":375
 *     '''
 *     #
 *     def __init__(self, fd, crossref=False, quote=False, pretty=0, nsize=1, sorted=1):             # <<<<<<<<<<<<<<
 * 
 *         self.max_size = 65000
 */
  __pyx_t_3 = __Pyx_PyBool_FromLong(0); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 375; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_k_28 = __pyx_t_3;
  __Pyx_GIVEREF(__pyx_t_3);
  __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyBool_FromLong(0); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 375; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_k_29 = __pyx_t_3;
  __Pyx_GIVEREF(__pyx_t_3);
  __pyx_t_3 = 0;

  /* "axon/_dumper.py":1
 * # coding: utf-8             # <<<<<<<<<<<<<<
 * 
 * #cython: boundscheck=False
 */
  __pyx_t_3 = PyDict_New(); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(((PyObject *)__pyx_t_3));
  if (PyDict_SetItem(__pyx_d, __pyx_n_s____test__, ((PyObject *)__pyx_t_3)) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(((PyObject *)__pyx_t_3)); __pyx_t_3 = 0;

  /* "axon/_objects.pxd":80
 *     return uname
 * 
 * cdef inline object py_as_name(object name):             # <<<<<<<<<<<<<<
 *     n = name_cache.get(name, None)
 *     if n is None:
 */
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  if (__pyx_m) {
    __Pyx_AddTraceback("init axon._dumper", __pyx_clineno, __pyx_lineno, __pyx_filename);
    Py_DECREF(__pyx_m); __pyx_m = 0;
  } else if (!PyErr_Occurred()) {
    PyErr_SetString(PyExc_ImportError, "init axon._dumper");
  }
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  #if PY_MAJOR_VERSION < 3
  return;
  #else
  return __pyx_m;
  #endif
}

/* Runtime support code */
#if CYTHON_REFNANNY
static __Pyx_RefNannyAPIStruct *__Pyx_RefNannyImportAPI(const char *modname) {
    PyObject *m = NULL, *p = NULL;
    void *r = NULL;
    m = PyImport_ImportModule((char *)modname);
    if (!m) goto end;
    p = PyObject_GetAttrString(m, (char *)"RefNannyAPI");
    if (!p) goto end;
    r = PyLong_AsVoidPtr(p);
end:
    Py_XDECREF(p);
    Py_XDECREF(m);
    return (__Pyx_RefNannyAPIStruct *)r;
}
#endif /* CYTHON_REFNANNY */

static PyObject *__Pyx_GetBuiltinName(PyObject *name) {
    PyObject* result = __Pyx_PyObject_GetAttrStr(__pyx_b, name);
    if (unlikely(!result)) {
        PyErr_Format(PyExc_NameError,
#if PY_MAJOR_VERSION >= 3
            "name '%U' is not defined", name);
#else
            "name '%s' is not defined", PyString_AS_STRING(name));
#endif
    }
    return result;
}

static void __Pyx_RaiseDoubleKeywordsError(
    const char* func_name,
    PyObject* kw_name)
{
    PyErr_Format(PyExc_TypeError,
        #if PY_MAJOR_VERSION >= 3
        "%s() got multiple values for keyword argument '%U'", func_name, kw_name);
        #else
        "%s() got multiple values for keyword argument '%s'", func_name,
        PyString_AsString(kw_name));
        #endif
}

static int __Pyx_ParseOptionalKeywords(
    PyObject *kwds,
    PyObject **argnames[],
    PyObject *kwds2,
    PyObject *values[],
    Py_ssize_t num_pos_args,
    const char* function_name)
{
    PyObject *key = 0, *value = 0;
    Py_ssize_t pos = 0;
    PyObject*** name;
    PyObject*** first_kw_arg = argnames + num_pos_args;
    while (PyDict_Next(kwds, &pos, &key, &value)) {
        name = first_kw_arg;
        while (*name && (**name != key)) name++;
        if (*name) {
            values[name-argnames] = value;
            continue;
        }
        name = first_kw_arg;
        #if PY_MAJOR_VERSION < 3
        if (likely(PyString_CheckExact(key)) || likely(PyString_Check(key))) {
            while (*name) {
                if ((CYTHON_COMPILING_IN_PYPY || PyString_GET_SIZE(**name) == PyString_GET_SIZE(key))
                        && _PyString_Eq(**name, key)) {
                    values[name-argnames] = value;
                    break;
                }
                name++;
            }
            if (*name) continue;
            else {
                PyObject*** argname = argnames;
                while (argname != first_kw_arg) {
                    if ((**argname == key) || (
                            (CYTHON_COMPILING_IN_PYPY || PyString_GET_SIZE(**argname) == PyString_GET_SIZE(key))
                             && _PyString_Eq(**argname, key))) {
                        goto arg_passed_twice;
                    }
                    argname++;
                }
            }
        } else
        #endif
        if (likely(PyUnicode_Check(key))) {
            while (*name) {
                int cmp = (**name == key) ? 0 :
                #if !CYTHON_COMPILING_IN_PYPY && PY_MAJOR_VERSION >= 3
                    (PyUnicode_GET_SIZE(**name) != PyUnicode_GET_SIZE(key)) ? 1 :
                #endif
                    PyUnicode_Compare(**name, key);
                if (cmp < 0 && unlikely(PyErr_Occurred())) goto bad;
                if (cmp == 0) {
                    values[name-argnames] = value;
                    break;
                }
                name++;
            }
            if (*name) continue;
            else {
                PyObject*** argname = argnames;
                while (argname != first_kw_arg) {
                    int cmp = (**argname == key) ? 0 :
                    #if !CYTHON_COMPILING_IN_PYPY && PY_MAJOR_VERSION >= 3
                        (PyUnicode_GET_SIZE(**argname) != PyUnicode_GET_SIZE(key)) ? 1 :
                    #endif
                        PyUnicode_Compare(**argname, key);
                    if (cmp < 0 && unlikely(PyErr_Occurred())) goto bad;
                    if (cmp == 0) goto arg_passed_twice;
                    argname++;
                }
            }
        } else
            goto invalid_keyword_type;
        if (kwds2) {
            if (unlikely(PyDict_SetItem(kwds2, key, value))) goto bad;
        } else {
            goto invalid_keyword;
        }
    }
    return 0;
arg_passed_twice:
    __Pyx_RaiseDoubleKeywordsError(function_name, key);
    goto bad;
invalid_keyword_type:
    PyErr_Format(PyExc_TypeError,
        "%s() keywords must be strings", function_name);
    goto bad;
invalid_keyword:
    PyErr_Format(PyExc_TypeError,
    #if PY_MAJOR_VERSION < 3
        "%s() got an unexpected keyword argument '%s'",
        function_name, PyString_AsString(key));
    #else
        "%s() got an unexpected keyword argument '%U'",
        function_name, key);
    #endif
bad:
    return -1;
}

static void __Pyx_RaiseArgtupleInvalid(
    const char* func_name,
    int exact,
    Py_ssize_t num_min,
    Py_ssize_t num_max,
    Py_ssize_t num_found)
{
    Py_ssize_t num_expected;
    const char *more_or_less;
    if (num_found < num_min) {
        num_expected = num_min;
        more_or_less = "at least";
    } else {
        num_expected = num_max;
        more_or_less = "at most";
    }
    if (exact) {
        more_or_less = "exactly";
    }
    PyErr_Format(PyExc_TypeError,
                 "%s() takes %s %" CYTHON_FORMAT_SSIZE_T "d positional argument%s (%" CYTHON_FORMAT_SSIZE_T "d given)",
                 func_name, more_or_less, num_expected,
                 (num_expected == 1) ? "" : "s", num_found);
}

static int __Pyx_ArgTypeTest(PyObject *obj, PyTypeObject *type, int none_allowed,
    const char *name, int exact)
{
    if (!type) {
        PyErr_Format(PyExc_SystemError, "Missing type object");
        return 0;
    }
    if (none_allowed && obj == Py_None) return 1;
    else if (exact) {
        if (Py_TYPE(obj) == type) return 1;
    }
    else {
        if (PyObject_TypeCheck(obj, type)) return 1;
    }
    PyErr_Format(PyExc_TypeError,
        "Argument '%s' has incorrect type (expected %s, got %s)",
        name, type->tp_name, Py_TYPE(obj)->tp_name);
    return 0;
}

static CYTHON_INLINE void __Pyx_RaiseClosureNameError(const char *varname) {
    PyErr_Format(PyExc_NameError, "free variable '%s' referenced before assignment in enclosing scope", varname);
}

static PyObject *
__Pyx_CyFunction_get_doc(__pyx_CyFunctionObject *op, CYTHON_UNUSED void *closure)
{
    if (unlikely(op->func_doc == NULL)) {
        if (op->func.m_ml->ml_doc) {
#if PY_MAJOR_VERSION >= 3
            op->func_doc = PyUnicode_FromString(op->func.m_ml->ml_doc);
#else
            op->func_doc = PyString_FromString(op->func.m_ml->ml_doc);
#endif
            if (unlikely(op->func_doc == NULL))
                return NULL;
        } else {
            Py_INCREF(Py_None);
            return Py_None;
        }
    }
    Py_INCREF(op->func_doc);
    return op->func_doc;
}
static int
__Pyx_CyFunction_set_doc(__pyx_CyFunctionObject *op, PyObject *value)
{
    PyObject *tmp = op->func_doc;
    if (value == NULL)
        value = Py_None; /* Mark as deleted */
    Py_INCREF(value);
    op->func_doc = value;
    Py_XDECREF(tmp);
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_name(__pyx_CyFunctionObject *op)
{
    if (unlikely(op->func_name == NULL)) {
#if PY_MAJOR_VERSION >= 3
        op->func_name = PyUnicode_InternFromString(op->func.m_ml->ml_name);
#else
        op->func_name = PyString_InternFromString(op->func.m_ml->ml_name);
#endif
        if (unlikely(op->func_name == NULL))
            return NULL;
    }
    Py_INCREF(op->func_name);
    return op->func_name;
}
static int
__Pyx_CyFunction_set_name(__pyx_CyFunctionObject *op, PyObject *value)
{
    PyObject *tmp;
#if PY_MAJOR_VERSION >= 3
    if (unlikely(value == NULL || !PyUnicode_Check(value))) {
#else
    if (unlikely(value == NULL || !PyString_Check(value))) {
#endif
        PyErr_SetString(PyExc_TypeError,
                        "__name__ must be set to a string object");
        return -1;
    }
    tmp = op->func_name;
    Py_INCREF(value);
    op->func_name = value;
    Py_XDECREF(tmp);
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_qualname(__pyx_CyFunctionObject *op)
{
    Py_INCREF(op->func_qualname);
    return op->func_qualname;
}
static int
__Pyx_CyFunction_set_qualname(__pyx_CyFunctionObject *op, PyObject *value)
{
    PyObject *tmp;
#if PY_MAJOR_VERSION >= 3
    if (unlikely(value == NULL || !PyUnicode_Check(value))) {
#else
    if (unlikely(value == NULL || !PyString_Check(value))) {
#endif
        PyErr_SetString(PyExc_TypeError,
                        "__qualname__ must be set to a string object");
        return -1;
    }
    tmp = op->func_qualname;
    Py_INCREF(value);
    op->func_qualname = value;
    Py_XDECREF(tmp);
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_self(__pyx_CyFunctionObject *m, CYTHON_UNUSED void *closure)
{
    PyObject *self;
    self = m->func_closure;
    if (self == NULL)
        self = Py_None;
    Py_INCREF(self);
    return self;
}
static PyObject *
__Pyx_CyFunction_get_dict(__pyx_CyFunctionObject *op)
{
    if (unlikely(op->func_dict == NULL)) {
        op->func_dict = PyDict_New();
        if (unlikely(op->func_dict == NULL))
            return NULL;
    }
    Py_INCREF(op->func_dict);
    return op->func_dict;
}
static int
__Pyx_CyFunction_set_dict(__pyx_CyFunctionObject *op, PyObject *value)
{
    PyObject *tmp;
    if (unlikely(value == NULL)) {
        PyErr_SetString(PyExc_TypeError,
               "function's dictionary may not be deleted");
        return -1;
    }
    if (unlikely(!PyDict_Check(value))) {
        PyErr_SetString(PyExc_TypeError,
               "setting function's dictionary to a non-dict");
        return -1;
    }
    tmp = op->func_dict;
    Py_INCREF(value);
    op->func_dict = value;
    Py_XDECREF(tmp);
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_globals(CYTHON_UNUSED __pyx_CyFunctionObject *op)
{
    PyObject* dict = PyModule_GetDict(__pyx_m);
    Py_XINCREF(dict);
    return dict;
}
static PyObject *
__Pyx_CyFunction_get_closure(CYTHON_UNUSED __pyx_CyFunctionObject *op)
{
    Py_INCREF(Py_None);
    return Py_None;
}
static PyObject *
__Pyx_CyFunction_get_code(__pyx_CyFunctionObject *op)
{
    PyObject* result = (op->func_code) ? op->func_code : Py_None;
    Py_INCREF(result);
    return result;
}
static int
__Pyx_CyFunction_init_defaults(__pyx_CyFunctionObject *op) {
    PyObject *res = op->defaults_getter((PyObject *) op);
    if (unlikely(!res))
        return -1;
    op->defaults_tuple = PyTuple_GET_ITEM(res, 0);
    Py_INCREF(op->defaults_tuple);
    op->defaults_kwdict = PyTuple_GET_ITEM(res, 1);
    Py_INCREF(op->defaults_kwdict);
    Py_DECREF(res);
    return 0;
}
static int
__Pyx_CyFunction_set_defaults(__pyx_CyFunctionObject *op, PyObject* value) {
    PyObject* tmp;
    if (!value) {
        value = Py_None;
    } else if (value != Py_None && !PyTuple_Check(value)) {
        PyErr_SetString(PyExc_TypeError,
                        "__defaults__ must be set to a tuple object");
        return -1;
    }
    Py_INCREF(value);
    tmp = op->defaults_tuple;
    op->defaults_tuple = value;
    Py_XDECREF(tmp);
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_defaults(__pyx_CyFunctionObject *op) {
    PyObject* result = op->defaults_tuple;
    if (unlikely(!result)) {
        if (op->defaults_getter) {
            if (__Pyx_CyFunction_init_defaults(op) < 0) return NULL;
            result = op->defaults_tuple;
        } else {
            result = Py_None;
        }
    }
    Py_INCREF(result);
    return result;
}
static int
__Pyx_CyFunction_set_kwdefaults(__pyx_CyFunctionObject *op, PyObject* value) {
    PyObject* tmp;
    if (!value) {
        value = Py_None;
    } else if (value != Py_None && !PyDict_Check(value)) {
        PyErr_SetString(PyExc_TypeError,
                        "__kwdefaults__ must be set to a dict object");
        return -1;
    }
    Py_INCREF(value);
    tmp = op->defaults_kwdict;
    op->defaults_kwdict = value;
    Py_XDECREF(tmp);
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_kwdefaults(__pyx_CyFunctionObject *op) {
    PyObject* result = op->defaults_kwdict;
    if (unlikely(!result)) {
        if (op->defaults_getter) {
            if (__Pyx_CyFunction_init_defaults(op) < 0) return NULL;
            result = op->defaults_kwdict;
        } else {
            result = Py_None;
        }
    }
    Py_INCREF(result);
    return result;
}
static int
__Pyx_CyFunction_set_annotations(__pyx_CyFunctionObject *op, PyObject* value) {
    PyObject* tmp;
    if (!value || value == Py_None) {
        value = NULL;
    } else if (!PyDict_Check(value)) {
        PyErr_SetString(PyExc_TypeError,
                        "__annotations__ must be set to a dict object");
        return -1;
    }
    Py_XINCREF(value);
    tmp = op->func_annotations;
    op->func_annotations = value;
    Py_XDECREF(tmp);
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_annotations(__pyx_CyFunctionObject *op) {
    PyObject* result = op->func_annotations;
    if (unlikely(!result)) {
        result = PyDict_New();
        if (unlikely(!result)) return NULL;
        op->func_annotations = result;
    }
    Py_INCREF(result);
    return result;
}
static PyGetSetDef __pyx_CyFunction_getsets[] = {
    {(char *) "func_doc", (getter)__Pyx_CyFunction_get_doc, (setter)__Pyx_CyFunction_set_doc, 0, 0},
    {(char *) "__doc__",  (getter)__Pyx_CyFunction_get_doc, (setter)__Pyx_CyFunction_set_doc, 0, 0},
    {(char *) "func_name", (getter)__Pyx_CyFunction_get_name, (setter)__Pyx_CyFunction_set_name, 0, 0},
    {(char *) "__name__", (getter)__Pyx_CyFunction_get_name, (setter)__Pyx_CyFunction_set_name, 0, 0},
    {(char *) "__qualname__", (getter)__Pyx_CyFunction_get_qualname, (setter)__Pyx_CyFunction_set_qualname, 0, 0},
    {(char *) "__self__", (getter)__Pyx_CyFunction_get_self, 0, 0, 0},
    {(char *) "func_dict", (getter)__Pyx_CyFunction_get_dict, (setter)__Pyx_CyFunction_set_dict, 0, 0},
    {(char *) "__dict__", (getter)__Pyx_CyFunction_get_dict, (setter)__Pyx_CyFunction_set_dict, 0, 0},
    {(char *) "func_globals", (getter)__Pyx_CyFunction_get_globals, 0, 0, 0},
    {(char *) "__globals__", (getter)__Pyx_CyFunction_get_globals, 0, 0, 0},
    {(char *) "func_closure", (getter)__Pyx_CyFunction_get_closure, 0, 0, 0},
    {(char *) "__closure__", (getter)__Pyx_CyFunction_get_closure, 0, 0, 0},
    {(char *) "func_code", (getter)__Pyx_CyFunction_get_code, 0, 0, 0},
    {(char *) "__code__", (getter)__Pyx_CyFunction_get_code, 0, 0, 0},
    {(char *) "func_defaults", (getter)__Pyx_CyFunction_get_defaults, (setter)__Pyx_CyFunction_set_defaults, 0, 0},
    {(char *) "__defaults__", (getter)__Pyx_CyFunction_get_defaults, (setter)__Pyx_CyFunction_set_defaults, 0, 0},
    {(char *) "__kwdefaults__", (getter)__Pyx_CyFunction_get_kwdefaults, (setter)__Pyx_CyFunction_set_kwdefaults, 0, 0},
    {(char *) "__annotations__", (getter)__Pyx_CyFunction_get_annotations, (setter)__Pyx_CyFunction_set_annotations, 0, 0},
    {0, 0, 0, 0, 0}
};
#ifndef PY_WRITE_RESTRICTED /* < Py2.5 */
#define PY_WRITE_RESTRICTED WRITE_RESTRICTED
#endif
static PyMemberDef __pyx_CyFunction_members[] = {
    {(char *) "__module__", T_OBJECT, offsetof(__pyx_CyFunctionObject, func.m_module), PY_WRITE_RESTRICTED, 0},
    {0, 0, 0,  0, 0}
};
static PyObject *
__Pyx_CyFunction_reduce(__pyx_CyFunctionObject *m, CYTHON_UNUSED PyObject *args)
{
#if PY_MAJOR_VERSION >= 3
    return PyUnicode_FromString(m->func.m_ml->ml_name);
#else
    return PyString_FromString(m->func.m_ml->ml_name);
#endif
}
static PyMethodDef __pyx_CyFunction_methods[] = {
    {__Pyx_NAMESTR("__reduce__"), (PyCFunction)__Pyx_CyFunction_reduce, METH_VARARGS, 0},
    {0, 0, 0, 0}
};
static PyObject *__Pyx_CyFunction_New(PyTypeObject *type, PyMethodDef *ml, int flags, PyObject* qualname,
                                      PyObject *closure, PyObject *module, PyObject* code) {
    __pyx_CyFunctionObject *op = PyObject_GC_New(__pyx_CyFunctionObject, type);
    if (op == NULL)
        return NULL;
    op->flags = flags;
    op->func_weakreflist = NULL;
    op->func.m_ml = ml;
    op->func.m_self = (PyObject *) op;
    Py_XINCREF(closure);
    op->func_closure = closure;
    Py_XINCREF(module);
    op->func.m_module = module;
    op->func_dict = NULL;
    op->func_name = NULL;
    Py_INCREF(qualname);
    op->func_qualname = qualname;
    op->func_doc = NULL;
    op->func_classobj = NULL;
    Py_XINCREF(code);
    op->func_code = code;
    op->defaults_pyobjects = 0;
    op->defaults = NULL;
    op->defaults_tuple = NULL;
    op->defaults_kwdict = NULL;
    op->defaults_getter = NULL;
    op->func_annotations = NULL;
    PyObject_GC_Track(op);
    return (PyObject *) op;
}
static int
__Pyx_CyFunction_clear(__pyx_CyFunctionObject *m)
{
    Py_CLEAR(m->func_closure);
    Py_CLEAR(m->func.m_module);
    Py_CLEAR(m->func_dict);
    Py_CLEAR(m->func_name);
    Py_CLEAR(m->func_qualname);
    Py_CLEAR(m->func_doc);
    Py_CLEAR(m->func_code);
    Py_CLEAR(m->func_classobj);
    Py_CLEAR(m->defaults_tuple);
    Py_CLEAR(m->defaults_kwdict);
    Py_CLEAR(m->func_annotations);
    if (m->defaults) {
        PyObject **pydefaults = __Pyx_CyFunction_Defaults(PyObject *, m);
        int i;
        for (i = 0; i < m->defaults_pyobjects; i++)
            Py_XDECREF(pydefaults[i]);
        PyMem_Free(m->defaults);
        m->defaults = NULL;
    }
    return 0;
}
static void __Pyx_CyFunction_dealloc(__pyx_CyFunctionObject *m)
{
    PyObject_GC_UnTrack(m);
    if (m->func_weakreflist != NULL)
        PyObject_ClearWeakRefs((PyObject *) m);
    __Pyx_CyFunction_clear(m);
    PyObject_GC_Del(m);
}
static int __Pyx_CyFunction_traverse(__pyx_CyFunctionObject *m, visitproc visit, void *arg)
{
    Py_VISIT(m->func_closure);
    Py_VISIT(m->func.m_module);
    Py_VISIT(m->func_dict);
    Py_VISIT(m->func_name);
    Py_VISIT(m->func_qualname);
    Py_VISIT(m->func_doc);
    Py_VISIT(m->func_code);
    Py_VISIT(m->func_classobj);
    Py_VISIT(m->defaults_tuple);
    Py_VISIT(m->defaults_kwdict);
    if (m->defaults) {
        PyObject **pydefaults = __Pyx_CyFunction_Defaults(PyObject *, m);
        int i;
        for (i = 0; i < m->defaults_pyobjects; i++)
            Py_VISIT(pydefaults[i]);
    }
    return 0;
}
static PyObject *__Pyx_CyFunction_descr_get(PyObject *func, PyObject *obj, PyObject *type)
{
    __pyx_CyFunctionObject *m = (__pyx_CyFunctionObject *) func;
    if (m->flags & __Pyx_CYFUNCTION_STATICMETHOD) {
        Py_INCREF(func);
        return func;
    }
    if (m->flags & __Pyx_CYFUNCTION_CLASSMETHOD) {
        if (type == NULL)
            type = (PyObject *)(Py_TYPE(obj));
        return PyMethod_New(func,
                            type, (PyObject *)(Py_TYPE(type)));
    }
    if (obj == Py_None)
        obj = NULL;
    return PyMethod_New(func, obj, type);
}
static PyObject*
__Pyx_CyFunction_repr(__pyx_CyFunctionObject *op)
{
#if PY_MAJOR_VERSION >= 3
    return PyUnicode_FromFormat("<cyfunction %U at %p>",
                                op->func_qualname, (void *)op);
#else
    return PyString_FromFormat("<cyfunction %s at %p>",
                               PyString_AsString(op->func_qualname), (void *)op);
#endif
}
#if CYTHON_COMPILING_IN_PYPY
static PyObject * __Pyx_CyFunction_Call(PyObject *func, PyObject *arg, PyObject *kw) {
    PyCFunctionObject* f = (PyCFunctionObject*)func;
    PyCFunction meth = PyCFunction_GET_FUNCTION(func);
    PyObject *self = PyCFunction_GET_SELF(func);
    Py_ssize_t size;
    switch (PyCFunction_GET_FLAGS(func) & ~(METH_CLASS | METH_STATIC | METH_COEXIST)) {
    case METH_VARARGS:
        if (likely(kw == NULL) || PyDict_Size(kw) == 0)
            return (*meth)(self, arg);
        break;
    case METH_VARARGS | METH_KEYWORDS:
        return (*(PyCFunctionWithKeywords)meth)(self, arg, kw);
    case METH_NOARGS:
        if (likely(kw == NULL) || PyDict_Size(kw) == 0) {
            size = PyTuple_GET_SIZE(arg);
            if (size == 0)
                return (*meth)(self, NULL);
            PyErr_Format(PyExc_TypeError,
                "%.200s() takes no arguments (%zd given)",
                f->m_ml->ml_name, size);
            return NULL;
        }
        break;
    case METH_O:
        if (likely(kw == NULL) || PyDict_Size(kw) == 0) {
            size = PyTuple_GET_SIZE(arg);
            if (size == 1)
                return (*meth)(self, PyTuple_GET_ITEM(arg, 0));
            PyErr_Format(PyExc_TypeError,
                "%.200s() takes exactly one argument (%zd given)",
                f->m_ml->ml_name, size);
            return NULL;
        }
        break;
    default:
        PyErr_SetString(PyExc_SystemError, "Bad call flags in "
                        "__Pyx_CyFunction_Call. METH_OLDARGS is no "
                        "longer supported!");
        return NULL;
    }
    PyErr_Format(PyExc_TypeError, "%.200s() takes no keyword arguments",
                 f->m_ml->ml_name);
    return NULL;
}
#else
static PyObject * __Pyx_CyFunction_Call(PyObject *func, PyObject *arg, PyObject *kw) {
	return PyCFunction_Call(func, arg, kw);
}
#endif
static PyTypeObject __pyx_CyFunctionType_type = {
    PyVarObject_HEAD_INIT(0, 0)
    __Pyx_NAMESTR("cython_function_or_method"), /*tp_name*/
    sizeof(__pyx_CyFunctionObject),   /*tp_basicsize*/
    0,                                  /*tp_itemsize*/
    (destructor) __Pyx_CyFunction_dealloc, /*tp_dealloc*/
    0,                                  /*tp_print*/
    0,                                  /*tp_getattr*/
    0,                                  /*tp_setattr*/
#if PY_MAJOR_VERSION < 3
    0,                                  /*tp_compare*/
#else
    0,                                  /*reserved*/
#endif
    (reprfunc) __Pyx_CyFunction_repr,   /*tp_repr*/
    0,                                  /*tp_as_number*/
    0,                                  /*tp_as_sequence*/
    0,                                  /*tp_as_mapping*/
    0,                                  /*tp_hash*/
    __Pyx_CyFunction_Call,              /*tp_call*/
    0,                                  /*tp_str*/
    0,                                  /*tp_getattro*/
    0,                                  /*tp_setattro*/
    0,                                  /*tp_as_buffer*/
    Py_TPFLAGS_DEFAULT | Py_TPFLAGS_HAVE_GC, /* tp_flags*/
    0,                                  /*tp_doc*/
    (traverseproc) __Pyx_CyFunction_traverse,   /*tp_traverse*/
    (inquiry) __Pyx_CyFunction_clear,   /*tp_clear*/
    0,                                  /*tp_richcompare*/
    offsetof(__pyx_CyFunctionObject, func_weakreflist), /* tp_weaklistoffse */
    0,                                  /*tp_iter*/
    0,                                  /*tp_iternext*/
    __pyx_CyFunction_methods,           /*tp_methods*/
    __pyx_CyFunction_members,           /*tp_members*/
    __pyx_CyFunction_getsets,           /*tp_getset*/
    0,                                  /*tp_base*/
    0,                                  /*tp_dict*/
    __Pyx_CyFunction_descr_get,         /*tp_descr_get*/
    0,                                  /*tp_descr_set*/
    offsetof(__pyx_CyFunctionObject, func_dict),/*tp_dictoffset*/
    0,                                  /*tp_init*/
    0,                                  /*tp_alloc*/
    0,                                  /*tp_new*/
    0,                                  /*tp_free*/
    0,                                  /*tp_is_gc*/
    0,                                  /*tp_bases*/
    0,                                  /*tp_mro*/
    0,                                  /*tp_cache*/
    0,                                  /*tp_subclasses*/
    0,                                  /*tp_weaklist*/
    0,                                  /*tp_del*/
#if PY_VERSION_HEX >= 0x02060000
    0,                                  /*tp_version_tag*/
#endif
};
static int __Pyx_CyFunction_init(void) {
#if !CYTHON_COMPILING_IN_PYPY
    __pyx_CyFunctionType_type.tp_call = PyCFunction_Call;
#endif
    if (PyType_Ready(&__pyx_CyFunctionType_type) < 0)
        return -1;
    __pyx_CyFunctionType = &__pyx_CyFunctionType_type;
    return 0;
}
static CYTHON_INLINE void *__Pyx_CyFunction_InitDefaults(PyObject *func, size_t size, int pyobjects) {
    __pyx_CyFunctionObject *m = (__pyx_CyFunctionObject *) func;
    m->defaults = PyMem_Malloc(size);
    if (!m->defaults)
        return PyErr_NoMemory();
    memset(m->defaults, 0, size);
    m->defaults_pyobjects = pyobjects;
    return m->defaults;
}
static CYTHON_INLINE void __Pyx_CyFunction_SetDefaultsTuple(PyObject *func, PyObject *tuple) {
    __pyx_CyFunctionObject *m = (__pyx_CyFunctionObject *) func;
    m->defaults_tuple = tuple;
    Py_INCREF(tuple);
}
static CYTHON_INLINE void __Pyx_CyFunction_SetDefaultsKwDict(PyObject *func, PyObject *dict) {
    __pyx_CyFunctionObject *m = (__pyx_CyFunctionObject *) func;
    m->defaults_kwdict = dict;
    Py_INCREF(dict);
}
static CYTHON_INLINE void __Pyx_CyFunction_SetAnnotationsDict(PyObject *func, PyObject *dict) {
    __pyx_CyFunctionObject *m = (__pyx_CyFunctionObject *) func;
    m->func_annotations = dict;
    Py_INCREF(dict);
}

static CYTHON_INLINE int __Pyx_TypeTest(PyObject *obj, PyTypeObject *type) {
    if (unlikely(!type)) {
        PyErr_Format(PyExc_SystemError, "Missing type object");
        return 0;
    }
    if (likely(PyObject_TypeCheck(obj, type)))
        return 1;
    PyErr_Format(PyExc_TypeError, "Cannot convert %.200s to %.200s",
                 Py_TYPE(obj)->tp_name, type->tp_name);
    return 0;
}

static CYTHON_INLINE Py_UCS4 __Pyx_GetItemInt_Unicode_Fast(PyObject* ustring, Py_ssize_t i,
                                                           int wraparound, int boundscheck) {
    Py_ssize_t length;
#if CYTHON_PEP393_ENABLED
    if (unlikely(__Pyx_PyUnicode_READY(ustring) < 0)) return (Py_UCS4)-1;
#endif
    if (wraparound | boundscheck) {
        length = __Pyx_PyUnicode_GET_LENGTH(ustring);
        if (wraparound & unlikely(i < 0)) i += length;
        if ((!boundscheck) || likely((0 <= i) & (i < length))) {
            return __Pyx_PyUnicode_READ_CHAR(ustring, i);
        } else {
            PyErr_SetString(PyExc_IndexError, "string index out of range");
            return (Py_UCS4)-1;
        }
    } else {
        return __Pyx_PyUnicode_READ_CHAR(ustring, i);
    }
}
static CYTHON_INLINE Py_UCS4 __Pyx_GetItemInt_Unicode_Generic(PyObject* ustring, PyObject* j) {
    Py_UCS4 uchar;
    PyObject *uchar_string;
    if (!j) return (Py_UCS4)-1;
    uchar_string = PyObject_GetItem(ustring, j);
    Py_DECREF(j);
    if (!uchar_string) return (Py_UCS4)-1;
#if CYTHON_PEP393_ENABLED
    if (unlikely(__Pyx_PyUnicode_READY(uchar_string) < 0)) {
        Py_DECREF(uchar_string);
        return (Py_UCS4)-1;
    }
#endif
    uchar = __Pyx_PyUnicode_READ_CHAR(uchar_string, 0);
    Py_DECREF(uchar_string);
    return uchar;
}

static CYTHON_INLINE PyObject* __Pyx_PyUnicode_Substring(
            PyObject* text, Py_ssize_t start, Py_ssize_t stop) {
    Py_ssize_t length;
#if CYTHON_PEP393_ENABLED
    if (unlikely(PyUnicode_READY(text) == -1)) return NULL;
    length = PyUnicode_GET_LENGTH(text);
#else
    length = PyUnicode_GET_SIZE(text);
#endif
    if (start < 0) {
        start += length;
        if (start < 0)
            start = 0;
    }
    if (stop < 0)
        stop += length;
    else if (stop > length)
        stop = length;
    length = stop - start;
    if (length <= 0)
        return PyUnicode_FromUnicode(NULL, 0);
#if CYTHON_PEP393_ENABLED
    return PyUnicode_FromKindAndData(PyUnicode_KIND(text),
        PyUnicode_1BYTE_DATA(text) + start*PyUnicode_KIND(text), stop-start);
#else
    return PyUnicode_FromUnicode(PyUnicode_AS_UNICODE(text)+start, stop-start);
#endif
}

static CYTHON_INLINE PyObject *__Pyx_GetModuleGlobalName(PyObject *name) {
    PyObject *result;
#if CYTHON_COMPILING_IN_CPYTHON
    result = PyDict_GetItem(__pyx_d, name);
    if (result) {
        Py_INCREF(result);
    } else {
#else
    result = PyObject_GetItem(__pyx_d, name);
    if (!result) {
        PyErr_Clear();
#endif
        result = __Pyx_GetBuiltinName(name);
    }
    return result;
}

static CYTHON_INLINE int __Pyx_CheckKeywordStrings(
    PyObject *kwdict,
    const char* function_name,
    int kw_allowed)
{
    PyObject* key = 0;
    Py_ssize_t pos = 0;
#if CPYTHON_COMPILING_IN_PYPY
    if (!kw_allowed && PyDict_Next(kwdict, &pos, &key, 0))
        goto invalid_keyword;
    return 1;
#else
    while (PyDict_Next(kwdict, &pos, &key, 0)) {
        #if PY_MAJOR_VERSION < 3
        if (unlikely(!PyString_CheckExact(key)) && unlikely(!PyString_Check(key)))
        #endif
            if (unlikely(!PyUnicode_Check(key)))
                goto invalid_keyword_type;
    }
    if ((!kw_allowed) && unlikely(key))
        goto invalid_keyword;
    return 1;
invalid_keyword_type:
    PyErr_Format(PyExc_TypeError,
        "%s() keywords must be strings", function_name);
    return 0;
#endif
invalid_keyword:
    PyErr_Format(PyExc_TypeError,
    #if PY_MAJOR_VERSION < 3
        "%s() got an unexpected keyword argument '%s'",
        function_name, PyString_AsString(key));
    #else
        "%s() got an unexpected keyword argument '%U'",
        function_name, key);
    #endif
    return 0;
}

static CYTHON_INLINE void __Pyx_ErrRestore(PyObject *type, PyObject *value, PyObject *tb) {
#if CYTHON_COMPILING_IN_CPYTHON
    PyObject *tmp_type, *tmp_value, *tmp_tb;
    PyThreadState *tstate = PyThreadState_GET();
    tmp_type = tstate->curexc_type;
    tmp_value = tstate->curexc_value;
    tmp_tb = tstate->curexc_traceback;
    tstate->curexc_type = type;
    tstate->curexc_value = value;
    tstate->curexc_traceback = tb;
    Py_XDECREF(tmp_type);
    Py_XDECREF(tmp_value);
    Py_XDECREF(tmp_tb);
#else
    PyErr_Restore(type, value, tb);
#endif
}
static CYTHON_INLINE void __Pyx_ErrFetch(PyObject **type, PyObject **value, PyObject **tb) {
#if CYTHON_COMPILING_IN_CPYTHON
    PyThreadState *tstate = PyThreadState_GET();
    *type = tstate->curexc_type;
    *value = tstate->curexc_value;
    *tb = tstate->curexc_traceback;
    tstate->curexc_type = 0;
    tstate->curexc_value = 0;
    tstate->curexc_traceback = 0;
#else
    PyErr_Fetch(type, value, tb);
#endif
}

static void __Pyx_WriteUnraisable(const char *name, CYTHON_UNUSED int clineno,
                                  CYTHON_UNUSED int lineno, CYTHON_UNUSED const char *filename) {
    PyObject *old_exc, *old_val, *old_tb;
    PyObject *ctx;
    __Pyx_ErrFetch(&old_exc, &old_val, &old_tb);
    #if PY_MAJOR_VERSION < 3
    ctx = PyString_FromString(name);
    #else
    ctx = PyUnicode_FromString(name);
    #endif
    __Pyx_ErrRestore(old_exc, old_val, old_tb);
    if (!ctx) {
        PyErr_WriteUnraisable(Py_None);
    } else {
        PyErr_WriteUnraisable(ctx);
        Py_DECREF(ctx);
    }
}

static PyObject* __Pyx_PyDict_GetItemDefault(PyObject* d, PyObject* key, PyObject* default_value) {
    PyObject* value;
#if PY_MAJOR_VERSION >= 3
    value = PyDict_GetItemWithError(d, key);
    if (unlikely(!value)) {
        if (unlikely(PyErr_Occurred()))
            return NULL;
        value = default_value;
    }
    Py_INCREF(value);
#else
    if (PyString_CheckExact(key) || PyUnicode_CheckExact(key) || PyInt_CheckExact(key)) {
        value = PyDict_GetItem(d, key);
        if (unlikely(!value)) {
            value = default_value;
        }
        Py_INCREF(value);
    } else {
        if (default_value == Py_None)
            default_value = NULL;
        value = PyObject_CallMethodObjArgs(
            d, __pyx_n_s__get, key, default_value, NULL);
    }
#endif
    return value;
}

#if PY_MAJOR_VERSION < 3
static void __Pyx_Raise(PyObject *type, PyObject *value, PyObject *tb,
                        CYTHON_UNUSED PyObject *cause) {
    Py_XINCREF(type);
    if (!value || value == Py_None)
        value = NULL;
    else
        Py_INCREF(value);
    if (!tb || tb == Py_None)
        tb = NULL;
    else {
        Py_INCREF(tb);
        if (!PyTraceBack_Check(tb)) {
            PyErr_SetString(PyExc_TypeError,
                "raise: arg 3 must be a traceback or None");
            goto raise_error;
        }
    }
    #if PY_VERSION_HEX < 0x02050000
    if (PyClass_Check(type)) {
    #else
    if (PyType_Check(type)) {
    #endif
#if CYTHON_COMPILING_IN_PYPY
        if (!value) {
            Py_INCREF(Py_None);
            value = Py_None;
        }
#endif
        PyErr_NormalizeException(&type, &value, &tb);
    } else {
        if (value) {
            PyErr_SetString(PyExc_TypeError,
                "instance exception may not have a separate value");
            goto raise_error;
        }
        value = type;
        #if PY_VERSION_HEX < 0x02050000
        if (PyInstance_Check(type)) {
            type = (PyObject*) ((PyInstanceObject*)type)->in_class;
            Py_INCREF(type);
        } else {
            type = 0;
            PyErr_SetString(PyExc_TypeError,
                "raise: exception must be an old-style class or instance");
            goto raise_error;
        }
        #else
        type = (PyObject*) Py_TYPE(type);
        Py_INCREF(type);
        if (!PyType_IsSubtype((PyTypeObject *)type, (PyTypeObject *)PyExc_BaseException)) {
            PyErr_SetString(PyExc_TypeError,
                "raise: exception class must be a subclass of BaseException");
            goto raise_error;
        }
        #endif
    }
    __Pyx_ErrRestore(type, value, tb);
    return;
raise_error:
    Py_XDECREF(value);
    Py_XDECREF(type);
    Py_XDECREF(tb);
    return;
}
#else /* Python 3+ */
static void __Pyx_Raise(PyObject *type, PyObject *value, PyObject *tb, PyObject *cause) {
    PyObject* owned_instance = NULL;
    if (tb == Py_None) {
        tb = 0;
    } else if (tb && !PyTraceBack_Check(tb)) {
        PyErr_SetString(PyExc_TypeError,
            "raise: arg 3 must be a traceback or None");
        goto bad;
    }
    if (value == Py_None)
        value = 0;
    if (PyExceptionInstance_Check(type)) {
        if (value) {
            PyErr_SetString(PyExc_TypeError,
                "instance exception may not have a separate value");
            goto bad;
        }
        value = type;
        type = (PyObject*) Py_TYPE(value);
    } else if (PyExceptionClass_Check(type)) {
        PyObject *args;
        if (!value)
            args = PyTuple_New(0);
        else if (PyTuple_Check(value)) {
            Py_INCREF(value);
            args = value;
        } else
            args = PyTuple_Pack(1, value);
        if (!args)
            goto bad;
        owned_instance = PyEval_CallObject(type, args);
        Py_DECREF(args);
        if (!owned_instance)
            goto bad;
        value = owned_instance;
        if (!PyExceptionInstance_Check(value)) {
            PyErr_Format(PyExc_TypeError,
                         "calling %R should have returned an instance of "
                         "BaseException, not %R",
                         type, Py_TYPE(value));
            goto bad;
        }
    } else {
        PyErr_SetString(PyExc_TypeError,
            "raise: exception class must be a subclass of BaseException");
        goto bad;
    }
#if PY_VERSION_HEX >= 0x03030000
    if (cause) {
#else
    if (cause && cause != Py_None) {
#endif
        PyObject *fixed_cause;
        if (cause == Py_None) {
            fixed_cause = NULL;
        } else if (PyExceptionClass_Check(cause)) {
            fixed_cause = PyObject_CallObject(cause, NULL);
            if (fixed_cause == NULL)
                goto bad;
        } else if (PyExceptionInstance_Check(cause)) {
            fixed_cause = cause;
            Py_INCREF(fixed_cause);
        } else {
            PyErr_SetString(PyExc_TypeError,
                            "exception causes must derive from "
                            "BaseException");
            goto bad;
        }
        PyException_SetCause(value, fixed_cause);
    }
    PyErr_SetObject(type, value);
    if (tb) {
        PyThreadState *tstate = PyThreadState_GET();
        PyObject* tmp_tb = tstate->curexc_traceback;
        if (tb != tmp_tb) {
            Py_INCREF(tb);
            tstate->curexc_traceback = tb;
            Py_XDECREF(tmp_tb);
        }
    }
bad:
    Py_XDECREF(owned_instance);
    return;
}
#endif

#if PY_MAJOR_VERSION >= 3
static CYTHON_INLINE PyObject* __Pyx_PyDict_Items(PyObject* d) {
    return PyObject_CallMethodObjArgs(d, __pyx_n_s__items, NULL);
}
#endif

static CYTHON_INLINE void __Pyx_RaiseTooManyValuesError(Py_ssize_t expected) {
    PyErr_Format(PyExc_ValueError,
                 "too many values to unpack (expected %" CYTHON_FORMAT_SSIZE_T "d)", expected);
}

static CYTHON_INLINE void __Pyx_RaiseNeedMoreValuesError(Py_ssize_t index) {
    PyErr_Format(PyExc_ValueError,
                 "need more than %" CYTHON_FORMAT_SSIZE_T "d value%s to unpack",
                 index, (index == 1) ? "" : "s");
}

static CYTHON_INLINE int __Pyx_IterFinish(void) {
#if CYTHON_COMPILING_IN_CPYTHON
    PyThreadState *tstate = PyThreadState_GET();
    PyObject* exc_type = tstate->curexc_type;
    if (unlikely(exc_type)) {
        if (likely(exc_type == PyExc_StopIteration) || PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration)) {
            PyObject *exc_value, *exc_tb;
            exc_value = tstate->curexc_value;
            exc_tb = tstate->curexc_traceback;
            tstate->curexc_type = 0;
            tstate->curexc_value = 0;
            tstate->curexc_traceback = 0;
            Py_DECREF(exc_type);
            Py_XDECREF(exc_value);
            Py_XDECREF(exc_tb);
            return 0;
        } else {
            return -1;
        }
    }
    return 0;
#else
    if (unlikely(PyErr_Occurred())) {
        if (likely(PyErr_ExceptionMatches(PyExc_StopIteration))) {
            PyErr_Clear();
            return 0;
        } else {
            return -1;
        }
    }
    return 0;
#endif
}

static int __Pyx_IternextUnpackEndCheck(PyObject *retval, Py_ssize_t expected) {
    if (unlikely(retval)) {
        Py_DECREF(retval);
        __Pyx_RaiseTooManyValuesError(expected);
        return -1;
    } else {
        return __Pyx_IterFinish();
    }
    return 0;
}

static CYTHON_INLINE PyObject *__Pyx_GetItemInt_Generic(PyObject *o, PyObject* j) {
    PyObject *r;
    if (!j) return NULL;
    r = PyObject_GetItem(o, j);
    Py_DECREF(j);
    return r;
}
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_List_Fast(PyObject *o, Py_ssize_t i,
                                                              int wraparound, int boundscheck) {
#if CYTHON_COMPILING_IN_CPYTHON
    if (wraparound & unlikely(i < 0)) i += PyList_GET_SIZE(o);
    if ((!boundscheck) || likely((0 <= i) & (i < PyList_GET_SIZE(o)))) {
        PyObject *r = PyList_GET_ITEM(o, i);
        Py_INCREF(r);
        return r;
    }
    return __Pyx_GetItemInt_Generic(o, PyInt_FromSsize_t(i));
#else
    return PySequence_GetItem(o, i);
#endif
}
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_Tuple_Fast(PyObject *o, Py_ssize_t i,
                                                              int wraparound, int boundscheck) {
#if CYTHON_COMPILING_IN_CPYTHON
    if (wraparound & unlikely(i < 0)) i += PyTuple_GET_SIZE(o);
    if ((!boundscheck) || likely((0 <= i) & (i < PyTuple_GET_SIZE(o)))) {
        PyObject *r = PyTuple_GET_ITEM(o, i);
        Py_INCREF(r);
        return r;
    }
    return __Pyx_GetItemInt_Generic(o, PyInt_FromSsize_t(i));
#else
    return PySequence_GetItem(o, i);
#endif
}
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_Fast(PyObject *o, Py_ssize_t i,
                                                     int is_list, int wraparound, int boundscheck) {
#if CYTHON_COMPILING_IN_CPYTHON
    if (is_list || PyList_CheckExact(o)) {
        Py_ssize_t n = ((!wraparound) | likely(i >= 0)) ? i : i + PyList_GET_SIZE(o);
        if ((!boundscheck) || (likely((n >= 0) & (n < PyList_GET_SIZE(o))))) {
            PyObject *r = PyList_GET_ITEM(o, n);
            Py_INCREF(r);
            return r;
        }
    }
    else if (PyTuple_CheckExact(o)) {
        Py_ssize_t n = ((!wraparound) | likely(i >= 0)) ? i : i + PyTuple_GET_SIZE(o);
        if ((!boundscheck) || likely((n >= 0) & (n < PyTuple_GET_SIZE(o)))) {
            PyObject *r = PyTuple_GET_ITEM(o, n);
            Py_INCREF(r);
            return r;
        }
    } else {
        PySequenceMethods *m = Py_TYPE(o)->tp_as_sequence;
        if (likely(m && m->sq_item)) {
            if (wraparound && unlikely(i < 0) && likely(m->sq_length)) {
                Py_ssize_t l = m->sq_length(o);
                if (likely(l >= 0)) {
                    i += l;
                } else {
                    if (PyErr_ExceptionMatches(PyExc_OverflowError))
                        PyErr_Clear();
                    else
                        return NULL;
                }
            }
            return m->sq_item(o, i);
        }
    }
#else
    if (is_list || PySequence_Check(o)) {
        return PySequence_GetItem(o, i);
    }
#endif
    return __Pyx_GetItemInt_Generic(o, PyInt_FromSsize_t(i));
}

static CYTHON_INLINE PyObject* __Pyx_PyObject_GetSlice(
        PyObject* obj, Py_ssize_t cstart, Py_ssize_t cstop,
        PyObject** _py_start, PyObject** _py_stop, PyObject** _py_slice,
        int has_cstart, int has_cstop, CYTHON_UNUSED int wraparound) {
#if CYTHON_COMPILING_IN_CPYTHON
    PyMappingMethods* mp;
#if PY_MAJOR_VERSION < 3
    PySequenceMethods* ms = Py_TYPE(obj)->tp_as_sequence;
    if (likely(ms && ms->sq_slice)) {
        if (!has_cstart) {
            if (_py_start && (*_py_start != Py_None)) {
                cstart = __Pyx_PyIndex_AsSsize_t(*_py_start);
                if ((cstart == (Py_ssize_t)-1) && PyErr_Occurred()) goto bad;
            } else
                cstart = 0;
        }
        if (!has_cstop) {
            if (_py_stop && (*_py_stop != Py_None)) {
                cstop = __Pyx_PyIndex_AsSsize_t(*_py_stop);
                if ((cstop == (Py_ssize_t)-1) && PyErr_Occurred()) goto bad;
            } else
                cstop = PY_SSIZE_T_MAX;
        }
        if (wraparound && unlikely((cstart < 0) | (cstop < 0)) && likely(ms->sq_length)) {
            Py_ssize_t l = ms->sq_length(obj);
            if (likely(l >= 0)) {
                if (cstop < 0) {
                    cstop += l;
                    if (cstop < 0) cstop = 0;
                }
                if (cstart < 0) {
                    cstart += l;
                    if (cstart < 0) cstart = 0;
                }
            } else {
                if (PyErr_ExceptionMatches(PyExc_OverflowError))
                    PyErr_Clear();
                else
                    goto bad;
            }
        }
        return ms->sq_slice(obj, cstart, cstop);
    }
#endif
    mp = Py_TYPE(obj)->tp_as_mapping;
    if (likely(mp && mp->mp_subscript))
#endif
    {
        PyObject* result;
        PyObject *py_slice, *py_start, *py_stop;
        if (_py_slice) {
            py_slice = *_py_slice;
        } else {
            PyObject* owned_start = NULL;
            PyObject* owned_stop = NULL;
            if (_py_start) {
                py_start = *_py_start;
            } else {
                if (has_cstart) {
                    owned_start = py_start = PyInt_FromSsize_t(cstart);
                    if (unlikely(!py_start)) goto bad;
                } else
                    py_start = Py_None;
            }
            if (_py_stop) {
                py_stop = *_py_stop;
            } else {
                if (has_cstop) {
                    owned_stop = py_stop = PyInt_FromSsize_t(cstop);
                    if (unlikely(!py_stop)) {
                        Py_XDECREF(owned_start);
                        goto bad;
                    }
                } else
                    py_stop = Py_None;
            }
            py_slice = PySlice_New(py_start, py_stop, Py_None);
            Py_XDECREF(owned_start);
            Py_XDECREF(owned_stop);
            if (unlikely(!py_slice)) goto bad;
        }
#if CYTHON_COMPILING_IN_CPYTHON
        result = mp->mp_subscript(obj, py_slice);
#else
        result = PyObject_GetItem(obj, py_slice);
#endif
        if (!_py_slice) {
            Py_DECREF(py_slice);
        }
        return result;
    }
    PyErr_Format(PyExc_TypeError,
        "'%.200s' object is unsliceable", Py_TYPE(obj)->tp_name);
bad:
    return NULL;
}

static CYTHON_INLINE void __Pyx_RaiseNoneNotIterableError(void) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not iterable");
}

static void __Pyx_UnpackTupleError(PyObject *t, Py_ssize_t index) {
    if (t == Py_None) {
      __Pyx_RaiseNoneNotIterableError();
    } else if (PyTuple_GET_SIZE(t) < index) {
      __Pyx_RaiseNeedMoreValuesError(PyTuple_GET_SIZE(t));
    } else {
      __Pyx_RaiseTooManyValuesError(index);
    }
}

static CYTHON_INLINE int __Pyx_unpack_tuple2(PyObject* tuple, PyObject** pvalue1, PyObject** pvalue2,
                                             int is_tuple, int has_known_size, int decref_tuple) {
    Py_ssize_t index;
    PyObject *value1 = NULL, *value2 = NULL, *iter = NULL;
    if (!is_tuple && unlikely(!PyTuple_Check(tuple))) {
        iternextfunc iternext;
        iter = PyObject_GetIter(tuple);
        if (unlikely(!iter)) goto bad;
        if (decref_tuple) { Py_DECREF(tuple); tuple = NULL; }
        iternext = Py_TYPE(iter)->tp_iternext;
        value1 = iternext(iter); if (unlikely(!value1)) { index = 0; goto unpacking_failed; }
        value2 = iternext(iter); if (unlikely(!value2)) { index = 1; goto unpacking_failed; }
        if (!has_known_size && unlikely(__Pyx_IternextUnpackEndCheck(iternext(iter), 2))) goto bad;
        Py_DECREF(iter);
    } else {
        if (!has_known_size && unlikely(PyTuple_GET_SIZE(tuple) != 2)) {
            __Pyx_UnpackTupleError(tuple, 2);
            goto bad;
        }
#if CYTHON_COMPILING_IN_PYPY
        value1 = PySequence_ITEM(tuple, 0);
        if (unlikely(!value1)) goto bad;
        value2 = PySequence_ITEM(tuple, 1);
        if (unlikely(!value2)) goto bad;
#else
        value1 = PyTuple_GET_ITEM(tuple, 0);
        value2 = PyTuple_GET_ITEM(tuple, 1);
        Py_INCREF(value1);
        Py_INCREF(value2);
#endif
        if (decref_tuple) { Py_DECREF(tuple); }
    }
    *pvalue1 = value1;
    *pvalue2 = value2;
    return 0;
unpacking_failed:
    if (!has_known_size && __Pyx_IterFinish() == 0)
        __Pyx_RaiseNeedMoreValuesError(index);
bad:
    Py_XDECREF(iter);
    Py_XDECREF(value1);
    Py_XDECREF(value2);
    if (decref_tuple) { Py_XDECREF(tuple); }
    return -1;
}

static CYTHON_INLINE PyObject* __Pyx_dict_iterator(PyObject* iterable, int is_dict, PyObject* method_name,
                                                   Py_ssize_t* p_orig_length, int* p_source_is_dict) {
    is_dict = is_dict || likely(PyDict_CheckExact(iterable));
    *p_source_is_dict = is_dict;
#if !CYTHON_COMPILING_IN_PYPY
    if (is_dict) {
        *p_orig_length = PyDict_Size(iterable);
        Py_INCREF(iterable);
        return iterable;
    }
#endif
    *p_orig_length = 0;
    if (method_name) {
        PyObject* iter;
        iterable = __Pyx_PyObject_CallMethod0(iterable, method_name);
        if (!iterable)
            return NULL;
#if !CYTHON_COMPILING_IN_PYPY
        if (PyTuple_CheckExact(iterable) || PyList_CheckExact(iterable))
            return iterable;
#endif
        iter = PyObject_GetIter(iterable);
        Py_DECREF(iterable);
        return iter;
    }
    return PyObject_GetIter(iterable);
}
static CYTHON_INLINE int __Pyx_dict_iter_next(PyObject* iter_obj, Py_ssize_t orig_length, Py_ssize_t* ppos,
                                              PyObject** pkey, PyObject** pvalue, PyObject** pitem, int source_is_dict) {
    PyObject* next_item;
#if !CYTHON_COMPILING_IN_PYPY
    if (source_is_dict) {
        PyObject *key, *value;
        if (unlikely(orig_length != PyDict_Size(iter_obj))) {
            PyErr_SetString(PyExc_RuntimeError, "dictionary changed size during iteration");
            return -1;
        }
        if (unlikely(!PyDict_Next(iter_obj, ppos, &key, &value))) {
            return 0;
        }
        if (pitem) {
            PyObject* tuple = PyTuple_New(2);
            if (unlikely(!tuple)) {
                return -1;
            }
            Py_INCREF(key);
            Py_INCREF(value);
            PyTuple_SET_ITEM(tuple, 0, key);
            PyTuple_SET_ITEM(tuple, 1, value);
            *pitem = tuple;
        } else {
            if (pkey) {
                Py_INCREF(key);
                *pkey = key;
            }
            if (pvalue) {
                Py_INCREF(value);
                *pvalue = value;
            }
        }
        return 1;
    } else if (PyTuple_CheckExact(iter_obj)) {
        Py_ssize_t pos = *ppos;
        if (unlikely(pos >= PyTuple_GET_SIZE(iter_obj))) return 0;
        *ppos = pos + 1;
        next_item = PyTuple_GET_ITEM(iter_obj, pos);
        Py_INCREF(next_item);
    } else if (PyList_CheckExact(iter_obj)) {
        Py_ssize_t pos = *ppos;
        if (unlikely(pos >= PyList_GET_SIZE(iter_obj))) return 0;
        *ppos = pos + 1;
        next_item = PyList_GET_ITEM(iter_obj, pos);
        Py_INCREF(next_item);
    } else
#endif
    {
        next_item = PyIter_Next(iter_obj);
        if (unlikely(!next_item)) {
            return __Pyx_IterFinish();
        }
    }
    if (pitem) {
        *pitem = next_item;
    } else if (pkey && pvalue) {
        if (__Pyx_unpack_tuple2(next_item, pkey, pvalue, source_is_dict, source_is_dict, 1))
            return -1;
    } else if (pkey) {
        *pkey = next_item;
    } else {
        *pvalue = next_item;
    }
    return 1;
}

static CYTHON_INLINE PyObject *__Pyx_PyIter_Next2(PyObject* iterator, PyObject* defval) {
    PyObject* next;
    iternextfunc iternext = Py_TYPE(iterator)->tp_iternext;
#if CYTHON_COMPILING_IN_CPYTHON
    if (unlikely(!iternext)) {
#else
    if (unlikely(!iternext) || unlikely(!PyIter_Check(iterator))) {
#endif
        PyErr_Format(PyExc_TypeError,
            "%.200s object is not an iterator", Py_TYPE(iterator)->tp_name);
        return NULL;
    }
    next = iternext(iterator);
    if (likely(next))
        return next;
#if CYTHON_COMPILING_IN_CPYTHON
#if PY_VERSION_HEX >= 0x03010000 || (PY_MAJOR_VERSION < 3 && PY_VERSION_HEX >= 0x02070000)
    if (unlikely(iternext == &_PyObject_NextNotImplemented))
        return NULL;
#endif
#endif
    if (defval) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
            if (unlikely(exc_type != PyExc_StopIteration) &&
                    !PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))
                return NULL;
            PyErr_Clear();
        }
        Py_INCREF(defval);
        return defval;
    }
    if (!PyErr_Occurred())
        PyErr_SetNone(PyExc_StopIteration);
    return NULL;
}

static int __Pyx_SetVtable(PyObject *dict, void *vtable) {
#if PY_VERSION_HEX >= 0x02070000 && !(PY_MAJOR_VERSION==3&&PY_MINOR_VERSION==0)
    PyObject *ob = PyCapsule_New(vtable, 0, 0);
#else
    PyObject *ob = PyCObject_FromVoidPtr(vtable, 0);
#endif
    if (!ob)
        goto bad;
    if (PyDict_SetItem(dict, __pyx_n_s____pyx_vtable__, ob) < 0)
        goto bad;
    Py_DECREF(ob);
    return 0;
bad:
    Py_XDECREF(ob);
    return -1;
}

static void* __Pyx_GetVtable(PyObject *dict) {
    void* ptr;
    PyObject *ob = PyObject_GetItem(dict, __pyx_n_s____pyx_vtable__);
    if (!ob)
        goto bad;
#if PY_VERSION_HEX >= 0x02070000 && !(PY_MAJOR_VERSION==3&&PY_MINOR_VERSION==0)
    ptr = PyCapsule_GetPointer(ob, 0);
#else
    ptr = PyCObject_AsVoidPtr(ob);
#endif
    if (!ptr && !PyErr_Occurred())
        PyErr_SetString(PyExc_RuntimeError, "invalid vtable found for imported type");
    Py_DECREF(ob);
    return ptr;
bad:
    Py_XDECREF(ob);
    return NULL;
}

static int __Pyx_GetException(PyObject **type, PyObject **value, PyObject **tb) {
    PyObject *local_type, *local_value, *local_tb;
#if CYTHON_COMPILING_IN_CPYTHON
    PyObject *tmp_type, *tmp_value, *tmp_tb;
    PyThreadState *tstate = PyThreadState_GET();
    local_type = tstate->curexc_type;
    local_value = tstate->curexc_value;
    local_tb = tstate->curexc_traceback;
    tstate->curexc_type = 0;
    tstate->curexc_value = 0;
    tstate->curexc_traceback = 0;
#else
    PyErr_Fetch(&local_type, &local_value, &local_tb);
#endif
    PyErr_NormalizeException(&local_type, &local_value, &local_tb);
#if CYTHON_COMPILING_IN_CPYTHON
    if (unlikely(tstate->curexc_type))
#else
    if (unlikely(PyErr_Occurred()))
#endif
        goto bad;
    #if PY_MAJOR_VERSION >= 3
    if (unlikely(PyException_SetTraceback(local_value, local_tb) < 0))
        goto bad;
    #endif
    Py_INCREF(local_type);
    Py_INCREF(local_value);
    Py_INCREF(local_tb);
    *type = local_type;
    *value = local_value;
    *tb = local_tb;
#if CYTHON_COMPILING_IN_CPYTHON
    tmp_type = tstate->exc_type;
    tmp_value = tstate->exc_value;
    tmp_tb = tstate->exc_traceback;
    tstate->exc_type = local_type;
    tstate->exc_value = local_value;
    tstate->exc_traceback = local_tb;
    /* Make sure tstate is in a consistent state when we XDECREF
       these objects (DECREF may run arbitrary code). */
    Py_XDECREF(tmp_type);
    Py_XDECREF(tmp_value);
    Py_XDECREF(tmp_tb);
#else
    PyErr_SetExcInfo(local_type, local_value, local_tb);
#endif
    return 0;
bad:
    *type = 0;
    *value = 0;
    *tb = 0;
    Py_XDECREF(local_type);
    Py_XDECREF(local_value);
    Py_XDECREF(local_tb);
    return -1;
}

static PyObject* __Pyx_ImportFrom(PyObject* module, PyObject* name) {
    PyObject* value = __Pyx_PyObject_GetAttrStr(module, name);
    if (unlikely(!value) && PyErr_ExceptionMatches(PyExc_AttributeError)) {
        PyErr_Format(PyExc_ImportError,
        #if PY_MAJOR_VERSION < 3
            "cannot import name %.230s", PyString_AS_STRING(name));
        #else
            "cannot import name %S", name);
        #endif
    }
    return value;
}

#if PY_MAJOR_VERSION >= 3
static CYTHON_INLINE PyObject* __Pyx_PyDict_Keys(PyObject* d) {
    return PyObject_CallMethodObjArgs(d, __pyx_n_s__keys, NULL);
}
#endif

static PyObject *__Pyx_Import(PyObject *name, PyObject *from_list, int level) {
    PyObject *empty_list = 0;
    PyObject *module = 0;
    PyObject *global_dict = 0;
    PyObject *empty_dict = 0;
    PyObject *list;
    #if PY_VERSION_HEX < 0x03030000
    PyObject *py_import;
    py_import = __Pyx_PyObject_GetAttrStr(__pyx_b, __pyx_n_s____import__);
    if (!py_import)
        goto bad;
    #endif
    if (from_list)
        list = from_list;
    else {
        empty_list = PyList_New(0);
        if (!empty_list)
            goto bad;
        list = empty_list;
    }
    global_dict = PyModule_GetDict(__pyx_m);
    if (!global_dict)
        goto bad;
    empty_dict = PyDict_New();
    if (!empty_dict)
        goto bad;
    #if PY_VERSION_HEX >= 0x02050000
    {
        #if PY_MAJOR_VERSION >= 3
        if (level == -1) {
            if (strchr(__Pyx_MODULE_NAME, '.')) {
                #if PY_VERSION_HEX < 0x03030000
                PyObject *py_level = PyInt_FromLong(1);
                if (!py_level)
                    goto bad;
                module = PyObject_CallFunctionObjArgs(py_import,
                    name, global_dict, empty_dict, list, py_level, NULL);
                Py_DECREF(py_level);
                #else
                module = PyImport_ImportModuleLevelObject(
                    name, global_dict, empty_dict, list, 1);
                #endif
                if (!module) {
                    if (!PyErr_ExceptionMatches(PyExc_ImportError))
                        goto bad;
                    PyErr_Clear();
                }
            }
            level = 0; /* try absolute import on failure */
        }
        #endif
        if (!module) {
            #if PY_VERSION_HEX < 0x03030000
            PyObject *py_level = PyInt_FromLong(level);
            if (!py_level)
                goto bad;
            module = PyObject_CallFunctionObjArgs(py_import,
                name, global_dict, empty_dict, list, py_level, NULL);
            Py_DECREF(py_level);
            #else
            module = PyImport_ImportModuleLevelObject(
                name, global_dict, empty_dict, list, level);
            #endif
        }
    }
    #else
    if (level>0) {
        PyErr_SetString(PyExc_RuntimeError, "Relative import is not supported for Python <=2.4.");
        goto bad;
    }
    module = PyObject_CallFunctionObjArgs(py_import,
        name, global_dict, empty_dict, list, NULL);
    #endif
bad:
    #if PY_VERSION_HEX < 0x03030000
    Py_XDECREF(py_import);
    #endif
    Py_XDECREF(empty_list);
    Py_XDECREF(empty_dict);
    return module;
}

static CYTHON_INLINE void __Pyx_ExceptionSave(PyObject **type, PyObject **value, PyObject **tb) {
#if CYTHON_COMPILING_IN_CPYTHON
    PyThreadState *tstate = PyThreadState_GET();
    *type = tstate->exc_type;
    *value = tstate->exc_value;
    *tb = tstate->exc_traceback;
    Py_XINCREF(*type);
    Py_XINCREF(*value);
    Py_XINCREF(*tb);
#else
    PyErr_GetExcInfo(type, value, tb);
#endif
}
static void __Pyx_ExceptionReset(PyObject *type, PyObject *value, PyObject *tb) {
#if CYTHON_COMPILING_IN_CPYTHON
    PyObject *tmp_type, *tmp_value, *tmp_tb;
    PyThreadState *tstate = PyThreadState_GET();
    tmp_type = tstate->exc_type;
    tmp_value = tstate->exc_value;
    tmp_tb = tstate->exc_traceback;
    tstate->exc_type = type;
    tstate->exc_value = value;
    tstate->exc_traceback = tb;
    Py_XDECREF(tmp_type);
    Py_XDECREF(tmp_value);
    Py_XDECREF(tmp_tb);
#else
    PyErr_SetExcInfo(type, value, tb);
#endif
}

static CYTHON_INLINE unsigned char __Pyx_PyInt_AsUnsignedChar(PyObject* x) {
    const unsigned char neg_one = (unsigned char)-1, const_zero = 0;
    const int is_unsigned = neg_one > const_zero;
    if (sizeof(unsigned char) < sizeof(long)) {
        long val = __Pyx_PyInt_AsLong(x);
        if (unlikely(val != (long)(unsigned char)val)) {
            if (!unlikely(val == -1 && PyErr_Occurred())) {
                PyErr_SetString(PyExc_OverflowError,
                    (is_unsigned && unlikely(val < 0)) ?
                    "can't convert negative value to unsigned char" :
                    "value too large to convert to unsigned char");
            }
            return (unsigned char)-1;
        }
        return (unsigned char)val;
    }
    return (unsigned char)__Pyx_PyInt_AsUnsignedLong(x);
}

static CYTHON_INLINE unsigned short __Pyx_PyInt_AsUnsignedShort(PyObject* x) {
    const unsigned short neg_one = (unsigned short)-1, const_zero = 0;
    const int is_unsigned = neg_one > const_zero;
    if (sizeof(unsigned short) < sizeof(long)) {
        long val = __Pyx_PyInt_AsLong(x);
        if (unlikely(val != (long)(unsigned short)val)) {
            if (!unlikely(val == -1 && PyErr_Occurred())) {
                PyErr_SetString(PyExc_OverflowError,
                    (is_unsigned && unlikely(val < 0)) ?
                    "can't convert negative value to unsigned short" :
                    "value too large to convert to unsigned short");
            }
            return (unsigned short)-1;
        }
        return (unsigned short)val;
    }
    return (unsigned short)__Pyx_PyInt_AsUnsignedLong(x);
}

static CYTHON_INLINE unsigned int __Pyx_PyInt_AsUnsignedInt(PyObject* x) {
    const unsigned int neg_one = (unsigned int)-1, const_zero = 0;
    const int is_unsigned = neg_one > const_zero;
    if (sizeof(unsigned int) < sizeof(long)) {
        long val = __Pyx_PyInt_AsLong(x);
        if (unlikely(val != (long)(unsigned int)val)) {
            if (!unlikely(val == -1 && PyErr_Occurred())) {
                PyErr_SetString(PyExc_OverflowError,
                    (is_unsigned && unlikely(val < 0)) ?
                    "can't convert negative value to unsigned int" :
                    "value too large to convert to unsigned int");
            }
            return (unsigned int)-1;
        }
        return (unsigned int)val;
    }
    return (unsigned int)__Pyx_PyInt_AsUnsignedLong(x);
}

static CYTHON_INLINE char __Pyx_PyInt_AsChar(PyObject* x) {
    const char neg_one = (char)-1, const_zero = 0;
    const int is_unsigned = neg_one > const_zero;
    if (sizeof(char) < sizeof(long)) {
        long val = __Pyx_PyInt_AsLong(x);
        if (unlikely(val != (long)(char)val)) {
            if (!unlikely(val == -1 && PyErr_Occurred())) {
                PyErr_SetString(PyExc_OverflowError,
                    (is_unsigned && unlikely(val < 0)) ?
                    "can't convert negative value to char" :
                    "value too large to convert to char");
            }
            return (char)-1;
        }
        return (char)val;
    }
    return (char)__Pyx_PyInt_AsLong(x);
}

static CYTHON_INLINE short __Pyx_PyInt_AsShort(PyObject* x) {
    const short neg_one = (short)-1, const_zero = 0;
    const int is_unsigned = neg_one > const_zero;
    if (sizeof(short) < sizeof(long)) {
        long val = __Pyx_PyInt_AsLong(x);
        if (unlikely(val != (long)(short)val)) {
            if (!unlikely(val == -1 && PyErr_Occurred())) {
                PyErr_SetString(PyExc_OverflowError,
                    (is_unsigned && unlikely(val < 0)) ?
                    "can't convert negative value to short" :
                    "value too large to convert to short");
            }
            return (short)-1;
        }
        return (short)val;
    }
    return (short)__Pyx_PyInt_AsLong(x);
}

static CYTHON_INLINE int __Pyx_PyInt_AsInt(PyObject* x) {
    const int neg_one = (int)-1, const_zero = 0;
    const int is_unsigned = neg_one > const_zero;
    if (sizeof(int) < sizeof(long)) {
        long val = __Pyx_PyInt_AsLong(x);
        if (unlikely(val != (long)(int)val)) {
            if (!unlikely(val == -1 && PyErr_Occurred())) {
                PyErr_SetString(PyExc_OverflowError,
                    (is_unsigned && unlikely(val < 0)) ?
                    "can't convert negative value to int" :
                    "value too large to convert to int");
            }
            return (int)-1;
        }
        return (int)val;
    }
    return (int)__Pyx_PyInt_AsLong(x);
}

static CYTHON_INLINE signed char __Pyx_PyInt_AsSignedChar(PyObject* x) {
    const signed char neg_one = (signed char)-1, const_zero = 0;
    const int is_unsigned = neg_one > const_zero;
    if (sizeof(signed char) < sizeof(long)) {
        long val = __Pyx_PyInt_AsLong(x);
        if (unlikely(val != (long)(signed char)val)) {
            if (!unlikely(val == -1 && PyErr_Occurred())) {
                PyErr_SetString(PyExc_OverflowError,
                    (is_unsigned && unlikely(val < 0)) ?
                    "can't convert negative value to signed char" :
                    "value too large to convert to signed char");
            }
            return (signed char)-1;
        }
        return (signed char)val;
    }
    return (signed char)__Pyx_PyInt_AsSignedLong(x);
}

static CYTHON_INLINE signed short __Pyx_PyInt_AsSignedShort(PyObject* x) {
    const signed short neg_one = (signed short)-1, const_zero = 0;
    const int is_unsigned = neg_one > const_zero;
    if (sizeof(signed short) < sizeof(long)) {
        long val = __Pyx_PyInt_AsLong(x);
        if (unlikely(val != (long)(signed short)val)) {
            if (!unlikely(val == -1 && PyErr_Occurred())) {
                PyErr_SetString(PyExc_OverflowError,
                    (is_unsigned && unlikely(val < 0)) ?
                    "can't convert negative value to signed short" :
                    "value too large to convert to signed short");
            }
            return (signed short)-1;
        }
        return (signed short)val;
    }
    return (signed short)__Pyx_PyInt_AsSignedLong(x);
}

static CYTHON_INLINE signed int __Pyx_PyInt_AsSignedInt(PyObject* x) {
    const signed int neg_one = (signed int)-1, const_zero = 0;
    const int is_unsigned = neg_one > const_zero;
    if (sizeof(signed int) < sizeof(long)) {
        long val = __Pyx_PyInt_AsLong(x);
        if (unlikely(val != (long)(signed int)val)) {
            if (!unlikely(val == -1 && PyErr_Occurred())) {
                PyErr_SetString(PyExc_OverflowError,
                    (is_unsigned && unlikely(val < 0)) ?
                    "can't convert negative value to signed int" :
                    "value too large to convert to signed int");
            }
            return (signed int)-1;
        }
        return (signed int)val;
    }
    return (signed int)__Pyx_PyInt_AsSignedLong(x);
}

static CYTHON_INLINE int __Pyx_PyInt_AsLongDouble(PyObject* x) {
    const int neg_one = (int)-1, const_zero = 0;
    const int is_unsigned = neg_one > const_zero;
    if (sizeof(int) < sizeof(long)) {
        long val = __Pyx_PyInt_AsLong(x);
        if (unlikely(val != (long)(int)val)) {
            if (!unlikely(val == -1 && PyErr_Occurred())) {
                PyErr_SetString(PyExc_OverflowError,
                    (is_unsigned && unlikely(val < 0)) ?
                    "can't convert negative value to int" :
                    "value too large to convert to int");
            }
            return (int)-1;
        }
        return (int)val;
    }
    return (int)__Pyx_PyInt_AsLong(x);
}

#if CYTHON_COMPILING_IN_CPYTHON && PY_MAJOR_VERSION >= 3
#if CYTHON_USE_PYLONG_INTERNALS
#include "longintrepr.h"
#endif
#endif
static CYTHON_INLINE unsigned long __Pyx_PyInt_AsUnsignedLong(PyObject* x) {
    const unsigned long neg_one = (unsigned long)-1, const_zero = 0;
    const int is_unsigned = neg_one > const_zero;
#if PY_MAJOR_VERSION < 3
    if (likely(PyInt_Check(x))) {
        long val = PyInt_AS_LONG(x);
        if (is_unsigned && unlikely(val < 0)) {
            PyErr_SetString(PyExc_OverflowError,
                            "can't convert negative value to unsigned long");
            return (unsigned long)-1;
        }
        return (unsigned long)val;
    } else
#endif
    if (likely(PyLong_Check(x))) {
        if (is_unsigned) {
#if CYTHON_COMPILING_IN_CPYTHON && PY_MAJOR_VERSION >= 3
#if CYTHON_USE_PYLONG_INTERNALS
            if (sizeof(digit) <= sizeof(unsigned long)) {
                switch (Py_SIZE(x)) {
                    case  0: return 0;
                    case  1: return (unsigned long) ((PyLongObject*)x)->ob_digit[0];
                }
            }
#endif
#endif
            if (unlikely(Py_SIZE(x) < 0)) {
                PyErr_SetString(PyExc_OverflowError,
                                "can't convert negative value to unsigned long");
                return (unsigned long)-1;
            }
            return (unsigned long)PyLong_AsUnsignedLong(x);
        } else {
#if CYTHON_COMPILING_IN_CPYTHON && PY_MAJOR_VERSION >= 3
#if CYTHON_USE_PYLONG_INTERNALS
            if (sizeof(digit) <= sizeof(unsigned long)) {
                switch (Py_SIZE(x)) {
                    case  0: return 0;
                    case  1: return +(unsigned long) ((PyLongObject*)x)->ob_digit[0];
                    case -1: return -(unsigned long) ((PyLongObject*)x)->ob_digit[0];
                }
            }
#endif
#endif
            return (unsigned long)PyLong_AsLong(x);
        }
    } else {
        unsigned long val;
        PyObject *tmp = __Pyx_PyNumber_Int(x);
        if (!tmp) return (unsigned long)-1;
        val = __Pyx_PyInt_AsUnsignedLong(tmp);
        Py_DECREF(tmp);
        return val;
    }
}

#if CYTHON_COMPILING_IN_CPYTHON && PY_MAJOR_VERSION >= 3
#if CYTHON_USE_PYLONG_INTERNALS
#include "longintrepr.h"
#endif
#endif
static CYTHON_INLINE unsigned PY_LONG_LONG __Pyx_PyInt_AsUnsignedLongLong(PyObject* x) {
    const unsigned PY_LONG_LONG neg_one = (unsigned PY_LONG_LONG)-1, const_zero = 0;
    const int is_unsigned = neg_one > const_zero;
#if PY_MAJOR_VERSION < 3
    if (likely(PyInt_Check(x))) {
        long val = PyInt_AS_LONG(x);
        if (is_unsigned && unlikely(val < 0)) {
            PyErr_SetString(PyExc_OverflowError,
                            "can't convert negative value to unsigned PY_LONG_LONG");
            return (unsigned PY_LONG_LONG)-1;
        }
        return (unsigned PY_LONG_LONG)val;
    } else
#endif
    if (likely(PyLong_Check(x))) {
        if (is_unsigned) {
#if CYTHON_COMPILING_IN_CPYTHON && PY_MAJOR_VERSION >= 3
#if CYTHON_USE_PYLONG_INTERNALS
            if (sizeof(digit) <= sizeof(unsigned PY_LONG_LONG)) {
                switch (Py_SIZE(x)) {
                    case  0: return 0;
                    case  1: return (unsigned PY_LONG_LONG) ((PyLongObject*)x)->ob_digit[0];
                }
            }
#endif
#endif
            if (unlikely(Py_SIZE(x) < 0)) {
                PyErr_SetString(PyExc_OverflowError,
                                "can't convert negative value to unsigned PY_LONG_LONG");
                return (unsigned PY_LONG_LONG)-1;
            }
            return (unsigned PY_LONG_LONG)PyLong_AsUnsignedLongLong(x);
        } else {
#if CYTHON_COMPILING_IN_CPYTHON && PY_MAJOR_VERSION >= 3
#if CYTHON_USE_PYLONG_INTERNALS
            if (sizeof(digit) <= sizeof(unsigned PY_LONG_LONG)) {
                switch (Py_SIZE(x)) {
                    case  0: return 0;
                    case  1: return +(unsigned PY_LONG_LONG) ((PyLongObject*)x)->ob_digit[0];
                    case -1: return -(unsigned PY_LONG_LONG) ((PyLongObject*)x)->ob_digit[0];
                }
            }
#endif
#endif
            return (unsigned PY_LONG_LONG)PyLong_AsLongLong(x);
        }
    } else {
        unsigned PY_LONG_LONG val;
        PyObject *tmp = __Pyx_PyNumber_Int(x);
        if (!tmp) return (unsigned PY_LONG_LONG)-1;
        val = __Pyx_PyInt_AsUnsignedLongLong(tmp);
        Py_DECREF(tmp);
        return val;
    }
}

#if CYTHON_COMPILING_IN_CPYTHON && PY_MAJOR_VERSION >= 3
#if CYTHON_USE_PYLONG_INTERNALS
#include "longintrepr.h"
#endif
#endif
static CYTHON_INLINE long __Pyx_PyInt_AsLong(PyObject* x) {
    const long neg_one = (long)-1, const_zero = 0;
    const int is_unsigned = neg_one > const_zero;
#if PY_MAJOR_VERSION < 3
    if (likely(PyInt_Check(x))) {
        long val = PyInt_AS_LONG(x);
        if (is_unsigned && unlikely(val < 0)) {
            PyErr_SetString(PyExc_OverflowError,
                            "can't convert negative value to long");
            return (long)-1;
        }
        return (long)val;
    } else
#endif
    if (likely(PyLong_Check(x))) {
        if (is_unsigned) {
#if CYTHON_COMPILING_IN_CPYTHON && PY_MAJOR_VERSION >= 3
#if CYTHON_USE_PYLONG_INTERNALS
            if (sizeof(digit) <= sizeof(long)) {
                switch (Py_SIZE(x)) {
                    case  0: return 0;
                    case  1: return (long) ((PyLongObject*)x)->ob_digit[0];
                }
            }
#endif
#endif
            if (unlikely(Py_SIZE(x) < 0)) {
                PyErr_SetString(PyExc_OverflowError,
                                "can't convert negative value to long");
                return (long)-1;
            }
            return (long)PyLong_AsUnsignedLong(x);
        } else {
#if CYTHON_COMPILING_IN_CPYTHON && PY_MAJOR_VERSION >= 3
#if CYTHON_USE_PYLONG_INTERNALS
            if (sizeof(digit) <= sizeof(long)) {
                switch (Py_SIZE(x)) {
                    case  0: return 0;
                    case  1: return +(long) ((PyLongObject*)x)->ob_digit[0];
                    case -1: return -(long) ((PyLongObject*)x)->ob_digit[0];
                }
            }
#endif
#endif
            return (long)PyLong_AsLong(x);
        }
    } else {
        long val;
        PyObject *tmp = __Pyx_PyNumber_Int(x);
        if (!tmp) return (long)-1;
        val = __Pyx_PyInt_AsLong(tmp);
        Py_DECREF(tmp);
        return val;
    }
}

#if CYTHON_COMPILING_IN_CPYTHON && PY_MAJOR_VERSION >= 3
#if CYTHON_USE_PYLONG_INTERNALS
#include "longintrepr.h"
#endif
#endif
static CYTHON_INLINE PY_LONG_LONG __Pyx_PyInt_AsLongLong(PyObject* x) {
    const PY_LONG_LONG neg_one = (PY_LONG_LONG)-1, const_zero = 0;
    const int is_unsigned = neg_one > const_zero;
#if PY_MAJOR_VERSION < 3
    if (likely(PyInt_Check(x))) {
        long val = PyInt_AS_LONG(x);
        if (is_unsigned && unlikely(val < 0)) {
            PyErr_SetString(PyExc_OverflowError,
                            "can't convert negative value to PY_LONG_LONG");
            return (PY_LONG_LONG)-1;
        }
        return (PY_LONG_LONG)val;
    } else
#endif
    if (likely(PyLong_Check(x))) {
        if (is_unsigned) {
#if CYTHON_COMPILING_IN_CPYTHON && PY_MAJOR_VERSION >= 3
#if CYTHON_USE_PYLONG_INTERNALS
            if (sizeof(digit) <= sizeof(PY_LONG_LONG)) {
                switch (Py_SIZE(x)) {
                    case  0: return 0;
                    case  1: return (PY_LONG_LONG) ((PyLongObject*)x)->ob_digit[0];
                }
            }
#endif
#endif
            if (unlikely(Py_SIZE(x) < 0)) {
                PyErr_SetString(PyExc_OverflowError,
                                "can't convert negative value to PY_LONG_LONG");
                return (PY_LONG_LONG)-1;
            }
            return (PY_LONG_LONG)PyLong_AsUnsignedLongLong(x);
        } else {
#if CYTHON_COMPILING_IN_CPYTHON && PY_MAJOR_VERSION >= 3
#if CYTHON_USE_PYLONG_INTERNALS
            if (sizeof(digit) <= sizeof(PY_LONG_LONG)) {
                switch (Py_SIZE(x)) {
                    case  0: return 0;
                    case  1: return +(PY_LONG_LONG) ((PyLongObject*)x)->ob_digit[0];
                    case -1: return -(PY_LONG_LONG) ((PyLongObject*)x)->ob_digit[0];
                }
            }
#endif
#endif
            return (PY_LONG_LONG)PyLong_AsLongLong(x);
        }
    } else {
        PY_LONG_LONG val;
        PyObject *tmp = __Pyx_PyNumber_Int(x);
        if (!tmp) return (PY_LONG_LONG)-1;
        val = __Pyx_PyInt_AsLongLong(tmp);
        Py_DECREF(tmp);
        return val;
    }
}

#if CYTHON_COMPILING_IN_CPYTHON && PY_MAJOR_VERSION >= 3
#if CYTHON_USE_PYLONG_INTERNALS
#include "longintrepr.h"
#endif
#endif
static CYTHON_INLINE signed long __Pyx_PyInt_AsSignedLong(PyObject* x) {
    const signed long neg_one = (signed long)-1, const_zero = 0;
    const int is_unsigned = neg_one > const_zero;
#if PY_MAJOR_VERSION < 3
    if (likely(PyInt_Check(x))) {
        long val = PyInt_AS_LONG(x);
        if (is_unsigned && unlikely(val < 0)) {
            PyErr_SetString(PyExc_OverflowError,
                            "can't convert negative value to signed long");
            return (signed long)-1;
        }
        return (signed long)val;
    } else
#endif
    if (likely(PyLong_Check(x))) {
        if (is_unsigned) {
#if CYTHON_COMPILING_IN_CPYTHON && PY_MAJOR_VERSION >= 3
#if CYTHON_USE_PYLONG_INTERNALS
            if (sizeof(digit) <= sizeof(signed long)) {
                switch (Py_SIZE(x)) {
                    case  0: return 0;
                    case  1: return (signed long) ((PyLongObject*)x)->ob_digit[0];
                }
            }
#endif
#endif
            if (unlikely(Py_SIZE(x) < 0)) {
                PyErr_SetString(PyExc_OverflowError,
                                "can't convert negative value to signed long");
                return (signed long)-1;
            }
            return (signed long)PyLong_AsUnsignedLong(x);
        } else {
#if CYTHON_COMPILING_IN_CPYTHON && PY_MAJOR_VERSION >= 3
#if CYTHON_USE_PYLONG_INTERNALS
            if (sizeof(digit) <= sizeof(signed long)) {
                switch (Py_SIZE(x)) {
                    case  0: return 0;
                    case  1: return +(signed long) ((PyLongObject*)x)->ob_digit[0];
                    case -1: return -(signed long) ((PyLongObject*)x)->ob_digit[0];
                }
            }
#endif
#endif
            return (signed long)PyLong_AsLong(x);
        }
    } else {
        signed long val;
        PyObject *tmp = __Pyx_PyNumber_Int(x);
        if (!tmp) return (signed long)-1;
        val = __Pyx_PyInt_AsSignedLong(tmp);
        Py_DECREF(tmp);
        return val;
    }
}

#if CYTHON_COMPILING_IN_CPYTHON && PY_MAJOR_VERSION >= 3
#if CYTHON_USE_PYLONG_INTERNALS
#include "longintrepr.h"
#endif
#endif
static CYTHON_INLINE signed PY_LONG_LONG __Pyx_PyInt_AsSignedLongLong(PyObject* x) {
    const signed PY_LONG_LONG neg_one = (signed PY_LONG_LONG)-1, const_zero = 0;
    const int is_unsigned = neg_one > const_zero;
#if PY_MAJOR_VERSION < 3
    if (likely(PyInt_Check(x))) {
        long val = PyInt_AS_LONG(x);
        if (is_unsigned && unlikely(val < 0)) {
            PyErr_SetString(PyExc_OverflowError,
                            "can't convert negative value to signed PY_LONG_LONG");
            return (signed PY_LONG_LONG)-1;
        }
        return (signed PY_LONG_LONG)val;
    } else
#endif
    if (likely(PyLong_Check(x))) {
        if (is_unsigned) {
#if CYTHON_COMPILING_IN_CPYTHON && PY_MAJOR_VERSION >= 3
#if CYTHON_USE_PYLONG_INTERNALS
            if (sizeof(digit) <= sizeof(signed PY_LONG_LONG)) {
                switch (Py_SIZE(x)) {
                    case  0: return 0;
                    case  1: return (signed PY_LONG_LONG) ((PyLongObject*)x)->ob_digit[0];
                }
            }
#endif
#endif
            if (unlikely(Py_SIZE(x) < 0)) {
                PyErr_SetString(PyExc_OverflowError,
                                "can't convert negative value to signed PY_LONG_LONG");
                return (signed PY_LONG_LONG)-1;
            }
            return (signed PY_LONG_LONG)PyLong_AsUnsignedLongLong(x);
        } else {
#if CYTHON_COMPILING_IN_CPYTHON && PY_MAJOR_VERSION >= 3
#if CYTHON_USE_PYLONG_INTERNALS
            if (sizeof(digit) <= sizeof(signed PY_LONG_LONG)) {
                switch (Py_SIZE(x)) {
                    case  0: return 0;
                    case  1: return +(signed PY_LONG_LONG) ((PyLongObject*)x)->ob_digit[0];
                    case -1: return -(signed PY_LONG_LONG) ((PyLongObject*)x)->ob_digit[0];
                }
            }
#endif
#endif
            return (signed PY_LONG_LONG)PyLong_AsLongLong(x);
        }
    } else {
        signed PY_LONG_LONG val;
        PyObject *tmp = __Pyx_PyNumber_Int(x);
        if (!tmp) return (signed PY_LONG_LONG)-1;
        val = __Pyx_PyInt_AsSignedLongLong(tmp);
        Py_DECREF(tmp);
        return val;
    }
}

static CYTHON_INLINE void __Pyx_ExceptionSwap(PyObject **type, PyObject **value, PyObject **tb) {
    PyObject *tmp_type, *tmp_value, *tmp_tb;
#if CYTHON_COMPILING_IN_CPYTHON
    PyThreadState *tstate = PyThreadState_GET();
    tmp_type = tstate->exc_type;
    tmp_value = tstate->exc_value;
    tmp_tb = tstate->exc_traceback;
    tstate->exc_type = *type;
    tstate->exc_value = *value;
    tstate->exc_traceback = *tb;
#else
    PyErr_GetExcInfo(&tmp_type, &tmp_value, &tmp_tb);
    PyErr_SetExcInfo(*type, *value, *tb);
#endif
    *type = tmp_type;
    *value = tmp_value;
    *tb = tmp_tb;
}

static PyObject *__Pyx_Generator_Next(PyObject *self);
static PyObject *__Pyx_Generator_Send(PyObject *self, PyObject *value);
static PyObject *__Pyx_Generator_Close(PyObject *self);
static PyObject *__Pyx_Generator_Throw(PyObject *gen, PyObject *args);
static PyTypeObject *__pyx_GeneratorType = 0;
#define __Pyx_Generator_CheckExact(obj) (Py_TYPE(obj) == __pyx_GeneratorType)
#define __Pyx_Generator_Undelegate(gen) Py_CLEAR((gen)->yieldfrom)
#if 1 || PY_VERSION_HEX < 0x030300B0
static int __Pyx_PyGen_FetchStopIterationValue(PyObject **pvalue) {
    PyObject *et, *ev, *tb;
    PyObject *value = NULL;
    __Pyx_ErrFetch(&et, &ev, &tb);
    if (!et) {
        Py_XDECREF(tb);
        Py_XDECREF(ev);
        Py_INCREF(Py_None);
        *pvalue = Py_None;
        return 0;
    }
    if (unlikely(et != PyExc_StopIteration) &&
            unlikely(!PyErr_GivenExceptionMatches(et, PyExc_StopIteration))) {
        __Pyx_ErrRestore(et, ev, tb);
        return -1;
    }
    if (likely(et == PyExc_StopIteration)) {
        if (likely(!ev) || !PyObject_IsInstance(ev, PyExc_StopIteration)) {
            if (!ev) {
                Py_INCREF(Py_None);
                ev = Py_None;
            }
            Py_XDECREF(tb);
            Py_DECREF(et);
            *pvalue = ev;
            return 0;
        }
    }
    PyErr_NormalizeException(&et, &ev, &tb);
    if (unlikely(!PyObject_IsInstance(ev, PyExc_StopIteration))) {
        __Pyx_ErrRestore(et, ev, tb);
        return -1;
    }
    Py_XDECREF(tb);
    Py_DECREF(et);
#if PY_VERSION_HEX >= 0x030300A0
    value = ((PyStopIterationObject *)ev)->value;
    Py_INCREF(value);
    Py_DECREF(ev);
#else
    {
        PyObject* args = PyObject_GetAttr(ev, __pyx_n_s__args);
        Py_DECREF(ev);
        if (likely(args)) {
            value = PyObject_GetItem(args, 0);
            Py_DECREF(args);
        }
        if (unlikely(!value)) {
            __Pyx_ErrRestore(NULL, NULL, NULL);
            Py_INCREF(Py_None);
            value = Py_None;
        }
    }
#endif
    *pvalue = value;
    return 0;
}
#endif
static CYTHON_INLINE
void __Pyx_Generator_ExceptionClear(__pyx_GeneratorObject *self) {
    PyObject *exc_type = self->exc_type;
    PyObject *exc_value = self->exc_value;
    PyObject *exc_traceback = self->exc_traceback;
    self->exc_type = NULL;
    self->exc_value = NULL;
    self->exc_traceback = NULL;
    Py_XDECREF(exc_type);
    Py_XDECREF(exc_value);
    Py_XDECREF(exc_traceback);
}
static CYTHON_INLINE
int __Pyx_Generator_CheckRunning(__pyx_GeneratorObject *gen) {
    if (unlikely(gen->is_running)) {
        PyErr_SetString(PyExc_ValueError,
                        "generator already executing");
        return 1;
    }
    return 0;
}
static CYTHON_INLINE
PyObject *__Pyx_Generator_SendEx(__pyx_GeneratorObject *self, PyObject *value) {
    PyObject *retval;
    assert(!self->is_running);
    if (unlikely(self->resume_label == 0)) {
        if (unlikely(value && value != Py_None)) {
            PyErr_SetString(PyExc_TypeError,
                            "can't send non-None value to a "
                            "just-started generator");
            return NULL;
        }
    }
    if (unlikely(self->resume_label == -1)) {
        PyErr_SetNone(PyExc_StopIteration);
        return NULL;
    }
    if (value) {
#if CYTHON_COMPILING_IN_PYPY
#else
        /* Generators always return to their most recent caller, not
         * necessarily their creator. */
        if (self->exc_traceback) {
            PyThreadState *tstate = PyThreadState_GET();
            PyTracebackObject *tb = (PyTracebackObject *) self->exc_traceback;
            PyFrameObject *f = tb->tb_frame;
            Py_XINCREF(tstate->frame);
            assert(f->f_back == NULL);
            f->f_back = tstate->frame;
        }
#endif
        __Pyx_ExceptionSwap(&self->exc_type, &self->exc_value,
                            &self->exc_traceback);
    } else {
        __Pyx_Generator_ExceptionClear(self);
    }
    self->is_running = 1;
    retval = self->body((PyObject *) self, value);
    self->is_running = 0;
    if (retval) {
        __Pyx_ExceptionSwap(&self->exc_type, &self->exc_value,
                            &self->exc_traceback);
#if CYTHON_COMPILING_IN_PYPY
#else
        /* Don't keep the reference to f_back any longer than necessary.  It
         * may keep a chain of frames alive or it could create a reference
         * cycle. */
        if (self->exc_traceback) {
            PyTracebackObject *tb = (PyTracebackObject *) self->exc_traceback;
            PyFrameObject *f = tb->tb_frame;
            Py_CLEAR(f->f_back);
        }
#endif
    } else {
        __Pyx_Generator_ExceptionClear(self);
    }
    return retval;
}
static CYTHON_INLINE
PyObject *__Pyx_Generator_FinishDelegation(__pyx_GeneratorObject *gen) {
    PyObject *ret;
    PyObject *val = NULL;
    __Pyx_Generator_Undelegate(gen);
    __Pyx_PyGen_FetchStopIterationValue(&val);
    ret = __Pyx_Generator_SendEx(gen, val);
    Py_XDECREF(val);
    return ret;
}
static PyObject *__Pyx_Generator_Next(PyObject *self) {
    __pyx_GeneratorObject *gen = (__pyx_GeneratorObject*) self;
    PyObject *yf = gen->yieldfrom;
    if (unlikely(__Pyx_Generator_CheckRunning(gen)))
        return NULL;
    if (yf) {
        PyObject *ret;
        gen->is_running = 1;
        ret = Py_TYPE(yf)->tp_iternext(yf);
        gen->is_running = 0;
        if (likely(ret)) {
            return ret;
        }
        return __Pyx_Generator_FinishDelegation(gen);
    }
    return __Pyx_Generator_SendEx(gen, Py_None);
}
static PyObject *__Pyx_Generator_Send(PyObject *self, PyObject *value) {
    __pyx_GeneratorObject *gen = (__pyx_GeneratorObject*) self;
    PyObject *yf = gen->yieldfrom;
    if (unlikely(__Pyx_Generator_CheckRunning(gen)))
        return NULL;
    if (yf) {
        PyObject *ret;
        gen->is_running = 1;
        if (__Pyx_Generator_CheckExact(yf)) {
            ret = __Pyx_Generator_Send(yf, value);
        } else {
            if (value == Py_None)
                ret = PyIter_Next(yf);
            else
                ret = __Pyx_PyObject_CallMethod1(yf, __pyx_n_s__send, value);
        }
        gen->is_running = 0;
        if (likely(ret)) {
            return ret;
        }
        return __Pyx_Generator_FinishDelegation(gen);
    }
    return __Pyx_Generator_SendEx(gen, value);
}
static int __Pyx_Generator_CloseIter(__pyx_GeneratorObject *gen, PyObject *yf) {
    PyObject *retval = NULL;
    int err = 0;
    if (__Pyx_Generator_CheckExact(yf)) {
        retval = __Pyx_Generator_Close(yf);
        if (!retval)
            return -1;
    } else {
        PyObject *meth;
        gen->is_running = 1;
        meth = PyObject_GetAttr(yf, __pyx_n_s__close);
        if (unlikely(!meth)) {
            if (!PyErr_ExceptionMatches(PyExc_AttributeError)) {
                PyErr_WriteUnraisable(yf);
            }
            PyErr_Clear();
        } else {
            retval = PyObject_CallFunction(meth, NULL);
            Py_DECREF(meth);
            if (!retval)
                err = -1;
        }
        gen->is_running = 0;
    }
    Py_XDECREF(retval);
    return err;
}
static PyObject *__Pyx_Generator_Close(PyObject *self) {
    __pyx_GeneratorObject *gen = (__pyx_GeneratorObject *) self;
    PyObject *retval, *raised_exception;
    PyObject *yf = gen->yieldfrom;
    int err = 0;
    if (unlikely(__Pyx_Generator_CheckRunning(gen)))
        return NULL;
    if (yf) {
        Py_INCREF(yf);
        err = __Pyx_Generator_CloseIter(gen, yf);
        __Pyx_Generator_Undelegate(gen);
        Py_DECREF(yf);
    }
    if (err == 0)
#if PY_VERSION_HEX < 0x02050000
        PyErr_SetNone(PyExc_StopIteration);
#else
        PyErr_SetNone(PyExc_GeneratorExit);
#endif
    retval = __Pyx_Generator_SendEx(gen, NULL);
    if (retval) {
        Py_DECREF(retval);
        PyErr_SetString(PyExc_RuntimeError,
                        "generator ignored GeneratorExit");
        return NULL;
    }
    raised_exception = PyErr_Occurred();
    if (!raised_exception
        || raised_exception == PyExc_StopIteration
#if PY_VERSION_HEX >= 0x02050000
        || raised_exception == PyExc_GeneratorExit
        || PyErr_GivenExceptionMatches(raised_exception, PyExc_GeneratorExit)
#endif
        || PyErr_GivenExceptionMatches(raised_exception, PyExc_StopIteration))
    {
        if (raised_exception) PyErr_Clear();      /* ignore these errors */
        Py_INCREF(Py_None);
        return Py_None;
    }
    return NULL;
}
static PyObject *__Pyx_Generator_Throw(PyObject *self, PyObject *args) {
    __pyx_GeneratorObject *gen = (__pyx_GeneratorObject *) self;
    PyObject *typ;
    PyObject *tb = NULL;
    PyObject *val = NULL;
    PyObject *yf = gen->yieldfrom;
    if (!PyArg_UnpackTuple(args, (char *)"throw", 1, 3, &typ, &val, &tb))
        return NULL;
    if (unlikely(__Pyx_Generator_CheckRunning(gen)))
        return NULL;
    if (yf) {
        PyObject *ret;
        Py_INCREF(yf);
#if PY_VERSION_HEX >= 0x02050000
        if (PyErr_GivenExceptionMatches(typ, PyExc_GeneratorExit)) {
            int err = __Pyx_Generator_CloseIter(gen, yf);
            Py_DECREF(yf);
            __Pyx_Generator_Undelegate(gen);
            if (err < 0)
                return __Pyx_Generator_SendEx(gen, NULL);
            goto throw_here;
        }
#endif
        gen->is_running = 1;
        if (__Pyx_Generator_CheckExact(yf)) {
            ret = __Pyx_Generator_Throw(yf, args);
        } else {
            PyObject *meth = PyObject_GetAttr(yf, __pyx_n_s__throw);
            if (unlikely(!meth)) {
                Py_DECREF(yf);
                if (!PyErr_ExceptionMatches(PyExc_AttributeError)) {
                    gen->is_running = 0;
                    return NULL;
                }
                PyErr_Clear();
                __Pyx_Generator_Undelegate(gen);
                gen->is_running = 0;
                goto throw_here;
            }
            ret = PyObject_CallObject(meth, args);
            Py_DECREF(meth);
        }
        gen->is_running = 0;
        Py_DECREF(yf);
        if (!ret) {
            ret = __Pyx_Generator_FinishDelegation(gen);
        }
        return ret;
    }
throw_here:
    __Pyx_Raise(typ, val, tb, NULL);
    return __Pyx_Generator_SendEx(gen, NULL);
}
static int __Pyx_Generator_traverse(PyObject *self, visitproc visit, void *arg) {
    __pyx_GeneratorObject *gen = (__pyx_GeneratorObject *) self;
    Py_VISIT(gen->closure);
    Py_VISIT(gen->classobj);
    Py_VISIT(gen->yieldfrom);
    Py_VISIT(gen->exc_type);
    Py_VISIT(gen->exc_value);
    Py_VISIT(gen->exc_traceback);
    return 0;
}
static int __Pyx_Generator_clear(PyObject *self) {
    __pyx_GeneratorObject *gen = (__pyx_GeneratorObject *) self;
    Py_CLEAR(gen->closure);
    Py_CLEAR(gen->classobj);
    Py_CLEAR(gen->yieldfrom);
    Py_CLEAR(gen->exc_type);
    Py_CLEAR(gen->exc_value);
    Py_CLEAR(gen->exc_traceback);
    return 0;
}
static void __Pyx_Generator_dealloc(PyObject *self) {
    __pyx_GeneratorObject *gen = (__pyx_GeneratorObject *) self;
    PyObject_GC_UnTrack(gen);
    if (gen->gi_weakreflist != NULL)
        PyObject_ClearWeakRefs(self);
    PyObject_GC_Track(self);
    if (gen->resume_label > 0) {
        Py_TYPE(gen)->tp_del(self);
        if (self->ob_refcnt > 0)
            return;                     /* resurrected.  :( */
    }
    PyObject_GC_UnTrack(self);
    __Pyx_Generator_clear(self);
    PyObject_GC_Del(gen);
}
static void __Pyx_Generator_del(PyObject *self) {
    PyObject *res;
    PyObject *error_type, *error_value, *error_traceback;
    __pyx_GeneratorObject *gen = (__pyx_GeneratorObject *) self;
    if (gen->resume_label <= 0)
        return ;
    assert(self->ob_refcnt == 0);
    self->ob_refcnt = 1;
    __Pyx_ErrFetch(&error_type, &error_value, &error_traceback);
    res = __Pyx_Generator_Close(self);
    if (res == NULL)
        PyErr_WriteUnraisable(self);
    else
        Py_DECREF(res);
    __Pyx_ErrRestore(error_type, error_value, error_traceback);
    /* Undo the temporary resurrection; can't use DECREF here, it would
     * cause a recursive call.
     */
    assert(self->ob_refcnt > 0);
    if (--self->ob_refcnt == 0)
        return; /* this is the normal path out */
    /* close() resurrected it!  Make it look like the original Py_DECREF
     * never happened.
     */
    {
        Py_ssize_t refcnt = self->ob_refcnt;
        _Py_NewReference(self);
        self->ob_refcnt = refcnt;
    }
#if CYTHON_COMPILING_IN_CPYTHON
    assert(PyType_IS_GC(self->ob_type) &&
           _Py_AS_GC(self)->gc.gc_refs != _PyGC_REFS_UNTRACKED);
    /* If Py_REF_DEBUG, _Py_NewReference bumped _Py_RefTotal, so
     * we need to undo that. */
    _Py_DEC_REFTOTAL;
#endif
    /* If Py_TRACE_REFS, _Py_NewReference re-added self to the object
     * chain, so no more to do there.
     * If COUNT_ALLOCS, the original decref bumped tp_frees, and
     * _Py_NewReference bumped tp_allocs:  both of those need to be
     * undone.
     */
#ifdef COUNT_ALLOCS
    --Py_TYPE(self)->tp_frees;
    --Py_TYPE(self)->tp_allocs;
#endif
}
static PyMemberDef __pyx_Generator_memberlist[] = {
    {(char *) "gi_running",
#if PY_VERSION_HEX >= 0x02060000
     T_BOOL,
#else
     T_BYTE,
#endif
     offsetof(__pyx_GeneratorObject, is_running),
     READONLY,
     NULL},
    {0, 0, 0, 0, 0}
};
static PyMethodDef __pyx_Generator_methods[] = {
    {__Pyx_NAMESTR("send"), (PyCFunction) __Pyx_Generator_Send, METH_O, 0},
    {__Pyx_NAMESTR("throw"), (PyCFunction) __Pyx_Generator_Throw, METH_VARARGS, 0},
    {__Pyx_NAMESTR("close"), (PyCFunction) __Pyx_Generator_Close, METH_NOARGS, 0},
    {0, 0, 0, 0}
};
static PyTypeObject __pyx_GeneratorType_type = {
    PyVarObject_HEAD_INIT(0, 0)
    __Pyx_NAMESTR("generator"),         /*tp_name*/
    sizeof(__pyx_GeneratorObject),      /*tp_basicsize*/
    0,                                  /*tp_itemsize*/
    (destructor) __Pyx_Generator_dealloc,/*tp_dealloc*/
    0,                                  /*tp_print*/
    0,                                  /*tp_getattr*/
    0,                                  /*tp_setattr*/
#if PY_MAJOR_VERSION < 3
    0,                                  /*tp_compare*/
#else
    0,                                  /*reserved*/
#endif
    0,                                   /*tp_repr*/
    0,                                  /*tp_as_number*/
    0,                                  /*tp_as_sequence*/
    0,                                  /*tp_as_mapping*/
    0,                                  /*tp_hash*/
    0,                                  /*tp_call*/
    0,                                  /*tp_str*/
    0,                                  /*tp_getattro*/
    0,                                  /*tp_setattro*/
    0,                                  /*tp_as_buffer*/
    Py_TPFLAGS_DEFAULT | Py_TPFLAGS_HAVE_GC, /* tp_flags*/
    0,                                  /*tp_doc*/
    (traverseproc) __Pyx_Generator_traverse,   /*tp_traverse*/
    0,                                  /*tp_clear*/
    0,                                  /*tp_richcompare*/
    offsetof(__pyx_GeneratorObject, gi_weakreflist), /* tp_weaklistoffse */
    0,                                  /*tp_iter*/
    (iternextfunc) __Pyx_Generator_Next, /*tp_iternext*/
    __pyx_Generator_methods,            /*tp_methods*/
    __pyx_Generator_memberlist,         /*tp_members*/
    0,                                  /*tp_getset*/
    0,                                  /*tp_base*/
    0,                                  /*tp_dict*/
    0,                                  /*tp_descr_get*/
    0,                                  /*tp_descr_set*/
    0,                                  /*tp_dictoffset*/
    0,                                  /*tp_init*/
    0,                                  /*tp_alloc*/
    0,                                  /*tp_new*/
    0,                                  /*tp_free*/
    0,                                  /*tp_is_gc*/
    0,                                  /*tp_bases*/
    0,                                  /*tp_mro*/
    0,                                  /*tp_cache*/
    0,                                  /*tp_subclasses*/
    0,                                  /*tp_weaklist*/
    __Pyx_Generator_del,                /*tp_del*/
#if PY_VERSION_HEX >= 0x02060000
    0,                                  /*tp_version_tag*/
#endif
};
static __pyx_GeneratorObject *__Pyx_Generator_New(__pyx_generator_body_t body,
                                                  PyObject *closure) {
    __pyx_GeneratorObject *gen =
        PyObject_GC_New(__pyx_GeneratorObject, &__pyx_GeneratorType_type);
    if (gen == NULL)
        return NULL;
    gen->body = body;
    gen->closure = closure;
    Py_XINCREF(closure);
    gen->is_running = 0;
    gen->resume_label = 0;
    gen->classobj = NULL;
    gen->yieldfrom = NULL;
    gen->exc_type = NULL;
    gen->exc_value = NULL;
    gen->exc_traceback = NULL;
    gen->gi_weakreflist = NULL;
    PyObject_GC_Track(gen);
    return gen;
}
static int __pyx_Generator_init(void) {
    __pyx_GeneratorType_type.tp_getattro = PyObject_GenericGetAttr;
    __pyx_GeneratorType_type.tp_iter = PyObject_SelfIter;
    if (PyType_Ready(&__pyx_GeneratorType_type)) {
        return -1;
    }
    __pyx_GeneratorType = &__pyx_GeneratorType_type;
    return 0;
}

static int __Pyx_check_binary_version(void) {
    char ctversion[4], rtversion[4];
    PyOS_snprintf(ctversion, 4, "%d.%d", PY_MAJOR_VERSION, PY_MINOR_VERSION);
    PyOS_snprintf(rtversion, 4, "%s", Py_GetVersion());
    if (ctversion[0] != rtversion[0] || ctversion[2] != rtversion[2]) {
        char message[200];
        PyOS_snprintf(message, sizeof(message),
                      "compiletime version %s of module '%.100s' "
                      "does not match runtime version %s",
                      ctversion, __Pyx_MODULE_NAME, rtversion);
        #if PY_VERSION_HEX < 0x02050000
        return PyErr_Warn(NULL, message);
        #else
        return PyErr_WarnEx(NULL, message, 1);
        #endif
    }
    return 0;
}

static int __Pyx_ExportVoidPtr(PyObject *name, void *p, const char *sig) {
    PyObject *d;
    PyObject *cobj = 0;
    d = PyDict_GetItem(__pyx_d, __pyx_n_s____pyx_capi__);
    Py_XINCREF(d);
    if (!d) {
        d = PyDict_New();
        if (!d)
            goto bad;
        if (__Pyx_PyObject_SetAttrStr(__pyx_m, __pyx_n_s____pyx_capi__, d) < 0)
            goto bad;
    }
#if PY_VERSION_HEX >= 0x02070000 && !(PY_MAJOR_VERSION==3 && PY_MINOR_VERSION==0)
    cobj = PyCapsule_New(p, sig, 0);
#else
    cobj = PyCObject_FromVoidPtrAndDesc(p, (void *)sig, 0);
#endif
    if (!cobj)
        goto bad;
    if (PyDict_SetItem(d, name, cobj) < 0)
        goto bad;
    Py_DECREF(cobj);
    Py_DECREF(d);
    return 0;
bad:
    Py_XDECREF(cobj);
    Py_XDECREF(d);
    return -1;
}

static int __Pyx_ExportFunction(const char *name, void (*f)(void), const char *sig) {
    PyObject *d = 0;
    PyObject *cobj = 0;
    union {
        void (*fp)(void);
        void *p;
    } tmp;
    d = PyObject_GetAttrString(__pyx_m, (char *)"__pyx_capi__");
    if (!d) {
        PyErr_Clear();
        d = PyDict_New();
        if (!d)
            goto bad;
        Py_INCREF(d);
        if (PyModule_AddObject(__pyx_m, (char *)"__pyx_capi__", d) < 0)
            goto bad;
    }
    tmp.fp = f;
#if PY_VERSION_HEX >= 0x02070000 && !(PY_MAJOR_VERSION==3&&PY_MINOR_VERSION==0)
    cobj = PyCapsule_New(tmp.p, sig, 0);
#else
    cobj = PyCObject_FromVoidPtrAndDesc(tmp.p, (void *)sig, 0);
#endif
    if (!cobj)
        goto bad;
    if (PyDict_SetItemString(d, name, cobj) < 0)
        goto bad;
    Py_DECREF(cobj);
    Py_DECREF(d);
    return 0;
bad:
    Py_XDECREF(cobj);
    Py_XDECREF(d);
    return -1;
}

#ifndef __PYX_HAVE_RT_ImportModule
#define __PYX_HAVE_RT_ImportModule
static PyObject *__Pyx_ImportModule(const char *name) {
    PyObject *py_name = 0;
    PyObject *py_module = 0;
    py_name = __Pyx_PyIdentifier_FromString(name);
    if (!py_name)
        goto bad;
    py_module = PyImport_Import(py_name);
    Py_DECREF(py_name);
    return py_module;
bad:
    Py_XDECREF(py_name);
    return 0;
}
#endif

#ifndef __PYX_HAVE_RT_ImportType
#define __PYX_HAVE_RT_ImportType
static PyTypeObject *__Pyx_ImportType(const char *module_name, const char *class_name,
    size_t size, int strict)
{
    PyObject *py_module = 0;
    PyObject *result = 0;
    PyObject *py_name = 0;
    char warning[200];
    Py_ssize_t basicsize;
#ifdef Py_LIMITED_API
    PyObject *py_basicsize;
#endif
    py_module = __Pyx_ImportModule(module_name);
    if (!py_module)
        goto bad;
    py_name = __Pyx_PyIdentifier_FromString(class_name);
    if (!py_name)
        goto bad;
    result = PyObject_GetAttr(py_module, py_name);
    Py_DECREF(py_name);
    py_name = 0;
    Py_DECREF(py_module);
    py_module = 0;
    if (!result)
        goto bad;
    if (!PyType_Check(result)) {
        PyErr_Format(PyExc_TypeError,
            "%s.%s is not a type object",
            module_name, class_name);
        goto bad;
    }
#ifndef Py_LIMITED_API
    basicsize = ((PyTypeObject *)result)->tp_basicsize;
#else
    py_basicsize = PyObject_GetAttrString(result, "__basicsize__");
    if (!py_basicsize)
        goto bad;
    basicsize = PyLong_AsSsize_t(py_basicsize);
    Py_DECREF(py_basicsize);
    py_basicsize = 0;
    if (basicsize == (Py_ssize_t)-1 && PyErr_Occurred())
        goto bad;
#endif
    if (!strict && (size_t)basicsize > size) {
        PyOS_snprintf(warning, sizeof(warning),
            "%s.%s size changed, may indicate binary incompatibility",
            module_name, class_name);
        #if PY_VERSION_HEX < 0x02050000
        if (PyErr_Warn(NULL, warning) < 0) goto bad;
        #else
        if (PyErr_WarnEx(NULL, warning, 0) < 0) goto bad;
        #endif
    }
    else if ((size_t)basicsize != size) {
        PyErr_Format(PyExc_ValueError,
            "%s.%s has the wrong size, try recompiling",
            module_name, class_name);
        goto bad;
    }
    return (PyTypeObject *)result;
bad:
    Py_XDECREF(py_module);
    Py_XDECREF(result);
    return NULL;
}
#endif

#ifndef __PYX_HAVE_RT_ImportVoidPtr
#define __PYX_HAVE_RT_ImportVoidPtr
static int __Pyx_ImportVoidPtr(PyObject *module, const char *name, void **p, const char *sig) {
    PyObject *d = 0;
    PyObject *cobj = 0;
    d = PyObject_GetAttrString(module, (char *)"__pyx_capi__");
    if (!d)
        goto bad;
    cobj = PyDict_GetItemString(d, name);
    if (!cobj) {
        PyErr_Format(PyExc_ImportError,
            "%s does not export expected C variable %s",
                PyModule_GetName(module), name);
        goto bad;
    }
#if PY_VERSION_HEX >= 0x02070000 && !(PY_MAJOR_VERSION==3 && PY_MINOR_VERSION==0)
    if (!PyCapsule_IsValid(cobj, sig)) {
        PyErr_Format(PyExc_TypeError,
            "C variable %s.%s has wrong signature (expected %s, got %s)",
             PyModule_GetName(module), name, sig, PyCapsule_GetName(cobj));
        goto bad;
    }
    *p = PyCapsule_GetPointer(cobj, sig);
#else
    {const char *desc, *s1, *s2;
    desc = (const char *)PyCObject_GetDesc(cobj);
    if (!desc)
        goto bad;
    s1 = desc; s2 = sig;
    while (*s1 != '\0' && *s1 == *s2) { s1++; s2++; }
    if (*s1 != *s2) {
        PyErr_Format(PyExc_TypeError,
            "C variable %s.%s has wrong signature (expected %s, got %s)",
             PyModule_GetName(module), name, sig, desc);
        goto bad;
    }
    *p = PyCObject_AsVoidPtr(cobj);}
#endif
    if (!(*p))
        goto bad;
    Py_DECREF(d);
    return 0;
bad:
    Py_XDECREF(d);
    return -1;
}
#endif

static int __pyx_bisect_code_objects(__Pyx_CodeObjectCacheEntry* entries, int count, int code_line) {
    int start = 0, mid = 0, end = count - 1;
    if (end >= 0 && code_line > entries[end].code_line) {
        return count;
    }
    while (start < end) {
        mid = (start + end) / 2;
        if (code_line < entries[mid].code_line) {
            end = mid;
        } else if (code_line > entries[mid].code_line) {
             start = mid + 1;
        } else {
            return mid;
        }
    }
    if (code_line <= entries[mid].code_line) {
        return mid;
    } else {
        return mid + 1;
    }
}
static PyCodeObject *__pyx_find_code_object(int code_line) {
    PyCodeObject* code_object;
    int pos;
    if (unlikely(!code_line) || unlikely(!__pyx_code_cache.entries)) {
        return NULL;
    }
    pos = __pyx_bisect_code_objects(__pyx_code_cache.entries, __pyx_code_cache.count, code_line);
    if (unlikely(pos >= __pyx_code_cache.count) || unlikely(__pyx_code_cache.entries[pos].code_line != code_line)) {
        return NULL;
    }
    code_object = __pyx_code_cache.entries[pos].code_object;
    Py_INCREF(code_object);
    return code_object;
}
static void __pyx_insert_code_object(int code_line, PyCodeObject* code_object) {
    int pos, i;
    __Pyx_CodeObjectCacheEntry* entries = __pyx_code_cache.entries;
    if (unlikely(!code_line)) {
        return;
    }
    if (unlikely(!entries)) {
        entries = (__Pyx_CodeObjectCacheEntry*)PyMem_Malloc(64*sizeof(__Pyx_CodeObjectCacheEntry));
        if (likely(entries)) {
            __pyx_code_cache.entries = entries;
            __pyx_code_cache.max_count = 64;
            __pyx_code_cache.count = 1;
            entries[0].code_line = code_line;
            entries[0].code_object = code_object;
            Py_INCREF(code_object);
        }
        return;
    }
    pos = __pyx_bisect_code_objects(__pyx_code_cache.entries, __pyx_code_cache.count, code_line);
    if ((pos < __pyx_code_cache.count) && unlikely(__pyx_code_cache.entries[pos].code_line == code_line)) {
        PyCodeObject* tmp = entries[pos].code_object;
        entries[pos].code_object = code_object;
        Py_DECREF(tmp);
        return;
    }
    if (__pyx_code_cache.count == __pyx_code_cache.max_count) {
        int new_max = __pyx_code_cache.max_count + 64;
        entries = (__Pyx_CodeObjectCacheEntry*)PyMem_Realloc(
            __pyx_code_cache.entries, new_max*sizeof(__Pyx_CodeObjectCacheEntry));
        if (unlikely(!entries)) {
            return;
        }
        __pyx_code_cache.entries = entries;
        __pyx_code_cache.max_count = new_max;
    }
    for (i=__pyx_code_cache.count; i>pos; i--) {
        entries[i] = entries[i-1];
    }
    entries[pos].code_line = code_line;
    entries[pos].code_object = code_object;
    __pyx_code_cache.count++;
    Py_INCREF(code_object);
}

#include "compile.h"
#include "frameobject.h"
#include "traceback.h"
static PyCodeObject* __Pyx_CreateCodeObjectForTraceback(
            const char *funcname, int c_line,
            int py_line, const char *filename) {
    PyCodeObject *py_code = 0;
    PyObject *py_srcfile = 0;
    PyObject *py_funcname = 0;
    #if PY_MAJOR_VERSION < 3
    py_srcfile = PyString_FromString(filename);
    #else
    py_srcfile = PyUnicode_FromString(filename);
    #endif
    if (!py_srcfile) goto bad;
    if (c_line) {
        #if PY_MAJOR_VERSION < 3
        py_funcname = PyString_FromFormat( "%s (%s:%d)", funcname, __pyx_cfilenm, c_line);
        #else
        py_funcname = PyUnicode_FromFormat( "%s (%s:%d)", funcname, __pyx_cfilenm, c_line);
        #endif
    }
    else {
        #if PY_MAJOR_VERSION < 3
        py_funcname = PyString_FromString(funcname);
        #else
        py_funcname = PyUnicode_FromString(funcname);
        #endif
    }
    if (!py_funcname) goto bad;
    py_code = __Pyx_PyCode_New(
        0,            /*int argcount,*/
        0,            /*int kwonlyargcount,*/
        0,            /*int nlocals,*/
        0,            /*int stacksize,*/
        0,            /*int flags,*/
        __pyx_empty_bytes, /*PyObject *code,*/
        __pyx_empty_tuple, /*PyObject *consts,*/
        __pyx_empty_tuple, /*PyObject *names,*/
        __pyx_empty_tuple, /*PyObject *varnames,*/
        __pyx_empty_tuple, /*PyObject *freevars,*/
        __pyx_empty_tuple, /*PyObject *cellvars,*/
        py_srcfile,   /*PyObject *filename,*/
        py_funcname,  /*PyObject *name,*/
        py_line,      /*int firstlineno,*/
        __pyx_empty_bytes  /*PyObject *lnotab*/
    );
    Py_DECREF(py_srcfile);
    Py_DECREF(py_funcname);
    return py_code;
bad:
    Py_XDECREF(py_srcfile);
    Py_XDECREF(py_funcname);
    return NULL;
}
static void __Pyx_AddTraceback(const char *funcname, int c_line,
                               int py_line, const char *filename) {
    PyCodeObject *py_code = 0;
    PyObject *py_globals = 0;
    PyFrameObject *py_frame = 0;
    py_code = __pyx_find_code_object(c_line ? c_line : py_line);
    if (!py_code) {
        py_code = __Pyx_CreateCodeObjectForTraceback(
            funcname, c_line, py_line, filename);
        if (!py_code) goto bad;
        __pyx_insert_code_object(c_line ? c_line : py_line, py_code);
    }
    py_globals = PyModule_GetDict(__pyx_m);
    if (!py_globals) goto bad;
    py_frame = PyFrame_New(
        PyThreadState_GET(), /*PyThreadState *tstate,*/
        py_code,             /*PyCodeObject *code,*/
        py_globals,          /*PyObject *globals,*/
        0                    /*PyObject *locals*/
    );
    if (!py_frame) goto bad;
    py_frame->f_lineno = py_line;
    PyTraceBack_Here(py_frame);
bad:
    Py_XDECREF(py_code);
    Py_XDECREF(py_frame);
}

static int __Pyx_InitStrings(__Pyx_StringTabEntry *t) {
    while (t->p) {
        #if PY_MAJOR_VERSION < 3
        if (t->is_unicode) {
            *t->p = PyUnicode_DecodeUTF8(t->s, t->n - 1, NULL);
        } else if (t->intern) {
            *t->p = PyString_InternFromString(t->s);
        } else {
            *t->p = PyString_FromStringAndSize(t->s, t->n - 1);
        }
        #else  /* Python 3+ has unicode identifiers */
        if (t->is_unicode | t->is_str) {
            if (t->intern) {
                *t->p = PyUnicode_InternFromString(t->s);
            } else if (t->encoding) {
                *t->p = PyUnicode_Decode(t->s, t->n - 1, t->encoding, NULL);
            } else {
                *t->p = PyUnicode_FromStringAndSize(t->s, t->n - 1);
            }
        } else {
            *t->p = PyBytes_FromStringAndSize(t->s, t->n - 1);
        }
        #endif
        if (!*t->p)
            return -1;
        ++t;
    }
    return 0;
}

static CYTHON_INLINE PyObject* __Pyx_PyUnicode_FromString(char* c_str) {
    return __Pyx_PyUnicode_FromStringAndSize(c_str, strlen(c_str));
}
static CYTHON_INLINE char* __Pyx_PyObject_AsString(PyObject* o) {
    Py_ssize_t ignore;
    return __Pyx_PyObject_AsStringAndSize(o, &ignore);
}
static CYTHON_INLINE char* __Pyx_PyObject_AsStringAndSize(PyObject* o, Py_ssize_t *length) {
#if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII || __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT
    if (
#if PY_MAJOR_VERSION < 3 && __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
            __Pyx_sys_getdefaultencoding_not_ascii &&
#endif
            PyUnicode_Check(o)) {
#if PY_VERSION_HEX < 0x03030000
        char* defenc_c;
        PyObject* defenc = _PyUnicode_AsDefaultEncodedString(o, NULL);
        if (!defenc) return NULL;
        defenc_c = PyBytes_AS_STRING(defenc);
#if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
        {
            char* end = defenc_c + PyBytes_GET_SIZE(defenc);
            char* c;
            for (c = defenc_c; c < end; c++) {
                if ((unsigned char) (*c) >= 128) {
                    PyUnicode_AsASCIIString(o);
                    return NULL;
                }
            }
        }
#endif /*__PYX_DEFAULT_STRING_ENCODING_IS_ASCII*/
        *length = PyBytes_GET_SIZE(defenc);
        return defenc_c;
#else /* PY_VERSION_HEX < 0x03030000 */
        if (PyUnicode_READY(o) == -1) return NULL;
#if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
        if (PyUnicode_IS_ASCII(o)) {
            *length = PyUnicode_GET_DATA_SIZE(o);
            return PyUnicode_AsUTF8(o);
        } else {
            PyUnicode_AsASCIIString(o);
            return NULL;
        }
#else /* __PYX_DEFAULT_STRING_ENCODING_IS_ASCII */
        return PyUnicode_AsUTF8AndSize(o, length);
#endif /* __PYX_DEFAULT_STRING_ENCODING_IS_ASCII */
#endif /* PY_VERSION_HEX < 0x03030000 */
    } else
#endif /* __PYX_DEFAULT_STRING_ENCODING_IS_ASCII  || __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT */
    {
        char* result;
        int r = PyBytes_AsStringAndSize(o, &result, length);
        if (r < 0) {
            return NULL;
        } else {
            return result;
        }
    }
}
static CYTHON_INLINE int __Pyx_PyObject_IsTrue(PyObject* x) {
   int is_true = x == Py_True;
   if (is_true | (x == Py_False) | (x == Py_None)) return is_true;
   else return PyObject_IsTrue(x);
}
static CYTHON_INLINE PyObject* __Pyx_PyNumber_Int(PyObject* x) {
  PyNumberMethods *m;
  const char *name = NULL;
  PyObject *res = NULL;
#if PY_MAJOR_VERSION < 3
  if (PyInt_Check(x) || PyLong_Check(x))
#else
  if (PyLong_Check(x))
#endif
    return Py_INCREF(x), x;
  m = Py_TYPE(x)->tp_as_number;
#if PY_MAJOR_VERSION < 3
  if (m && m->nb_int) {
    name = "int";
    res = PyNumber_Int(x);
  }
  else if (m && m->nb_long) {
    name = "long";
    res = PyNumber_Long(x);
  }
#else
  if (m && m->nb_int) {
    name = "int";
    res = PyNumber_Long(x);
  }
#endif
  if (res) {
#if PY_MAJOR_VERSION < 3
    if (!PyInt_Check(res) && !PyLong_Check(res)) {
#else
    if (!PyLong_Check(res)) {
#endif
      PyErr_Format(PyExc_TypeError,
                   "__%s__ returned non-%s (type %.200s)",
                   name, name, Py_TYPE(res)->tp_name);
      Py_DECREF(res);
      return NULL;
    }
  }
  else if (!PyErr_Occurred()) {
    PyErr_SetString(PyExc_TypeError,
                    "an integer is required");
  }
  return res;
}
static CYTHON_INLINE Py_ssize_t __Pyx_PyIndex_AsSsize_t(PyObject* b) {
  Py_ssize_t ival;
  PyObject* x = PyNumber_Index(b);
  if (!x) return -1;
  ival = PyInt_AsSsize_t(x);
  Py_DECREF(x);
  return ival;
}
static CYTHON_INLINE PyObject * __Pyx_PyInt_FromSize_t(size_t ival) {
#if PY_VERSION_HEX < 0x02050000
   if (ival <= LONG_MAX)
       return PyInt_FromLong((long)ival);
   else {
       unsigned char *bytes = (unsigned char *) &ival;
       int one = 1; int little = (int)*(unsigned char*)&one;
       return _PyLong_FromByteArray(bytes, sizeof(size_t), little, 0);
   }
#else
   return PyInt_FromSize_t(ival);
#endif
}
static CYTHON_INLINE size_t __Pyx_PyInt_AsSize_t(PyObject* x) {
   unsigned PY_LONG_LONG val = __Pyx_PyInt_AsUnsignedLongLong(x);
   if (unlikely(val != (unsigned PY_LONG_LONG)(size_t)val)) {
       if ((val != (unsigned PY_LONG_LONG)-1) || !PyErr_Occurred())
           PyErr_SetString(PyExc_OverflowError,
                           "value too large to convert to size_t");
       return (size_t)-1;
   }
   return (size_t)val;
}


#endif /* Py_PYTHON_H */
